/*******************************************************************************
   OrderEntry Database - Version 1.0 
   Created 2016-09-22 (Military date format)
   Script: CreateOrderEntry.sql
   Description: Creates DataAccess Worlwide's Order Entry Sampe database
                as "OrderEntry" AND populates it with data.
   DB Server: Microsoft SQL Server 2008 and up
   Author: Nils G Svedmyr
   Website: http://www.rdctools.com
********************************************************************************/
USE [master]
GO

/*******************************************************************************
   DROP database if it EXISTS
********************************************************************************/
IF EXISTS (SELECT NAME FROM master.dbo.sysdatabases WHERE NAME = N'OrderEntry')
BEGIN
                ALTER DATABASE [OrderEntry] SET OFFLINE WITH ROLLBACK IMMEDIATE;
                ALTER DATABASE [OrderEntry] SET ONLINE;
                DROP DATABASE [OrderEntry];
END
GO

/*******************************************************************************
   Create database
********************************************************************************/
CREATE DATABASE [OrderEntry];
GO

USE [OrderEntry];
GO
/*******************************************************************************
   CREATE Tables
********************************************************************************/
CREATE TABLE [dbo].[Customer](
	[RECNUM] [int] IDENTITY(1,1) NOT NULL,
	[Customer_Number] [int] NOT NULL,
	[Name] [char](30) NOT NULL,
	[Address] [char](30) NOT NULL,
	[City] [char](14) NOT NULL,
	[State] [char](2) NOT NULL,
	[Zip] [char](10) NOT NULL,
	[Phone_Number] [char](20) NOT NULL,
	[Fax_Number] [char](20) NOT NULL,
	[EMail_Address] [char](30) NOT NULL,
	[Credit_Limit] [numeric](8, 2) NOT NULL,
	[Purchases] [numeric](8, 2) NOT NULL,
	[Balance] [numeric](8, 2) NOT NULL,
	[Comments] [text] NOT NULL,
	[Status] [char](1) NOT NULL,
 CONSTRAINT [Customer001_PK] PRIMARY KEY CLUSTERED 
(
	[Customer_Number] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO
CREATE TABLE [dbo].[Invt](
	[RECNUM] [int] IDENTITY(1,1) NOT NULL,
	[Item_ID] [char](10) NOT NULL,
	[Description] [char](35) NOT NULL,
	[Vendor_ID] [int] NOT NULL,
	[Vendor_Part_ID] [char](15) NOT NULL,
	[Unit_Price] [numeric](8, 2) NOT NULL,
	[On_Hand] [int] NOT NULL,
 CONSTRAINT [Invt001_PK] PRIMARY KEY CLUSTERED 
(
	[Item_ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[OrderDtl](
	[RECNUM] [int] IDENTITY(1,1) NOT NULL,
	[Order_Number] [int] NOT NULL,
	[Detail_Number] [smallint] NOT NULL,
	[Item_ID] [char](10) NOT NULL,
	[Qty_Ordered] [int] NOT NULL,
	[Price] [numeric](8, 2) NOT NULL,
	[Extended_Price] [numeric](10, 2) NOT NULL,
 CONSTRAINT [OrderDtl001_PK] PRIMARY KEY CLUSTERED 
(
	[Order_Number] ASC,
	[Detail_Number] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[OrderHea](
	[RECNUM] [int] IDENTITY(1,1) NOT NULL,
	[Order_Number] [int] NOT NULL,
	[Customer_Number] [int] NOT NULL,
	[Order_Date] [datetime] NOT NULL,
	[Terms] [char](12) NOT NULL,
	[Ship_Via] [char](12) NOT NULL,
	[Ordered_By] [char](12) NOT NULL,
	[SalesPerson_ID] [char](4) NOT NULL,
	[Order_Total] [numeric](10, 2) NOT NULL,
	[Last_Detail_Num] [smallint] NOT NULL,
 CONSTRAINT [OrderHea001_PK] PRIMARY KEY CLUSTERED 
(
	[Order_Number] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[OrdSys](
	[Order_Number] [int] NOT NULL,
	[Cust_Number] [int] NOT NULL,
	[Vendor_Number] [int] NOT NULL
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[SalesP](
	[RECNUM] [int] IDENTITY(1,1) NOT NULL,
	[ID] [char](4) NOT NULL,
	[Name] [char](25) NOT NULL,
 CONSTRAINT [SalesP001_PK] PRIMARY KEY CLUSTERED 
(
	[ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[Users](
	[RECNUM] [int] IDENTITY(1,1) NOT NULL,
	[LoginName] [char](10) NOT NULL,
	[Password] [char](10) NOT NULL,
	[Rights] [smallint] NOT NULL,
	[Full_Name] [char](30) NOT NULL,
	[Last_Login] [datetime] NOT NULL,
 CONSTRAINT [Users001_PK] PRIMARY KEY CLUSTERED 
(
	[LoginName] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[Vendor](
	[RECNUM] [int] IDENTITY(1,1) NOT NULL,
	[ID] [int] NOT NULL,
	[Name] [char](30) NOT NULL,
	[Address] [char](30) NOT NULL,
	[City] [char](14) NOT NULL,
	[State] [char](2) NOT NULL,
	[Zip] [char](10) NOT NULL,
	[Phone_Number] [char](20) NOT NULL,
	[Fax_Number] [char](20) NOT NULL,
 CONSTRAINT [Vendor001_PK] PRIMARY KEY CLUSTERED 
(
	[ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
SET IDENTITY_INSERT [dbo].[Customer] ON 
GO

/*******************************************************************************
   CREATE UNIQUE Indexes
********************************************************************************/
CREATE UNIQUE NONCLUSTERED INDEX [Customer000] ON [dbo].[Customer]
(
	[RECNUM] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
SET ANSI_PADDING ON

GO
/****** Object:  Index [Customer002]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [Customer002] ON [dbo].[Customer]
(
	[NAME] ASC,
	[Customer_Number] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
/****** Object:  Index [Customer003]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [Customer003] ON [dbo].[Customer]
(
	[Balance] ASC,
	[Customer_Number] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
/****** Object:  Index [Invt000]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [Invt000] ON [dbo].[Invt]
(
	[RECNUM] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
SET ANSI_PADDING ON

GO
/****** Object:  Index [Invt002]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [Invt002] ON [dbo].[Invt]
(
	[Vendor_ID] ASC,
	[Vendor_Part_ID] ASC,
	[Item_ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
SET ANSI_PADDING ON

GO
/****** Object:  Index [Invt003]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [Invt003] ON [dbo].[Invt]
(
	[Description] ASC,
	[Item_ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
/****** Object:  Index [OrderDtl000]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [OrderDtl000] ON [dbo].[OrderDtl]
(
	[RECNUM] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
/****** Object:  Index [OrderHea000]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [OrderHea000] ON [dbo].[OrderHea]
(
	[RECNUM] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
/****** Object:  Index [OrderHea002]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [OrderHea002] ON [dbo].[OrderHea]
(
	[Customer_Number] ASC,
	[Order_Number] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
/****** Object:  Index [OrderHea003]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [OrderHea003] ON [dbo].[OrderHea]
(
	[Order_Date] ASC,
	[Order_Number] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
/****** Object:  Index [SalesP000]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [SalesP000] ON [dbo].[SalesP]
(
	[RECNUM] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
SET ANSI_PADDING ON

GO
/****** Object:  Index [SalesP002]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [SalesP002] ON [dbo].[SalesP]
(
	[NAME] ASC,
	[ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
/****** Object:  Index [Users000]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [Users000] ON [dbo].[Users]
(
	[RECNUM] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
SET ANSI_PADDING ON

GO
/****** Object:  Index [Users002]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [Users002] ON [dbo].[Users]
(
	[LoginName] ASC,
	[Password] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
/****** Object:  Index [Vendor000]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [Vendor000] ON [dbo].[Vendor]
(
	[RECNUM] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO
SET ANSI_PADDING ON

GO
/****** Object:  Index [Vendor002]    Script Date: 2016-09-21 17:29:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [Vendor002] ON [dbo].[Vendor]
(
	[NAME] ASC,
	[ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO

/*******************************************************************************
   Populate Tables
********************************************************************************/
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [NAME], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (1, 1, N'Access Miles                  ', N'1400 NW 190 Ave               ', N'Miami         ', N'FL', N'331766017 ', N'305-555-0012        ', N'305-555-0017        ', N'customerservice@amiles.com    ', CAST(6320.00 AS NUMERIC(8, 2)), CAST(10640.00 AS NUMERIC(8, 2)), CAST(10640.00 AS NUMERIC(8, 2)), N'Innovative company & administrators of mileage programs. Give them a big discount. Also a great resource for leads and reselling, great place to pickup tips on obtaining best rates & fares.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (2, 2, N'American Products, Inc.       ', N'12314 Portland Ave., N.E.     ', N'Redmond       ', N'WA', N'980522350 ', N'425-555-7518        ', N'425-555-7519        ', N'sales@americanprodinc.com     ', CAST(2022.00 AS Numeric(8, 2)), CAST(2044.00 AS Numeric(8, 2)), CAST(2044.00 AS Numeric(8, 2)), N'Produces homegrown fruits and vegetables. All natural foods grown and sold without chemicals.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (3, 3, N'Ortega Emergency Care Center  ', N'56789 SW 199th Street         ', N'Dallas        ', N'TX', N'752340247 ', N'972-555-8317        ', N'972-555-8318        ', N'ortegacenter@emergencycare.com', CAST(2088.00 AS Numeric(8, 2)), CAST(2178.00 AS Numeric(8, 2)), CAST(2178.00 AS Numeric(8, 2)), N'This center has a sophisticated, brand new network system, with Windows workstations with Visual DataFlex in every room in the emergency ward.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (4, 4, N'Ace Manufacturers, Inc.       ', N'123 NorthEast Industrial Park ', N'Peoria        ', N'IL', N'61605     ', N'309-555-3215        ', N'309-555-3216        ', N'ami@acemanfinc.com            ', CAST(1409.00 AS Numeric(8, 2)), CAST(818.00 AS Numeric(8, 2)), CAST(818.00 AS Numeric(8, 2)), N'Excellent, steadily growing account. Purchases have increased 15% per year for several years, with an all time high of 34% last year. Think about increasing discount for additional incentive.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (5, 5, N'True Value Machine & Tool Comp', N'7654 City Center Blvd         ', N'Warwick       ', N'RI', N'02886     ', N'401-555-8579        ', N'401-555-8580        ', N'truevalue@hotmail.com         ', CAST(1649.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(8, 2)), N'New account as of last year. Looks like a growing business and should generate more funds within a year or two.', N'N')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (6, 6, N'Big River Public Schools      ', N'P.O. Box 331                  ', N'Salem         ', N'OR', N'97301     ', N'503-555-7516        ', N'503-555-7517        ', N'bigriver@publicschools.edu    ', CAST(5143.00 AS Numeric(8, 2)), CAST(8288.00 AS Numeric(8, 2)), CAST(8288.00 AS Numeric(8, 2)), N'2,100 public schools along Big River. Superintendant is Timothy Bear.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (7, 7, N'General Food Supplies         ', N'4444 Park Ave.                ', N'Tucson        ', N'AZ', N'805705    ', N'520-555-8173        ', N'520-555-8174        ', N'help@generalfoodsupplies.com  ', CAST(1586.00 AS Numeric(8, 2)), CAST(1173.00 AS Numeric(8, 2)), CAST(1173.00 AS Numeric(8, 2)), N'Small business owned by the Cartwright family. Nice people, will probably remain a single location company.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (8, 8, N'Wilson Bolt & Nut Company     ', N'P.O. BOX 456                  ', N'Atlanta       ', N'GA', N'30303     ', N'404-555-7294        ', N'404-555-7295        ', N'wilsonbolt@nutcompany.com     ', CAST(3277.00 AS Numeric(8, 2)), CAST(4557.00 AS Numeric(8, 2)), CAST(4557.00 AS Numeric(8, 2)), N'Small manufacturer of precision bolts and nuts for engineering purposes. May have found a great niche market.', N'N')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (9, 9, N'Rectangle Service Center      ', N'Route 12, Box 4444            ', N'Columbia      ', N'MD', N'210467682 ', N'410-555-7518        ', N'410-555-7519        ', N'helpcenter@rectanglesrvc.com  ', CAST(1183.00 AS Numeric(8, 2)), CAST(367.00 AS Numeric(8, 2)), CAST(367.00 AS Numeric(8, 2)), N'Just opened account. We are currently pricing equipment and supplies for this account. Should be excellent customer.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (10, 10, N'Youth for Brass Springs, Inc. ', N'P.O. Box 789                  ', N'Denver        ', N'CO', N'80204     ', N'303-555-9573        ', N'303-555-9574        ', N'margie@youthforbrass.com      ', CAST(2386.00 AS Numeric(8, 2)), CAST(2772.00 AS Numeric(8, 2)), CAST(2772.00 AS Numeric(8, 2)), N'Youth club founded by local parents for involving kids in activities that further the town and children''s interests. Non-profit organization.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (11, 11, N'America West Hospital         ', N'P.O. Drawer 3333              ', N'San Diego     ', N'CA', N'654320000 ', N'619-555-1873        ', N'619-555-1874        ', N'admin@americawesthospital.com ', CAST(1910.00 AS Numeric(8, 2)), CAST(1821.00 AS Numeric(8, 2)), CAST(1821.00 AS Numeric(8, 2)), N'Small outpatient center in suburb of San Diego. Partner with multiple PPO and PCO providers.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (12, 12, N'Stunning Software Corp.       ', N'9876 N. Dakota St.            ', N'Fresno        ', N'CA', N'93703     ', N'559-555-1313        ', N'559-555-1314        ', N'tech@stunsftwr.com            ', CAST(2015.00 AS Numeric(8, 2)), CAST(2031.00 AS Numeric(8, 2)), CAST(2031.00 AS Numeric(8, 2)), N'Up and coming software company. Provides add-on utilities for Visual DataFlex for email and internet usage.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (13, 13, N'3A Software                   ', N'1600 Technology Circle        ', N'La Mesa       ', N'CA', N'91914     ', N'619-555-5246        ', N'619-555-5247        ', N'3asoftware@yahoo.com          ', CAST(2774.00 AS Numeric(8, 2)), CAST(3550.00 AS Numeric(8, 2)), CAST(3550.00 AS Numeric(8, 2)), N'These guys have developed some really nifty DataFlex stuff, from DataFlex 3.x in character mode to Visual DataFlex Web Application Server. Keep them in mind for technical consulting.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (14, 14, N'Zorro Cutlery                 ', N'12121 SE 12th Street          ', N'San Diego     ', N'CA', N'92154     ', N'619-555-4137        ', N'619-555-4138        ', N'info@zorrocutl.com            ', CAST(1454.00 AS Numeric(8, 2)), CAST(911.00 AS Numeric(8, 2)), CAST(911.00 AS Numeric(8, 2)), N'Knives, scissors, and miscellaneous cutting instruments for all purposes. They are also on the cutting edge of technology, with Visual DataFlex running their entire operation, from sales to accounting.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (15, 15, N'Automotive Parts              ', N'78550 NW 64th Street          ', N'Miami         ', N'FL', N'33168     ', N'305-555-1244        ', N'305-555-1245        ', N'info@autoparts.net            ', CAST(1000.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Autoparts and accessories.', N'N')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (16, 16, N'San Carlos Brewing Company    ', N'1111 Main Ave                 ', N'San Carlos    ', N'CA', N'94070     ', N'650-555-8475        ', N'650-555-8476        ', N'sales@sancarlosbrew.net       ', CAST(1204.00 AS Numeric(8, 2)), CAST(408.00 AS Numeric(8, 2)), CAST(408.00 AS Numeric(8, 2)), N'Excellent new brewery. Makes several flavors of original recipe beer. Look for seasonal sales high during summer months.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (17, 17, N'Addie Record & Boutique       ', N'5948 Saint Stephens Road      ', N'Eight Mile    ', N'AL', N'36613     ', N'251-555-5803        ', N'251-555-5804        ', N'addierecordboutique@aol.com   ', CAST(500.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Perfect Boutique for old music.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (18, 18, N'Keyboard Kastle               ', N'4433 South 98 Road            ', N'Omaha         ', N'NE', N'68102     ', N'402-555-9400        ', N'402-555-9401        ', N'keyboard@thekastle.com        ', CAST(4400.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Best place for keyboards. Great prices.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (19, 19, N'Butter Jukebox 3000           ', N'1251 Sheridan Avenue          ', N'Bronx         ', N'NY', N'10456     ', N'718-555-8106        ', N'718-555-8107        ', N'music@butterjukebox.com       ', CAST(1050.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Excellent source for Jukeboxes. Wholesale only.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (20, 20, N'Amplified Version             ', N'8303 Dauphin St               ', N'Mobile        ', N'AL', N'36606     ', N'251-555-9488        ', N'251-555-9489        ', N'amplifiedversion@msn.com      ', CAST(225.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Music Store.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (21, 21, N'Brads & Nors                  ', N'2051 Summit Boulevard, Ste 180', N'Birmingham    ', N'AL', N'35243     ', N'205-555-0665        ', N'205-555-0666        ', N'barnesnoble@bellsouth.net     ', CAST(10000.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Every book possible in this store.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (22, 22, N'Better Living Products        ', N'10895 AL Highway 108          ', N'Boaz          ', N'AL', N'35957     ', N'256-555-1311        ', N'256-555-1312        ', N'betterlivingproducts@msn.com  ', CAST(4500.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Home made products to clean your home with.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (23, 23, N'Ecol-Stripe LLC               ', N'138 South Ocen Boulevard      ', N'Boonville     ', N'MO', N'65201     ', N'703-555-6522        ', N'703-555-6523        ', N'ecolstripe@companys.com       ', CAST(9438.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Home improvements.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (24, 24, N'Leader Construction Co        ', N'9731 SW 39 Avenue             ', N'Saint Peters  ', N'MO', N'63303     ', N'636-555-9272        ', N'636-555-9273        ', N'leader@construct.com          ', CAST(10000.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(8, 2)), N'Leader in construction companys.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               ', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (25, 25, N'Designer Fencing Company      ', N'3333 Moreau Rd                ', N'Columbia      ', N'MO', N'65201     ', N'573-555-9209        ', N'573-555-9210        ', N'designerfencing@bellsouth.com ', CAST(6000.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Wooden, chain linked, and white picked fences.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (26, 26, N'Sr Howard Gutter & Supply     ', N'4990 St Anthony Rd            ', N'Celina        ', N'OH', N'45822     ', N'419-555-4733        ', N'419-555-4734        ', N'howard@guttersupply.com       ', CAST(500.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(8, 2)), N'', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (27, 27, N'A New Leef                    ', N'PO Box 367                    ', N'Imperial      ', N'NE', N'69033     ', N'308-555-5030        ', N'308-555-5031        ', N'you@newleef.com               ', CAST(6400.00 AS Numeric(8, 2)), CAST(18928.00 AS Numeric(8, 2)), CAST(18928.00 AS Numeric(8, 2)), N'Remodeling homes and companys.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (28, 28, N'Community Church Of Providence', N'372 Waylnd Av                 ', N'Providence    ', N'RI', N'02906     ', N'401-555-9388        ', N'401-555-9389        ', N'pastor@providencechurch.com   ', CAST(1000.00 AS Numeric(8, 2)), CAST(1856.00 AS Numeric(8, 2)), CAST(1856.00 AS Numeric(8, 2)), N'Community church for all religions.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (29, 29, N'Karlson Thrift Store          ', N'9415 Main Street              ', N'Heavener      ', N'OK', N'74937     ', N'918-555-4410        ', N'918-555-4411        ', N'karlson@thethriftstore.com    ', CAST(250.00 AS Numeric(8, 2)), CAST(583.00 AS Numeric(8, 2)), CAST(583.00 AS Numeric(8, 2)), N'Thrift store where you can buy, donate or sell all kinds of items.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (30, 30, N'Eleven West                   ', N'2901 West Memorial Road       ', N'Oklahoma City ', N'OK', N'73134     ', N'405-555-9510        ', N'405-555-9511        ', N'shoes@elevenwest.com          ', CAST(300.00 AS Numeric(8, 2)), CAST(190.00 AS Numeric(8, 2)), CAST(190.00 AS Numeric(8, 2)), N'Only work shoes.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (31, 31, N'A-A-B Fashion Uniforms        ', N'93245 East 28th Street        ', N'Tulsa         ', N'OK', N'74114     ', N'918-555-5500        ', N'918-555-5501        ', N'uniforms@aab.com              ', CAST(250.00 AS Numeric(8, 2)), CAST(2495.00 AS Numeric(8, 2)), CAST(2495.00 AS Numeric(8, 2)), N'Anything from school to work uniforms.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (32, 32, N'Marathon Sports               ', N'16954 Massachusetts Road      ', N'Cambridge     ', N'MA', N'02138     ', N'617-555-4561        ', N'617-555-4562        ', N'sportsstuff@marathon.com      ', CAST(550.00 AS Numeric(8, 2)), CAST(15190.00 AS Numeric(8, 2)), CAST(15190.00 AS Numeric(8, 2)), N'All kinds of sports wear possible.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (33, 33, N'Camiro''s Athletic Soles       ', N'920 Main Street               ', N'Wakefield     ', N'RI', N'02879     ', N'401-555-9353        ', N'401-555-9354        ', N'camiro@athleticsoles.com      ', CAST(750.00 AS Numeric(8, 2)), CAST(7430.00 AS Numeric(8, 2)), CAST(7430.00 AS Numeric(8, 2)), N'Small shop for athletic foot gear.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (34, 34, N'Armando & Peter Shoe Repair   ', N'11291 Postal Road             ', N'Warwick       ', N'RI', N'02888     ', N'401-555-1516        ', N'401-555-1517        ', N'armandoorpeter@shoerepair.com ', CAST(200.00 AS Numeric(8, 2)), CAST(218.00 AS Numeric(8, 2)), CAST(218.00 AS Numeric(8, 2)), N'Repair even the unrepairable shoe.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (35, 35, N'Baby Gapster                  ', N'1 Providence Place            ', N'Lincoln       ', N'RI', N'02886     ', N'401-555-4433        ', N'401-555-4434        ', N'clothes@babygapster.com       ', CAST(540.00 AS Numeric(8, 2)), CAST(4725.00 AS Numeric(8, 2)), CAST(4725.00 AS Numeric(8, 2)), N'Clothing boutique for children only.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (36, 36, N'LaBecchio, Lois B. DDS        ', N'1760 Wilson Blvd., Suite 100  ', N'Arlington     ', N'VA', N'22209     ', N'703-555-9225        ', N'703-555-9226        ', N'dentistry@labecchiolois.com   ', CAST(5050.00 AS Numeric(8, 2)), CAST(705.00 AS Numeric(8, 2)), CAST(705.00 AS Numeric(8, 2)), N'Dentist', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (37, 37, N'Berkley Plaza Theatre         ', N'Berkley Plaza Shop            ', N'Martinsburg   ', N'WV', N'25401     ', N'304-555-3039        ', N'304-555-3040        ', N'movies@berkleyplaza.com       ', CAST(350.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(8, 2)), N'Movie Theatre that only play movies that are out on video.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (38, 38, N'One Tradeshow Shop.com, Inc   ', N'3802 Hummingbird Rd           ', N'Wausau        ', N'WI', N'54401     ', N'888-555-8070        ', N'888-555-8071        ', N'onetradeshow@internet.com     ', CAST(5400.00 AS Numeric(8, 2)), CAST(4136.00 AS Numeric(8, 2)), CAST(4136.00 AS Numeric(8, 2)), N'Produce graphics, design, build, and import displays. Excellent online catalog.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (39, 39, N'500 Plus News Magazine        ', N'128 Cottonwood Avenue         ', N'Hartland      ', N'WI', N'53029     ', N'262-555-3675        ', N'262-555-3676        ', N'500plus@newsmagazine.com      ', CAST(150.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Magazine which provides information about news around the world.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (40, 40, N'WISH Radio Station            ', N'1312 North Pearla Street      ', N'Berlin        ', N'WI', N'54923     ', N'920-555-3611        ', N'920-555-3612        ', N'wishradio@stations.com        ', CAST(1500.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Number one station for hits around the world. ', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (41, 41, N'National Information Systems  ', N'120 Back Street               ', N'Beaver Dam    ', N'WI', N'53916     ', N'920-555-8872        ', N'920-555-8873        ', N'nationalinfosys@systems.com   ', CAST(5400.00 AS Numeric(8, 2)), CAST(2924.00 AS Numeric(8, 2)), CAST(2924.00 AS Numeric(8, 2)), N'Provide consulting services for information systems worldwide.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (42, 42, N'Excel & Achiev Driver Services', N'11900 West 44th Avenue        ', N'Wheat Ridge   ', N'CO', N'80033     ', N'303-555-9428        ', N'303-555-9429        ', N'driving@services.com          ', CAST(750.00 AS Numeric(8, 2)), CAST(8924.00 AS Numeric(8, 2)), CAST(8924.00 AS Numeric(8, 2)), N'Driving school that will definitely have you driving like a pro.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (43, 43, N'B V Telecommunications        ', N'3905 Concord Pike             ', N'Wilmington    ', N'DE', N'19803     ', N'302-555-4783        ', N'302-555-4784        ', N'bv@telecommunications.com     ', CAST(7500.00 AS Numeric(8, 2)), CAST(840.00 AS Numeric(8, 2)), CAST(840.00 AS Numeric(8, 2)), N'Provide telecommunications for commercial company''s.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (44, 44, N'Homebizz Sound                ', N'1945 North Hunter Forge Road  ', N'Newark        ', N'DE', N'19713     ', N'302-555-7387        ', N'302-555-7388        ', N'sound@homebizz.com            ', CAST(8000.00 AS Numeric(8, 2)), CAST(1483.00 AS Numeric(8, 2)), CAST(1483.00 AS Numeric(8, 2)), N'Provide and install complete sound systems for the home.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (45, 45, N'Professional Video Sales Inc  ', N'3705 Concord Pike             ', N'Wilmington    ', N'DE', N'19803     ', N'302-555-4783        ', N'302-555-4784        ', N'videosales@pros.com           ', CAST(620.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Will record and sell videos at low cost.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (46, 46, N'210 On Clark                  ', N'210 West Clark Street         ', N'Champaign     ', N'IL', N'61820     ', N'217-555-3598        ', N'217-555-3599        ', N'210@clubs.com                 ', CAST(1000.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(8, 2)), N'Best night club in town.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (47, 47, N'Mechanics 0505                ', N'3090 South 51st West          ', N'Rexburg       ', N'ID', N'83440     ', N'208-555-3560        ', N'208-555-3561        ', N'mechanics@0505.com            ', CAST(500.00 AS Numeric(8, 2)), CAST(1877.00 AS Numeric(8, 2)), CAST(1877.00 AS Numeric(8, 2)), N'Certified mechanics who can work on any make of a vehicle.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (48, 48, N'Century 20 Chrysler           ', N'PO Box 988                    ', N'Blackfoot     ', N'ID', N'83221     ', N'208-555-7851        ', N'208-555-7852        ', N'chrysler@century20.com        ', CAST(1500.00 AS Numeric(8, 2)), CAST(302.00 AS Numeric(8, 2)), CAST(302.00 AS Numeric(8, 2)), N'Dealer of Chryslers.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (49, 49, N'B & H Copiers Inc             ', N'1557 East 66th Street         ', N'Brooklyn      ', N'NY', N'11234     ', N'718-555-2411        ', N'718-555-2412        ', N'bhcopiersinc@bellsouth.com    ', CAST(1200.00 AS Numeric(8, 2)), CAST(1877.00 AS Numeric(8, 2)), CAST(1877.00 AS Numeric(8, 2)), N'Printing company.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (50, 50, N'Mahony Anndrew H MD           ', N'9107 Collins Avenue           ', N'Middlebury    ', N'VT', N'05753     ', N'802-555-3883        ', N'802-555-3884        ', N'drmahony@mds.com              ', CAST(5000.00 AS Numeric(8, 2)), CAST(64.00 AS Numeric(8, 2)), CAST(64.00 AS Numeric(8, 2)), N'Physician', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (51, 51, N'Bean & Company Contracting Inc', N'758 Fort Avenue               ', N'Sheridan      ', N'WY', N'82801     ', N'307-555-6747        ', N'307-555-6748        ', N'beancontracting@contracts.com ', CAST(5600.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(8, 2)), N'Build/rebeuild homes and commercial buildings.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (52, 52, N'Walkman''s Supply              ', N'1302 E Lincoln Road           ', N'Alcoa         ', N'TN', N'37701     ', N'865-555-9827        ', N'865-555-9828        ', N'walkmanssupply@bellsouth.net  ', CAST(4200.00 AS Numeric(8, 2)), CAST(4925.00 AS Numeric(8, 2)), CAST(4925.00 AS Numeric(8, 2)), N'Construction supplier.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (53, 53, N'Professional Carpet Care      ', N'87019 SW 89 Circle Suite 100  ', N'Knoxville     ', N'TN', N'37902     ', N'865-555-5734        ', N'865-555-5735        ', N'carpetcare@pros.com           ', CAST(800.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(8, 2)), N'Clean carpets at a low price.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (54, 54, N'Creative Notions              ', N'3191 Dynasty Rd               ', N'District Heigh', N'MD', N'20774     ', N'301-555-5688        ', N'301-555-5689        ', N'creativenotions@msn.com       ', CAST(350.00 AS Numeric(8, 2)), CAST(3048.00 AS Numeric(8, 2)), CAST(3048.00 AS Numeric(8, 2)), N'High class place for beauty care. Will give you a complete make over in minutes!', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (55, 55, N'Dyana Body Gym                ', N'1907 W Washington Ave         ', N'Lovington     ', N'NM', N'88260     ', N'505-555-3962        ', N'505-555-3963        ', N'dyana@bodygym.com             ', CAST(920.00 AS Numeric(8, 2)), CAST(14750.00 AS Numeric(8, 2)), CAST(14750.00 AS Numeric(8, 2)), N'A physical fitness place where great motivators encourage you to feel great about yourself by working out on top notch machinery.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (56, 56, N'Capital Racquet Center        ', N'3290 South 15th Street        ', N'Bismark       ', N'ND', N'58503     ', N'701-555-2216        ', N'701-555-2217        ', N'raquetcenter@thecap.com       ', CAST(1300.00 AS Numeric(8, 2)), CAST(2950.00 AS Numeric(8, 2)), CAST(2950.00 AS Numeric(8, 2)), N'', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (57, 57, N'Eidisoon''s Florist            ', N'8535 Parallel Parkway         ', N'Kansas City   ', N'KS', N'66112     ', N'913-555-2998        ', N'913-555-2999        ', N'eidisoon@allflorist.com       ', CAST(550.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Florist store. They do advance orders only.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (58, 58, N'Larry''s Fine Wines            ', N'5373 Mill Way                 ', N'New Bedford   ', N'MA', N'02740     ', N'508-555-9996        ', N'508-555-9997        ', N'larrysfinewiners@liq.com      ', CAST(350.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (59, 59, N'SJ Storage                    ', N'1188 East State Road 140      ', N'Valparaiso    ', N'IN', N'46385     ', N'219-555-4625        ', N'219-555-4626        ', N'sjstorage@in.com              ', CAST(1000.00 AS Numeric(8, 2)), CAST(2220.00 AS Numeric(8, 2)), CAST(2220.00 AS Numeric(8, 2)), N'Storage for commercial businesses only.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (60, 60, N'BONY Trading                  ', N'3197 Commercial Place         ', N'Palisades Park', N'NJ', N'07650     ', N'201-555-9441        ', N'201-555-9442        ', N'konytrading@tradezone.com     ', CAST(2400.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Assist in Trading.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (61, 61, N'Four Season''s                 ', N'3347 Walnut Street            ', N'Cincinnati    ', N'OH', N'45241     ', N'513-555-7133        ', N'513-555-7134        ', N'fourseasons@imports.com       ', CAST(2000.00 AS Numeric(8, 2)), CAST(340.00 AS Numeric(8, 2)), CAST(340.00 AS Numeric(8, 2)), N'Imports for commercial businesses.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (62, 62, N'Haly Many Fine Art            ', N'Poipe Shopping Villa          ', N'Koloa         ', N'HI', N'96756     ', N'808-555-7422        ', N'808-555-7423        ', N'halymany@fineart.com          ', CAST(550.00 AS Numeric(8, 2)), CAST(1125.00 AS Numeric(8, 2)), CAST(1125.00 AS Numeric(8, 2)), N'Hawaii''s finest Art Gallery.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (63, 63, N'Packsaddle Hop Ranch          ', N'RR 1 Box 290                  ', N'Rochelle      ', N'TX', N'76872     ', N'325-555-4635        ', N'325-555-4636        ', N'packsaddlehop@ranches.com     ', CAST(250.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(8, 2)), N'All horse breeds available at anytime.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (64, 64, N'Meagle Lease To Own           ', N'3155 East 1400 South          ', N'Logan         ', N'UT', N'84341     ', N'435-555-7522        ', N'435-555-7523        ', N'leasetoown@meagles.com        ', CAST(350.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(8, 2)), N'You can rent any type of furniture and can decide purchase at a later date.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (65, 65, N'Meriann Title Corp.           ', N'5454 Michigan Ave             ', N'La Porte      ', N'IN', N'46350     ', N'219-555-3248        ', N'219-555-3249        ', N'meriann@titles.com            ', CAST(1250.00 AS Numeric(8, 2)), CAST(512.00 AS Numeric(8, 2)), CAST(512.00 AS Numeric(8, 2)), N'Title company.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (66, 66, N'VKF Building Relocation       ', N'24 Mount Hermon Road Frnt     ', N'Scotts Valley ', N'CA', N'95066     ', N'831-555-4611        ', N'831-555-4612        ', N'vkf@books.com                 ', CAST(500.00 AS Numeric(8, 2)), CAST(500.00 AS Numeric(8, 2)), CAST(500.00 AS Numeric(8, 2)), N'Magazines and Newspapers.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (67, 67, N'Schoolastic Book Fairs        ', N'250 Lisa Drive # D            ', N'New Castle    ', N'DE', N'19720     ', N'302-555-3221        ', N'302-555-3222        ', N'bookfaris@schoolastic.edu     ', CAST(10000.00 AS Numeric(8, 2)), CAST(7558.00 AS Numeric(8, 2)), CAST(7558.00 AS Numeric(8, 2)), N'Assist public schools in having book fairs.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (68, 68, N'Towne & County Motor Inn      ', N'Route 5                       ', N'Gorham        ', N'NH', N'03581     ', N'603-555-4663        ', N'603-555-4664        ', N'townecounty@motorinn.com      ', CAST(500.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Resort, Inn, Entertainment', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (69, 69, N'R&S Reliable Service Air      ', N'7661 State Road 557           ', N'Polk City     ', N'FL', N'33868     ', N'863-555-9561        ', N'863-555-9562        ', N'rs@reliableservice.com        ', CAST(0.00 AS Numeric(8, 2)), CAST(3954.00 AS Numeric(8, 2)), CAST(3954.00 AS Numeric(8, 2)), N'In Repairs All Makes and Models Equipment Replacement', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (70, 70, N'Tameblyn Apartments           ', N'1231 South Locust Street      ', N'Manteno       ', N'IL', N'60950     ', N'815-555-4683        ', N'815-555-4684        ', N'tameblyn@apartments.com       ', CAST(5500.00 AS Numeric(8, 2)), CAST(1450.00 AS Numeric(8, 2)), CAST(1450.00 AS Numeric(8, 2)), N'Residential apartments, availability upon request.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (71, 71, N'Rapido Release Bail Bonding   ', N'1923 Ida Street Suite A       ', N'Tupelo        ', N'MS', N'38801     ', N'662-555-3658        ', N'662-555-3659        ', N'rapidorelease@bailbonds.com   ', CAST(150.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Bail bonds.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          ', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (72, 72, N'Youngin''s Beauty Supply Inc   ', N'320 Howarde Street            ', N'Greenwood     ', N'MS', N'38930     ', N'662-555-4559        ', N'662-555-4560        ', N'baeutysupply@youngins.com     ', CAST(1800.00 AS Numeric(8, 2)), CAST(1390.00 AS Numeric(8, 2)), CAST(1390.00 AS Numeric(8, 2)), N'Beauty salon supplies and retail. Equipment rentals.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (73, 73, N'Hoffbenny & Associates        ', N'2011 Central Avenue East      ', N'Great Falls   ', N'MT', N'59404     ', N'406-555-4532        ', N'406-555-4533        ', N'hoffbenny@bookkeeping.com     ', CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Auditing, Accounting, Bookkeeping ', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (74, 74, N'Hamherst Country Club         ', N'702 Poemah Road               ', N'Amherst       ', N'NH', N'03031     ', N'603-555-6739        ', N'603-555-6740        ', N'hamherst@golfing.com          ', CAST(1260.00 AS Numeric(8, 2)), CAST(3254.00 AS Numeric(8, 2)), CAST(3254.00 AS Numeric(8, 2)), N'18 Holes, Lessons, Outings ', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (75, 75, N'Feasant Ridge Country Club    ', N'140 Country Club Road         ', N'Gilford       ', N'NH', N'03249     ', N'603-555-7808        ', N'603-555-7809        ', N'feasantridge@countryclub.com  ', CAST(250.00 AS Numeric(8, 2)), CAST(1350.00 AS Numeric(8, 2)), CAST(1350.00 AS Numeric(8, 2)), N'Country Club, Driving Ranges ', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (76, 76, N'Idleyad Trading Post & Liquor ', N'29879 North Umpqua Highway    ', N'Idleyld Park  ', N'OR', N'97447     ', N'541-555-3404        ', N'541-555-3405        ', N'idleyad@msn.com               ', CAST(1000.00 AS Numeric(8, 2)), CAST(500.00 AS Numeric(8, 2)), CAST(500.00 AS Numeric(8, 2)), N'Tackle, Campgrounds, Rv Parks ', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (77, 77, N'Image Technology Corp         ', N'9353 Southeast Alansa Drive   ', N'Hubbard       ', N'OR', N'97032     ', N'503-555-2223        ', N'503-555-2224        ', N'imagetech@hotmail.com         ', CAST(5000.00 AS Numeric(8, 2)), CAST(4724.00 AS Numeric(8, 2)), CAST(4724.00 AS Numeric(8, 2)), N'Metal, Repairs, Sharpening', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (78, 78, N'P & Dantro Co Inc             ', N'1005 E Philadelphia St        ', N'York          ', N'PA', N'17404     ', N'717-555-6922        ', N'717-555-6923        ', N'pdantro@whereever.com         ', CAST(1500.00 AS Numeric(8, 2)), CAST(652.00 AS Numeric(8, 2)), CAST(652.00 AS Numeric(8, 2)), N'Knives & Cutlery retail, food processing equipment & supplies, slicing machines and butchers equipment and supplies.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (79, 79, N'Ye Oldey Gun Shop             ', N'3701 Hamilton Street          ', N'New Bethlehem ', N'PA', N'16242     ', N'814-555-3813        ', N'814-555-3814        ', N'YeOldeyGunShop@msn.com        ', CAST(3500.00 AS Numeric(8, 2)), CAST(3200.00 AS Numeric(8, 2)), CAST(3200.00 AS Numeric(8, 2)), N'Guns, service and repair.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (80, 80, N'Yorkey Barbell Company        ', N'3309 Board Street             ', N'York          ', N'PA', N'17402     ', N'717-555-6481        ', N'717-555-6482        ', N'yorkeybarbell@what.com        ', CAST(550.00 AS Numeric(8, 2)), CAST(4337.00 AS Numeric(8, 2)), CAST(4337.00 AS Numeric(8, 2)), N'Excercise and fitness equipment & supplies dealers.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (81, 81, N'Commershial Bank Of Ozark     ', N'280 North Merrick Avenue      ', N'Ozark         ', N'AL', N'36360     ', N'334-555-8731        ', N'331-555-8732        ', N'commbank@ozark.com            ', CAST(5400.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Home, Banking, Hud', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (82, 82, N'A & B Car Rental-Baranof Motor', N'1009 Sawmill Creek Road       ', N'Sitka         ', N'AK', N'99835     ', N'907-555-9228        ', N'907-555-9229        ', N'abcarrental@who.com           ', CAST(600.00 AS Numeric(8, 2)), CAST(3185.00 AS Numeric(8, 2)), CAST(3185.00 AS Numeric(8, 2)), N'Trucks, Vans, Leasing ', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (83, 83, N'F & S Automotive              ', N'6770 East Frier Drive Suite 10', N'Glendale      ', N'AZ', N'85303     ', N'623-555-9305        ', N'623-555-9306        ', N'fsautomotive@here.net         ', CAST(450.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Maintenance', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (84, 84, N'Access Personnel Corp.        ', N'2311 Wood St                  ', N'Texarkana     ', N'TX', N'75501     ', N'903-555-9817        ', N'903-555-9818        ', N'accesspersonal@work.com       ', CAST(1000.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Placement, Permanent, Temporary ', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (85, 85, N'A S A P Services              ', N'1810 North Crossover Road     ', N'Fayetteville  ', N'AR', N'72701     ', N'479-555-0675        ', N'479-555-0676        ', N'asapservices@ummm.com         ', CAST(100.00 AS Numeric(8, 2)), CAST(508.00 AS Numeric(8, 2)), CAST(508.00 AS Numeric(8, 2)), N'Temporary Employment Agency', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [NAME], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (86, 86, N'A Child''s Garden              ', N'690 West Dunne Road           ', N'Morgan Hill   ', N'CA', N'95037     ', N'408-555-7787        ', N'408-555-7788        ', N'achildsgarden@eve.com         ', CAST(750.00 AS NUMERIC(8, 2)), CAST(0.00 AS NUMERIC(8, 2)), CAST(0.00 AS NUMERIC(8, 2)), N'Elementary, Education ', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (87, 87, N'Kennie & Associates Inc       ', N'210 West 10th Street          ', N'Loveland      ', N'CO', N'80537     ', N'970-555-6305        ', N'970-555-6306        ', N'kennieassoc@work.com          ', CAST(5000.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Contractors', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [NAME], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (88, 88, N'Topnotch Communications Inc   ', N'1055 Stonewall Farms Rd       ', N'Mahopac       ', N'NY', N'10541     ', N'914-555-3504        ', N'914-555-3505        ', N'topnotchcomm@communicate.com  ', CAST(10000.00 AS NUMERIC(8, 2)), CAST(0.00 AS NUMERIC(8, 2)), CAST(0.00 AS NUMERIC(8, 2)), N'Networking, LAN, Auto Attendant, Software, Data Communications, Lines, WAN, Data, Business, Leasing, Cabling, Installation, Maintenance, Upgrades, Dsl, Voice Mail', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (89, 89, N'Whalie Computer Associates    ', N'51 Whalley Way                ', N'Southwick     ', N'MA', N'01077     ', N'413-555-5698        ', N'413-555-5699        ', N'whaliecomp@associates.com     ', CAST(4200.00 AS Numeric(8, 2)), CAST(1557.00 AS Numeric(8, 2)), CAST(1557.00 AS Numeric(8, 2)), N'Software, Business, Installation, Hardware', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (90, 90, N'Datalook                      ', N'4450 11th Avenue              ', N'New York      ', N'NY', N'10001     ', N'212-555-6891        ', N'212-555-6892        ', N'sales@datalook.com            ', CAST(8200.00 AS Numeric(8, 2)), CAST(4900.00 AS Numeric(8, 2)), CAST(4900.00 AS Numeric(8, 2)), N'Services, Notebooks, LAN, Linux, Unix, WAN, Desktops, Consulting, Cabling, Data Recovery, Installation, Maintenance, Service Contracts, Upgrades, Networking', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (91, 91, N'Darieeno Computer             ', N'10578 Postal Road             ', N'Darien        ', N'CT', N'06820     ', N'203-555-8675        ', N'203-555-8676        ', N'help@darieeno.com             ', CAST(950.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Services, Software, Repairs, Business, Free Estimate', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (92, 92, N'Utopeea Systems Corp          ', N'1372 Old Forgie Road          ', N'New Castle    ', N'DE', N'19801     ', N'302-555-7707        ', N'302-555-7708        ', N'utopeeasystems@corps.com      ', CAST(500.00 AS Numeric(8, 2)), CAST(400.00 AS Numeric(8, 2)), CAST(400.00 AS Numeric(8, 2)), N'Build applications in Sql, Asp, Microsoft.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (93, 93, N'Forte Mayer Construction      ', N'2287 83rd Street Northwest    ', N'Washington    ', N'DC', N'20001     ', N'202-555-6953        ', N'202-555-6954        ', N'fortemayer@contruction.net    ', CAST(5000.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Construction, Paving, Repairs', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (94, 94, N'Union Enterprise of Seminole  ', N'4183 Central Park Circle      ', N'Stanford      ', N'FL', N'32771     ', N'407-555-3316        ', N'407-555-3317        ', N'unionenterprise@seminole.com  ', CAST(2000.00 AS Numeric(8, 2)), CAST(658.00 AS Numeric(8, 2)), CAST(658.00 AS Numeric(8, 2)), N'Electric Contractors', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (95, 95, N'Provedance Christian Academy  ', N'4595 Lawrenceville Hwy SW     ', N'Lilburn       ', N'GA', N'30047     ', N'770-555-2797        ', N'770-555-2798        ', N'www.providencechristian.net   ', CAST(1000.00 AS Numeric(8, 2)), CAST(1950.00 AS Numeric(8, 2)), CAST(1950.00 AS Numeric(8, 2)), N'Christian private Schools, Elementary & Secondary Education', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (96, 96, N'Korner Bakery Kafe            ', N'305 West Monroe St            ', N'Chicago       ', N'IL', N'60603     ', N'312-555-3700        ', N'312-555-3701        ', N'kornerbakerykafe@who.net      ', CAST(1060.00 AS Numeric(8, 2)), CAST(3287.00 AS Numeric(8, 2)), CAST(3287.00 AS Numeric(8, 2)), N'Cafe, Restaurant, and Bakery.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (97, 97, N'Raccoon Bait & Tackle-Shell Co', N'RR 10 Box 191                 ', N'Rockville     ', N'IN', N'47872     ', N'765-555-4185        ', N'765-555-4186        ', N'baitandtackle@supplies.com    ', CAST(800.00 AS Numeric(8, 2)), CAST(25425.00 AS Numeric(8, 2)), CAST(25425.00 AS Numeric(8, 2)), N'Fly Fishing Equipment & Supplies', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (98, 98, N'La Avenida Mexican Store      ', N'1606 B Ave W                  ', N'Oskaloosa     ', N'IA', N'52577     ', N'641-555-7334        ', N'641-555-7335        ', N'mexicanstore@whoknows.com     ', CAST(250.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), CAST(0.00 AS Numeric(8, 2)), N'Mexican grocery store.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (99, 99, N'228 Fuel Express Pizzas & Food', N'Hwys 228 & 28                 ', N'Floyd         ', N'IA', N'50435     ', N'641-555-2387        ', N'641-555-2388        ', N'228fuelpizzafood@quickbite.com', CAST(500.00 AS Numeric(8, 2)), CAST(22853.00 AS Numeric(8, 2)), CAST(22853.00 AS Numeric(8, 2)), N'Gasoline, Pizza Restaurant and quick sandwiches.', N'Y')
INSERT [dbo].[Customer] ([RECNUM], [Customer_Number], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number], [EMail_Address], [Credit_Limit], [Purchases], [Balance], [Comments], [Status]) VALUES (100, 100, N'Absoraka Cruise & Travel      ', N'1173 15th Road                ', N'Cody          ', N'WY', N'82414     ', N'307-555-7020        ', N'307-555-7021        ', N'absorakacruisetravel@trips.net', CAST(1250.00 AS Numeric(8, 2)), CAST(17000.00 AS Numeric(8, 2)), CAST(17000.00 AS Numeric(8, 2)), N'Open Mon-Sat. Travel Agents', N'Y')
GO
SET IDENTITY_INSERT [dbo].[Customer] OFF
SET IDENTITY_INSERT [dbo].[Invt] ON 

INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (45, N'ACE1      ', N'Ace marks the spot                 ', 6, N'ace1-1         ', CAST(25.00 AS Numeric(8, 2)), 89)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (46, N'ACE-2     ', N'More Ace Stuff                     ', 6, N'ac2-2-2        ', CAST(15.00 AS Numeric(8, 2)), 89)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (26, N'BEARS     ', N'The Bears of North America         ', 3, N'BR-1-98        ', CAST(32.00 AS Numeric(8, 2)), 636)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (36, N'BRIDGE    ', N'Famous Bridges I''ve Known - Photos ', 3, N'BE-7789-88     ', CAST(195.00 AS Numeric(8, 2)), 614)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (3, N'CASE      ', N'Understanding Case Technology      ', 4, N'TBS-CASE       ', CAST(39.00 AS Numeric(8, 2)), 705)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (15, N'CITIES    ', N'Cities I''ve Enjoyed - Photo Essays ', 2, N'BW-CITIES      ', CAST(49.00 AS Numeric(8, 2)), 896)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (2, N'CUA       ', N'The CUA Reference Guide            ', 2, N'BW-CUA-1       ', CAST(49.00 AS Numeric(8, 2)), 891)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (5, N'DATES     ', N'The 100 Important Dates in History ', 2, N'BW-DATES       ', CAST(29.00 AS Numeric(8, 2)), 131)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (6, N'DT        ', N'The Database Programmer''s Tool     ', 7, N'SP-DPT-1       ', CAST(179.00 AS Numeric(8, 2)), 713)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (7, N'DT PK     ', N'Database Toolbox and Software      ', 7, N'SP-DTS         ', CAST(229.00 AS Numeric(8, 2)), 779)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (31, N'FLEX-O-MAT', N'The Flex-O-Matic Excerise Kit      ', 3, N'BE-FLEX        ', CAST(295.00 AS Numeric(8, 2)), 535)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (11, N'GOLD      ', N'The Gold Hunter''s Prospect Kit     ', 2, N'BW-GOLD        ', CAST(779.00 AS Numeric(8, 2)), 670)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (12, N'GOLD-DLX  ', N'The Deluxe Gold Prospecting Kit    ', 2, N'GOLD-DLX       ', CAST(1079.00 AS Numeric(8, 2)), 582)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (42, N'JEWELRY-DL', N'The Deluxe Jewelry Kit             ', 3, N'BE-DJK-DLX     ', CAST(1749.00 AS Numeric(8, 2)), 623)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (41, N'JEWELRY-I ', N'The Basic Jewelry Kit              ', 3, N'BE-BJK-1       ', CAST(1299.00 AS Numeric(8, 2)), 663)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (29, N'JOKES     ', N'The Best of Computer Humor         ', 3, N'BE-12345-12    ', CAST(12.00 AS Numeric(8, 2)), 590)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (38, N'MAPS      ', N'Maps of the National Parks         ', 3, N'BE-MAPS        ', CAST(145.00 AS Numeric(8, 2)), 284)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (4, N'MENU      ', N'Menu Planning for the Busy Family  ', 8, N'PM-1234        ', CAST(129.00 AS Numeric(8, 2)), 691)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (13, N'MODEMS    ', N'The Modem User''s Fun-Kit           ', 7, N'SP-MDM-1       ', CAST(129.00 AS Numeric(8, 2)), 874)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (28, N'NITE-LITE ', N'The Reader''s Night-Light           ', 3, N'BE-XTRA-LMP    ', CAST(24.00 AS Numeric(8, 2)), 674)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (47, N'OBM       ', N'How to Buy Old Books               ', 10, N'OBM-OBM1       ', CAST(22.00 AS Numeric(8, 2)), 20)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (32, N'OFFICE-1  ', N'Understanding Office Data Flow     ', 9, N'BWB-123092     ', CAST(45.00 AS Numeric(8, 2)), 559)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (33, N'OFFICE-2  ', N'Office Communication Methods       ', 9, N'BWB-09873      ', CAST(65.00 AS Numeric(8, 2)), 577)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (35, N'OFFICE-S  ', N'How to Manage the Small Office     ', 9, N'BWB-99875      ', CAST(19.00 AS Numeric(8, 2)), 706)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (27, N'O''NEILLS  ', N'O''Neill''s 1001 Gems of Irish Music ', 3, N'BE-ON1001      ', CAST(45.00 AS Numeric(8, 2)), 633)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (16, N'PICTURE   ', N'Pictures the World Loves           ', 2, N'BW-PICTURES-092', CAST(29.00 AS Numeric(8, 2)), 609)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (25, N'POOL      ', N'Build Your Own Pool                ', 5, N'CR-1239423     ', CAST(15.00 AS Numeric(8, 2)), 594)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (17, N'POPUP     ', N'The Peter Rabbit Popup Box Set     ', 2, N'BW-BP-PW       ', CAST(49.00 AS Numeric(8, 2)), 734)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (19, N'PULLMAN   ', N'Pullman Cars of the 1930''s         ', 2, N'BW-PULLMAN     ', CAST(49.00 AS Numeric(8, 2)), 719)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (14, N'REPORTS   ', N'1001 Common Business Reports       ', 9, N'BWB-123093     ', CAST(179.00 AS Numeric(8, 2)), 821)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (18, N'REPORTS II', N'The Top 5,000 Reports in Government', 8, N'PM-5000GR      ', CAST(199.00 AS Numeric(8, 2)), 722)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (9, N'RUNMTR    ', N'The Runner''s Pulse-o-meter         ', 2, N'BW-RPM-1       ', CAST(79.00 AS Numeric(8, 2)), 823)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (10, N'RUNMTR2   ', N'The Runner''s Timer-Pulse-Heart     ', 2, N'BW-RTP         ', CAST(199.00 AS Numeric(8, 2)), 533)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (37, N'STARTREK  ', N'Star Trek Collector Gold Plate     ', 3, N'BE-XTA-STCGP   ', CAST(1599.00 AS Numeric(8, 2)), 685)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (20, N'TABLE     ', N'Build Your Own Table - Pine Kit    ', 5, N'CR-TBL-PIN     ', CAST(179.00 AS Numeric(8, 2)), 732)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (24, N'TABLE-MAH ', N'Build Your Own Table - Mahogany    ', 5, N'CR-TBL-MAH     ', CAST(1250.00 AS Numeric(8, 2)), 652)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (21, N'TABLE-MPL ', N'Build Your Own Table - Maple Kit   ', 5, N'CR-TBL-MPL     ', CAST(319.00 AS Numeric(8, 2)), 828)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (43, N'TEXT-1    ', N'Computers Made Easy, Volume I      ', 7, N'SP-CME1        ', CAST(99.00 AS Numeric(8, 2)), 993)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (44, N'TEXT-2    ', N'Computers Made Easy, Volume II     ', 7, N'SP-CME2        ', CAST(59.00 AS Numeric(8, 2)), 93)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (1, N'TEXT-3    ', N'Computers Made Easy, Volume III    ', 7, N'SP-CME3        ', CAST(69.00 AS Numeric(8, 2)), 88)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (23, N'TEXT-4    ', N'Computers Made Easy, Volume IV     ', 7, N'SP-CME4        ', CAST(99.00 AS Numeric(8, 2)), 993)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (30, N'TEXT-ALL  ', N'Computers Made Easy, Boxed Set     ', 7, N'SP-CME-BOX     ', CAST(595.00 AS Numeric(8, 2)), 652)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (40, N'UN-CL-1   ', N'Unix in the Classroom (10 user)    ', 7, N'SP-UNIX-10     ', CAST(399.00 AS Numeric(8, 2)), 679)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (39, N'UN-CL-2   ', N'Unix in the Classroon (30 user)    ', 7, N'SP-UNIX-30     ', CAST(659.00 AS Numeric(8, 2)), 711)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (8, N'UNIXGUIDE ', N'The Complete Unix Guide. Vol 1     ', 7, N'SP-UG-1        ', CAST(499.00 AS Numeric(8, 2)), 551)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (22, N'UPDATE    ', N'How to Update Your Own Computer    ', 4, N'TBS-SMOKE      ', CAST(19.00 AS Numeric(8, 2)), 868)
INSERT [dbo].[Invt] ([RECNUM], [Item_ID], [Description], [Vendor_ID], [Vendor_Part_ID], [Unit_Price], [On_Hand]) VALUES (34, N'VINO-LM   ', N'A Guide to the Wines of La Mesa    ', 3, N'BE-VINO-LM     ', CAST(5.00 AS Numeric(8, 2)), 373)
SET IDENTITY_INSERT [dbo].[Invt] OFF
SET IDENTITY_INSERT [dbo].[OrderDtl] ON 

INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (7, 101, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (6, 101, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (62, 101, 3, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (64, 101, 5, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (5, 102, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4, 102, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3, 102, 3, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2, 102, 4, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1, 103, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (8, 103, 2, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (9, 103, 3, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (10, 103, 4, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (11, 104, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (12, 104, 2, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (13, 105, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (14, 105, 2, N'MODEMS    ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (15, 105, 3, N'TABLE-MAH ', 1, CAST(1250.00 AS Numeric(8, 2)), CAST(1250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (68, 105, 4, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (16, 106, 1, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (17, 106, 2, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (19, 107, 1, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (20, 107, 2, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (21, 108, 1, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (22, 108, 2, N'GOLD-DLX  ', 2, CAST(1079.00 AS Numeric(8, 2)), CAST(2158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (23, 109, 1, N'MODEMS    ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (24, 109, 2, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (25, 109, 3, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (26, 110, 1, N'TABLE-MPL ', 2, CAST(319.00 AS Numeric(8, 2)), CAST(638.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (27, 110, 2, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (28, 110, 3, N'UN-CL-1   ', 1, CAST(399.00 AS Numeric(8, 2)), CAST(399.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (29, 111, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (30, 111, 2, N'RUNMTR2   ', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (18, 111, 3, N'POPUP     ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (31, 112, 1, N'JEWELRY-DL', 1, CAST(1749.00 AS Numeric(8, 2)), CAST(1749.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (32, 112, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (97, 112, 3, N'UN-CL-2   ', 2, CAST(659.00 AS Numeric(8, 2)), CAST(1318.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (34, 113, 2, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (98, 113, 3, N'JOKES     ', 5, CAST(12.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (99, 113, 4, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (100, 113, 5, N'UNIXGUIDE ', 3, CAST(499.00 AS Numeric(8, 2)), CAST(1497.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (36, 114, 2, N'MODEMS    ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (37, 114, 3, N'REPORTS II', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (38, 115, 1, N'JEWELRY-DL', 1, CAST(1749.00 AS Numeric(8, 2)), CAST(1749.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (39, 115, 2, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (40, 116, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (41, 116, 3, N'MAPS      ', 30, CAST(145.00 AS Numeric(8, 2)), CAST(4350.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (42, 117, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (43, 118, 1, N'UN-CL-2   ', 2, CAST(659.00 AS Numeric(8, 2)), CAST(1318.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (44, 118, 3, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (45, 119, 1, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (46, 119, 2, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (35, 119, 3, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (48, 120, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (49, 120, 3, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (50, 120, 4, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (47, 120, 5, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (51, 121, 1, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (52, 121, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (53, 121, 3, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (54, 122, 1, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (55, 122, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (56, 122, 3, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (57, 122, 4, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (58, 123, 1, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (59, 123, 2, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (60, 123, 3, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (61, 123, 4, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (65, 124, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (66, 124, 4, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (69, 125, 16, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (67, 125, 17, N'DATES     ', 200, CAST(29.00 AS Numeric(8, 2)), CAST(5800.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (70, 126, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (71, 126, 2, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (72, 126, 3, N'DT PK     ', 3, CAST(229.00 AS Numeric(8, 2)), CAST(687.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (84, 126, 4, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (73, 127, 1, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (74, 127, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (75, 127, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (76, 127, 4, N'GOLD-DLX  ', 2, CAST(1079.00 AS Numeric(8, 2)), CAST(2158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (77, 127, 5, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (78, 127, 6, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (79, 128, 1, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (80, 128, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (81, 128, 3, N'DATES     ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (82, 128, 4, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (83, 128, 5, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (85, 129, 1, N'DATES     ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (86, 129, 2, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (63, 130, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (88, 130, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (87, 130, 3, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (89, 130, 4, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (90, 130, 5, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (92, 130, 10, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (91, 131, 1, N'BEARS     ', 2, CAST(30.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (93, 131, 4, N'BEARS     ', 2, CAST(30.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (94, 131, 5, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (95, 132, 1, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (96, 132, 2, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (33, 133, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (101, 133, 2, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (102, 134, 1, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (103, 135, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (104, 135, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (105, 136, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (106, 136, 2, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (107, 137, 1, N'ACE1      ', 10, CAST(25.00 AS Numeric(8, 2)), CAST(250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (108, 137, 2, N'ACE-2     ', 10, CAST(15.00 AS Numeric(8, 2)), CAST(150.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (109, 138, 1, N'BEARS     ', 3, CAST(32.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (110, 138, 2, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (111, 139, 1, N'JEWELRY-DL', 1, CAST(1749.00 AS Numeric(8, 2)), CAST(1749.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (112, 140, 1, N'FLEX-O-MAT', 5, CAST(295.00 AS Numeric(8, 2)), CAST(1475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (113, 141, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (114, 141, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (115, 142, 1, N'MAPS      ', 50, CAST(145.00 AS Numeric(8, 2)), CAST(7250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (116, 143, 1, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (117, 143, 2, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (118, 143, 3, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (119, 144, 1, N'DATES     ', 25, CAST(29.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (120, 144, 2, N'POPUP     ', 25, CAST(49.00 AS Numeric(8, 2)), CAST(1225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (121, 145, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (122, 145, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (123, 145, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (124, 146, 1, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (125, 146, 2, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (126, 146, 3, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (127, 146, 4, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (128, 146, 5, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (129, 147, 1, N'VINO-LM   ', 10, CAST(5.00 AS Numeric(8, 2)), CAST(50.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (130, 148, 1, N'UN-CL-1   ', 3, CAST(399.00 AS Numeric(8, 2)), CAST(1197.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (131, 148, 2, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (132, 149, 1, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (133, 150, 1, N'FLEX-O-MAT', 50, CAST(295.00 AS Numeric(8, 2)), CAST(14750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (134, 151, 1, N'O''NEILLS  ', 25, CAST(45.00 AS Numeric(8, 2)), CAST(1125.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (135, 151, 2, N'TABLE     ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (136, 152, 1, N'TABLE-MAH ', 1, CAST(1250.00 AS Numeric(8, 2)), CAST(1250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (137, 152, 2, N'TABLE-MPL ', 1, CAST(319.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (138, 153, 1, N'JEWELRY-DL', 1, CAST(1749.00 AS Numeric(8, 2)), CAST(1749.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (139, 153, 2, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (140, 154, 1, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (141, 154, 2, N'DT PK     ', 15, CAST(229.00 AS Numeric(8, 2)), CAST(3435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (142, 155, 1, N'MAPS      ', 100, CAST(145.00 AS Numeric(8, 2)), CAST(14500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (143, 156, 1, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (144, 156, 2, N'PULLMAN   ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (145, 157, 1, N'RUNMTR    ', 6, CAST(79.00 AS Numeric(8, 2)), CAST(474.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (146, 157, 2, N'RUNMTR2   ', 12, CAST(199.00 AS Numeric(8, 2)), CAST(2388.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (147, 158, 1, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (148, 159, 1, N'JOKES     ', 10, CAST(12.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (149, 160, 1, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (150, 160, 2, N'REPORTS II', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (151, 161, 1, N'MAPS      ', 25, CAST(145.00 AS Numeric(8, 2)), CAST(3625.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (152, 161, 2, N'CITIES    ', 25, CAST(49.00 AS Numeric(8, 2)), CAST(1225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (153, 162, 1, N'BEARS     ', 4, CAST(32.00 AS Numeric(8, 2)), CAST(128.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (154, 162, 2, N'STARTREK  ', 3, CAST(1599.00 AS Numeric(8, 2)), CAST(4797.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (155, 163, 1, N'MAPS      ', 100, CAST(145.00 AS Numeric(8, 2)), CAST(14500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (156, 164, 1, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (157, 164, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (158, 165, 1, N'MENU      ', 25, CAST(129.00 AS Numeric(8, 2)), CAST(3225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (159, 166, 1, N'NITE-LITE ', 1, CAST(24.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (160, 166, 2, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (161, 166, 3, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (162, 167, 1, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (163, 167, 2, N'OFFICE-1  ', 10, CAST(45.00 AS Numeric(8, 2)), CAST(450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (164, 168, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (165, 168, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (166, 168, 3, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (167, 169, 1, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (168, 169, 2, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (169, 170, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (170, 170, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (171, 170, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (172, 170, 4, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (173, 170, 5, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (174, 171, 1, N'JOKES     ', 5, CAST(12.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (175, 172, 1, N'ACE-2     ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (176, 172, 2, N'ACE1      ', 1, CAST(25.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (178, 173, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (179, 173, 2, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (180, 174, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (181, 174, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (182, 174, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (183, 175, 1, N'GOLD-DLX  ', 1, CAST(1079.00 AS Numeric(8, 2)), CAST(1079.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (184, 176, 1, N'FLEX-O-MAT', 10, CAST(295.00 AS Numeric(8, 2)), CAST(2950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (185, 177, 1, N'BRIDGE    ', 5, CAST(195.00 AS Numeric(8, 2)), CAST(975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (186, 177, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (187, 177, 3, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (188, 178, 1, N'DT PK     ', 2, CAST(229.00 AS Numeric(8, 2)), CAST(458.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (189, 179, 1, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (190, 179, 2, N'TABLE-MAH ', 1, CAST(1250.00 AS Numeric(8, 2)), CAST(1250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (191, 179, 3, N'TABLE-MPL ', 1, CAST(319.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (192, 179, 4, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (193, 179, 5, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (194, 179, 6, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (195, 180, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (196, 180, 2, N'CUA       ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (197, 181, 1, N'BRIDGE    ', 3, CAST(195.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (198, 182, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (199, 182, 2, N'POPUP     ', 25, CAST(49.00 AS Numeric(8, 2)), CAST(1225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (200, 182, 3, N'PULLMAN   ', 25, CAST(49.00 AS Numeric(8, 2)), CAST(1225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (201, 183, 1, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (202, 183, 2, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (203, 183, 3, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (204, 183, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (205, 183, 5, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (206, 184, 1, N'MODEMS    ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (207, 184, 2, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (208, 185, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (209, 186, 1, N'STARTREK  ', 5, CAST(1599.00 AS Numeric(8, 2)), CAST(7995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (210, 187, 1, N'REPORTS II', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (211, 188, 1, N'OFFICE-1  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (212, 188, 2, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (213, 188, 3, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (214, 189, 1, N'UN-CL-1   ', 12, CAST(399.00 AS Numeric(8, 2)), CAST(4788.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (215, 189, 2, N'UN-CL-2   ', 12, CAST(659.00 AS Numeric(8, 2)), CAST(7908.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (216, 189, 3, N'UNIXGUIDE ', 12, CAST(499.00 AS Numeric(8, 2)), CAST(5988.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (217, 190, 1, N'RUNMTR    ', 20, CAST(79.00 AS Numeric(8, 2)), CAST(1580.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (218, 190, 2, N'RUNMTR2   ', 25, CAST(199.00 AS Numeric(8, 2)), CAST(4975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (219, 191, 1, N'O''NEILLS  ', 13, CAST(45.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (220, 192, 1, N'GOLD      ', 5, CAST(779.00 AS Numeric(8, 2)), CAST(3895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (221, 193, 1, N'CITIES    ', 21, CAST(49.00 AS Numeric(8, 2)), CAST(1029.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (222, 193, 2, N'MAPS      ', 21, CAST(145.00 AS Numeric(8, 2)), CAST(3045.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (223, 194, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (224, 194, 2, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (225, 194, 3, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (226, 194, 4, N'VINO-LM   ', 4, CAST(5.00 AS Numeric(8, 2)), CAST(20.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (227, 195, 1, N'POOL      ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (228, 195, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (229, 196, 1, N'FLEX-O-MAT', 50, CAST(295.00 AS Numeric(8, 2)), CAST(14750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (230, 197, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (231, 197, 2, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (232, 198, 1, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (233, 198, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (234, 198, 3, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (235, 198, 4, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (236, 199, 1, N'VINO-LM   ', 100, CAST(5.00 AS Numeric(8, 2)), CAST(500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (237, 200, 1, N'NITE-LITE ', 100, CAST(24.00 AS Numeric(8, 2)), CAST(2400.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (238, 200, 2, N'POPUP     ', 40, CAST(49.00 AS Numeric(8, 2)), CAST(1960.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (239, 200, 3, N'STARTREK  ', 2, CAST(1599.00 AS Numeric(8, 2)), CAST(3198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (240, 201, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (241, 201, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (242, 201, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (243, 202, 1, N'PICTURE   ', 50, CAST(29.00 AS Numeric(8, 2)), CAST(1450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (244, 203, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (245, 203, 2, N'RUNMTR2   ', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (246, 204, 1, N'MAPS      ', 15, CAST(145.00 AS Numeric(8, 2)), CAST(2175.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (247, 205, 1, N'JOKES     ', 50, CAST(12.00 AS Numeric(8, 2)), CAST(600.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (248, 205, 2, N'POOL      ', 50, CAST(15.00 AS Numeric(8, 2)), CAST(750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (249, 206, 1, N'VINO-LM   ', 100, CAST(5.00 AS Numeric(8, 2)), CAST(500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (250, 207, 1, N'BEARS     ', 100, CAST(32.00 AS Numeric(8, 2)), CAST(3200.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (251, 208, 1, N'CITIES    ', 50, CAST(49.00 AS Numeric(8, 2)), CAST(2450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (252, 209, 1, N'TEXT-ALL  ', 5, CAST(595.00 AS Numeric(8, 2)), CAST(2975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (253, 210, 1, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (254, 210, 2, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (255, 210, 3, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (256, 210, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (257, 211, 1, N'UN-CL-1   ', 1, CAST(399.00 AS Numeric(8, 2)), CAST(399.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (258, 211, 2, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (259, 211, 3, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (260, 212, 1, N'CUA       ', 100, CAST(49.00 AS Numeric(8, 2)), CAST(4900.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (261, 213, 1, N'PICTURE   ', 100, CAST(29.00 AS Numeric(8, 2)), CAST(2900.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (262, 214, 1, N'BRIDGE    ', 50, CAST(195.00 AS Numeric(8, 2)), CAST(9750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (263, 215, 1, N'POOL      ', 100, CAST(15.00 AS Numeric(8, 2)), CAST(1500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (264, 216, 1, N'DATES     ', 25, CAST(29.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (265, 216, 2, N'DT        ', 25, CAST(179.00 AS Numeric(8, 2)), CAST(4475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (266, 216, 3, N'DT PK     ', 25, CAST(229.00 AS Numeric(8, 2)), CAST(5725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (267, 217, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (268, 217, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (269, 217, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (270, 217, 4, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (271, 218, 1, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (177, 218, 2, N'POPUP     ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (272, 218, 3, N'DT        ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (273, 218, 5, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (274, 219, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (275, 219, 2, N'CITIES    ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (276, 219, 3, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (277, 219, 4, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (278, 220, 1, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (279, 220, 2, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (280, 220, 3, N'TEXT-4    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (281, 220, 4, N'REPORTS   ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (282, 221, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (283, 221, 2, N'GOLD      ', 4, CAST(779.00 AS Numeric(8, 2)), CAST(3116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (284, 222, 1, N'MENU      ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (285, 222, 2, N'MODEMS    ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (286, 222, 3, N'TABLE-MAH ', 7, CAST(1250.00 AS Numeric(8, 2)), CAST(8750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (287, 222, 4, N'REPORTS   ', 12, CAST(179.00 AS Numeric(8, 2)), CAST(2148.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (288, 223, 1, N'PULLMAN   ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (289, 223, 2, N'TABLE     ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (290, 224, 1, N'REPORTS   ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (291, 224, 2, N'CUA       ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (292, 225, 1, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (293, 225, 2, N'GOLD-DLX  ', 1, CAST(1079.00 AS Numeric(8, 2)), CAST(1079.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (294, 226, 1, N'MODEMS    ', 10, CAST(129.00 AS Numeric(8, 2)), CAST(1290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (295, 226, 2, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (296, 226, 3, N'TEXT-2    ', 4, CAST(59.00 AS Numeric(8, 2)), CAST(236.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (297, 227, 1, N'TABLE-MPL ', 5, CAST(319.00 AS Numeric(8, 2)), CAST(1595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (298, 227, 2, N'JEWELRY-I ', 7, CAST(1299.00 AS Numeric(8, 2)), CAST(9093.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (299, 227, 3, N'UN-CL-1   ', 7, CAST(399.00 AS Numeric(8, 2)), CAST(2793.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (300, 228, 1, N'RUNMTR    ', 7, CAST(79.00 AS Numeric(8, 2)), CAST(553.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (301, 228, 2, N'RUNMTR2   ', 13, CAST(199.00 AS Numeric(8, 2)), CAST(2587.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (302, 228, 3, N'POPUP     ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (303, 229, 1, N'JEWELRY-DL', 1, CAST(1749.00 AS Numeric(8, 2)), CAST(1749.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (304, 229, 2, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (305, 229, 3, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (306, 230, 2, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (307, 230, 3, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (308, 230, 4, N'TEXT-ALL  ', 12, CAST(595.00 AS Numeric(8, 2)), CAST(7140.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (309, 230, 5, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (310, 231, 2, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (311, 231, 3, N'REPORTS II', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (312, 232, 1, N'JEWELRY-DL', 5, CAST(1749.00 AS Numeric(8, 2)), CAST(8745.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (313, 232, 2, N'FLEX-O-MAT', 5, CAST(295.00 AS Numeric(8, 2)), CAST(1475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (314, 233, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (315, 233, 3, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (316, 234, 1, N'JEWELRY-I ', 4, CAST(1299.00 AS Numeric(8, 2)), CAST(5196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (317, 235, 1, N'UN-CL-2   ', 4, CAST(659.00 AS Numeric(8, 2)), CAST(2636.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (318, 235, 3, N'FLEX-O-MAT', 13, CAST(295.00 AS Numeric(8, 2)), CAST(3835.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (319, 236, 1, N'OFFICE-2  ', 13, CAST(65.00 AS Numeric(8, 2)), CAST(845.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (320, 236, 2, N'PULLMAN   ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (321, 236, 3, N'TEXT-1    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (322, 237, 2, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (323, 237, 3, N'DATES     ', 13, CAST(29.00 AS Numeric(8, 2)), CAST(377.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (324, 237, 4, N'PICTURE   ', 13, CAST(29.00 AS Numeric(8, 2)), CAST(377.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (325, 237, 5, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (326, 238, 1, N'TEXT-ALL  ', 4, CAST(595.00 AS Numeric(8, 2)), CAST(2380.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (327, 238, 2, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (328, 238, 3, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (329, 239, 1, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (330, 239, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (331, 239, 3, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (332, 239, 4, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (333, 240, 1, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (334, 240, 2, N'MENU      ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (335, 240, 3, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (336, 240, 4, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (337, 241, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (338, 241, 4, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (339, 242, 16, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (340, 242, 17, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (341, 243, 1, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (342, 243, 2, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (343, 243, 3, N'DT PK     ', 11, CAST(229.00 AS Numeric(8, 2)), CAST(2519.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (344, 243, 4, N'MENU      ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (345, 244, 1, N'DT        ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (346, 244, 2, N'CITIES    ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (347, 244, 3, N'TEXT-3    ', 11, CAST(69.00 AS Numeric(8, 2)), CAST(759.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (348, 244, 4, N'GOLD-DLX  ', 4, CAST(1079.00 AS Numeric(8, 2)), CAST(4316.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (349, 244, 5, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (350, 244, 6, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (351, 245, 1, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (352, 245, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (353, 245, 3, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (354, 245, 4, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (355, 245, 5, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (356, 246, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (357, 246, 2, N'DT PK     ', 3, CAST(229.00 AS Numeric(8, 2)), CAST(687.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (358, 247, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (359, 247, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (360, 247, 3, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (361, 247, 4, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (362, 247, 5, N'DATES     ', 15, CAST(29.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (363, 247, 10, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (364, 248, 1, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (365, 248, 4, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (366, 248, 5, N'VINO-LM   ', 11, CAST(5.00 AS Numeric(8, 2)), CAST(55.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (367, 249, 1, N'DT        ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (368, 249, 2, N'DT PK     ', 6, CAST(229.00 AS Numeric(8, 2)), CAST(1374.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (369, 250, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (370, 250, 2, N'DT        ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (371, 251, 1, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (372, 252, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (373, 252, 2, N'CUA       ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (374, 253, 1, N'BRIDGE    ', 7, CAST(195.00 AS Numeric(8, 2)), CAST(1365.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (375, 253, 2, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (376, 254, 1, N'ACE1      ', 2, CAST(25.00 AS Numeric(8, 2)), CAST(50.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (377, 254, 2, N'ACE-2     ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (378, 255, 1, N'BEARS     ', 3, CAST(32.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (379, 255, 2, N'GOLD      ', 3, CAST(779.00 AS Numeric(8, 2)), CAST(2337.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (380, 256, 1, N'JEWELRY-DL', 6, CAST(1749.00 AS Numeric(8, 2)), CAST(10494.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (381, 257, 1, N'FLEX-O-MAT', 5, CAST(295.00 AS Numeric(8, 2)), CAST(1475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (382, 258, 1, N'O''NEILLS  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (383, 258, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (384, 259, 1, N'MAPS      ', 5, CAST(145.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (385, 260, 1, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (386, 260, 2, N'CUA       ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (387, 260, 3, N'DT        ', 14, CAST(179.00 AS Numeric(8, 2)), CAST(2506.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (388, 261, 1, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (389, 261, 2, N'POPUP     ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (390, 262, 1, N'OFFICE-1  ', 16, CAST(45.00 AS Numeric(8, 2)), CAST(720.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (391, 262, 2, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (392, 262, 3, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (393, 263, 1, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (394, 263, 2, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (395, 263, 3, N'TEXT-2    ', 10, CAST(59.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (396, 263, 4, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (397, 263, 5, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (398, 264, 1, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (399, 265, 1, N'UN-CL-1   ', 5, CAST(399.00 AS Numeric(8, 2)), CAST(1995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (400, 265, 2, N'UN-CL-2   ', 5, CAST(659.00 AS Numeric(8, 2)), CAST(3295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (401, 266, 1, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (402, 267, 1, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (403, 268, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (404, 268, 2, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (405, 269, 1, N'TABLE-MAH ', 5, CAST(1250.00 AS Numeric(8, 2)), CAST(6250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (406, 269, 2, N'TABLE-MPL ', 10, CAST(319.00 AS Numeric(8, 2)), CAST(3190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (407, 270, 1, N'JEWELRY-DL', 3, CAST(1749.00 AS Numeric(8, 2)), CAST(5247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (408, 270, 2, N'JEWELRY-I ', 5, CAST(1299.00 AS Numeric(8, 2)), CAST(6495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (409, 271, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (410, 271, 2, N'DT PK     ', 7, CAST(229.00 AS Numeric(8, 2)), CAST(1603.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (411, 272, 1, N'MAPS      ', 5, CAST(145.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (412, 273, 1, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (413, 273, 2, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (414, 274, 1, N'RUNMTR    ', 10, CAST(79.00 AS Numeric(8, 2)), CAST(790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (415, 274, 2, N'RUNMTR2   ', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (416, 275, 1, N'OFFICE-S  ', 17, CAST(19.00 AS Numeric(8, 2)), CAST(323.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (417, 276, 1, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (418, 277, 1, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (419, 277, 2, N'REPORTS II', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (420, 278, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (421, 278, 2, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (422, 279, 1, N'BEARS     ', 4, CAST(32.00 AS Numeric(8, 2)), CAST(128.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (423, 279, 2, N'STARTREK  ', 14, CAST(1599.00 AS Numeric(8, 2)), CAST(22386.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (424, 280, 1, N'MAPS      ', 16, CAST(145.00 AS Numeric(8, 2)), CAST(2320.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (425, 281, 1, N'OFFICE-S  ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (426, 281, 2, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (427, 282, 1, N'MENU      ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (428, 283, 1, N'NITE-LITE ', 4, CAST(24.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (429, 283, 2, N'TABLE     ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (430, 283, 3, N'UPDATE    ', 13, CAST(19.00 AS Numeric(8, 2)), CAST(247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (431, 284, 1, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (432, 284, 2, N'OFFICE-1  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (433, 285, 1, N'BRIDGE    ', 7, CAST(195.00 AS Numeric(8, 2)), CAST(1365.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (434, 285, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (435, 285, 3, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (436, 286, 1, N'UPDATE    ', 10, CAST(19.00 AS Numeric(8, 2)), CAST(190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (437, 286, 2, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (438, 287, 1, N'TEXT-1    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (439, 287, 2, N'TEXT-2    ', 6, CAST(59.00 AS Numeric(8, 2)), CAST(354.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (440, 287, 3, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (441, 287, 4, N'TEXT-4    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (442, 287, 5, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (443, 288, 1, N'JOKES     ', 2, CAST(12.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (444, 289, 1, N'ACE-2     ', 3, CAST(15.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (445, 289, 2, N'ACE1      ', 3, CAST(25.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (446, 290, 1, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (447, 290, 2, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (448, 291, 1, N'OFFICE-1  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (449, 291, 2, N'OFFICE-2  ', 6, CAST(65.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (450, 291, 3, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (451, 292, 1, N'GOLD-DLX  ', 1, CAST(1079.00 AS Numeric(8, 2)), CAST(1079.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (452, 293, 1, N'FLEX-O-MAT', 5, CAST(295.00 AS Numeric(8, 2)), CAST(1475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (453, 294, 1, N'BRIDGE    ', 5, CAST(195.00 AS Numeric(8, 2)), CAST(975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (454, 294, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (455, 294, 3, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (456, 295, 1, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (457, 296, 1, N'TABLE     ', 10, CAST(179.00 AS Numeric(8, 2)), CAST(1790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (458, 296, 2, N'TABLE-MAH ', 8, CAST(1250.00 AS Numeric(8, 2)), CAST(10000.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (459, 296, 3, N'TABLE-MPL ', 8, CAST(319.00 AS Numeric(8, 2)), CAST(2552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (460, 296, 4, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (461, 296, 5, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (462, 296, 6, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (463, 297, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (464, 297, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (465, 298, 1, N'BRIDGE    ', 8, CAST(195.00 AS Numeric(8, 2)), CAST(1560.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (466, 299, 1, N'O''NEILLS  ', 8, CAST(45.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (467, 299, 2, N'POPUP     ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (468, 299, 3, N'PULLMAN   ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (469, 300, 1, N'TEXT-1    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (470, 300, 2, N'TEXT-2    ', 8, CAST(59.00 AS Numeric(8, 2)), CAST(472.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (471, 300, 3, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (472, 300, 4, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (473, 300, 5, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (474, 301, 1, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (475, 301, 2, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (476, 302, 1, N'JEWELRY-I ', 14, CAST(1299.00 AS Numeric(8, 2)), CAST(18186.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (477, 303, 1, N'STARTREK  ', 3, CAST(1599.00 AS Numeric(8, 2)), CAST(4797.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (478, 304, 1, N'REPORTS II', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (479, 305, 1, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (480, 305, 2, N'OFFICE-2  ', 4, CAST(65.00 AS Numeric(8, 2)), CAST(260.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (481, 305, 3, N'OFFICE-S  ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (482, 306, 1, N'UN-CL-1   ', 4, CAST(399.00 AS Numeric(8, 2)), CAST(1596.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (483, 306, 2, N'UN-CL-2   ', 3, CAST(659.00 AS Numeric(8, 2)), CAST(1977.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (484, 306, 3, N'UNIXGUIDE ', 3, CAST(499.00 AS Numeric(8, 2)), CAST(1497.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (485, 307, 1, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (486, 307, 2, N'RUNMTR2   ', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (487, 308, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (488, 309, 1, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (489, 310, 1, N'CITIES    ', 17, CAST(49.00 AS Numeric(8, 2)), CAST(833.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (490, 310, 2, N'MAPS      ', 4, CAST(145.00 AS Numeric(8, 2)), CAST(580.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (491, 311, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (492, 311, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (493, 311, 3, N'UPDATE    ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (494, 311, 4, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (495, 312, 1, N'POOL      ', 7, CAST(15.00 AS Numeric(8, 2)), CAST(105.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (496, 312, 2, N'POPUP     ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (497, 313, 1, N'FLEX-O-MAT', 8, CAST(295.00 AS Numeric(8, 2)), CAST(2360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (498, 314, 1, N'BRIDGE    ', 8, CAST(195.00 AS Numeric(8, 2)), CAST(1560.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (499, 314, 2, N'DATES     ', 14, CAST(29.00 AS Numeric(8, 2)), CAST(406.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (500, 315, 1, N'MENU      ', 14, CAST(129.00 AS Numeric(8, 2)), CAST(1806.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (501, 315, 2, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (502, 315, 3, N'REPORTS   ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (503, 315, 4, N'VINO-LM   ', 9, CAST(5.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (504, 316, 1, N'VINO-LM   ', 8, CAST(5.00 AS Numeric(8, 2)), CAST(40.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (505, 317, 1, N'NITE-LITE ', 3, CAST(24.00 AS Numeric(8, 2)), CAST(72.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (506, 317, 2, N'POPUP     ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (507, 317, 3, N'STARTREK  ', 3, CAST(1599.00 AS Numeric(8, 2)), CAST(4797.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (508, 318, 1, N'OFFICE-1  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (509, 318, 2, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (510, 318, 3, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (511, 319, 1, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (512, 320, 1, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (513, 320, 2, N'RUNMTR2   ', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (514, 321, 1, N'MAPS      ', 6, CAST(145.00 AS Numeric(8, 2)), CAST(870.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (515, 322, 1, N'JOKES     ', 6, CAST(12.00 AS Numeric(8, 2)), CAST(72.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (516, 322, 2, N'POOL      ', 6, CAST(15.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (517, 323, 1, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (518, 324, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (519, 325, 1, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (520, 326, 1, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (521, 327, 1, N'TEXT-1    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (522, 327, 2, N'TEXT-2    ', 5, CAST(59.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (523, 327, 3, N'TEXT-3    ', 5, CAST(69.00 AS Numeric(8, 2)), CAST(345.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (524, 327, 4, N'TEXT-4    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (525, 328, 1, N'UN-CL-1   ', 5, CAST(399.00 AS Numeric(8, 2)), CAST(1995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (526, 328, 2, N'UN-CL-2   ', 5, CAST(659.00 AS Numeric(8, 2)), CAST(3295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (527, 328, 3, N'UNIXGUIDE ', 9, CAST(499.00 AS Numeric(8, 2)), CAST(4491.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (528, 329, 1, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (529, 330, 1, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (530, 331, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (531, 332, 1, N'POOL      ', 8, CAST(15.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (532, 333, 1, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (533, 333, 2, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (534, 333, 3, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (535, 334, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (536, 334, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (537, 334, 3, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (538, 334, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (539, 335, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (540, 335, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (541, 335, 3, N'DT        ', 17, CAST(179.00 AS Numeric(8, 2)), CAST(3043.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (542, 335, 5, N'MENU      ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (543, 336, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (544, 336, 2, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (545, 336, 3, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (546, 336, 4, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (547, 337, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (548, 337, 2, N'RUNMTR    ', 13, CAST(79.00 AS Numeric(8, 2)), CAST(1027.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (549, 337, 3, N'TEXT-4    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (550, 337, 4, N'REPORTS   ', 17, CAST(179.00 AS Numeric(8, 2)), CAST(3043.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (551, 338, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (552, 338, 2, N'GOLD      ', 5, CAST(779.00 AS Numeric(8, 2)), CAST(3895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (553, 339, 1, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (554, 339, 2, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (555, 339, 3, N'TABLE-MAH ', 5, CAST(1250.00 AS Numeric(8, 2)), CAST(6250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (556, 339, 4, N'REPORTS   ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (557, 340, 1, N'PULLMAN   ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (558, 340, 2, N'TABLE     ', 14, CAST(179.00 AS Numeric(8, 2)), CAST(2506.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (559, 341, 1, N'REPORTS   ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (560, 341, 2, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (561, 342, 1, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (562, 342, 2, N'GOLD-DLX  ', 3, CAST(1079.00 AS Numeric(8, 2)), CAST(3237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (563, 343, 1, N'MODEMS    ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (564, 343, 2, N'REPORTS   ', 10, CAST(179.00 AS Numeric(8, 2)), CAST(1790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (565, 343, 3, N'TEXT-2    ', 13, CAST(59.00 AS Numeric(8, 2)), CAST(767.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (566, 344, 1, N'TABLE-MPL ', 12, CAST(319.00 AS Numeric(8, 2)), CAST(3828.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (567, 344, 2, N'JEWELRY-I ', 11, CAST(1299.00 AS Numeric(8, 2)), CAST(14289.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (568, 344, 3, N'UN-CL-1   ', 10, CAST(399.00 AS Numeric(8, 2)), CAST(3990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (569, 345, 1, N'RUNMTR    ', 2, CAST(79.00 AS Numeric(8, 2)), CAST(158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (570, 345, 2, N'RUNMTR2   ', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (571, 345, 3, N'POPUP     ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (572, 346, 1, N'JEWELRY-DL', 3, CAST(1749.00 AS Numeric(8, 2)), CAST(5247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (573, 346, 2, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (574, 346, 3, N'UN-CL-2   ', 4, CAST(659.00 AS Numeric(8, 2)), CAST(2636.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (575, 347, 2, N'UPDATE    ', 14, CAST(19.00 AS Numeric(8, 2)), CAST(266.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (576, 347, 3, N'JOKES     ', 14, CAST(12.00 AS Numeric(8, 2)), CAST(168.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (577, 347, 4, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (578, 347, 5, N'UNIXGUIDE ', 8, CAST(499.00 AS Numeric(8, 2)), CAST(3992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (579, 348, 2, N'MODEMS    ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (580, 348, 3, N'REPORTS II', 6, CAST(199.00 AS Numeric(8, 2)), CAST(1194.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (581, 349, 1, N'JEWELRY-DL', 6, CAST(1749.00 AS Numeric(8, 2)), CAST(10494.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (582, 349, 2, N'FLEX-O-MAT', 11, CAST(295.00 AS Numeric(8, 2)), CAST(3245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (583, 350, 1, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (584, 350, 3, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (585, 351, 1, N'JEWELRY-I ', 11, CAST(1299.00 AS Numeric(8, 2)), CAST(14289.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (586, 352, 1, N'UN-CL-2   ', 11, CAST(659.00 AS Numeric(8, 2)), CAST(7249.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (587, 352, 3, N'FLEX-O-MAT', 7, CAST(295.00 AS Numeric(8, 2)), CAST(2065.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (588, 353, 1, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (589, 353, 2, N'PULLMAN   ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (590, 353, 3, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (591, 354, 2, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (592, 354, 3, N'DATES     ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (593, 354, 4, N'PICTURE   ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (594, 354, 5, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (595, 355, 1, N'TEXT-ALL  ', 6, CAST(595.00 AS Numeric(8, 2)), CAST(3570.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (596, 355, 2, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (597, 355, 3, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (598, 356, 1, N'GOLD      ', 3, CAST(779.00 AS Numeric(8, 2)), CAST(2337.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (599, 356, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (600, 356, 3, N'CITIES    ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (601, 356, 4, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (602, 357, 1, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (603, 357, 2, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (604, 357, 3, N'PICTURE   ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (605, 357, 4, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (606, 358, 2, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (607, 358, 4, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (608, 359, 16, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (609, 359, 17, N'DATES     ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (610, 360, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (611, 360, 2, N'DATES     ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (612, 360, 3, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (613, 360, 4, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (614, 361, 1, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (615, 361, 2, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (616, 361, 3, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (617, 361, 4, N'GOLD-DLX  ', 7, CAST(1079.00 AS Numeric(8, 2)), CAST(7553.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (618, 361, 5, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (619, 361, 6, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (620, 362, 1, N'TEXT-3    ', 9, CAST(69.00 AS Numeric(8, 2)), CAST(621.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (621, 362, 2, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (622, 362, 3, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (623, 362, 4, N'CUA       ', 17, CAST(49.00 AS Numeric(8, 2)), CAST(833.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (624, 362, 5, N'TEXT-3    ', 9, CAST(69.00 AS Numeric(8, 2)), CAST(621.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (625, 363, 1, N'DATES     ', 15, CAST(29.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (626, 363, 2, N'DT PK     ', 7, CAST(229.00 AS Numeric(8, 2)), CAST(1603.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (627, 364, 1, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (628, 364, 2, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (629, 364, 3, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (630, 364, 4, N'MENU      ', 10, CAST(129.00 AS Numeric(8, 2)), CAST(1290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (631, 364, 5, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (632, 364, 10, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (633, 365, 1, N'BEARS     ', 5, CAST(30.00 AS Numeric(8, 2)), CAST(150.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (634, 365, 4, N'BEARS     ', 10, CAST(30.00 AS Numeric(8, 2)), CAST(300.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (635, 365, 5, N'VINO-LM   ', 10, CAST(5.00 AS Numeric(8, 2)), CAST(50.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (636, 366, 1, N'DT        ', 10, CAST(179.00 AS Numeric(8, 2)), CAST(1790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (637, 366, 2, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (638, 367, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (639, 367, 2, N'DT        ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (640, 368, 1, N'DT        ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (641, 369, 1, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (642, 369, 2, N'CUA       ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (643, 370, 1, N'BRIDGE    ', 10, CAST(195.00 AS Numeric(8, 2)), CAST(1950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (644, 370, 2, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (645, 371, 1, N'ACE1      ', 5, CAST(25.00 AS Numeric(8, 2)), CAST(125.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (646, 371, 2, N'ACE-2     ', 5, CAST(15.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (647, 372, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (648, 372, 2, N'GOLD      ', 16, CAST(779.00 AS Numeric(8, 2)), CAST(12464.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (649, 373, 1, N'JEWELRY-DL', 16, CAST(1749.00 AS Numeric(8, 2)), CAST(27984.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (650, 374, 1, N'FLEX-O-MAT', 16, CAST(295.00 AS Numeric(8, 2)), CAST(4720.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (651, 375, 1, N'O''NEILLS  ', 16, CAST(45.00 AS Numeric(8, 2)), CAST(720.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (652, 375, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (653, 376, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (654, 377, 1, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (655, 377, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (656, 377, 3, N'DT        ', 15, CAST(179.00 AS Numeric(8, 2)), CAST(2685.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (657, 378, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (658, 378, 2, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (659, 379, 1, N'OFFICE-1  ', 10, CAST(45.00 AS Numeric(8, 2)), CAST(450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (660, 379, 2, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (661, 379, 3, N'OFFICE-S  ', 13, CAST(19.00 AS Numeric(8, 2)), CAST(247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (662, 380, 1, N'UPDATE    ', 13, CAST(19.00 AS Numeric(8, 2)), CAST(247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (663, 380, 2, N'TEXT-1    ', 9, CAST(99.00 AS Numeric(8, 2)), CAST(891.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (664, 380, 3, N'TEXT-2    ', 4, CAST(59.00 AS Numeric(8, 2)), CAST(236.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (665, 380, 4, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (666, 380, 5, N'TEXT-4    ', 17, CAST(99.00 AS Numeric(8, 2)), CAST(1683.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (667, 381, 1, N'VINO-LM   ', 17, CAST(5.00 AS Numeric(8, 2)), CAST(85.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (668, 382, 1, N'UN-CL-1   ', 8, CAST(399.00 AS Numeric(8, 2)), CAST(3192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (669, 382, 2, N'UN-CL-2   ', 8, CAST(659.00 AS Numeric(8, 2)), CAST(5272.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (670, 383, 1, N'UNIXGUIDE ', 8, CAST(499.00 AS Numeric(8, 2)), CAST(3992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (671, 384, 1, N'FLEX-O-MAT', 8, CAST(295.00 AS Numeric(8, 2)), CAST(2360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (672, 385, 1, N'O''NEILLS  ', 9, CAST(45.00 AS Numeric(8, 2)), CAST(405.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (673, 385, 2, N'TABLE     ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (674, 386, 1, N'TABLE-MAH ', 2, CAST(1250.00 AS Numeric(8, 2)), CAST(2500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (675, 386, 2, N'TABLE-MPL ', 9, CAST(319.00 AS Numeric(8, 2)), CAST(2871.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (676, 387, 1, N'JEWELRY-DL', 3, CAST(1749.00 AS Numeric(8, 2)), CAST(5247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (677, 387, 2, N'JEWELRY-I ', 3, CAST(1299.00 AS Numeric(8, 2)), CAST(3897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (678, 388, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (679, 388, 2, N'DT PK     ', 6, CAST(229.00 AS Numeric(8, 2)), CAST(1374.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (680, 389, 1, N'MAPS      ', 10, CAST(145.00 AS Numeric(8, 2)), CAST(1450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (681, 390, 1, N'PICTURE   ', 16, CAST(29.00 AS Numeric(8, 2)), CAST(464.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (682, 390, 2, N'PULLMAN   ', 16, CAST(49.00 AS Numeric(8, 2)), CAST(784.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (683, 391, 1, N'RUNMTR    ', 16, CAST(79.00 AS Numeric(8, 2)), CAST(1264.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (684, 391, 2, N'RUNMTR2   ', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (685, 392, 1, N'OFFICE-S  ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (686, 393, 1, N'JOKES     ', 12, CAST(12.00 AS Numeric(8, 2)), CAST(144.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (687, 394, 1, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (688, 394, 2, N'REPORTS II', 6, CAST(199.00 AS Numeric(8, 2)), CAST(1194.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (689, 395, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (690, 395, 2, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (691, 396, 1, N'BEARS     ', 9, CAST(32.00 AS Numeric(8, 2)), CAST(288.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (692, 396, 2, N'STARTREK  ', 6, CAST(1599.00 AS Numeric(8, 2)), CAST(9594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (693, 397, 1, N'MAPS      ', 16, CAST(145.00 AS Numeric(8, 2)), CAST(2320.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (694, 398, 1, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (695, 398, 2, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (696, 399, 1, N'MENU      ', 11, CAST(129.00 AS Numeric(8, 2)), CAST(1419.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (697, 400, 1, N'NITE-LITE ', 4, CAST(24.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (698, 400, 2, N'TABLE     ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (699, 400, 3, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (700, 401, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (701, 401, 2, N'OFFICE-1  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (702, 402, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (703, 402, 2, N'CITIES    ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (704, 402, 3, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (705, 403, 1, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (706, 403, 2, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (707, 404, 1, N'TEXT-1    ', 12, CAST(99.00 AS Numeric(8, 2)), CAST(1188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (708, 404, 2, N'TEXT-2    ', 12, CAST(59.00 AS Numeric(8, 2)), CAST(708.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (709, 404, 3, N'TEXT-3    ', 14, CAST(69.00 AS Numeric(8, 2)), CAST(966.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (710, 404, 4, N'TEXT-4    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (711, 404, 5, N'TEXT-ALL  ', 5, CAST(595.00 AS Numeric(8, 2)), CAST(2975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (712, 405, 1, N'JOKES     ', 2, CAST(12.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (713, 406, 1, N'ACE-2     ', 7, CAST(15.00 AS Numeric(8, 2)), CAST(105.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (714, 406, 2, N'ACE1      ', 1, CAST(25.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (715, 407, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (716, 407, 2, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (717, 408, 1, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (718, 408, 2, N'OFFICE-2  ', 4, CAST(65.00 AS Numeric(8, 2)), CAST(260.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (719, 408, 3, N'OFFICE-S  ', 15, CAST(19.00 AS Numeric(8, 2)), CAST(285.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (720, 409, 1, N'GOLD-DLX  ', 9, CAST(1079.00 AS Numeric(8, 2)), CAST(9711.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (721, 410, 1, N'FLEX-O-MAT', 7, CAST(295.00 AS Numeric(8, 2)), CAST(2065.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (722, 411, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (723, 411, 2, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (724, 411, 3, N'VINO-LM   ', 3, CAST(5.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (725, 412, 1, N'DT PK     ', 8, CAST(229.00 AS Numeric(8, 2)), CAST(1832.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (726, 413, 1, N'TABLE     ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (727, 413, 2, N'TABLE-MAH ', 7, CAST(1250.00 AS Numeric(8, 2)), CAST(8750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (728, 413, 3, N'TABLE-MPL ', 7, CAST(319.00 AS Numeric(8, 2)), CAST(2233.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (729, 413, 4, N'OFFICE-1  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (730, 413, 5, N'OFFICE-2  ', 7, CAST(65.00 AS Numeric(8, 2)), CAST(455.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (731, 413, 6, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (732, 414, 1, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (733, 414, 2, N'CUA       ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (734, 415, 1, N'BRIDGE    ', 12, CAST(195.00 AS Numeric(8, 2)), CAST(2340.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (735, 416, 1, N'O''NEILLS  ', 12, CAST(45.00 AS Numeric(8, 2)), CAST(540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (736, 416, 2, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (737, 416, 3, N'PULLMAN   ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (738, 417, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (739, 417, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (740, 417, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (741, 417, 4, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (742, 417, 5, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (743, 418, 1, N'MODEMS    ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (744, 418, 2, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (745, 419, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (746, 420, 1, N'STARTREK  ', 16, CAST(1599.00 AS Numeric(8, 2)), CAST(25584.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (747, 421, 1, N'REPORTS II', 7, CAST(199.00 AS Numeric(8, 2)), CAST(1393.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (748, 422, 1, N'OFFICE-1  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (749, 422, 2, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (750, 422, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (751, 423, 1, N'UN-CL-1   ', 12, CAST(399.00 AS Numeric(8, 2)), CAST(4788.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (752, 423, 2, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (753, 423, 3, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (754, 424, 1, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (755, 424, 2, N'RUNMTR2   ', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (756, 425, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (757, 426, 1, N'GOLD      ', 2, CAST(779.00 AS Numeric(8, 2)), CAST(1558.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (758, 427, 1, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (759, 427, 2, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (760, 428, 1, N'O''NEILLS  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (761, 428, 2, N'PICTURE   ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (762, 428, 3, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (763, 428, 4, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (764, 429, 1, N'POOL      ', 6, CAST(15.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (765, 429, 2, N'POPUP     ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (766, 430, 1, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (767, 431, 1, N'BRIDGE    ', 8, CAST(195.00 AS Numeric(8, 2)), CAST(1560.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (768, 431, 2, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (769, 432, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (770, 432, 2, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (771, 432, 3, N'REPORTS   ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (772, 432, 4, N'VINO-LM   ', 9, CAST(5.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (773, 433, 1, N'VINO-LM   ', 5, CAST(5.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (774, 434, 1, N'NITE-LITE ', 1, CAST(24.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (775, 434, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (776, 434, 3, N'STARTREK  ', 1, CAST(1599.00 AS Numeric(8, 2)), CAST(1599.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (777, 435, 1, N'OFFICE-1  ', 9, CAST(45.00 AS Numeric(8, 2)), CAST(405.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (778, 435, 2, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (779, 435, 3, N'OFFICE-S  ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (780, 436, 1, N'PICTURE   ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (781, 437, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (782, 437, 2, N'RUNMTR2   ', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (783, 438, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (784, 439, 1, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (785, 439, 2, N'POOL      ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (786, 440, 1, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (787, 441, 1, N'BEARS     ', 2, CAST(32.00 AS Numeric(8, 2)), CAST(64.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (788, 442, 1, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (789, 443, 1, N'TEXT-ALL  ', 16, CAST(595.00 AS Numeric(8, 2)), CAST(9520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (790, 444, 1, N'TEXT-1    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (791, 444, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (792, 444, 3, N'TEXT-3    ', 11, CAST(69.00 AS Numeric(8, 2)), CAST(759.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (793, 444, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (794, 445, 1, N'UN-CL-1   ', 13, CAST(399.00 AS Numeric(8, 2)), CAST(5187.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (795, 445, 2, N'UN-CL-2   ', 6, CAST(659.00 AS Numeric(8, 2)), CAST(3954.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (796, 445, 3, N'UNIXGUIDE ', 7, CAST(499.00 AS Numeric(8, 2)), CAST(3493.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (797, 446, 1, N'CUA       ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (798, 447, 1, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (799, 448, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (800, 449, 1, N'POOL      ', 3, CAST(15.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (801, 450, 1, N'DATES     ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (802, 450, 2, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (803, 450, 3, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (804, 451, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (805, 451, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (806, 451, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (807, 451, 4, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (808, 452, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (809, 452, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (810, 452, 3, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (811, 452, 5, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (812, 453, 1, N'CASE      ', 12, CAST(39.00 AS Numeric(8, 2)), CAST(468.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (813, 453, 2, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (814, 453, 3, N'MENU      ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (815, 453, 4, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (816, 454, 1, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (817, 454, 2, N'RUNMTR    ', 8, CAST(79.00 AS Numeric(8, 2)), CAST(632.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (818, 454, 3, N'TEXT-4    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (819, 454, 4, N'REPORTS   ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (820, 455, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (821, 455, 2, N'GOLD      ', 4, CAST(779.00 AS Numeric(8, 2)), CAST(3116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (822, 456, 1, N'MENU      ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (823, 456, 2, N'MODEMS    ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (824, 456, 3, N'TABLE-MAH ', 12, CAST(1250.00 AS Numeric(8, 2)), CAST(15000.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (825, 456, 4, N'REPORTS   ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (826, 457, 1, N'PULLMAN   ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (827, 457, 2, N'TABLE     ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (828, 458, 1, N'REPORTS   ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (829, 458, 2, N'CUA       ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (830, 459, 1, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (831, 459, 2, N'GOLD-DLX  ', 4, CAST(1079.00 AS Numeric(8, 2)), CAST(4316.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (832, 460, 1, N'MODEMS    ', 13, CAST(129.00 AS Numeric(8, 2)), CAST(1677.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (833, 460, 2, N'REPORTS   ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (834, 460, 3, N'TEXT-2    ', 3, CAST(59.00 AS Numeric(8, 2)), CAST(177.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (835, 461, 1, N'TABLE-MPL ', 3, CAST(319.00 AS Numeric(8, 2)), CAST(957.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (836, 461, 2, N'JEWELRY-I ', 11, CAST(1299.00 AS Numeric(8, 2)), CAST(14289.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (837, 461, 3, N'UN-CL-1   ', 4, CAST(399.00 AS Numeric(8, 2)), CAST(1596.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (838, 462, 1, N'RUNMTR    ', 16, CAST(79.00 AS Numeric(8, 2)), CAST(1264.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (839, 462, 2, N'RUNMTR2   ', 16, CAST(199.00 AS Numeric(8, 2)), CAST(3184.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (840, 462, 3, N'POPUP     ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (841, 463, 1, N'JEWELRY-DL', 13, CAST(1749.00 AS Numeric(8, 2)), CAST(22737.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (842, 463, 2, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (843, 463, 3, N'UN-CL-2   ', 8, CAST(659.00 AS Numeric(8, 2)), CAST(5272.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (844, 464, 2, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (845, 464, 3, N'JOKES     ', 7, CAST(12.00 AS Numeric(8, 2)), CAST(84.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (846, 464, 4, N'TEXT-ALL  ', 7, CAST(595.00 AS Numeric(8, 2)), CAST(4165.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (847, 464, 5, N'UNIXGUIDE ', 7, CAST(499.00 AS Numeric(8, 2)), CAST(3493.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (848, 465, 2, N'MODEMS    ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (849, 465, 3, N'REPORTS II', 7, CAST(199.00 AS Numeric(8, 2)), CAST(1393.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (850, 466, 1, N'JEWELRY-DL', 1, CAST(1749.00 AS Numeric(8, 2)), CAST(1749.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (851, 466, 2, N'FLEX-O-MAT', 7, CAST(295.00 AS Numeric(8, 2)), CAST(2065.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (852, 467, 1, N'MENU      ', 7, CAST(129.00 AS Numeric(8, 2)), CAST(903.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (853, 467, 3, N'MAPS      ', 7, CAST(145.00 AS Numeric(8, 2)), CAST(1015.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (854, 468, 1, N'JEWELRY-I ', 4, CAST(1299.00 AS Numeric(8, 2)), CAST(5196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (855, 469, 1, N'UN-CL-2   ', 14, CAST(659.00 AS Numeric(8, 2)), CAST(9226.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (856, 469, 3, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (857, 470, 1, N'OFFICE-2  ', 6, CAST(65.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (858, 470, 2, N'PULLMAN   ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (859, 470, 3, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (860, 471, 2, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (861, 471, 3, N'DATES     ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (862, 471, 4, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (863, 471, 5, N'TEXT-3    ', 10, CAST(69.00 AS Numeric(8, 2)), CAST(690.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (864, 472, 1, N'TEXT-ALL  ', 10, CAST(595.00 AS Numeric(8, 2)), CAST(5950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (865, 472, 2, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (866, 472, 3, N'CUA       ', 15, CAST(49.00 AS Numeric(8, 2)), CAST(735.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (867, 473, 1, N'GOLD      ', 14, CAST(779.00 AS Numeric(8, 2)), CAST(10906.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (868, 473, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (869, 473, 3, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (870, 473, 4, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (871, 474, 1, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (872, 474, 2, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (873, 474, 3, N'PICTURE   ', 17, CAST(29.00 AS Numeric(8, 2)), CAST(493.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (874, 474, 4, N'DT PK     ', 11, CAST(229.00 AS Numeric(8, 2)), CAST(2519.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (875, 475, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (876, 475, 4, N'DT        ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (877, 476, 16, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (878, 476, 17, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (879, 477, 1, N'CASE      ', 17, CAST(39.00 AS Numeric(8, 2)), CAST(663.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (880, 477, 2, N'DATES     ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (881, 477, 3, N'DT PK     ', 12, CAST(229.00 AS Numeric(8, 2)), CAST(2748.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (882, 477, 4, N'MENU      ', 12, CAST(129.00 AS Numeric(8, 2)), CAST(1548.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (883, 478, 1, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (884, 478, 2, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (885, 478, 3, N'TEXT-3    ', 14, CAST(69.00 AS Numeric(8, 2)), CAST(966.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (886, 478, 4, N'GOLD-DLX  ', 14, CAST(1079.00 AS Numeric(8, 2)), CAST(15106.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (887, 478, 5, N'TEXT-3    ', 14, CAST(69.00 AS Numeric(8, 2)), CAST(966.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (888, 478, 6, N'CASE      ', 14, CAST(39.00 AS Numeric(8, 2)), CAST(546.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (889, 479, 1, N'TEXT-3    ', 14, CAST(69.00 AS Numeric(8, 2)), CAST(966.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (890, 479, 2, N'CASE      ', 14, CAST(39.00 AS Numeric(8, 2)), CAST(546.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (891, 479, 3, N'DATES     ', 14, CAST(29.00 AS Numeric(8, 2)), CAST(406.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (892, 479, 4, N'CUA       ', 16, CAST(49.00 AS Numeric(8, 2)), CAST(784.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (893, 479, 5, N'TEXT-3    ', 14, CAST(69.00 AS Numeric(8, 2)), CAST(966.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (894, 480, 1, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (895, 480, 2, N'DT PK     ', 2, CAST(229.00 AS Numeric(8, 2)), CAST(458.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (896, 481, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (897, 481, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (898, 481, 3, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (899, 481, 4, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (900, 481, 5, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (901, 481, 10, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (902, 482, 1, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (903, 482, 4, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (904, 482, 5, N'VINO-LM   ', 7, CAST(5.00 AS Numeric(8, 2)), CAST(35.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (905, 483, 1, N'DT        ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (906, 483, 2, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (907, 484, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (908, 484, 2, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (909, 485, 1, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (910, 486, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (911, 486, 2, N'CUA       ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (912, 487, 1, N'BRIDGE    ', 8, CAST(195.00 AS Numeric(8, 2)), CAST(1560.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (913, 487, 2, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (914, 488, 1, N'ACE1      ', 8, CAST(25.00 AS Numeric(8, 2)), CAST(200.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (915, 488, 2, N'ACE-2     ', 8, CAST(15.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (916, 489, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (917, 489, 2, N'GOLD      ', 7, CAST(779.00 AS Numeric(8, 2)), CAST(5453.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (918, 490, 1, N'JEWELRY-DL', 2, CAST(1749.00 AS Numeric(8, 2)), CAST(3498.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (919, 491, 1, N'FLEX-O-MAT', 2, CAST(295.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (920, 492, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (921, 492, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (922, 493, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (923, 494, 1, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (924, 494, 2, N'CUA       ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (925, 494, 3, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (926, 495, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (927, 495, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (928, 496, 1, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (929, 496, 2, N'OFFICE-2  ', 7, CAST(65.00 AS Numeric(8, 2)), CAST(455.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (930, 496, 3, N'OFFICE-S  ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (931, 497, 1, N'UPDATE    ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (932, 497, 2, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (933, 497, 3, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (934, 497, 4, N'TEXT-3    ', 10, CAST(69.00 AS Numeric(8, 2)), CAST(690.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (935, 497, 5, N'TEXT-4    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (936, 498, 1, N'VINO-LM   ', 5, CAST(5.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (937, 499, 1, N'UN-CL-1   ', 1, CAST(399.00 AS Numeric(8, 2)), CAST(399.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (938, 499, 2, N'UN-CL-2   ', 5, CAST(659.00 AS Numeric(8, 2)), CAST(3295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (939, 500, 1, N'UNIXGUIDE ', 5, CAST(499.00 AS Numeric(8, 2)), CAST(2495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (940, 501, 1, N'FLEX-O-MAT', 2, CAST(295.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (941, 502, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (942, 502, 2, N'TABLE     ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (943, 503, 1, N'TABLE-MAH ', 10, CAST(1250.00 AS Numeric(8, 2)), CAST(12500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (944, 503, 2, N'TABLE-MPL ', 1, CAST(319.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (945, 504, 1, N'JEWELRY-DL', 1, CAST(1749.00 AS Numeric(8, 2)), CAST(1749.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (946, 504, 2, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (947, 505, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (948, 505, 2, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (949, 506, 1, N'MAPS      ', 7, CAST(145.00 AS Numeric(8, 2)), CAST(1015.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (950, 507, 1, N'PICTURE   ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (951, 507, 2, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (952, 508, 1, N'RUNMTR    ', 10, CAST(79.00 AS Numeric(8, 2)), CAST(790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (953, 508, 2, N'RUNMTR2   ', 10, CAST(199.00 AS Numeric(8, 2)), CAST(1990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (954, 509, 1, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (955, 510, 1, N'JOKES     ', 3, CAST(12.00 AS Numeric(8, 2)), CAST(36.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (956, 511, 1, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (957, 511, 2, N'REPORTS II', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (958, 512, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (959, 512, 2, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (960, 513, 1, N'BEARS     ', 12, CAST(32.00 AS Numeric(8, 2)), CAST(384.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (961, 513, 2, N'STARTREK  ', 12, CAST(1599.00 AS Numeric(8, 2)), CAST(19188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (962, 514, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (963, 515, 1, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (964, 515, 2, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (965, 516, 1, N'MENU      ', 7, CAST(129.00 AS Numeric(8, 2)), CAST(903.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (966, 517, 1, N'NITE-LITE ', 7, CAST(24.00 AS Numeric(8, 2)), CAST(168.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (967, 517, 2, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (968, 517, 3, N'UPDATE    ', 12, CAST(19.00 AS Numeric(8, 2)), CAST(228.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (969, 518, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (970, 518, 2, N'OFFICE-1  ', 10, CAST(45.00 AS Numeric(8, 2)), CAST(450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (971, 519, 1, N'BRIDGE    ', 10, CAST(195.00 AS Numeric(8, 2)), CAST(1950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (972, 519, 2, N'CITIES    ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (973, 519, 3, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (974, 520, 1, N'UPDATE    ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (975, 520, 2, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (976, 521, 1, N'TEXT-1    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (977, 521, 2, N'TEXT-2    ', 13, CAST(59.00 AS Numeric(8, 2)), CAST(767.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (978, 521, 3, N'TEXT-3    ', 11, CAST(69.00 AS Numeric(8, 2)), CAST(759.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (979, 521, 4, N'TEXT-4    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (980, 521, 5, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (981, 522, 1, N'JOKES     ', 8, CAST(12.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (982, 523, 1, N'ACE-2     ', 8, CAST(15.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (983, 523, 2, N'ACE1      ', 1, CAST(25.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (984, 524, 1, N'DATES     ', 13, CAST(29.00 AS Numeric(8, 2)), CAST(377.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (985, 524, 2, N'DT        ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (986, 525, 1, N'OFFICE-1  ', 13, CAST(45.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (987, 525, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (988, 525, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (989, 526, 1, N'GOLD-DLX  ', 1, CAST(1079.00 AS Numeric(8, 2)), CAST(1079.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (990, 527, 1, N'FLEX-O-MAT', 9, CAST(295.00 AS Numeric(8, 2)), CAST(2655.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (991, 528, 1, N'BRIDGE    ', 5, CAST(195.00 AS Numeric(8, 2)), CAST(975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (992, 528, 2, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (993, 528, 3, N'VINO-LM   ', 4, CAST(5.00 AS Numeric(8, 2)), CAST(20.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (994, 529, 1, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (995, 530, 1, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (996, 530, 2, N'TABLE-MAH ', 1, CAST(1250.00 AS Numeric(8, 2)), CAST(1250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (997, 530, 3, N'TABLE-MPL ', 1, CAST(319.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (998, 530, 4, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (999, 530, 5, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1000, 530, 6, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1001, 531, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1002, 531, 2, N'CUA       ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1003, 532, 1, N'BRIDGE    ', 2, CAST(195.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1004, 533, 1, N'O''NEILLS  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1005, 533, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1006, 533, 3, N'PULLMAN   ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1007, 534, 1, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1008, 534, 2, N'TEXT-2    ', 15, CAST(59.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1009, 534, 3, N'TEXT-3    ', 8, CAST(69.00 AS Numeric(8, 2)), CAST(552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1010, 534, 4, N'TEXT-4    ', 12, CAST(99.00 AS Numeric(8, 2)), CAST(1188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1011, 534, 5, N'TEXT-ALL  ', 4, CAST(595.00 AS Numeric(8, 2)), CAST(2380.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1012, 535, 1, N'MODEMS    ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1013, 535, 2, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1014, 536, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1015, 537, 1, N'STARTREK  ', 3, CAST(1599.00 AS Numeric(8, 2)), CAST(4797.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1016, 538, 1, N'REPORTS II', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1017, 539, 1, N'OFFICE-1  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1018, 539, 2, N'OFFICE-2  ', 12, CAST(65.00 AS Numeric(8, 2)), CAST(780.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1019, 539, 3, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1020, 540, 1, N'UN-CL-1   ', 8, CAST(399.00 AS Numeric(8, 2)), CAST(3192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1021, 540, 2, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1022, 540, 3, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1023, 541, 1, N'RUNMTR    ', 11, CAST(79.00 AS Numeric(8, 2)), CAST(869.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1024, 541, 2, N'RUNMTR2   ', 11, CAST(199.00 AS Numeric(8, 2)), CAST(2189.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1025, 542, 1, N'O''NEILLS  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1026, 543, 1, N'GOLD      ', 4, CAST(779.00 AS Numeric(8, 2)), CAST(3116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1027, 544, 1, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1028, 544, 2, N'MAPS      ', 13, CAST(145.00 AS Numeric(8, 2)), CAST(1885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1029, 545, 1, N'O''NEILLS  ', 6, CAST(45.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1030, 545, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1031, 545, 3, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1032, 545, 4, N'VINO-LM   ', 3, CAST(5.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1033, 546, 1, N'POOL      ', 2, CAST(15.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1034, 546, 2, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1035, 547, 1, N'FLEX-O-MAT', 2, CAST(295.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1036, 548, 1, N'BRIDGE    ', 2, CAST(195.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1037, 548, 2, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1038, 549, 1, N'MENU      ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1039, 549, 2, N'OFFICE-2  ', 4, CAST(65.00 AS Numeric(8, 2)), CAST(260.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1040, 549, 3, N'REPORTS   ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1041, 549, 4, N'VINO-LM   ', 3, CAST(5.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1042, 550, 1, N'VINO-LM   ', 13, CAST(5.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1043, 551, 1, N'NITE-LITE ', 1, CAST(24.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1044, 551, 2, N'POPUP     ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1045, 551, 3, N'STARTREK  ', 9, CAST(1599.00 AS Numeric(8, 2)), CAST(14391.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1046, 552, 1, N'OFFICE-1  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1047, 552, 2, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1048, 552, 3, N'OFFICE-S  ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1049, 553, 1, N'PICTURE   ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1050, 554, 1, N'RUNMTR    ', 16, CAST(79.00 AS Numeric(8, 2)), CAST(1264.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1051, 554, 2, N'RUNMTR2   ', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1052, 555, 1, N'MAPS      ', 9, CAST(145.00 AS Numeric(8, 2)), CAST(1305.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1053, 556, 1, N'JOKES     ', 5, CAST(12.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1054, 556, 2, N'POOL      ', 16, CAST(15.00 AS Numeric(8, 2)), CAST(240.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1055, 557, 1, N'VINO-LM   ', 3, CAST(5.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1056, 558, 1, N'BEARS     ', 12, CAST(32.00 AS Numeric(8, 2)), CAST(384.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1057, 559, 1, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1058, 560, 1, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1059, 561, 1, N'TEXT-1    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1060, 561, 2, N'TEXT-2    ', 6, CAST(59.00 AS Numeric(8, 2)), CAST(354.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1061, 561, 3, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1062, 561, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1063, 562, 1, N'UN-CL-1   ', 2, CAST(399.00 AS Numeric(8, 2)), CAST(798.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1064, 562, 2, N'UN-CL-2   ', 2, CAST(659.00 AS Numeric(8, 2)), CAST(1318.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1065, 562, 3, N'UNIXGUIDE ', 3, CAST(499.00 AS Numeric(8, 2)), CAST(1497.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1066, 563, 1, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1067, 564, 1, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1068, 565, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1069, 566, 1, N'POOL      ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1070, 567, 1, N'DATES     ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1071, 567, 2, N'DT        ', 10, CAST(179.00 AS Numeric(8, 2)), CAST(1790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1072, 567, 3, N'DT PK     ', 11, CAST(229.00 AS Numeric(8, 2)), CAST(2519.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1073, 568, 1, N'TEXT-1    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1074, 568, 2, N'TEXT-2    ', 4, CAST(59.00 AS Numeric(8, 2)), CAST(236.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1075, 568, 3, N'TEXT-3    ', 11, CAST(69.00 AS Numeric(8, 2)), CAST(759.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1076, 568, 4, N'TEXT-4    ', 11, CAST(99.00 AS Numeric(8, 2)), CAST(1089.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1077, 569, 1, N'RUNMTR    ', 10, CAST(79.00 AS Numeric(8, 2)), CAST(790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1078, 569, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1079, 569, 3, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1080, 569, 5, N'MENU      ', 7, CAST(129.00 AS Numeric(8, 2)), CAST(903.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1081, 570, 1, N'CASE      ', 11, CAST(39.00 AS Numeric(8, 2)), CAST(429.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1082, 570, 2, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1083, 570, 3, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1084, 570, 4, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1085, 571, 1, N'DATES     ', 15, CAST(29.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1086, 571, 2, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1087, 571, 3, N'TEXT-4    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1088, 571, 4, N'REPORTS   ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1089, 572, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1090, 572, 2, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1091, 573, 1, N'MENU      ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1092, 573, 2, N'MODEMS    ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1093, 573, 3, N'TABLE-MAH ', 10, CAST(1250.00 AS Numeric(8, 2)), CAST(12500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1094, 573, 4, N'REPORTS   ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1095, 574, 1, N'PULLMAN   ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1096, 574, 2, N'TABLE     ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1097, 575, 1, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1098, 575, 2, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1099, 576, 1, N'UNIXGUIDE ', 13, CAST(499.00 AS Numeric(8, 2)), CAST(6487.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1100, 576, 2, N'GOLD-DLX  ', 4, CAST(1079.00 AS Numeric(8, 2)), CAST(4316.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1101, 577, 1, N'MODEMS    ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1102, 577, 2, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1103, 577, 3, N'TEXT-2    ', 16, CAST(59.00 AS Numeric(8, 2)), CAST(944.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1104, 578, 1, N'TABLE-MPL ', 16, CAST(319.00 AS Numeric(8, 2)), CAST(5104.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1105, 578, 2, N'JEWELRY-I ', 2, CAST(1299.00 AS Numeric(8, 2)), CAST(2598.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1106, 578, 3, N'UN-CL-1   ', 6, CAST(399.00 AS Numeric(8, 2)), CAST(2394.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1107, 579, 1, N'RUNMTR    ', 12, CAST(79.00 AS Numeric(8, 2)), CAST(948.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1108, 579, 2, N'RUNMTR2   ', 12, CAST(199.00 AS Numeric(8, 2)), CAST(2388.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1109, 579, 3, N'POPUP     ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1110, 580, 1, N'JEWELRY-DL', 12, CAST(1749.00 AS Numeric(8, 2)), CAST(20988.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1111, 580, 2, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1112, 580, 3, N'UN-CL-2   ', 13, CAST(659.00 AS Numeric(8, 2)), CAST(8567.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1113, 581, 2, N'UPDATE    ', 10, CAST(19.00 AS Numeric(8, 2)), CAST(190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1114, 581, 3, N'JOKES     ', 4, CAST(12.00 AS Numeric(8, 2)), CAST(48.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1115, 581, 4, N'TEXT-ALL  ', 4, CAST(595.00 AS Numeric(8, 2)), CAST(2380.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1116, 581, 5, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1117, 582, 2, N'MODEMS    ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1118, 582, 3, N'REPORTS II', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1119, 583, 1, N'JEWELRY-DL', 8, CAST(1749.00 AS Numeric(8, 2)), CAST(13992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1120, 583, 2, N'FLEX-O-MAT', 7, CAST(295.00 AS Numeric(8, 2)), CAST(2065.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1121, 584, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1122, 584, 3, N'MAPS      ', 8, CAST(145.00 AS Numeric(8, 2)), CAST(1160.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1123, 585, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1124, 586, 1, N'UN-CL-2   ', 16, CAST(659.00 AS Numeric(8, 2)), CAST(10544.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1125, 586, 3, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1126, 587, 1, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1127, 587, 2, N'PULLMAN   ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1128, 587, 3, N'TEXT-1    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1129, 588, 2, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1130, 588, 3, N'DATES     ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1131, 588, 4, N'PICTURE   ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1132, 588, 5, N'TEXT-3    ', 5, CAST(69.00 AS Numeric(8, 2)), CAST(345.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1133, 589, 1, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1134, 589, 2, N'PICTURE   ', 12, CAST(29.00 AS Numeric(8, 2)), CAST(348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1135, 589, 3, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1136, 590, 1, N'GOLD      ', 4, CAST(779.00 AS Numeric(8, 2)), CAST(3116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1137, 590, 2, N'CASE      ', 16, CAST(39.00 AS Numeric(8, 2)), CAST(624.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1138, 590, 3, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1139, 590, 4, N'PICTURE   ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1140, 591, 1, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1141, 591, 2, N'MENU      ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1142, 591, 3, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1143, 591, 4, N'DT PK     ', 8, CAST(229.00 AS Numeric(8, 2)), CAST(1832.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1144, 592, 2, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1145, 592, 4, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1146, 593, 16, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1147, 593, 17, N'DATES     ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1148, 594, 1, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1149, 594, 2, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1150, 594, 3, N'DT PK     ', 7, CAST(229.00 AS Numeric(8, 2)), CAST(1603.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1151, 594, 4, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1152, 595, 1, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1153, 595, 2, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1154, 595, 3, N'TEXT-3    ', 5, CAST(69.00 AS Numeric(8, 2)), CAST(345.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1155, 595, 4, N'GOLD-DLX  ', 5, CAST(1079.00 AS Numeric(8, 2)), CAST(5395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1156, 595, 5, N'TEXT-3    ', 8, CAST(69.00 AS Numeric(8, 2)), CAST(552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1157, 595, 6, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1158, 596, 1, N'TEXT-3    ', 8, CAST(69.00 AS Numeric(8, 2)), CAST(552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1159, 596, 2, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1160, 596, 3, N'DATES     ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1161, 596, 4, N'CUA       ', 16, CAST(49.00 AS Numeric(8, 2)), CAST(784.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1162, 596, 5, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1163, 597, 1, N'DATES     ', 17, CAST(29.00 AS Numeric(8, 2)), CAST(493.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1164, 597, 2, N'DT PK     ', 15, CAST(229.00 AS Numeric(8, 2)), CAST(3435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1165, 598, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1166, 598, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1167, 598, 3, N'CITIES    ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1168, 598, 4, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1169, 598, 5, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1170, 598, 10, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1171, 599, 1, N'BEARS     ', 9, CAST(30.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1172, 599, 4, N'BEARS     ', 9, CAST(30.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1173, 599, 5, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1174, 600, 1, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1175, 600, 2, N'DT PK     ', 6, CAST(229.00 AS Numeric(8, 2)), CAST(1374.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1176, 601, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1177, 601, 2, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1178, 602, 1, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1179, 603, 1, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1180, 603, 2, N'CUA       ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1181, 604, 1, N'BRIDGE    ', 15, CAST(195.00 AS Numeric(8, 2)), CAST(2925.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1182, 604, 2, N'CITIES    ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1183, 605, 1, N'ACE1      ', 9, CAST(25.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1184, 605, 2, N'ACE-2     ', 14, CAST(15.00 AS Numeric(8, 2)), CAST(210.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1185, 606, 1, N'BEARS     ', 14, CAST(32.00 AS Numeric(8, 2)), CAST(448.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1186, 606, 2, N'GOLD      ', 14, CAST(779.00 AS Numeric(8, 2)), CAST(10906.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1187, 607, 1, N'JEWELRY-DL', 14, CAST(1749.00 AS Numeric(8, 2)), CAST(24486.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1188, 608, 1, N'FLEX-O-MAT', 11, CAST(295.00 AS Numeric(8, 2)), CAST(3245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1189, 609, 1, N'O''NEILLS  ', 10, CAST(45.00 AS Numeric(8, 2)), CAST(450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1190, 609, 2, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1191, 610, 1, N'MAPS      ', 9, CAST(145.00 AS Numeric(8, 2)), CAST(1305.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1192, 611, 1, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1193, 611, 2, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1194, 611, 3, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1195, 612, 1, N'DATES     ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1196, 612, 2, N'POPUP     ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1197, 613, 1, N'OFFICE-1  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1198, 613, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1199, 613, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1200, 614, 1, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1201, 614, 2, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1202, 614, 3, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1203, 614, 4, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1204, 614, 5, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1205, 615, 1, N'VINO-LM   ', 9, CAST(5.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1206, 616, 1, N'UN-CL-1   ', 4, CAST(399.00 AS Numeric(8, 2)), CAST(1596.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1207, 616, 2, N'UN-CL-2   ', 14, CAST(659.00 AS Numeric(8, 2)), CAST(9226.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1208, 617, 1, N'UNIXGUIDE ', 14, CAST(499.00 AS Numeric(8, 2)), CAST(6986.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1209, 618, 1, N'FLEX-O-MAT', 8, CAST(295.00 AS Numeric(8, 2)), CAST(2360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1210, 619, 1, N'O''NEILLS  ', 9, CAST(45.00 AS Numeric(8, 2)), CAST(405.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1211, 619, 2, N'TABLE     ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1212, 620, 1, N'TABLE-MAH ', 4, CAST(1250.00 AS Numeric(8, 2)), CAST(5000.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1213, 620, 2, N'TABLE-MPL ', 1, CAST(319.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1214, 621, 1, N'JEWELRY-DL', 4, CAST(1749.00 AS Numeric(8, 2)), CAST(6996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1215, 621, 2, N'JEWELRY-I ', 13, CAST(1299.00 AS Numeric(8, 2)), CAST(16887.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1216, 622, 1, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1217, 622, 2, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1218, 623, 1, N'MAPS      ', 7, CAST(145.00 AS Numeric(8, 2)), CAST(1015.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1219, 624, 1, N'PICTURE   ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1220, 624, 2, N'PULLMAN   ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1221, 625, 1, N'RUNMTR    ', 2, CAST(79.00 AS Numeric(8, 2)), CAST(158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1222, 625, 2, N'RUNMTR2   ', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1223, 626, 1, N'OFFICE-S  ', 9, CAST(19.00 AS Numeric(8, 2)), CAST(171.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1224, 627, 1, N'JOKES     ', 9, CAST(12.00 AS Numeric(8, 2)), CAST(108.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1225, 628, 1, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1226, 628, 2, N'REPORTS II', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1227, 629, 1, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1228, 629, 2, N'CITIES    ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1229, 630, 1, N'BEARS     ', 6, CAST(32.00 AS Numeric(8, 2)), CAST(192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1230, 630, 2, N'STARTREK  ', 3, CAST(1599.00 AS Numeric(8, 2)), CAST(4797.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1231, 631, 1, N'MAPS      ', 12, CAST(145.00 AS Numeric(8, 2)), CAST(1740.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1232, 632, 1, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1233, 632, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1234, 633, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1235, 634, 1, N'NITE-LITE ', 2, CAST(24.00 AS Numeric(8, 2)), CAST(48.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1236, 634, 2, N'TABLE     ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1237, 634, 3, N'UPDATE    ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1238, 635, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1239, 635, 2, N'OFFICE-1  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1240, 636, 1, N'BRIDGE    ', 7, CAST(195.00 AS Numeric(8, 2)), CAST(1365.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1241, 636, 2, N'CITIES    ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1242, 636, 3, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1243, 637, 1, N'UPDATE    ', 11, CAST(19.00 AS Numeric(8, 2)), CAST(209.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1244, 637, 2, N'OFFICE-S  ', 13, CAST(19.00 AS Numeric(8, 2)), CAST(247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1245, 638, 1, N'TEXT-1    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1246, 638, 2, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1247, 638, 3, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1248, 638, 4, N'TEXT-4    ', 10, CAST(99.00 AS Numeric(8, 2)), CAST(990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1249, 638, 5, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1250, 639, 1, N'JOKES     ', 3, CAST(12.00 AS Numeric(8, 2)), CAST(36.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1251, 640, 1, N'ACE-2     ', 3, CAST(15.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1252, 640, 2, N'ACE1      ', 5, CAST(25.00 AS Numeric(8, 2)), CAST(125.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1253, 641, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1254, 641, 2, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1255, 642, 1, N'OFFICE-1  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1256, 642, 2, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1257, 642, 3, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1258, 643, 1, N'GOLD-DLX  ', 9, CAST(1079.00 AS Numeric(8, 2)), CAST(9711.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1259, 644, 1, N'FLEX-O-MAT', 9, CAST(295.00 AS Numeric(8, 2)), CAST(2655.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1260, 645, 1, N'BRIDGE    ', 9, CAST(195.00 AS Numeric(8, 2)), CAST(1755.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1261, 645, 2, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1262, 645, 3, N'VINO-LM   ', 6, CAST(5.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1263, 646, 1, N'DT PK     ', 11, CAST(229.00 AS Numeric(8, 2)), CAST(2519.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1264, 647, 1, N'TABLE     ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1265, 647, 2, N'TABLE-MAH ', 11, CAST(1250.00 AS Numeric(8, 2)), CAST(13750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1266, 647, 3, N'TABLE-MPL ', 1, CAST(319.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1267, 647, 4, N'OFFICE-1  ', 13, CAST(45.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1268, 647, 5, N'OFFICE-2  ', 13, CAST(65.00 AS Numeric(8, 2)), CAST(845.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1269, 647, 6, N'OFFICE-S  ', 12, CAST(19.00 AS Numeric(8, 2)), CAST(228.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1270, 648, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1271, 648, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1272, 649, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1273, 650, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1274, 650, 2, N'POPUP     ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1275, 650, 3, N'PULLMAN   ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1276, 651, 1, N'TEXT-1    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1277, 651, 2, N'TEXT-2    ', 4, CAST(59.00 AS Numeric(8, 2)), CAST(236.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1278, 651, 3, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1279, 651, 4, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1280, 651, 5, N'TEXT-ALL  ', 9, CAST(595.00 AS Numeric(8, 2)), CAST(5355.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1281, 652, 1, N'MODEMS    ', 13, CAST(129.00 AS Numeric(8, 2)), CAST(1677.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1282, 652, 2, N'REPORTS   ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1283, 653, 1, N'JEWELRY-I ', 3, CAST(1299.00 AS Numeric(8, 2)), CAST(3897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1284, 654, 1, N'STARTREK  ', 9, CAST(1599.00 AS Numeric(8, 2)), CAST(14391.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1285, 655, 1, N'REPORTS II', 6, CAST(199.00 AS Numeric(8, 2)), CAST(1194.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1286, 656, 1, N'OFFICE-1  ', 9, CAST(45.00 AS Numeric(8, 2)), CAST(405.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1287, 656, 2, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1288, 656, 3, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1289, 657, 1, N'UN-CL-1   ', 16, CAST(399.00 AS Numeric(8, 2)), CAST(6384.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1290, 657, 2, N'UN-CL-2   ', 16, CAST(659.00 AS Numeric(8, 2)), CAST(10544.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1291, 657, 3, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1292, 658, 1, N'RUNMTR    ', 2, CAST(79.00 AS Numeric(8, 2)), CAST(158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1293, 658, 2, N'RUNMTR2   ', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1294, 659, 1, N'O''NEILLS  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1295, 660, 1, N'GOLD      ', 8, CAST(779.00 AS Numeric(8, 2)), CAST(6232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1296, 661, 1, N'CITIES    ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1297, 661, 2, N'MAPS      ', 6, CAST(145.00 AS Numeric(8, 2)), CAST(870.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1298, 662, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1299, 662, 2, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1300, 662, 3, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1301, 662, 4, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1302, 663, 1, N'POOL      ', 2, CAST(15.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1303, 663, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1304, 664, 1, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1305, 665, 1, N'BRIDGE    ', 11, CAST(195.00 AS Numeric(8, 2)), CAST(2145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1306, 665, 2, N'DATES     ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1307, 666, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1308, 666, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1309, 666, 3, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1310, 666, 4, N'VINO-LM   ', 7, CAST(5.00 AS Numeric(8, 2)), CAST(35.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1311, 667, 1, N'VINO-LM   ', 6, CAST(5.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1312, 668, 1, N'NITE-LITE ', 6, CAST(24.00 AS Numeric(8, 2)), CAST(144.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1313, 668, 2, N'POPUP     ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1314, 668, 3, N'STARTREK  ', 13, CAST(1599.00 AS Numeric(8, 2)), CAST(20787.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1315, 669, 1, N'OFFICE-1  ', 13, CAST(45.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1316, 669, 2, N'OFFICE-2  ', 13, CAST(65.00 AS Numeric(8, 2)), CAST(845.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1317, 669, 3, N'OFFICE-S  ', 13, CAST(19.00 AS Numeric(8, 2)), CAST(247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1318, 670, 1, N'PICTURE   ', 12, CAST(29.00 AS Numeric(8, 2)), CAST(348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1319, 671, 1, N'RUNMTR    ', 15, CAST(79.00 AS Numeric(8, 2)), CAST(1185.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1320, 671, 2, N'RUNMTR2   ', 15, CAST(199.00 AS Numeric(8, 2)), CAST(2985.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1321, 672, 1, N'MAPS      ', 5, CAST(145.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1322, 673, 1, N'JOKES     ', 5, CAST(12.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1323, 673, 2, N'POOL      ', 5, CAST(15.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1324, 674, 1, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1325, 675, 1, N'BEARS     ', 3, CAST(32.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1326, 676, 1, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1327, 677, 1, N'TEXT-ALL  ', 6, CAST(595.00 AS Numeric(8, 2)), CAST(3570.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1328, 678, 1, N'TEXT-1    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1329, 678, 2, N'TEXT-2    ', 5, CAST(59.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1330, 678, 3, N'TEXT-3    ', 15, CAST(69.00 AS Numeric(8, 2)), CAST(1035.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1331, 678, 4, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1332, 679, 1, N'UN-CL-1   ', 6, CAST(399.00 AS Numeric(8, 2)), CAST(2394.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1333, 679, 2, N'UN-CL-2   ', 6, CAST(659.00 AS Numeric(8, 2)), CAST(3954.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1334, 679, 3, N'UNIXGUIDE ', 8, CAST(499.00 AS Numeric(8, 2)), CAST(3992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1335, 680, 1, N'CUA       ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1336, 681, 1, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1337, 682, 1, N'BRIDGE    ', 3, CAST(195.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1338, 683, 1, N'POOL      ', 3, CAST(15.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1339, 684, 1, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1340, 684, 2, N'DT        ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1341, 684, 3, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1342, 685, 1, N'TEXT-1    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1343, 685, 2, N'TEXT-2    ', 3, CAST(59.00 AS Numeric(8, 2)), CAST(177.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1344, 685, 3, N'TEXT-3    ', 9, CAST(69.00 AS Numeric(8, 2)), CAST(621.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1345, 685, 4, N'TEXT-4    ', 9, CAST(99.00 AS Numeric(8, 2)), CAST(891.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1346, 686, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1347, 686, 2, N'POPUP     ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1348, 686, 3, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1349, 686, 5, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1350, 687, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1351, 687, 2, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1352, 687, 3, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1353, 687, 4, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1354, 688, 1, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1355, 688, 2, N'RUNMTR    ', 7, CAST(79.00 AS Numeric(8, 2)), CAST(553.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1356, 688, 3, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1357, 688, 4, N'REPORTS   ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1358, 689, 1, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1359, 689, 2, N'GOLD      ', 17, CAST(779.00 AS Numeric(8, 2)), CAST(13243.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1360, 690, 1, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1361, 690, 2, N'MODEMS    ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1362, 690, 3, N'TABLE-MAH ', 2, CAST(1250.00 AS Numeric(8, 2)), CAST(2500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1363, 690, 4, N'REPORTS   ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1364, 691, 1, N'PULLMAN   ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1365, 691, 2, N'TABLE     ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1366, 692, 1, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1367, 692, 2, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1368, 693, 1, N'UNIXGUIDE ', 3, CAST(499.00 AS Numeric(8, 2)), CAST(1497.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1369, 693, 2, N'GOLD-DLX  ', 5, CAST(1079.00 AS Numeric(8, 2)), CAST(5395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1370, 694, 1, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1371, 694, 2, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1372, 694, 3, N'TEXT-2    ', 8, CAST(59.00 AS Numeric(8, 2)), CAST(472.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1373, 695, 1, N'TABLE-MPL ', 5, CAST(319.00 AS Numeric(8, 2)), CAST(1595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1374, 695, 2, N'JEWELRY-I ', 9, CAST(1299.00 AS Numeric(8, 2)), CAST(11691.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1375, 695, 3, N'UN-CL-1   ', 9, CAST(399.00 AS Numeric(8, 2)), CAST(3591.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1376, 696, 1, N'RUNMTR    ', 9, CAST(79.00 AS Numeric(8, 2)), CAST(711.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1377, 696, 2, N'RUNMTR2   ', 9, CAST(199.00 AS Numeric(8, 2)), CAST(1791.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1378, 696, 3, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1379, 697, 1, N'JEWELRY-DL', 3, CAST(1749.00 AS Numeric(8, 2)), CAST(5247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1380, 697, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1381, 697, 3, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1382, 698, 2, N'UPDATE    ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1383, 698, 3, N'JOKES     ', 4, CAST(12.00 AS Numeric(8, 2)), CAST(48.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1384, 698, 4, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1385, 698, 5, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1386, 699, 2, N'MODEMS    ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1387, 699, 3, N'REPORTS II', 9, CAST(199.00 AS Numeric(8, 2)), CAST(1791.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1388, 700, 1, N'JEWELRY-DL', 12, CAST(1749.00 AS Numeric(8, 2)), CAST(20988.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1389, 700, 2, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1390, 701, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1391, 701, 3, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1392, 702, 1, N'JEWELRY-I ', 4, CAST(1299.00 AS Numeric(8, 2)), CAST(5196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1393, 703, 1, N'UN-CL-2   ', 11, CAST(659.00 AS Numeric(8, 2)), CAST(7249.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1394, 703, 3, N'FLEX-O-MAT', 11, CAST(295.00 AS Numeric(8, 2)), CAST(3245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1395, 704, 1, N'OFFICE-2  ', 7, CAST(65.00 AS Numeric(8, 2)), CAST(455.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1396, 704, 2, N'PULLMAN   ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1397, 704, 3, N'TEXT-1    ', 11, CAST(99.00 AS Numeric(8, 2)), CAST(1089.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1398, 705, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1399, 705, 3, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1400, 705, 4, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1401, 705, 5, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1402, 706, 1, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1403, 706, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1404, 706, 3, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1405, 707, 1, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1406, 707, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1407, 707, 3, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1408, 707, 4, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1409, 708, 1, N'CITIES    ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1410, 708, 2, N'MENU      ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1411, 708, 3, N'PICTURE   ', 16, CAST(29.00 AS Numeric(8, 2)), CAST(464.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1412, 708, 4, N'DT PK     ', 12, CAST(229.00 AS Numeric(8, 2)), CAST(2748.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1413, 709, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1414, 709, 4, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1415, 710, 16, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1416, 710, 17, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1417, 711, 1, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1418, 711, 2, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1419, 711, 3, N'DT PK     ', 8, CAST(229.00 AS Numeric(8, 2)), CAST(1832.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1420, 711, 4, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1421, 712, 1, N'DT        ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1422, 712, 2, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1423, 712, 3, N'TEXT-3    ', 9, CAST(69.00 AS Numeric(8, 2)), CAST(621.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1424, 712, 4, N'GOLD-DLX  ', 9, CAST(1079.00 AS Numeric(8, 2)), CAST(9711.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1425, 712, 5, N'TEXT-3    ', 12, CAST(69.00 AS Numeric(8, 2)), CAST(828.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1426, 712, 6, N'CASE      ', 12, CAST(39.00 AS Numeric(8, 2)), CAST(468.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1427, 713, 1, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1428, 713, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1429, 713, 3, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1430, 713, 4, N'CUA       ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1431, 713, 5, N'TEXT-3    ', 8, CAST(69.00 AS Numeric(8, 2)), CAST(552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1432, 714, 1, N'DATES     ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1433, 714, 2, N'DT PK     ', 10, CAST(229.00 AS Numeric(8, 2)), CAST(2290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1434, 715, 1, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1435, 715, 2, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1436, 715, 3, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1437, 715, 4, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1438, 715, 5, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1439, 715, 10, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1440, 716, 1, N'BEARS     ', 3, CAST(30.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1441, 716, 4, N'BEARS     ', 10, CAST(30.00 AS Numeric(8, 2)), CAST(300.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1442, 716, 5, N'VINO-LM   ', 4, CAST(5.00 AS Numeric(8, 2)), CAST(20.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1443, 717, 1, N'DT        ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1444, 717, 2, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1445, 718, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1446, 718, 2, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1447, 719, 1, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1448, 720, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1449, 720, 2, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1450, 721, 1, N'BRIDGE    ', 6, CAST(195.00 AS Numeric(8, 2)), CAST(1170.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1451, 721, 2, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1452, 722, 1, N'ACE1      ', 14, CAST(25.00 AS Numeric(8, 2)), CAST(350.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1453, 722, 2, N'ACE-2     ', 12, CAST(15.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1454, 723, 1, N'BEARS     ', 12, CAST(32.00 AS Numeric(8, 2)), CAST(384.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1455, 723, 2, N'GOLD      ', 7, CAST(779.00 AS Numeric(8, 2)), CAST(5453.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1456, 724, 1, N'JEWELRY-DL', 4, CAST(1749.00 AS Numeric(8, 2)), CAST(6996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1457, 725, 1, N'FLEX-O-MAT', 4, CAST(295.00 AS Numeric(8, 2)), CAST(1180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1458, 726, 1, N'O''NEILLS  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1459, 726, 2, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1460, 727, 1, N'MAPS      ', 8, CAST(145.00 AS Numeric(8, 2)), CAST(1160.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1461, 728, 1, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1462, 728, 2, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1463, 728, 3, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1464, 729, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1465, 729, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1466, 730, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1467, 730, 2, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1468, 730, 3, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1469, 731, 1, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1470, 731, 2, N'TEXT-1    ', 9, CAST(99.00 AS Numeric(8, 2)), CAST(891.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1471, 731, 3, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1472, 731, 4, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1473, 731, 5, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1474, 732, 1, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1475, 733, 1, N'UN-CL-1   ', 6, CAST(399.00 AS Numeric(8, 2)), CAST(2394.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1476, 733, 2, N'UN-CL-2   ', 15, CAST(659.00 AS Numeric(8, 2)), CAST(9885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1477, 734, 1, N'UNIXGUIDE ', 12, CAST(499.00 AS Numeric(8, 2)), CAST(5988.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1478, 735, 1, N'FLEX-O-MAT', 10, CAST(295.00 AS Numeric(8, 2)), CAST(2950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1479, 736, 1, N'O''NEILLS  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1480, 736, 2, N'TABLE     ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1481, 737, 1, N'TABLE-MAH ', 4, CAST(1250.00 AS Numeric(8, 2)), CAST(5000.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1482, 737, 2, N'TABLE-MPL ', 4, CAST(319.00 AS Numeric(8, 2)), CAST(1276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1483, 738, 1, N'JEWELRY-DL', 4, CAST(1749.00 AS Numeric(8, 2)), CAST(6996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1484, 738, 2, N'JEWELRY-I ', 4, CAST(1299.00 AS Numeric(8, 2)), CAST(5196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1485, 739, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1486, 739, 2, N'DT PK     ', 3, CAST(229.00 AS Numeric(8, 2)), CAST(687.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1487, 740, 1, N'MAPS      ', 3, CAST(145.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1488, 741, 1, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1489, 741, 2, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1490, 742, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1491, 742, 2, N'RUNMTR2   ', 12, CAST(199.00 AS Numeric(8, 2)), CAST(2388.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1492, 743, 1, N'OFFICE-S  ', 16, CAST(19.00 AS Numeric(8, 2)), CAST(304.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1493, 744, 1, N'JOKES     ', 5, CAST(12.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1494, 745, 1, N'REPORTS   ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1495, 745, 2, N'REPORTS II', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1496, 746, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1497, 746, 2, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1498, 747, 1, N'BEARS     ', 5, CAST(32.00 AS Numeric(8, 2)), CAST(160.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1499, 747, 2, N'STARTREK  ', 2, CAST(1599.00 AS Numeric(8, 2)), CAST(3198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1500, 748, 1, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1501, 749, 1, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1502, 749, 2, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1503, 750, 1, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1504, 751, 1, N'NITE-LITE ', 8, CAST(24.00 AS Numeric(8, 2)), CAST(192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1505, 751, 2, N'TABLE     ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1506, 751, 3, N'UPDATE    ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1507, 752, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1508, 752, 2, N'OFFICE-1  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1509, 753, 1, N'BRIDGE    ', 5, CAST(195.00 AS Numeric(8, 2)), CAST(975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1510, 753, 2, N'CITIES    ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1511, 753, 3, N'PICTURE   ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1512, 754, 1, N'UPDATE    ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1513, 754, 2, N'OFFICE-S  ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1514, 755, 1, N'TEXT-1    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1515, 755, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1516, 755, 3, N'TEXT-3    ', 5, CAST(69.00 AS Numeric(8, 2)), CAST(345.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1517, 755, 4, N'TEXT-4    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1518, 755, 5, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1519, 756, 1, N'JOKES     ', 8, CAST(12.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1520, 757, 1, N'ACE-2     ', 10, CAST(15.00 AS Numeric(8, 2)), CAST(150.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1521, 757, 2, N'ACE1      ', 3, CAST(25.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1522, 758, 1, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1523, 758, 2, N'DT        ', 15, CAST(179.00 AS Numeric(8, 2)), CAST(2685.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1524, 759, 1, N'OFFICE-1  ', 11, CAST(45.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1525, 759, 2, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1526, 759, 3, N'OFFICE-S  ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1527, 760, 1, N'GOLD-DLX  ', 3, CAST(1079.00 AS Numeric(8, 2)), CAST(3237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1528, 761, 1, N'FLEX-O-MAT', 5, CAST(295.00 AS Numeric(8, 2)), CAST(1475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1529, 762, 1, N'BRIDGE    ', 9, CAST(195.00 AS Numeric(8, 2)), CAST(1755.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1530, 762, 2, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1531, 762, 3, N'VINO-LM   ', 4, CAST(5.00 AS Numeric(8, 2)), CAST(20.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1532, 763, 1, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1533, 764, 1, N'TABLE     ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1534, 764, 2, N'TABLE-MAH ', 4, CAST(1250.00 AS Numeric(8, 2)), CAST(5000.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1535, 764, 3, N'TABLE-MPL ', 4, CAST(319.00 AS Numeric(8, 2)), CAST(1276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1536, 764, 4, N'OFFICE-1  ', 6, CAST(45.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1537, 764, 5, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1538, 764, 6, N'OFFICE-S  ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1539, 765, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1540, 765, 2, N'CUA       ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1541, 766, 1, N'BRIDGE    ', 2, CAST(195.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1542, 767, 1, N'O''NEILLS  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1543, 767, 2, N'POPUP     ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1544, 767, 3, N'PULLMAN   ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1545, 768, 1, N'TEXT-1    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1546, 768, 2, N'TEXT-2    ', 7, CAST(59.00 AS Numeric(8, 2)), CAST(413.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1547, 768, 3, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1548, 768, 4, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1549, 768, 5, N'TEXT-ALL  ', 11, CAST(595.00 AS Numeric(8, 2)), CAST(6545.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1550, 769, 1, N'MODEMS    ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1551, 769, 2, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1552, 770, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1553, 771, 1, N'STARTREK  ', 2, CAST(1599.00 AS Numeric(8, 2)), CAST(3198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1554, 772, 1, N'REPORTS II', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1555, 773, 1, N'OFFICE-1  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1556, 773, 2, N'OFFICE-2  ', 7, CAST(65.00 AS Numeric(8, 2)), CAST(455.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1557, 773, 3, N'OFFICE-S  ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1558, 774, 1, N'UN-CL-1   ', 4, CAST(399.00 AS Numeric(8, 2)), CAST(1596.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1559, 774, 2, N'UN-CL-2   ', 3, CAST(659.00 AS Numeric(8, 2)), CAST(1977.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1560, 774, 3, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1561, 775, 1, N'RUNMTR    ', 2, CAST(79.00 AS Numeric(8, 2)), CAST(158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1562, 775, 2, N'RUNMTR2   ', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1563, 776, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1564, 777, 1, N'GOLD      ', 2, CAST(779.00 AS Numeric(8, 2)), CAST(1558.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1565, 778, 1, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1566, 778, 2, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1567, 779, 1, N'O''NEILLS  ', 8, CAST(45.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1568, 779, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1569, 779, 3, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1570, 779, 4, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1571, 780, 1, N'POOL      ', 6, CAST(15.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1572, 780, 2, N'POPUP     ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1573, 781, 1, N'FLEX-O-MAT', 6, CAST(295.00 AS Numeric(8, 2)), CAST(1770.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1574, 782, 1, N'BRIDGE    ', 9, CAST(195.00 AS Numeric(8, 2)), CAST(1755.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1575, 782, 2, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1576, 783, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1577, 783, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1578, 783, 3, N'REPORTS   ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1579, 783, 4, N'VINO-LM   ', 9, CAST(5.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1580, 784, 1, N'VINO-LM   ', 5, CAST(5.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1581, 785, 1, N'NITE-LITE ', 5, CAST(24.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1582, 785, 2, N'POPUP     ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1583, 785, 3, N'STARTREK  ', 4, CAST(1599.00 AS Numeric(8, 2)), CAST(6396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1584, 786, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1585, 786, 2, N'OFFICE-2  ', 7, CAST(65.00 AS Numeric(8, 2)), CAST(455.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1586, 786, 3, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1587, 787, 1, N'PICTURE   ', 13, CAST(29.00 AS Numeric(8, 2)), CAST(377.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1588, 788, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1589, 788, 2, N'RUNMTR2   ', 15, CAST(199.00 AS Numeric(8, 2)), CAST(2985.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1590, 789, 1, N'MAPS      ', 15, CAST(145.00 AS Numeric(8, 2)), CAST(2175.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1591, 790, 1, N'JOKES     ', 15, CAST(12.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1592, 790, 2, N'POOL      ', 10, CAST(15.00 AS Numeric(8, 2)), CAST(150.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1593, 791, 1, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1594, 792, 1, N'BEARS     ', 3, CAST(32.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1595, 793, 1, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1596, 794, 1, N'TEXT-ALL  ', 13, CAST(595.00 AS Numeric(8, 2)), CAST(7735.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1597, 795, 1, N'TEXT-1    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1598, 795, 2, N'TEXT-2    ', 13, CAST(59.00 AS Numeric(8, 2)), CAST(767.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1599, 795, 3, N'TEXT-3    ', 5, CAST(69.00 AS Numeric(8, 2)), CAST(345.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1600, 795, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1601, 796, 1, N'UN-CL-1   ', 1, CAST(399.00 AS Numeric(8, 2)), CAST(399.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1602, 796, 2, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1603, 796, 3, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1604, 797, 1, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1605, 798, 1, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1606, 799, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1607, 800, 1, N'POOL      ', 7, CAST(15.00 AS Numeric(8, 2)), CAST(105.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1608, 801, 1, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1609, 801, 2, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1610, 801, 3, N'DT PK     ', 5, CAST(229.00 AS Numeric(8, 2)), CAST(1145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1611, 802, 1, N'TEXT-1    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1612, 802, 2, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1613, 802, 3, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1614, 802, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1615, 803, 1, N'RUNMTR    ', 10, CAST(79.00 AS Numeric(8, 2)), CAST(790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1616, 803, 2, N'POPUP     ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1617, 803, 3, N'DT        ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1618, 803, 5, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1619, 804, 1, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1620, 804, 2, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1621, 804, 3, N'MENU      ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1622, 804, 4, N'DT        ', 14, CAST(179.00 AS Numeric(8, 2)), CAST(2506.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1623, 805, 1, N'DATES     ', 14, CAST(29.00 AS Numeric(8, 2)), CAST(406.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1624, 805, 2, N'RUNMTR    ', 14, CAST(79.00 AS Numeric(8, 2)), CAST(1106.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1625, 805, 3, N'TEXT-4    ', 11, CAST(99.00 AS Numeric(8, 2)), CAST(1089.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1626, 805, 4, N'REPORTS   ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1627, 806, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1628, 806, 2, N'GOLD      ', 5, CAST(779.00 AS Numeric(8, 2)), CAST(3895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1629, 807, 1, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1630, 807, 2, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1631, 807, 3, N'TABLE-MAH ', 3, CAST(1250.00 AS Numeric(8, 2)), CAST(3750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1632, 807, 4, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1633, 808, 1, N'PULLMAN   ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1634, 808, 2, N'TABLE     ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1635, 809, 1, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1636, 809, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1637, 810, 1, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1638, 810, 2, N'GOLD-DLX  ', 3, CAST(1079.00 AS Numeric(8, 2)), CAST(3237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1639, 811, 1, N'MODEMS    ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1640, 811, 2, N'REPORTS   ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1641, 811, 3, N'TEXT-2    ', 9, CAST(59.00 AS Numeric(8, 2)), CAST(531.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1642, 812, 1, N'TABLE-MPL ', 9, CAST(319.00 AS Numeric(8, 2)), CAST(2871.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1643, 812, 2, N'JEWELRY-I ', 12, CAST(1299.00 AS Numeric(8, 2)), CAST(15588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1644, 812, 3, N'UN-CL-1   ', 12, CAST(399.00 AS Numeric(8, 2)), CAST(4788.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1645, 813, 1, N'RUNMTR    ', 10, CAST(79.00 AS Numeric(8, 2)), CAST(790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1646, 813, 2, N'RUNMTR2   ', 10, CAST(199.00 AS Numeric(8, 2)), CAST(1990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1647, 813, 3, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1648, 814, 1, N'JEWELRY-DL', 1, CAST(1749.00 AS Numeric(8, 2)), CAST(1749.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1649, 814, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1650, 814, 3, N'UN-CL-2   ', 3, CAST(659.00 AS Numeric(8, 2)), CAST(1977.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1651, 815, 2, N'UPDATE    ', 13, CAST(19.00 AS Numeric(8, 2)), CAST(247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1652, 815, 3, N'JOKES     ', 13, CAST(12.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1653, 815, 4, N'TEXT-ALL  ', 4, CAST(595.00 AS Numeric(8, 2)), CAST(2380.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1654, 815, 5, N'UNIXGUIDE ', 6, CAST(499.00 AS Numeric(8, 2)), CAST(2994.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1655, 816, 2, N'MODEMS    ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1656, 816, 3, N'REPORTS II', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1657, 817, 1, N'JEWELRY-DL', 8, CAST(1749.00 AS Numeric(8, 2)), CAST(13992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1658, 817, 2, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1659, 818, 1, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1660, 818, 3, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1661, 819, 1, N'JEWELRY-I ', 13, CAST(1299.00 AS Numeric(8, 2)), CAST(16887.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1662, 820, 1, N'UN-CL-2   ', 13, CAST(659.00 AS Numeric(8, 2)), CAST(8567.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1663, 820, 3, N'FLEX-O-MAT', 3, CAST(295.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1664, 821, 1, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1665, 821, 2, N'PULLMAN   ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1666, 821, 3, N'TEXT-1    ', 9, CAST(99.00 AS Numeric(8, 2)), CAST(891.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1667, 822, 2, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1668, 822, 3, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1669, 822, 4, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1670, 822, 5, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1671, 823, 1, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1672, 823, 2, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1673, 823, 3, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1674, 824, 1, N'GOLD      ', 10, CAST(779.00 AS Numeric(8, 2)), CAST(7790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1675, 824, 2, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1676, 824, 3, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1677, 824, 4, N'PICTURE   ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1678, 825, 1, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1679, 825, 2, N'MENU      ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1680, 825, 3, N'PICTURE   ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1681, 825, 4, N'DT PK     ', 10, CAST(229.00 AS Numeric(8, 2)), CAST(2290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1682, 826, 2, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1683, 826, 4, N'DT        ', 10, CAST(179.00 AS Numeric(8, 2)), CAST(1790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1684, 827, 16, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1685, 827, 17, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1686, 828, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1687, 828, 2, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1688, 828, 3, N'DT PK     ', 2, CAST(229.00 AS Numeric(8, 2)), CAST(458.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1689, 828, 4, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1690, 829, 1, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1691, 829, 2, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1692, 829, 3, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1693, 829, 4, N'GOLD-DLX  ', 13, CAST(1079.00 AS Numeric(8, 2)), CAST(14027.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1694, 829, 5, N'TEXT-3    ', 13, CAST(69.00 AS Numeric(8, 2)), CAST(897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1695, 829, 6, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1696, 830, 1, N'TEXT-3    ', 10, CAST(69.00 AS Numeric(8, 2)), CAST(690.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1697, 830, 2, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1698, 830, 3, N'DATES     ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1699, 830, 4, N'CUA       ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1700, 830, 5, N'TEXT-3    ', 11, CAST(69.00 AS Numeric(8, 2)), CAST(759.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1701, 831, 1, N'DATES     ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1702, 831, 2, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1703, 832, 1, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1704, 832, 2, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1705, 832, 3, N'CITIES    ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1706, 832, 4, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1707, 832, 5, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1708, 832, 10, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1709, 833, 1, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1710, 833, 4, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1711, 833, 5, N'VINO-LM   ', 6, CAST(5.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1712, 834, 1, N'DT        ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1713, 834, 2, N'DT PK     ', 6, CAST(229.00 AS Numeric(8, 2)), CAST(1374.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1714, 835, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1715, 835, 2, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1716, 836, 1, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1717, 837, 1, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1718, 837, 2, N'CUA       ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1719, 838, 1, N'BRIDGE    ', 14, CAST(195.00 AS Numeric(8, 2)), CAST(2730.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1720, 838, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1721, 839, 1, N'ACE1      ', 3, CAST(25.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1722, 839, 2, N'ACE-2     ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1723, 840, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1724, 840, 2, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1725, 841, 1, N'JEWELRY-DL', 5, CAST(1749.00 AS Numeric(8, 2)), CAST(8745.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1726, 842, 1, N'FLEX-O-MAT', 4, CAST(295.00 AS Numeric(8, 2)), CAST(1180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1727, 843, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1728, 843, 2, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1729, 844, 1, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1730, 845, 1, N'UPDATE    ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1731, 845, 2, N'CUA       ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1732, 845, 3, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1733, 846, 1, N'DATES     ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1734, 846, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1735, 847, 1, N'OFFICE-1  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1736, 847, 2, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1737, 847, 3, N'OFFICE-S  ', 9, CAST(19.00 AS Numeric(8, 2)), CAST(171.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1738, 848, 1, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1739, 848, 2, N'TEXT-1    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1740, 848, 3, N'TEXT-2    ', 3, CAST(59.00 AS Numeric(8, 2)), CAST(177.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1741, 848, 4, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1742, 848, 5, N'TEXT-4    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1743, 849, 1, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1744, 850, 1, N'UN-CL-1   ', 7, CAST(399.00 AS Numeric(8, 2)), CAST(2793.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1745, 850, 2, N'UN-CL-2   ', 5, CAST(659.00 AS Numeric(8, 2)), CAST(3295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1746, 851, 1, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1747, 852, 1, N'FLEX-O-MAT', 2, CAST(295.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1748, 853, 1, N'O''NEILLS  ', 8, CAST(45.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1749, 853, 2, N'TABLE     ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1750, 854, 1, N'TABLE-MAH ', 11, CAST(1250.00 AS Numeric(8, 2)), CAST(13750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1751, 854, 2, N'TABLE-MPL ', 11, CAST(319.00 AS Numeric(8, 2)), CAST(3509.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1752, 855, 1, N'JEWELRY-DL', 7, CAST(1749.00 AS Numeric(8, 2)), CAST(12243.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1753, 855, 2, N'JEWELRY-I ', 3, CAST(1299.00 AS Numeric(8, 2)), CAST(3897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1754, 856, 1, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1755, 856, 2, N'DT PK     ', 8, CAST(229.00 AS Numeric(8, 2)), CAST(1832.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1756, 857, 1, N'MAPS      ', 10, CAST(145.00 AS Numeric(8, 2)), CAST(1450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1757, 858, 1, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1758, 858, 2, N'PULLMAN   ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1759, 859, 1, N'RUNMTR    ', 10, CAST(79.00 AS Numeric(8, 2)), CAST(790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1760, 859, 2, N'RUNMTR2   ', 10, CAST(199.00 AS Numeric(8, 2)), CAST(1990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1761, 860, 1, N'OFFICE-S  ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1762, 861, 1, N'JOKES     ', 4, CAST(12.00 AS Numeric(8, 2)), CAST(48.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1763, 862, 1, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1764, 862, 2, N'REPORTS II', 4, CAST(199.00 AS Numeric(8, 2)), CAST(796.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1765, 863, 1, N'MAPS      ', 3, CAST(145.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1766, 863, 2, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1767, 864, 1, N'BEARS     ', 6, CAST(32.00 AS Numeric(8, 2)), CAST(192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1768, 864, 2, N'STARTREK  ', 1, CAST(1599.00 AS Numeric(8, 2)), CAST(1599.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1769, 865, 1, N'MAPS      ', 3, CAST(145.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1770, 866, 1, N'OFFICE-S  ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1771, 866, 2, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1772, 867, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1773, 868, 1, N'NITE-LITE ', 1, CAST(24.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1774, 868, 2, N'TABLE     ', 12, CAST(179.00 AS Numeric(8, 2)), CAST(2148.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1775, 868, 3, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1776, 869, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1777, 869, 2, N'OFFICE-1  ', 10, CAST(45.00 AS Numeric(8, 2)), CAST(450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1778, 870, 1, N'BRIDGE    ', 9, CAST(195.00 AS Numeric(8, 2)), CAST(1755.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1779, 870, 2, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1780, 870, 3, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1781, 871, 1, N'UPDATE    ', 11, CAST(19.00 AS Numeric(8, 2)), CAST(209.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1782, 871, 2, N'OFFICE-S  ', 16, CAST(19.00 AS Numeric(8, 2)), CAST(304.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1783, 872, 1, N'TEXT-1    ', 16, CAST(99.00 AS Numeric(8, 2)), CAST(1584.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1784, 872, 2, N'TEXT-2    ', 6, CAST(59.00 AS Numeric(8, 2)), CAST(354.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1785, 872, 3, N'TEXT-3    ', 9, CAST(69.00 AS Numeric(8, 2)), CAST(621.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1786, 872, 4, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1787, 872, 5, N'TEXT-ALL  ', 5, CAST(595.00 AS Numeric(8, 2)), CAST(2975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1788, 873, 1, N'JOKES     ', 5, CAST(12.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1789, 874, 1, N'ACE-2     ', 5, CAST(15.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1790, 874, 2, N'ACE1      ', 5, CAST(25.00 AS Numeric(8, 2)), CAST(125.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1791, 875, 1, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1792, 875, 2, N'DT        ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1793, 876, 1, N'OFFICE-1  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1794, 876, 2, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1795, 876, 3, N'OFFICE-S  ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1796, 877, 1, N'GOLD-DLX  ', 3, CAST(1079.00 AS Numeric(8, 2)), CAST(3237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1797, 878, 1, N'FLEX-O-MAT', 5, CAST(295.00 AS Numeric(8, 2)), CAST(1475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1798, 879, 1, N'BRIDGE    ', 5, CAST(195.00 AS Numeric(8, 2)), CAST(975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1799, 879, 2, N'PICTURE   ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1800, 879, 3, N'VINO-LM   ', 10, CAST(5.00 AS Numeric(8, 2)), CAST(50.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1801, 880, 1, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1802, 881, 1, N'TABLE     ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1803, 881, 2, N'TABLE-MAH ', 6, CAST(1250.00 AS Numeric(8, 2)), CAST(7500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1804, 881, 3, N'TABLE-MPL ', 5, CAST(319.00 AS Numeric(8, 2)), CAST(1595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1805, 881, 4, N'OFFICE-1  ', 11, CAST(45.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1806, 881, 5, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1807, 881, 6, N'OFFICE-S  ', 17, CAST(19.00 AS Numeric(8, 2)), CAST(323.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1808, 882, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1809, 882, 2, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1810, 883, 1, N'BRIDGE    ', 3, CAST(195.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1811, 884, 1, N'O''NEILLS  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1812, 884, 2, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1813, 884, 3, N'PULLMAN   ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1814, 885, 1, N'TEXT-1    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1815, 885, 2, N'TEXT-2    ', 10, CAST(59.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1816, 885, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1817, 885, 4, N'TEXT-4    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1818, 885, 5, N'TEXT-ALL  ', 6, CAST(595.00 AS Numeric(8, 2)), CAST(3570.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1819, 886, 1, N'MODEMS    ', 15, CAST(129.00 AS Numeric(8, 2)), CAST(1935.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1820, 886, 2, N'REPORTS   ', 15, CAST(179.00 AS Numeric(8, 2)), CAST(2685.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1821, 887, 1, N'JEWELRY-I ', 15, CAST(1299.00 AS Numeric(8, 2)), CAST(19485.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1822, 888, 1, N'STARTREK  ', 9, CAST(1599.00 AS Numeric(8, 2)), CAST(14391.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1823, 889, 1, N'REPORTS II', 9, CAST(199.00 AS Numeric(8, 2)), CAST(1791.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1824, 890, 1, N'OFFICE-1  ', 11, CAST(45.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1825, 890, 2, N'OFFICE-2  ', 10, CAST(65.00 AS Numeric(8, 2)), CAST(650.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1826, 890, 3, N'OFFICE-S  ', 10, CAST(19.00 AS Numeric(8, 2)), CAST(190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1827, 891, 1, N'UN-CL-1   ', 9, CAST(399.00 AS Numeric(8, 2)), CAST(3591.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1828, 891, 2, N'UN-CL-2   ', 9, CAST(659.00 AS Numeric(8, 2)), CAST(5931.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1829, 891, 3, N'UNIXGUIDE ', 3, CAST(499.00 AS Numeric(8, 2)), CAST(1497.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1830, 892, 1, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1831, 892, 2, N'RUNMTR2   ', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1832, 893, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1833, 894, 1, N'GOLD      ', 14, CAST(779.00 AS Numeric(8, 2)), CAST(10906.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1834, 895, 1, N'CITIES    ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1835, 895, 2, N'MAPS      ', 14, CAST(145.00 AS Numeric(8, 2)), CAST(2030.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1836, 896, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1837, 896, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1838, 896, 3, N'UPDATE    ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1839, 896, 4, N'VINO-LM   ', 6, CAST(5.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1840, 897, 1, N'POOL      ', 6, CAST(15.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1841, 897, 2, N'POPUP     ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1842, 898, 1, N'FLEX-O-MAT', 6, CAST(295.00 AS Numeric(8, 2)), CAST(1770.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1843, 899, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1844, 899, 2, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1845, 900, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1846, 900, 2, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1847, 900, 3, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1848, 900, 4, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1849, 901, 1, N'VINO-LM   ', 14, CAST(5.00 AS Numeric(8, 2)), CAST(70.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1850, 902, 1, N'NITE-LITE ', 14, CAST(24.00 AS Numeric(8, 2)), CAST(336.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1851, 902, 2, N'POPUP     ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1852, 902, 3, N'STARTREK  ', 6, CAST(1599.00 AS Numeric(8, 2)), CAST(9594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1853, 903, 1, N'OFFICE-1  ', 6, CAST(45.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1854, 903, 2, N'OFFICE-2  ', 6, CAST(65.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1855, 903, 3, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1856, 904, 1, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1857, 905, 1, N'RUNMTR    ', 8, CAST(79.00 AS Numeric(8, 2)), CAST(632.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1858, 905, 2, N'RUNMTR2   ', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1859, 906, 1, N'MAPS      ', 5, CAST(145.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1860, 907, 1, N'JOKES     ', 7, CAST(12.00 AS Numeric(8, 2)), CAST(84.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1861, 907, 2, N'POOL      ', 6, CAST(15.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1862, 908, 1, N'VINO-LM   ', 6, CAST(5.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1863, 909, 1, N'BEARS     ', 6, CAST(32.00 AS Numeric(8, 2)), CAST(192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1864, 910, 1, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1865, 911, 1, N'TEXT-ALL  ', 9, CAST(595.00 AS Numeric(8, 2)), CAST(5355.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1866, 912, 1, N'TEXT-1    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1867, 912, 2, N'TEXT-2    ', 4, CAST(59.00 AS Numeric(8, 2)), CAST(236.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1868, 912, 3, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1869, 912, 4, N'TEXT-4    ', 9, CAST(99.00 AS Numeric(8, 2)), CAST(891.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1870, 913, 1, N'UN-CL-1   ', 2, CAST(399.00 AS Numeric(8, 2)), CAST(798.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1871, 913, 2, N'UN-CL-2   ', 4, CAST(659.00 AS Numeric(8, 2)), CAST(2636.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1872, 913, 3, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1873, 914, 1, N'CUA       ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1874, 915, 1, N'PICTURE   ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1875, 916, 1, N'BRIDGE    ', 9, CAST(195.00 AS Numeric(8, 2)), CAST(1755.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1876, 917, 1, N'POOL      ', 8, CAST(15.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1877, 918, 1, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1878, 918, 2, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1879, 918, 3, N'DT PK     ', 5, CAST(229.00 AS Numeric(8, 2)), CAST(1145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1880, 919, 1, N'TEXT-1    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1881, 919, 2, N'TEXT-2    ', 8, CAST(59.00 AS Numeric(8, 2)), CAST(472.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1882, 919, 3, N'TEXT-3    ', 13, CAST(69.00 AS Numeric(8, 2)), CAST(897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1883, 919, 4, N'TEXT-4    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1884, 920, 1, N'RUNMTR    ', 13, CAST(79.00 AS Numeric(8, 2)), CAST(1027.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1885, 920, 2, N'POPUP     ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1886, 920, 3, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1887, 920, 5, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1888, 921, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1889, 921, 2, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1890, 921, 3, N'MENU      ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1891, 921, 4, N'DT        ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1892, 922, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1893, 922, 2, N'RUNMTR    ', 6, CAST(79.00 AS Numeric(8, 2)), CAST(474.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1894, 922, 3, N'TEXT-4    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1895, 922, 4, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1896, 923, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1897, 923, 2, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1898, 924, 1, N'MENU      ', 15, CAST(129.00 AS Numeric(8, 2)), CAST(1935.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1899, 924, 2, N'MODEMS    ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1900, 924, 3, N'TABLE-MAH ', 4, CAST(1250.00 AS Numeric(8, 2)), CAST(5000.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1901, 924, 4, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1902, 925, 1, N'PULLMAN   ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1903, 925, 2, N'TABLE     ', 10, CAST(179.00 AS Numeric(8, 2)), CAST(1790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1904, 926, 1, N'REPORTS   ', 16, CAST(179.00 AS Numeric(8, 2)), CAST(2864.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1905, 926, 2, N'CUA       ', 16, CAST(49.00 AS Numeric(8, 2)), CAST(784.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1906, 927, 1, N'UNIXGUIDE ', 16, CAST(499.00 AS Numeric(8, 2)), CAST(7984.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1907, 927, 2, N'GOLD-DLX  ', 13, CAST(1079.00 AS Numeric(8, 2)), CAST(14027.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1908, 928, 1, N'MODEMS    ', 13, CAST(129.00 AS Numeric(8, 2)), CAST(1677.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1909, 928, 2, N'REPORTS   ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1910, 928, 3, N'TEXT-2    ', 13, CAST(59.00 AS Numeric(8, 2)), CAST(767.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1911, 929, 1, N'TABLE-MPL ', 3, CAST(319.00 AS Numeric(8, 2)), CAST(957.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1912, 929, 2, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1913, 929, 3, N'UN-CL-1   ', 9, CAST(399.00 AS Numeric(8, 2)), CAST(3591.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1914, 930, 1, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1915, 930, 2, N'RUNMTR2   ', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1916, 930, 3, N'POPUP     ', 18, CAST(49.00 AS Numeric(8, 2)), CAST(882.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1917, 931, 1, N'JEWELRY-DL', 10, CAST(1749.00 AS Numeric(8, 2)), CAST(17490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1918, 931, 2, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1919, 931, 3, N'UN-CL-2   ', 6, CAST(659.00 AS Numeric(8, 2)), CAST(3954.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1920, 932, 2, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1921, 932, 3, N'JOKES     ', 8, CAST(12.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1922, 932, 4, N'TEXT-ALL  ', 4, CAST(595.00 AS Numeric(8, 2)), CAST(2380.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1923, 932, 5, N'UNIXGUIDE ', 5, CAST(499.00 AS Numeric(8, 2)), CAST(2495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1924, 933, 2, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1925, 933, 3, N'REPORTS II', 6, CAST(199.00 AS Numeric(8, 2)), CAST(1194.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1926, 934, 1, N'JEWELRY-DL', 6, CAST(1749.00 AS Numeric(8, 2)), CAST(10494.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1927, 934, 2, N'FLEX-O-MAT', 6, CAST(295.00 AS Numeric(8, 2)), CAST(1770.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1928, 935, 1, N'MENU      ', 7, CAST(129.00 AS Numeric(8, 2)), CAST(903.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1929, 935, 3, N'MAPS      ', 9, CAST(145.00 AS Numeric(8, 2)), CAST(1305.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1930, 936, 1, N'JEWELRY-I ', 9, CAST(1299.00 AS Numeric(8, 2)), CAST(11691.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1931, 937, 1, N'UN-CL-2   ', 5, CAST(659.00 AS Numeric(8, 2)), CAST(3295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1932, 937, 3, N'FLEX-O-MAT', 3, CAST(295.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1933, 938, 1, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1934, 938, 2, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1935, 938, 3, N'TEXT-1    ', 14, CAST(99.00 AS Numeric(8, 2)), CAST(1386.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1936, 939, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1937, 939, 3, N'DATES     ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1938, 939, 4, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1939, 939, 5, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1940, 940, 1, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1941, 940, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1942, 940, 3, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1943, 941, 1, N'GOLD      ', 3, CAST(779.00 AS Numeric(8, 2)), CAST(2337.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1944, 941, 2, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1945, 941, 3, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1946, 941, 4, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1947, 942, 1, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1948, 942, 2, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1949, 942, 3, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1950, 942, 4, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1951, 943, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1952, 943, 4, N'DT        ', 12, CAST(179.00 AS Numeric(8, 2)), CAST(2148.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1953, 944, 16, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1954, 944, 17, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1955, 945, 1, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1956, 945, 2, N'DATES     ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1957, 945, 3, N'DT PK     ', 10, CAST(229.00 AS Numeric(8, 2)), CAST(2290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1958, 945, 4, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1959, 946, 1, N'DT        ', 12, CAST(179.00 AS Numeric(8, 2)), CAST(2148.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1960, 946, 2, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1961, 946, 3, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1962, 946, 4, N'GOLD-DLX  ', 7, CAST(1079.00 AS Numeric(8, 2)), CAST(7553.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1963, 946, 5, N'TEXT-3    ', 5, CAST(69.00 AS Numeric(8, 2)), CAST(345.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1964, 946, 6, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1965, 947, 1, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1966, 947, 2, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1967, 947, 3, N'DATES     ', 12, CAST(29.00 AS Numeric(8, 2)), CAST(348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1968, 947, 4, N'CUA       ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1969, 947, 5, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1970, 948, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1971, 948, 2, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1972, 949, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1973, 949, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1974, 949, 3, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1975, 949, 4, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1976, 949, 5, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1977, 949, 10, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1978, 950, 1, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1979, 950, 4, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1980, 950, 5, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1981, 951, 1, N'DT        ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1982, 951, 2, N'DT PK     ', 11, CAST(229.00 AS Numeric(8, 2)), CAST(2519.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1983, 952, 1, N'CASE      ', 11, CAST(39.00 AS Numeric(8, 2)), CAST(429.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1984, 952, 2, N'DT        ', 14, CAST(179.00 AS Numeric(8, 2)), CAST(2506.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1985, 953, 1, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1986, 954, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1987, 954, 2, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1988, 955, 1, N'BRIDGE    ', 13, CAST(195.00 AS Numeric(8, 2)), CAST(2535.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1989, 955, 2, N'CITIES    ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1990, 956, 1, N'ACE1      ', 14, CAST(25.00 AS Numeric(8, 2)), CAST(350.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1991, 956, 2, N'ACE-2     ', 12, CAST(15.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1992, 957, 1, N'BEARS     ', 4, CAST(32.00 AS Numeric(8, 2)), CAST(128.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1993, 957, 2, N'GOLD      ', 4, CAST(779.00 AS Numeric(8, 2)), CAST(3116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1994, 958, 1, N'JEWELRY-DL', 14, CAST(1749.00 AS Numeric(8, 2)), CAST(24486.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1995, 959, 1, N'FLEX-O-MAT', 3, CAST(295.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1996, 960, 1, N'O''NEILLS  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1997, 960, 2, N'PICTURE   ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1998, 961, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (1999, 962, 1, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2000, 962, 2, N'CUA       ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2001, 962, 3, N'DT        ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2002, 963, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2003, 963, 2, N'POPUP     ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2004, 964, 1, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2005, 964, 2, N'OFFICE-2  ', 4, CAST(65.00 AS Numeric(8, 2)), CAST(260.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2006, 964, 3, N'OFFICE-S  ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2007, 965, 1, N'UPDATE    ', 9, CAST(19.00 AS Numeric(8, 2)), CAST(171.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2008, 965, 2, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2009, 965, 3, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2010, 965, 4, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2011, 965, 5, N'TEXT-4    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2012, 966, 1, N'VINO-LM   ', 13, CAST(5.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2013, 967, 1, N'UN-CL-1   ', 3, CAST(399.00 AS Numeric(8, 2)), CAST(1197.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2014, 967, 2, N'UN-CL-2   ', 8, CAST(659.00 AS Numeric(8, 2)), CAST(5272.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2015, 968, 1, N'UNIXGUIDE ', 8, CAST(499.00 AS Numeric(8, 2)), CAST(3992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2016, 969, 1, N'FLEX-O-MAT', 5, CAST(295.00 AS Numeric(8, 2)), CAST(1475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2017, 970, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2018, 970, 2, N'TABLE     ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2019, 971, 1, N'TABLE-MAH ', 6, CAST(1250.00 AS Numeric(8, 2)), CAST(7500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2020, 971, 2, N'TABLE-MPL ', 5, CAST(319.00 AS Numeric(8, 2)), CAST(1595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2021, 972, 1, N'JEWELRY-DL', 5, CAST(1749.00 AS Numeric(8, 2)), CAST(8745.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2022, 972, 2, N'JEWELRY-I ', 5, CAST(1299.00 AS Numeric(8, 2)), CAST(6495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2023, 973, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2024, 973, 2, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2025, 974, 1, N'MAPS      ', 5, CAST(145.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2026, 975, 1, N'PICTURE   ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2027, 975, 2, N'PULLMAN   ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2028, 976, 1, N'RUNMTR    ', 9, CAST(79.00 AS Numeric(8, 2)), CAST(711.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2029, 976, 2, N'RUNMTR2   ', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2030, 977, 1, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2031, 978, 1, N'JOKES     ', 8, CAST(12.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2032, 979, 1, N'REPORTS   ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2033, 979, 2, N'REPORTS II', 6, CAST(199.00 AS Numeric(8, 2)), CAST(1194.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2034, 980, 1, N'MAPS      ', 6, CAST(145.00 AS Numeric(8, 2)), CAST(870.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2035, 980, 2, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2036, 981, 1, N'BEARS     ', 7, CAST(32.00 AS Numeric(8, 2)), CAST(224.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2037, 981, 2, N'STARTREK  ', 7, CAST(1599.00 AS Numeric(8, 2)), CAST(11193.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2038, 982, 1, N'MAPS      ', 9, CAST(145.00 AS Numeric(8, 2)), CAST(1305.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2039, 983, 1, N'OFFICE-S  ', 10, CAST(19.00 AS Numeric(8, 2)), CAST(190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2040, 983, 2, N'OFFICE-2  ', 10, CAST(65.00 AS Numeric(8, 2)), CAST(650.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2041, 984, 1, N'MENU      ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2042, 985, 1, N'NITE-LITE ', 8, CAST(24.00 AS Numeric(8, 2)), CAST(192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2043, 985, 2, N'TABLE     ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2044, 985, 3, N'UPDATE    ', 18, CAST(19.00 AS Numeric(8, 2)), CAST(342.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2045, 986, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2046, 986, 2, N'OFFICE-1  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2047, 987, 1, N'BRIDGE    ', 3, CAST(195.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2048, 987, 2, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2049, 987, 3, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2050, 988, 1, N'UPDATE    ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2051, 988, 2, N'OFFICE-S  ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2052, 989, 1, N'TEXT-1    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2053, 989, 2, N'TEXT-2    ', 6, CAST(59.00 AS Numeric(8, 2)), CAST(354.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2054, 989, 3, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2055, 989, 4, N'TEXT-4    ', 9, CAST(99.00 AS Numeric(8, 2)), CAST(891.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2056, 989, 5, N'TEXT-ALL  ', 12, CAST(595.00 AS Numeric(8, 2)), CAST(7140.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2057, 990, 1, N'JOKES     ', 12, CAST(12.00 AS Numeric(8, 2)), CAST(144.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2058, 991, 1, N'ACE-2     ', 12, CAST(15.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2059, 991, 2, N'ACE1      ', 4, CAST(25.00 AS Numeric(8, 2)), CAST(100.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2060, 992, 1, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2061, 992, 2, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2062, 993, 1, N'OFFICE-1  ', 8, CAST(45.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2063, 993, 2, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2064, 993, 3, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2065, 994, 1, N'GOLD-DLX  ', 3, CAST(1079.00 AS Numeric(8, 2)), CAST(3237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2066, 995, 1, N'FLEX-O-MAT', 3, CAST(295.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2067, 996, 1, N'BRIDGE    ', 8, CAST(195.00 AS Numeric(8, 2)), CAST(1560.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2068, 996, 2, N'PICTURE   ', 14, CAST(29.00 AS Numeric(8, 2)), CAST(406.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2069, 996, 3, N'VINO-LM   ', 14, CAST(5.00 AS Numeric(8, 2)), CAST(70.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2070, 997, 1, N'DT PK     ', 14, CAST(229.00 AS Numeric(8, 2)), CAST(3206.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2071, 998, 1, N'TABLE     ', 14, CAST(179.00 AS Numeric(8, 2)), CAST(2506.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2072, 998, 2, N'TABLE-MAH ', 3, CAST(1250.00 AS Numeric(8, 2)), CAST(3750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2073, 998, 3, N'TABLE-MPL ', 9, CAST(319.00 AS Numeric(8, 2)), CAST(2871.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2074, 998, 4, N'OFFICE-1  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2075, 998, 5, N'OFFICE-2  ', 4, CAST(65.00 AS Numeric(8, 2)), CAST(260.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2076, 998, 6, N'OFFICE-S  ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2077, 999, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2078, 999, 2, N'CUA       ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2079, 1000, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2080, 1001, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2081, 1001, 2, N'POPUP     ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2082, 1001, 3, N'PULLMAN   ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2083, 1002, 1, N'TEXT-1    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2084, 1002, 2, N'TEXT-2    ', 8, CAST(59.00 AS Numeric(8, 2)), CAST(472.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2085, 1002, 3, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2086, 1002, 4, N'TEXT-4    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2087, 1002, 5, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2088, 1003, 1, N'MODEMS    ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2089, 1003, 2, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2090, 1004, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2091, 1005, 1, N'STARTREK  ', 6, CAST(1599.00 AS Numeric(8, 2)), CAST(9594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2092, 1006, 1, N'REPORTS II', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2093, 1007, 1, N'OFFICE-1  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2094, 1007, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2095, 1007, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2096, 1008, 1, N'UN-CL-1   ', 1, CAST(399.00 AS Numeric(8, 2)), CAST(399.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2097, 1008, 2, N'UN-CL-2   ', 4, CAST(659.00 AS Numeric(8, 2)), CAST(2636.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2098, 1008, 3, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2099, 1009, 1, N'RUNMTR    ', 4, CAST(79.00 AS Numeric(8, 2)), CAST(316.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2100, 1009, 2, N'RUNMTR2   ', 12, CAST(199.00 AS Numeric(8, 2)), CAST(2388.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2101, 1010, 1, N'O''NEILLS  ', 12, CAST(45.00 AS Numeric(8, 2)), CAST(540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2102, 1011, 1, N'GOLD      ', 12, CAST(779.00 AS Numeric(8, 2)), CAST(9348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2103, 1012, 1, N'CITIES    ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2104, 1012, 2, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2105, 1013, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2106, 1013, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2107, 1013, 3, N'UPDATE    ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2108, 1013, 4, N'VINO-LM   ', 7, CAST(5.00 AS Numeric(8, 2)), CAST(35.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2109, 1014, 1, N'POOL      ', 5, CAST(15.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2110, 1014, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2111, 1015, 1, N'FLEX-O-MAT', 8, CAST(295.00 AS Numeric(8, 2)), CAST(2360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2112, 1016, 1, N'BRIDGE    ', 8, CAST(195.00 AS Numeric(8, 2)), CAST(1560.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2113, 1016, 2, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2114, 1017, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2115, 1017, 2, N'OFFICE-2  ', 6, CAST(65.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2116, 1017, 3, N'REPORTS   ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2117, 1017, 4, N'VINO-LM   ', 6, CAST(5.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2118, 1018, 1, N'VINO-LM   ', 4, CAST(5.00 AS Numeric(8, 2)), CAST(20.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2119, 1019, 1, N'NITE-LITE ', 6, CAST(24.00 AS Numeric(8, 2)), CAST(144.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2120, 1019, 2, N'POPUP     ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2121, 1019, 3, N'STARTREK  ', 9, CAST(1599.00 AS Numeric(8, 2)), CAST(14391.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2122, 1020, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2123, 1020, 2, N'OFFICE-2  ', 6, CAST(65.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2124, 1020, 3, N'OFFICE-S  ', 14, CAST(19.00 AS Numeric(8, 2)), CAST(266.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2125, 1021, 1, N'PICTURE   ', 14, CAST(29.00 AS Numeric(8, 2)), CAST(406.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2126, 1022, 1, N'RUNMTR    ', 14, CAST(79.00 AS Numeric(8, 2)), CAST(1106.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2127, 1022, 2, N'RUNMTR2   ', 14, CAST(199.00 AS Numeric(8, 2)), CAST(2786.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2128, 1023, 1, N'MAPS      ', 3, CAST(145.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2129, 1024, 1, N'JOKES     ', 3, CAST(12.00 AS Numeric(8, 2)), CAST(36.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2130, 1024, 2, N'POOL      ', 10, CAST(15.00 AS Numeric(8, 2)), CAST(150.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2131, 1025, 1, N'VINO-LM   ', 3, CAST(5.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2132, 1026, 1, N'BEARS     ', 3, CAST(32.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2133, 1027, 1, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2134, 1028, 1, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2135, 1029, 1, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2136, 1029, 2, N'TEXT-2    ', 3, CAST(59.00 AS Numeric(8, 2)), CAST(177.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2137, 1029, 3, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2138, 1029, 4, N'TEXT-4    ', 11, CAST(99.00 AS Numeric(8, 2)), CAST(1089.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2139, 1030, 1, N'UN-CL-1   ', 8, CAST(399.00 AS Numeric(8, 2)), CAST(3192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2140, 1030, 2, N'UN-CL-2   ', 6, CAST(659.00 AS Numeric(8, 2)), CAST(3954.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2141, 1030, 3, N'UNIXGUIDE ', 5, CAST(499.00 AS Numeric(8, 2)), CAST(2495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2142, 1031, 1, N'CUA       ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2143, 1032, 1, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2144, 1033, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2145, 1034, 1, N'POOL      ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2146, 1035, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2147, 1035, 2, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2148, 1035, 3, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2149, 1036, 1, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2150, 1036, 2, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2151, 1036, 3, N'TEXT-3    ', 14, CAST(69.00 AS Numeric(8, 2)), CAST(966.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2152, 1036, 4, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2153, 1037, 1, N'RUNMTR    ', 4, CAST(79.00 AS Numeric(8, 2)), CAST(316.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2154, 1037, 2, N'POPUP     ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2155, 1037, 3, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2156, 1037, 5, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2157, 1038, 1, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2158, 1038, 2, N'CITIES    ', 15, CAST(49.00 AS Numeric(8, 2)), CAST(735.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2159, 1038, 3, N'MENU      ', 15, CAST(129.00 AS Numeric(8, 2)), CAST(1935.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2160, 1038, 4, N'DT        ', 15, CAST(179.00 AS Numeric(8, 2)), CAST(2685.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2161, 1039, 1, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2162, 1039, 2, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2163, 1039, 3, N'TEXT-4    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2164, 1039, 4, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2165, 1040, 1, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2166, 1040, 2, N'GOLD      ', 9, CAST(779.00 AS Numeric(8, 2)), CAST(7011.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2167, 1041, 1, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2168, 1041, 2, N'MODEMS    ', 11, CAST(129.00 AS Numeric(8, 2)), CAST(1419.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2169, 1041, 3, N'TABLE-MAH ', 17, CAST(1250.00 AS Numeric(8, 2)), CAST(21250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2170, 1041, 4, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2171, 1042, 1, N'PULLMAN   ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2172, 1042, 2, N'TABLE     ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2173, 1043, 1, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2174, 1043, 2, N'CUA       ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2175, 1044, 1, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2176, 1044, 2, N'GOLD-DLX  ', 5, CAST(1079.00 AS Numeric(8, 2)), CAST(5395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2177, 1045, 1, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2178, 1045, 2, N'REPORTS   ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2179, 1045, 3, N'TEXT-2    ', 5, CAST(59.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2180, 1046, 1, N'TABLE-MPL ', 10, CAST(319.00 AS Numeric(8, 2)), CAST(3190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2181, 1046, 2, N'JEWELRY-I ', 13, CAST(1299.00 AS Numeric(8, 2)), CAST(16887.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2182, 1046, 3, N'UN-CL-1   ', 11, CAST(399.00 AS Numeric(8, 2)), CAST(4389.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2183, 1047, 1, N'RUNMTR    ', 9, CAST(79.00 AS Numeric(8, 2)), CAST(711.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2184, 1047, 2, N'RUNMTR2   ', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2185, 1047, 3, N'POPUP     ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2186, 1048, 1, N'JEWELRY-DL', 6, CAST(1749.00 AS Numeric(8, 2)), CAST(10494.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2187, 1048, 2, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2188, 1048, 3, N'UN-CL-2   ', 7, CAST(659.00 AS Numeric(8, 2)), CAST(4613.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2189, 1049, 2, N'UPDATE    ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2190, 1049, 3, N'JOKES     ', 7, CAST(12.00 AS Numeric(8, 2)), CAST(84.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2191, 1049, 4, N'TEXT-ALL  ', 9, CAST(595.00 AS Numeric(8, 2)), CAST(5355.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2192, 1049, 5, N'UNIXGUIDE ', 7, CAST(499.00 AS Numeric(8, 2)), CAST(3493.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2193, 1050, 2, N'MODEMS    ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2194, 1050, 3, N'REPORTS II', 16, CAST(199.00 AS Numeric(8, 2)), CAST(3184.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2195, 1051, 1, N'JEWELRY-DL', 5, CAST(1749.00 AS Numeric(8, 2)), CAST(8745.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2196, 1051, 2, N'FLEX-O-MAT', 12, CAST(295.00 AS Numeric(8, 2)), CAST(3540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2197, 1052, 1, N'MENU      ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2198, 1052, 3, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2199, 1053, 1, N'JEWELRY-I ', 2, CAST(1299.00 AS Numeric(8, 2)), CAST(2598.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2200, 1054, 1, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2201, 1054, 3, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2202, 1055, 1, N'OFFICE-2  ', 9, CAST(65.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2203, 1055, 2, N'PULLMAN   ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2204, 1055, 3, N'TEXT-1    ', 9, CAST(99.00 AS Numeric(8, 2)), CAST(891.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2205, 1056, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2206, 1056, 3, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2207, 1056, 4, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2208, 1056, 5, N'TEXT-3    ', 8, CAST(69.00 AS Numeric(8, 2)), CAST(552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2209, 1057, 1, N'TEXT-ALL  ', 8, CAST(595.00 AS Numeric(8, 2)), CAST(4760.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2210, 1057, 2, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2211, 1057, 3, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2212, 1058, 1, N'GOLD      ', 14, CAST(779.00 AS Numeric(8, 2)), CAST(10906.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2213, 1058, 2, N'CASE      ', 15, CAST(39.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2214, 1058, 3, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2215, 1058, 4, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2216, 1059, 1, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2217, 1059, 2, N'MENU      ', 7, CAST(129.00 AS Numeric(8, 2)), CAST(903.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2218, 1059, 3, N'PICTURE   ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2219, 1059, 4, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2220, 1060, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2221, 1060, 4, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2222, 1061, 16, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2223, 1061, 17, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2224, 1062, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2225, 1062, 2, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2226, 1062, 3, N'DT PK     ', 5, CAST(229.00 AS Numeric(8, 2)), CAST(1145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2227, 1062, 4, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2228, 1063, 1, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2229, 1063, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2230, 1063, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2231, 1063, 4, N'GOLD-DLX  ', 1, CAST(1079.00 AS Numeric(8, 2)), CAST(1079.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2232, 1063, 5, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2233, 1063, 6, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2234, 1064, 1, N'TEXT-3    ', 11, CAST(69.00 AS Numeric(8, 2)), CAST(759.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2235, 1064, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2236, 1064, 3, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2237, 1064, 4, N'CUA       ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2238, 1064, 5, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2239, 1065, 1, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2240, 1065, 2, N'DT PK     ', 5, CAST(229.00 AS Numeric(8, 2)), CAST(1145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2241, 1066, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2242, 1066, 2, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2243, 1066, 3, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2244, 1066, 4, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2245, 1066, 5, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2246, 1066, 10, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2247, 1067, 1, N'BEARS     ', 4, CAST(30.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2248, 1067, 4, N'BEARS     ', 2, CAST(30.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2249, 1067, 5, N'VINO-LM   ', 4, CAST(5.00 AS Numeric(8, 2)), CAST(20.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2250, 1068, 1, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2251, 1068, 2, N'DT PK     ', 6, CAST(229.00 AS Numeric(8, 2)), CAST(1374.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2252, 1069, 1, N'CASE      ', 11, CAST(39.00 AS Numeric(8, 2)), CAST(429.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2253, 1069, 2, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2254, 1070, 1, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2255, 1071, 1, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2256, 1071, 2, N'CUA       ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2257, 1072, 1, N'BRIDGE    ', 8, CAST(195.00 AS Numeric(8, 2)), CAST(1560.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2258, 1072, 2, N'CITIES    ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2259, 1073, 1, N'ACE1      ', 9, CAST(25.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2260, 1073, 2, N'ACE-2     ', 9, CAST(15.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2261, 1074, 1, N'BEARS     ', 9, CAST(32.00 AS Numeric(8, 2)), CAST(288.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2262, 1074, 2, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2263, 1075, 1, N'JEWELRY-DL', 3, CAST(1749.00 AS Numeric(8, 2)), CAST(5247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2264, 1076, 1, N'FLEX-O-MAT', 6, CAST(295.00 AS Numeric(8, 2)), CAST(1770.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2265, 1077, 1, N'O''NEILLS  ', 6, CAST(45.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2266, 1077, 2, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2267, 1078, 1, N'MAPS      ', 7, CAST(145.00 AS Numeric(8, 2)), CAST(1015.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2268, 1079, 1, N'UPDATE    ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2269, 1079, 2, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2270, 1079, 3, N'DT        ', 14, CAST(179.00 AS Numeric(8, 2)), CAST(2506.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2271, 1080, 1, N'DATES     ', 14, CAST(29.00 AS Numeric(8, 2)), CAST(406.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2272, 1080, 2, N'POPUP     ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2273, 1081, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2274, 1081, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2275, 1081, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2276, 1082, 1, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2277, 1082, 2, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2278, 1082, 3, N'TEXT-2    ', 7, CAST(59.00 AS Numeric(8, 2)), CAST(413.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2279, 1082, 4, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2280, 1082, 5, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2281, 1083, 1, N'VINO-LM   ', 4, CAST(5.00 AS Numeric(8, 2)), CAST(20.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2282, 1084, 1, N'UN-CL-1   ', 4, CAST(399.00 AS Numeric(8, 2)), CAST(1596.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2283, 1084, 2, N'UN-CL-2   ', 2, CAST(659.00 AS Numeric(8, 2)), CAST(1318.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2284, 1085, 1, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2285, 1086, 1, N'FLEX-O-MAT', 2, CAST(295.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2286, 1087, 1, N'O''NEILLS  ', 10, CAST(45.00 AS Numeric(8, 2)), CAST(450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2287, 1087, 2, N'TABLE     ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2288, 1088, 1, N'TABLE-MAH ', 3, CAST(1250.00 AS Numeric(8, 2)), CAST(3750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2289, 1088, 2, N'TABLE-MPL ', 3, CAST(319.00 AS Numeric(8, 2)), CAST(957.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2290, 1089, 1, N'JEWELRY-DL', 8, CAST(1749.00 AS Numeric(8, 2)), CAST(13992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2291, 1089, 2, N'JEWELRY-I ', 8, CAST(1299.00 AS Numeric(8, 2)), CAST(10392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2292, 1090, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2293, 1090, 2, N'DT PK     ', 6, CAST(229.00 AS Numeric(8, 2)), CAST(1374.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2294, 1091, 1, N'MAPS      ', 8, CAST(145.00 AS Numeric(8, 2)), CAST(1160.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2295, 1092, 1, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2296, 1092, 2, N'PULLMAN   ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2297, 1093, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2298, 1093, 2, N'RUNMTR2   ', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2299, 1094, 1, N'OFFICE-S  ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2300, 1095, 1, N'JOKES     ', 7, CAST(12.00 AS Numeric(8, 2)), CAST(84.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2301, 1096, 1, N'REPORTS   ', 15, CAST(179.00 AS Numeric(8, 2)), CAST(2685.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2302, 1096, 2, N'REPORTS II', 11, CAST(199.00 AS Numeric(8, 2)), CAST(2189.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2303, 1097, 1, N'MAPS      ', 11, CAST(145.00 AS Numeric(8, 2)), CAST(1595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2304, 1097, 2, N'CITIES    ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2305, 1098, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2306, 1098, 2, N'STARTREK  ', 1, CAST(1599.00 AS Numeric(8, 2)), CAST(1599.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2307, 1099, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2308, 1100, 1, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2309, 1100, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2310, 1101, 1, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2311, 1102, 1, N'NITE-LITE ', 9, CAST(24.00 AS Numeric(8, 2)), CAST(216.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2312, 1102, 2, N'TABLE     ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2313, 1102, 3, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2314, 1103, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2315, 1103, 2, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2316, 1104, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2317, 1104, 2, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2318, 1104, 3, N'PICTURE   ', 15, CAST(29.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2319, 1105, 1, N'UPDATE    ', 15, CAST(19.00 AS Numeric(8, 2)), CAST(285.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2320, 1105, 2, N'OFFICE-S  ', 15, CAST(19.00 AS Numeric(8, 2)), CAST(285.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2321, 1106, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2322, 1106, 2, N'TEXT-2    ', 7, CAST(59.00 AS Numeric(8, 2)), CAST(413.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2323, 1106, 3, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2324, 1106, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2325, 1106, 5, N'TEXT-ALL  ', 7, CAST(595.00 AS Numeric(8, 2)), CAST(4165.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2326, 1107, 1, N'JOKES     ', 7, CAST(12.00 AS Numeric(8, 2)), CAST(84.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2327, 1108, 1, N'ACE-2     ', 4, CAST(15.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2328, 1108, 2, N'ACE1      ', 5, CAST(25.00 AS Numeric(8, 2)), CAST(125.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2329, 1109, 1, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2330, 1109, 2, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2331, 1110, 1, N'OFFICE-1  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2332, 1110, 2, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2333, 1110, 3, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2334, 1111, 1, N'GOLD-DLX  ', 1, CAST(1079.00 AS Numeric(8, 2)), CAST(1079.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2335, 1112, 1, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2336, 1113, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2337, 1113, 2, N'PICTURE   ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2338, 1113, 3, N'VINO-LM   ', 11, CAST(5.00 AS Numeric(8, 2)), CAST(55.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2339, 1114, 1, N'DT PK     ', 11, CAST(229.00 AS Numeric(8, 2)), CAST(2519.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2340, 1115, 1, N'TABLE     ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2341, 1115, 2, N'TABLE-MAH ', 10, CAST(1250.00 AS Numeric(8, 2)), CAST(12500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2342, 1115, 3, N'TABLE-MPL ', 10, CAST(319.00 AS Numeric(8, 2)), CAST(3190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2343, 1115, 4, N'OFFICE-1  ', 10, CAST(45.00 AS Numeric(8, 2)), CAST(450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2344, 1115, 5, N'OFFICE-2  ', 13, CAST(65.00 AS Numeric(8, 2)), CAST(845.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2345, 1115, 6, N'OFFICE-S  ', 13, CAST(19.00 AS Numeric(8, 2)), CAST(247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2346, 1116, 1, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2347, 1116, 2, N'CUA       ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2348, 1117, 1, N'BRIDGE    ', 10, CAST(195.00 AS Numeric(8, 2)), CAST(1950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2349, 1118, 1, N'O''NEILLS  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2350, 1118, 2, N'POPUP     ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2351, 1118, 3, N'PULLMAN   ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2352, 1119, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2353, 1119, 2, N'TEXT-2    ', 13, CAST(59.00 AS Numeric(8, 2)), CAST(767.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2354, 1119, 3, N'TEXT-3    ', 13, CAST(69.00 AS Numeric(8, 2)), CAST(897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2355, 1119, 4, N'TEXT-4    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2356, 1119, 5, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2357, 1120, 1, N'MODEMS    ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2358, 1120, 2, N'REPORTS   ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2359, 1121, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2360, 1122, 1, N'STARTREK  ', 1, CAST(1599.00 AS Numeric(8, 2)), CAST(1599.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2361, 1123, 1, N'REPORTS II', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2362, 1124, 1, N'OFFICE-1  ', 12, CAST(45.00 AS Numeric(8, 2)), CAST(540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2363, 1124, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2364, 1124, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2365, 1125, 1, N'UN-CL-1   ', 1, CAST(399.00 AS Numeric(8, 2)), CAST(399.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2366, 1125, 2, N'UN-CL-2   ', 8, CAST(659.00 AS Numeric(8, 2)), CAST(5272.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2367, 1125, 3, N'UNIXGUIDE ', 5, CAST(499.00 AS Numeric(8, 2)), CAST(2495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2368, 1126, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2369, 1126, 2, N'RUNMTR2   ', 11, CAST(199.00 AS Numeric(8, 2)), CAST(2189.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2370, 1127, 1, N'O''NEILLS  ', 13, CAST(45.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2371, 1128, 1, N'GOLD      ', 13, CAST(779.00 AS Numeric(8, 2)), CAST(10127.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2372, 1129, 1, N'CITIES    ', 18, CAST(49.00 AS Numeric(8, 2)), CAST(882.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2373, 1129, 2, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2374, 1130, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2375, 1130, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2376, 1130, 3, N'UPDATE    ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2377, 1130, 4, N'VINO-LM   ', 5, CAST(5.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2378, 1131, 1, N'POOL      ', 16, CAST(15.00 AS Numeric(8, 2)), CAST(240.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2379, 1131, 2, N'POPUP     ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2380, 1132, 1, N'FLEX-O-MAT', 18, CAST(295.00 AS Numeric(8, 2)), CAST(5310.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2381, 1133, 1, N'BRIDGE    ', 18, CAST(195.00 AS Numeric(8, 2)), CAST(3510.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2382, 1133, 2, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2383, 1134, 1, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2384, 1134, 2, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2385, 1134, 3, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2386, 1134, 4, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2387, 1135, 1, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2388, 1136, 1, N'NITE-LITE ', 4, CAST(24.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2389, 1136, 2, N'POPUP     ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2390, 1136, 3, N'STARTREK  ', 5, CAST(1599.00 AS Numeric(8, 2)), CAST(7995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2391, 1137, 1, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2392, 1137, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2393, 1137, 3, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2394, 1138, 1, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2395, 1139, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2396, 1139, 2, N'RUNMTR2   ', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2397, 1140, 1, N'MAPS      ', 8, CAST(145.00 AS Numeric(8, 2)), CAST(1160.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2398, 1141, 1, N'JOKES     ', 2, CAST(12.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2399, 1141, 2, N'POOL      ', 5, CAST(15.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2400, 1142, 1, N'VINO-LM   ', 5, CAST(5.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2401, 1143, 1, N'BEARS     ', 3, CAST(32.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2402, 1144, 1, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2403, 1145, 1, N'TEXT-ALL  ', 7, CAST(595.00 AS Numeric(8, 2)), CAST(4165.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2404, 1146, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2405, 1146, 2, N'TEXT-2    ', 9, CAST(59.00 AS Numeric(8, 2)), CAST(531.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2406, 1146, 3, N'TEXT-3    ', 9, CAST(69.00 AS Numeric(8, 2)), CAST(621.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2407, 1146, 4, N'TEXT-4    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2408, 1147, 1, N'UN-CL-1   ', 1, CAST(399.00 AS Numeric(8, 2)), CAST(399.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2409, 1147, 2, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2410, 1147, 3, N'UNIXGUIDE ', 9, CAST(499.00 AS Numeric(8, 2)), CAST(4491.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2411, 1148, 1, N'CUA       ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2412, 1149, 1, N'PICTURE   ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2413, 1150, 1, N'BRIDGE    ', 3, CAST(195.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2414, 1151, 1, N'POOL      ', 5, CAST(15.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2415, 1152, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2416, 1152, 2, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2417, 1152, 3, N'DT PK     ', 7, CAST(229.00 AS Numeric(8, 2)), CAST(1603.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2418, 1153, 1, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2419, 1153, 2, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2420, 1153, 3, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2421, 1153, 4, N'TEXT-4    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2422, 1154, 1, N'RUNMTR    ', 18, CAST(79.00 AS Numeric(8, 2)), CAST(1422.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2423, 1154, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2424, 1154, 3, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2425, 1154, 5, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2426, 1155, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2427, 1155, 2, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2428, 1155, 3, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2429, 1155, 4, N'DT        ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2430, 1156, 1, N'DATES     ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2431, 1156, 2, N'RUNMTR    ', 10, CAST(79.00 AS Numeric(8, 2)), CAST(790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2432, 1156, 3, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2433, 1156, 4, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2434, 1157, 1, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2435, 1157, 2, N'GOLD      ', 9, CAST(779.00 AS Numeric(8, 2)), CAST(7011.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2436, 1158, 1, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2437, 1158, 2, N'MODEMS    ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2438, 1158, 3, N'TABLE-MAH ', 13, CAST(1250.00 AS Numeric(8, 2)), CAST(16250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2439, 1158, 4, N'REPORTS   ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2440, 1159, 1, N'PULLMAN   ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2441, 1159, 2, N'TABLE     ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2442, 1160, 1, N'REPORTS   ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2443, 1160, 2, N'CUA       ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2444, 1161, 1, N'UNIXGUIDE ', 7, CAST(499.00 AS Numeric(8, 2)), CAST(3493.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2445, 1161, 2, N'GOLD-DLX  ', 4, CAST(1079.00 AS Numeric(8, 2)), CAST(4316.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2446, 1162, 1, N'MODEMS    ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2447, 1162, 2, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2448, 1162, 3, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2449, 1163, 1, N'TABLE-MPL ', 1, CAST(319.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2450, 1163, 2, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2451, 1163, 3, N'UN-CL-1   ', 6, CAST(399.00 AS Numeric(8, 2)), CAST(2394.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2452, 1164, 1, N'RUNMTR    ', 8, CAST(79.00 AS Numeric(8, 2)), CAST(632.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2453, 1164, 2, N'RUNMTR2   ', 18, CAST(199.00 AS Numeric(8, 2)), CAST(3582.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2454, 1164, 3, N'POPUP     ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2455, 1165, 1, N'JEWELRY-DL', 8, CAST(1749.00 AS Numeric(8, 2)), CAST(13992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2456, 1165, 2, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2457, 1165, 3, N'UN-CL-2   ', 8, CAST(659.00 AS Numeric(8, 2)), CAST(5272.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2458, 1166, 2, N'UPDATE    ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2459, 1166, 3, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2460, 1166, 4, N'TEXT-ALL  ', 7, CAST(595.00 AS Numeric(8, 2)), CAST(4165.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2461, 1166, 5, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2462, 1167, 2, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2463, 1167, 3, N'REPORTS II', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2464, 1168, 1, N'JEWELRY-DL', 5, CAST(1749.00 AS Numeric(8, 2)), CAST(8745.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2465, 1168, 2, N'FLEX-O-MAT', 7, CAST(295.00 AS Numeric(8, 2)), CAST(2065.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2466, 1169, 1, N'MENU      ', 7, CAST(129.00 AS Numeric(8, 2)), CAST(903.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2467, 1169, 3, N'MAPS      ', 11, CAST(145.00 AS Numeric(8, 2)), CAST(1595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2468, 1170, 1, N'JEWELRY-I ', 6, CAST(1299.00 AS Numeric(8, 2)), CAST(7794.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2469, 1171, 1, N'UN-CL-2   ', 7, CAST(659.00 AS Numeric(8, 2)), CAST(4613.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2470, 1171, 3, N'FLEX-O-MAT', 7, CAST(295.00 AS Numeric(8, 2)), CAST(2065.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2471, 1172, 1, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2472, 1172, 2, N'PULLMAN   ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2473, 1172, 3, N'TEXT-1    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2474, 1173, 2, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2475, 1173, 3, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2476, 1173, 4, N'PICTURE   ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2477, 1173, 5, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2478, 1174, 1, N'TEXT-ALL  ', 4, CAST(595.00 AS Numeric(8, 2)), CAST(2380.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2479, 1174, 2, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2480, 1174, 3, N'CUA       ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2481, 1175, 1, N'GOLD      ', 5, CAST(779.00 AS Numeric(8, 2)), CAST(3895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2482, 1175, 2, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2483, 1175, 3, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2484, 1175, 4, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2485, 1176, 1, N'CITIES    ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2486, 1176, 2, N'MENU      ', 14, CAST(129.00 AS Numeric(8, 2)), CAST(1806.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2487, 1176, 3, N'PICTURE   ', 14, CAST(29.00 AS Numeric(8, 2)), CAST(406.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2488, 1176, 4, N'DT PK     ', 10, CAST(229.00 AS Numeric(8, 2)), CAST(2290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2489, 1177, 2, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2490, 1177, 4, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2491, 1178, 16, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2492, 1178, 17, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2493, 1179, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2494, 1179, 2, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2495, 1179, 3, N'DT PK     ', 7, CAST(229.00 AS Numeric(8, 2)), CAST(1603.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2496, 1179, 4, N'MENU      ', 14, CAST(129.00 AS Numeric(8, 2)), CAST(1806.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2497, 1180, 1, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2498, 1180, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2499, 1180, 3, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2500, 1180, 4, N'GOLD-DLX  ', 11, CAST(1079.00 AS Numeric(8, 2)), CAST(11869.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2501, 1180, 5, N'TEXT-3    ', 5, CAST(69.00 AS Numeric(8, 2)), CAST(345.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2502, 1180, 6, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2503, 1181, 1, N'TEXT-3    ', 5, CAST(69.00 AS Numeric(8, 2)), CAST(345.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2504, 1181, 2, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2505, 1181, 3, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2506, 1181, 4, N'CUA       ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2507, 1181, 5, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2508, 1182, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2509, 1182, 2, N'DT PK     ', 5, CAST(229.00 AS Numeric(8, 2)), CAST(1145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2510, 1183, 1, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2511, 1183, 2, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2512, 1183, 3, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2513, 1183, 4, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2514, 1183, 5, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2515, 1183, 10, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2516, 1184, 1, N'BEARS     ', 7, CAST(30.00 AS Numeric(8, 2)), CAST(210.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2517, 1184, 4, N'BEARS     ', 7, CAST(30.00 AS Numeric(8, 2)), CAST(210.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2518, 1184, 5, N'VINO-LM   ', 4, CAST(5.00 AS Numeric(8, 2)), CAST(20.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2519, 1185, 1, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2520, 1185, 2, N'DT PK     ', 2, CAST(229.00 AS Numeric(8, 2)), CAST(458.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2521, 1186, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2522, 1186, 2, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2523, 1187, 1, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2524, 1188, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2525, 1188, 2, N'CUA       ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2526, 1189, 1, N'BRIDGE    ', 9, CAST(195.00 AS Numeric(8, 2)), CAST(1755.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2527, 1189, 2, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2528, 1190, 1, N'ACE1      ', 8, CAST(25.00 AS Numeric(8, 2)), CAST(200.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2529, 1190, 2, N'ACE-2     ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2530, 1191, 1, N'BEARS     ', 10, CAST(32.00 AS Numeric(8, 2)), CAST(320.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2531, 1191, 2, N'GOLD      ', 10, CAST(779.00 AS Numeric(8, 2)), CAST(7790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2532, 1192, 1, N'JEWELRY-DL', 7, CAST(1749.00 AS Numeric(8, 2)), CAST(12243.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2533, 1193, 1, N'FLEX-O-MAT', 4, CAST(295.00 AS Numeric(8, 2)), CAST(1180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2534, 1194, 1, N'O''NEILLS  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2535, 1194, 2, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2536, 1195, 1, N'MAPS      ', 4, CAST(145.00 AS Numeric(8, 2)), CAST(580.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2537, 1196, 1, N'UPDATE    ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2538, 1196, 2, N'CUA       ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2539, 1196, 3, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2540, 1197, 1, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2541, 1197, 2, N'POPUP     ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2542, 1198, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2543, 1198, 2, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2544, 1198, 3, N'OFFICE-S  ', 14, CAST(19.00 AS Numeric(8, 2)), CAST(266.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2545, 1199, 1, N'UPDATE    ', 15, CAST(19.00 AS Numeric(8, 2)), CAST(285.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2546, 1199, 2, N'TEXT-1    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2547, 1199, 3, N'TEXT-2    ', 5, CAST(59.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2548, 1199, 4, N'TEXT-3    ', 13, CAST(69.00 AS Numeric(8, 2)), CAST(897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2549, 1199, 5, N'TEXT-4    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2550, 1200, 1, N'VINO-LM   ', 13, CAST(5.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2551, 1201, 1, N'UN-CL-1   ', 5, CAST(399.00 AS Numeric(8, 2)), CAST(1995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2552, 1201, 2, N'UN-CL-2   ', 7, CAST(659.00 AS Numeric(8, 2)), CAST(4613.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2553, 1202, 1, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2554, 1203, 1, N'FLEX-O-MAT', 8, CAST(295.00 AS Numeric(8, 2)), CAST(2360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2555, 1204, 1, N'O''NEILLS  ', 8, CAST(45.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2556, 1204, 2, N'TABLE     ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2557, 1205, 1, N'TABLE-MAH ', 1, CAST(1250.00 AS Numeric(8, 2)), CAST(1250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2558, 1205, 2, N'TABLE-MPL ', 6, CAST(319.00 AS Numeric(8, 2)), CAST(1914.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2559, 1206, 1, N'JEWELRY-DL', 2, CAST(1749.00 AS Numeric(8, 2)), CAST(3498.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2560, 1206, 2, N'JEWELRY-I ', 2, CAST(1299.00 AS Numeric(8, 2)), CAST(2598.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2561, 1207, 1, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2562, 1207, 2, N'DT PK     ', 7, CAST(229.00 AS Numeric(8, 2)), CAST(1603.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2563, 1208, 1, N'MAPS      ', 4, CAST(145.00 AS Numeric(8, 2)), CAST(580.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2564, 1209, 1, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2565, 1209, 2, N'PULLMAN   ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2566, 1210, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2567, 1210, 2, N'RUNMTR2   ', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2568, 1211, 1, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2569, 1212, 1, N'JOKES     ', 9, CAST(12.00 AS Numeric(8, 2)), CAST(108.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2570, 1213, 1, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2571, 1213, 2, N'REPORTS II', 6, CAST(199.00 AS Numeric(8, 2)), CAST(1194.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2572, 1214, 1, N'MAPS      ', 6, CAST(145.00 AS Numeric(8, 2)), CAST(870.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2573, 1214, 2, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2574, 1215, 1, N'BEARS     ', 9, CAST(32.00 AS Numeric(8, 2)), CAST(288.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2575, 1215, 2, N'STARTREK  ', 7, CAST(1599.00 AS Numeric(8, 2)), CAST(11193.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2576, 1216, 1, N'MAPS      ', 12, CAST(145.00 AS Numeric(8, 2)), CAST(1740.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2577, 1217, 1, N'OFFICE-S  ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2578, 1217, 2, N'OFFICE-2  ', 13, CAST(65.00 AS Numeric(8, 2)), CAST(845.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2579, 1218, 1, N'MENU      ', 12, CAST(129.00 AS Numeric(8, 2)), CAST(1548.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2580, 1219, 1, N'NITE-LITE ', 2, CAST(24.00 AS Numeric(8, 2)), CAST(48.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2581, 1219, 2, N'TABLE     ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2582, 1219, 3, N'UPDATE    ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2583, 1220, 1, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2584, 1220, 2, N'OFFICE-1  ', 8, CAST(45.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2585, 1221, 1, N'BRIDGE    ', 4, CAST(195.00 AS Numeric(8, 2)), CAST(780.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2586, 1221, 2, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2587, 1221, 3, N'PICTURE   ', 17, CAST(29.00 AS Numeric(8, 2)), CAST(493.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2588, 1222, 1, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2589, 1222, 2, N'OFFICE-S  ', 12, CAST(19.00 AS Numeric(8, 2)), CAST(228.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2590, 1223, 1, N'TEXT-1    ', 12, CAST(99.00 AS Numeric(8, 2)), CAST(1188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2591, 1223, 2, N'TEXT-2    ', 7, CAST(59.00 AS Numeric(8, 2)), CAST(413.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2592, 1223, 3, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2593, 1223, 4, N'TEXT-4    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2594, 1223, 5, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2595, 1224, 1, N'JOKES     ', 5, CAST(12.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2596, 1225, 1, N'ACE-2     ', 3, CAST(15.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2597, 1225, 2, N'ACE1      ', 4, CAST(25.00 AS Numeric(8, 2)), CAST(100.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2598, 1226, 1, N'DATES     ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2599, 1226, 2, N'DT        ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
GO
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2600, 1227, 1, N'OFFICE-1  ', 11, CAST(45.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2601, 1227, 2, N'OFFICE-2  ', 11, CAST(65.00 AS Numeric(8, 2)), CAST(715.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2602, 1227, 3, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2603, 1228, 1, N'GOLD-DLX  ', 3, CAST(1079.00 AS Numeric(8, 2)), CAST(3237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2604, 1229, 1, N'FLEX-O-MAT', 5, CAST(295.00 AS Numeric(8, 2)), CAST(1475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2605, 1230, 1, N'BRIDGE    ', 3, CAST(195.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2606, 1230, 2, N'PICTURE   ', 13, CAST(29.00 AS Numeric(8, 2)), CAST(377.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2607, 1230, 3, N'VINO-LM   ', 7, CAST(5.00 AS Numeric(8, 2)), CAST(35.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2608, 1231, 1, N'DT PK     ', 7, CAST(229.00 AS Numeric(8, 2)), CAST(1603.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2609, 1232, 1, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2610, 1232, 2, N'TABLE-MAH ', 15, CAST(1250.00 AS Numeric(8, 2)), CAST(18750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2611, 1232, 3, N'TABLE-MPL ', 5, CAST(319.00 AS Numeric(8, 2)), CAST(1595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2612, 1232, 4, N'OFFICE-1  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2613, 1232, 5, N'OFFICE-2  ', 9, CAST(65.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2614, 1232, 6, N'OFFICE-S  ', 9, CAST(19.00 AS Numeric(8, 2)), CAST(171.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2615, 1233, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2616, 1233, 2, N'CUA       ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2617, 1234, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2618, 1235, 1, N'O''NEILLS  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2619, 1235, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2620, 1235, 3, N'PULLMAN   ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2621, 1236, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2622, 1236, 2, N'TEXT-2    ', 7, CAST(59.00 AS Numeric(8, 2)), CAST(413.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2623, 1236, 3, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2624, 1236, 4, N'TEXT-4    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2625, 1236, 5, N'TEXT-ALL  ', 8, CAST(595.00 AS Numeric(8, 2)), CAST(4760.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2626, 1237, 1, N'MODEMS    ', 13, CAST(129.00 AS Numeric(8, 2)), CAST(1677.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2627, 1237, 2, N'REPORTS   ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2628, 1238, 1, N'JEWELRY-I ', 12, CAST(1299.00 AS Numeric(8, 2)), CAST(15588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2629, 1239, 1, N'STARTREK  ', 12, CAST(1599.00 AS Numeric(8, 2)), CAST(19188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2630, 1240, 1, N'REPORTS II', 4, CAST(199.00 AS Numeric(8, 2)), CAST(796.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2631, 1241, 1, N'OFFICE-1  ', 9, CAST(45.00 AS Numeric(8, 2)), CAST(405.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2632, 1241, 2, N'OFFICE-2  ', 9, CAST(65.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2633, 1241, 3, N'OFFICE-S  ', 13, CAST(19.00 AS Numeric(8, 2)), CAST(247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2634, 1242, 1, N'UN-CL-1   ', 3, CAST(399.00 AS Numeric(8, 2)), CAST(1197.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2635, 1242, 2, N'UN-CL-2   ', 3, CAST(659.00 AS Numeric(8, 2)), CAST(1977.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2636, 1242, 3, N'UNIXGUIDE ', 12, CAST(499.00 AS Numeric(8, 2)), CAST(5988.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2637, 1243, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2638, 1243, 2, N'RUNMTR2   ', 4, CAST(199.00 AS Numeric(8, 2)), CAST(796.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2639, 1244, 1, N'O''NEILLS  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2640, 1245, 1, N'GOLD      ', 12, CAST(779.00 AS Numeric(8, 2)), CAST(9348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2641, 1246, 1, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2642, 1246, 2, N'MAPS      ', 6, CAST(145.00 AS Numeric(8, 2)), CAST(870.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2643, 1247, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2644, 1247, 2, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2645, 1247, 3, N'UPDATE    ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2646, 1247, 4, N'VINO-LM   ', 4, CAST(5.00 AS Numeric(8, 2)), CAST(20.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2647, 1248, 1, N'POOL      ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2648, 1248, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2649, 1249, 1, N'FLEX-O-MAT', 7, CAST(295.00 AS Numeric(8, 2)), CAST(2065.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2650, 1250, 1, N'BRIDGE    ', 7, CAST(195.00 AS Numeric(8, 2)), CAST(1365.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2651, 1250, 2, N'DATES     ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2652, 1251, 1, N'MENU      ', 10, CAST(129.00 AS Numeric(8, 2)), CAST(1290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2653, 1251, 2, N'OFFICE-2  ', 10, CAST(65.00 AS Numeric(8, 2)), CAST(650.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2654, 1251, 3, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2655, 1251, 4, N'VINO-LM   ', 3, CAST(5.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2656, 1252, 1, N'VINO-LM   ', 3, CAST(5.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2657, 1253, 1, N'NITE-LITE ', 3, CAST(24.00 AS Numeric(8, 2)), CAST(72.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2658, 1253, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2659, 1253, 3, N'STARTREK  ', 4, CAST(1599.00 AS Numeric(8, 2)), CAST(6396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2660, 1254, 1, N'OFFICE-1  ', 6, CAST(45.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2661, 1254, 2, N'OFFICE-2  ', 6, CAST(65.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2662, 1254, 3, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2663, 1255, 1, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2664, 1256, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2665, 1256, 2, N'RUNMTR2   ', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2666, 1257, 1, N'MAPS      ', 8, CAST(145.00 AS Numeric(8, 2)), CAST(1160.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2667, 1258, 1, N'JOKES     ', 2, CAST(12.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2668, 1258, 2, N'POOL      ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2669, 1259, 1, N'VINO-LM   ', 13, CAST(5.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2670, 1260, 1, N'BEARS     ', 11, CAST(32.00 AS Numeric(8, 2)), CAST(352.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2671, 1261, 1, N'CITIES    ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2672, 1262, 1, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2673, 1263, 1, N'TEXT-1    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2674, 1263, 2, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2675, 1263, 3, N'TEXT-3    ', 14, CAST(69.00 AS Numeric(8, 2)), CAST(966.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2676, 1263, 4, N'TEXT-4    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2677, 1264, 1, N'UN-CL-1   ', 13, CAST(399.00 AS Numeric(8, 2)), CAST(5187.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2678, 1264, 2, N'UN-CL-2   ', 7, CAST(659.00 AS Numeric(8, 2)), CAST(4613.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2679, 1264, 3, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2680, 1265, 1, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2681, 1266, 1, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2682, 1267, 1, N'BRIDGE    ', 6, CAST(195.00 AS Numeric(8, 2)), CAST(1170.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2683, 1268, 1, N'POOL      ', 6, CAST(15.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2684, 1269, 1, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2685, 1269, 2, N'DT        ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2686, 1269, 3, N'DT PK     ', 2, CAST(229.00 AS Numeric(8, 2)), CAST(458.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2687, 1270, 1, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2688, 1270, 2, N'TEXT-2    ', 12, CAST(59.00 AS Numeric(8, 2)), CAST(708.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2689, 1270, 3, N'TEXT-3    ', 12, CAST(69.00 AS Numeric(8, 2)), CAST(828.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2690, 1270, 4, N'TEXT-4    ', 11, CAST(99.00 AS Numeric(8, 2)), CAST(1089.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2691, 1271, 1, N'RUNMTR    ', 9, CAST(79.00 AS Numeric(8, 2)), CAST(711.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2692, 1271, 2, N'POPUP     ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2693, 1271, 3, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2694, 1271, 5, N'MENU      ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2695, 1272, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2696, 1272, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2697, 1272, 3, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2698, 1272, 4, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2699, 1273, 1, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2700, 1273, 2, N'RUNMTR    ', 2, CAST(79.00 AS Numeric(8, 2)), CAST(158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2701, 1273, 3, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2702, 1273, 4, N'REPORTS   ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2703, 1274, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2704, 1274, 2, N'GOLD      ', 4, CAST(779.00 AS Numeric(8, 2)), CAST(3116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2705, 1275, 1, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2706, 1275, 2, N'MODEMS    ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2707, 1275, 3, N'TABLE-MAH ', 2, CAST(1250.00 AS Numeric(8, 2)), CAST(2500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2708, 1275, 4, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2709, 1276, 1, N'PULLMAN   ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2710, 1276, 2, N'TABLE     ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2711, 1277, 1, N'REPORTS   ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2712, 1277, 2, N'CUA       ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2713, 1278, 1, N'UNIXGUIDE ', 6, CAST(499.00 AS Numeric(8, 2)), CAST(2994.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2714, 1278, 2, N'GOLD-DLX  ', 6, CAST(1079.00 AS Numeric(8, 2)), CAST(6474.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2715, 1279, 1, N'MODEMS    ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2716, 1279, 2, N'REPORTS   ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2717, 1279, 3, N'TEXT-2    ', 6, CAST(59.00 AS Numeric(8, 2)), CAST(354.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2718, 1280, 1, N'TABLE-MPL ', 10, CAST(319.00 AS Numeric(8, 2)), CAST(3190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2719, 1280, 2, N'JEWELRY-I ', 5, CAST(1299.00 AS Numeric(8, 2)), CAST(6495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2720, 1280, 3, N'UN-CL-1   ', 10, CAST(399.00 AS Numeric(8, 2)), CAST(3990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2721, 1281, 1, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2722, 1281, 2, N'RUNMTR2   ', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2723, 1281, 3, N'POPUP     ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2724, 1282, 1, N'JEWELRY-DL', 6, CAST(1749.00 AS Numeric(8, 2)), CAST(10494.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2725, 1282, 2, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2726, 1282, 3, N'UN-CL-2   ', 7, CAST(659.00 AS Numeric(8, 2)), CAST(4613.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2727, 1283, 2, N'UPDATE    ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2728, 1283, 3, N'JOKES     ', 8, CAST(12.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2729, 1283, 4, N'TEXT-ALL  ', 8, CAST(595.00 AS Numeric(8, 2)), CAST(4760.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2730, 1283, 5, N'UNIXGUIDE ', 8, CAST(499.00 AS Numeric(8, 2)), CAST(3992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2731, 1284, 2, N'MODEMS    ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2732, 1284, 3, N'REPORTS II', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2733, 1285, 1, N'JEWELRY-DL', 14, CAST(1749.00 AS Numeric(8, 2)), CAST(24486.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2734, 1285, 2, N'FLEX-O-MAT', 14, CAST(295.00 AS Numeric(8, 2)), CAST(4130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2735, 1286, 1, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2736, 1286, 3, N'MAPS      ', 6, CAST(145.00 AS Numeric(8, 2)), CAST(870.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2737, 1287, 1, N'JEWELRY-I ', 6, CAST(1299.00 AS Numeric(8, 2)), CAST(7794.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2738, 1288, 1, N'UN-CL-2   ', 7, CAST(659.00 AS Numeric(8, 2)), CAST(4613.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2739, 1288, 3, N'FLEX-O-MAT', 2, CAST(295.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2740, 1289, 1, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2741, 1289, 2, N'PULLMAN   ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2742, 1289, 3, N'TEXT-1    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2743, 1290, 2, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2744, 1290, 3, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2745, 1290, 4, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2746, 1290, 5, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2747, 1291, 1, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2748, 1291, 2, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2749, 1291, 3, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2750, 1292, 1, N'GOLD      ', 3, CAST(779.00 AS Numeric(8, 2)), CAST(2337.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2751, 1292, 2, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2752, 1292, 3, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2753, 1292, 4, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2754, 1293, 1, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2755, 1293, 2, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2756, 1293, 3, N'PICTURE   ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2757, 1293, 4, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2758, 1294, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2759, 1294, 4, N'DT        ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2760, 1295, 16, N'CASE      ', 11, CAST(39.00 AS Numeric(8, 2)), CAST(429.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2761, 1295, 17, N'DATES     ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2762, 1296, 1, N'CASE      ', 11, CAST(39.00 AS Numeric(8, 2)), CAST(429.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2763, 1296, 2, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2764, 1296, 3, N'DT PK     ', 5, CAST(229.00 AS Numeric(8, 2)), CAST(1145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2765, 1296, 4, N'MENU      ', 12, CAST(129.00 AS Numeric(8, 2)), CAST(1548.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2766, 1297, 1, N'DT        ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2767, 1297, 2, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2768, 1297, 3, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2769, 1297, 4, N'GOLD-DLX  ', 6, CAST(1079.00 AS Numeric(8, 2)), CAST(6474.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2770, 1297, 5, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2771, 1297, 6, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2772, 1298, 1, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2773, 1298, 2, N'CASE      ', 14, CAST(39.00 AS Numeric(8, 2)), CAST(546.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2774, 1298, 3, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2775, 1298, 4, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2776, 1298, 5, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2777, 1299, 1, N'DATES     ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2778, 1299, 2, N'DT PK     ', 11, CAST(229.00 AS Numeric(8, 2)), CAST(2519.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2779, 1300, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2780, 1300, 2, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2781, 1300, 3, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2782, 1300, 4, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2783, 1300, 5, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2784, 1300, 10, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2785, 1301, 1, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2786, 1301, 4, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2787, 1301, 5, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2788, 1302, 1, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2789, 1302, 2, N'DT PK     ', 7, CAST(229.00 AS Numeric(8, 2)), CAST(1603.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2790, 1303, 1, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2791, 1303, 2, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2792, 1304, 1, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2793, 1305, 1, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2794, 1305, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2795, 1306, 1, N'BRIDGE    ', 6, CAST(195.00 AS Numeric(8, 2)), CAST(1170.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2796, 1306, 2, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2797, 1307, 1, N'ACE1      ', 10, CAST(25.00 AS Numeric(8, 2)), CAST(250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2798, 1307, 2, N'ACE-2     ', 14, CAST(15.00 AS Numeric(8, 2)), CAST(210.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2799, 1308, 1, N'BEARS     ', 2, CAST(32.00 AS Numeric(8, 2)), CAST(64.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2800, 1308, 2, N'GOLD      ', 5, CAST(779.00 AS Numeric(8, 2)), CAST(3895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2801, 1309, 1, N'JEWELRY-DL', 3, CAST(1749.00 AS Numeric(8, 2)), CAST(5247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2802, 1310, 1, N'FLEX-O-MAT', 9, CAST(295.00 AS Numeric(8, 2)), CAST(2655.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2803, 1311, 1, N'O''NEILLS  ', 6, CAST(45.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2804, 1311, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2805, 1312, 1, N'MAPS      ', 5, CAST(145.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2806, 1313, 1, N'UPDATE    ', 12, CAST(19.00 AS Numeric(8, 2)), CAST(228.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2807, 1313, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2808, 1313, 3, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2809, 1314, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2810, 1314, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2811, 1315, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2812, 1315, 2, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2813, 1315, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2814, 1316, 1, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2815, 1316, 2, N'TEXT-1    ', 16, CAST(99.00 AS Numeric(8, 2)), CAST(1584.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2816, 1316, 3, N'TEXT-2    ', 16, CAST(59.00 AS Numeric(8, 2)), CAST(944.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2817, 1316, 4, N'TEXT-3    ', 10, CAST(69.00 AS Numeric(8, 2)), CAST(690.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2818, 1316, 5, N'TEXT-4    ', 14, CAST(99.00 AS Numeric(8, 2)), CAST(1386.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2819, 1317, 1, N'VINO-LM   ', 12, CAST(5.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2820, 1318, 1, N'UN-CL-1   ', 12, CAST(399.00 AS Numeric(8, 2)), CAST(4788.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2821, 1318, 2, N'UN-CL-2   ', 12, CAST(659.00 AS Numeric(8, 2)), CAST(7908.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2822, 1319, 1, N'UNIXGUIDE ', 13, CAST(499.00 AS Numeric(8, 2)), CAST(6487.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2823, 1320, 1, N'FLEX-O-MAT', 13, CAST(295.00 AS Numeric(8, 2)), CAST(3835.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2824, 1321, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2825, 1321, 2, N'TABLE     ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2826, 1322, 1, N'TABLE-MAH ', 6, CAST(1250.00 AS Numeric(8, 2)), CAST(7500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2827, 1322, 2, N'TABLE-MPL ', 16, CAST(319.00 AS Numeric(8, 2)), CAST(5104.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2828, 1323, 1, N'JEWELRY-DL', 1, CAST(1749.00 AS Numeric(8, 2)), CAST(1749.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2829, 1323, 2, N'JEWELRY-I ', 11, CAST(1299.00 AS Numeric(8, 2)), CAST(14289.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2830, 1324, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2831, 1324, 2, N'DT PK     ', 12, CAST(229.00 AS Numeric(8, 2)), CAST(2748.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2832, 1325, 1, N'MAPS      ', 12, CAST(145.00 AS Numeric(8, 2)), CAST(1740.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2833, 1326, 1, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2834, 1326, 2, N'PULLMAN   ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2835, 1327, 1, N'RUNMTR    ', 4, CAST(79.00 AS Numeric(8, 2)), CAST(316.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2836, 1327, 2, N'RUNMTR2   ', 6, CAST(199.00 AS Numeric(8, 2)), CAST(1194.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2837, 1328, 1, N'OFFICE-S  ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2838, 1329, 1, N'JOKES     ', 3, CAST(12.00 AS Numeric(8, 2)), CAST(36.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2839, 1330, 1, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2840, 1330, 2, N'REPORTS II', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2841, 1331, 1, N'MAPS      ', 4, CAST(145.00 AS Numeric(8, 2)), CAST(580.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2842, 1331, 2, N'CITIES    ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2843, 1332, 1, N'BEARS     ', 6, CAST(32.00 AS Numeric(8, 2)), CAST(192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2844, 1332, 2, N'STARTREK  ', 12, CAST(1599.00 AS Numeric(8, 2)), CAST(19188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2845, 1333, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2846, 1334, 1, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2847, 1334, 2, N'OFFICE-2  ', 13, CAST(65.00 AS Numeric(8, 2)), CAST(845.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2848, 1335, 1, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2849, 1336, 1, N'NITE-LITE ', 2, CAST(24.00 AS Numeric(8, 2)), CAST(48.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2850, 1336, 2, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2851, 1336, 3, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2852, 1337, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2853, 1337, 2, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2854, 1338, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2855, 1338, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2856, 1338, 3, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2857, 1339, 1, N'UPDATE    ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2858, 1339, 2, N'OFFICE-S  ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2859, 1340, 1, N'TEXT-1    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2860, 1340, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2861, 1340, 3, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2862, 1340, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2863, 1340, 5, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2864, 1341, 1, N'JOKES     ', 2, CAST(12.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2865, 1342, 1, N'ACE-2     ', 2, CAST(15.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2866, 1342, 2, N'ACE1      ', 1, CAST(25.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2867, 1343, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2868, 1343, 2, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2869, 1344, 1, N'OFFICE-1  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2870, 1344, 2, N'OFFICE-2  ', 10, CAST(65.00 AS Numeric(8, 2)), CAST(650.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2871, 1344, 3, N'OFFICE-S  ', 10, CAST(19.00 AS Numeric(8, 2)), CAST(190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2872, 1345, 1, N'GOLD-DLX  ', 10, CAST(1079.00 AS Numeric(8, 2)), CAST(10790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2873, 1346, 1, N'FLEX-O-MAT', 12, CAST(295.00 AS Numeric(8, 2)), CAST(3540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2874, 1347, 1, N'BRIDGE    ', 4, CAST(195.00 AS Numeric(8, 2)), CAST(780.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2875, 1347, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2876, 1347, 3, N'VINO-LM   ', 5, CAST(5.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2877, 1348, 1, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2878, 1349, 1, N'TABLE     ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2879, 1349, 2, N'TABLE-MAH ', 4, CAST(1250.00 AS Numeric(8, 2)), CAST(5000.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2880, 1349, 3, N'TABLE-MPL ', 4, CAST(319.00 AS Numeric(8, 2)), CAST(1276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2881, 1349, 4, N'OFFICE-1  ', 8, CAST(45.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2882, 1349, 5, N'OFFICE-2  ', 14, CAST(65.00 AS Numeric(8, 2)), CAST(910.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2883, 1349, 6, N'OFFICE-S  ', 12, CAST(19.00 AS Numeric(8, 2)), CAST(228.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2884, 1350, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2885, 1350, 2, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2886, 1351, 1, N'BRIDGE    ', 7, CAST(195.00 AS Numeric(8, 2)), CAST(1365.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2887, 1352, 1, N'O''NEILLS  ', 9, CAST(45.00 AS Numeric(8, 2)), CAST(405.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2888, 1352, 2, N'POPUP     ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2889, 1352, 3, N'PULLMAN   ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2890, 1353, 1, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2891, 1353, 2, N'TEXT-2    ', 3, CAST(59.00 AS Numeric(8, 2)), CAST(177.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2892, 1353, 3, N'TEXT-3    ', 8, CAST(69.00 AS Numeric(8, 2)), CAST(552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2893, 1353, 4, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2894, 1353, 5, N'TEXT-ALL  ', 10, CAST(595.00 AS Numeric(8, 2)), CAST(5950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2895, 1354, 1, N'MODEMS    ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2896, 1354, 2, N'REPORTS   ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2897, 1355, 1, N'JEWELRY-I ', 14, CAST(1299.00 AS Numeric(8, 2)), CAST(18186.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2898, 1356, 1, N'STARTREK  ', 3, CAST(1599.00 AS Numeric(8, 2)), CAST(4797.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2899, 1357, 1, N'REPORTS II', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2900, 1358, 1, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2901, 1358, 2, N'OFFICE-2  ', 14, CAST(65.00 AS Numeric(8, 2)), CAST(910.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2902, 1358, 3, N'OFFICE-S  ', 14, CAST(19.00 AS Numeric(8, 2)), CAST(266.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2903, 1359, 1, N'UN-CL-1   ', 7, CAST(399.00 AS Numeric(8, 2)), CAST(2793.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2904, 1359, 2, N'UN-CL-2   ', 12, CAST(659.00 AS Numeric(8, 2)), CAST(7908.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2905, 1359, 3, N'UNIXGUIDE ', 12, CAST(499.00 AS Numeric(8, 2)), CAST(5988.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2906, 1360, 1, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2907, 1360, 2, N'RUNMTR2   ', 4, CAST(199.00 AS Numeric(8, 2)), CAST(796.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2908, 1361, 1, N'O''NEILLS  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2909, 1362, 1, N'GOLD      ', 4, CAST(779.00 AS Numeric(8, 2)), CAST(3116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2910, 1363, 1, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2911, 1363, 2, N'MAPS      ', 5, CAST(145.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2912, 1364, 1, N'O''NEILLS  ', 15, CAST(45.00 AS Numeric(8, 2)), CAST(675.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2913, 1364, 2, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2914, 1364, 3, N'UPDATE    ', 10, CAST(19.00 AS Numeric(8, 2)), CAST(190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2915, 1364, 4, N'VINO-LM   ', 8, CAST(5.00 AS Numeric(8, 2)), CAST(40.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2916, 1365, 1, N'POOL      ', 4, CAST(15.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2917, 1365, 2, N'POPUP     ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2918, 1366, 1, N'FLEX-O-MAT', 3, CAST(295.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2919, 1367, 1, N'BRIDGE    ', 3, CAST(195.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2920, 1367, 2, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2921, 1368, 1, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2922, 1368, 2, N'OFFICE-2  ', 6, CAST(65.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2923, 1368, 3, N'REPORTS   ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2924, 1368, 4, N'VINO-LM   ', 6, CAST(5.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2925, 1369, 1, N'VINO-LM   ', 11, CAST(5.00 AS Numeric(8, 2)), CAST(55.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2926, 1370, 1, N'NITE-LITE ', 13, CAST(24.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2927, 1370, 2, N'POPUP     ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2928, 1370, 3, N'STARTREK  ', 4, CAST(1599.00 AS Numeric(8, 2)), CAST(6396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2929, 1371, 1, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2930, 1371, 2, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2931, 1371, 3, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2932, 1372, 1, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2933, 1373, 1, N'RUNMTR    ', 2, CAST(79.00 AS Numeric(8, 2)), CAST(158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2934, 1373, 2, N'RUNMTR2   ', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2935, 1374, 1, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2936, 1375, 1, N'JOKES     ', 8, CAST(12.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2937, 1375, 2, N'POOL      ', 13, CAST(15.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2938, 1376, 1, N'VINO-LM   ', 13, CAST(5.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2939, 1377, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2940, 1378, 1, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2941, 1379, 1, N'TEXT-ALL  ', 5, CAST(595.00 AS Numeric(8, 2)), CAST(2975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2942, 1380, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2943, 1380, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2944, 1380, 3, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2945, 1380, 4, N'TEXT-4    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2946, 1381, 1, N'UN-CL-1   ', 2, CAST(399.00 AS Numeric(8, 2)), CAST(798.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2947, 1381, 2, N'UN-CL-2   ', 9, CAST(659.00 AS Numeric(8, 2)), CAST(5931.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2948, 1381, 3, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2949, 1382, 1, N'CUA       ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2950, 1383, 1, N'PICTURE   ', 15, CAST(29.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2951, 1384, 1, N'BRIDGE    ', 15, CAST(195.00 AS Numeric(8, 2)), CAST(2925.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2952, 1385, 1, N'POOL      ', 15, CAST(15.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2953, 1386, 1, N'DATES     ', 15, CAST(29.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2954, 1386, 2, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2955, 1386, 3, N'DT PK     ', 7, CAST(229.00 AS Numeric(8, 2)), CAST(1603.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2956, 1387, 1, N'TEXT-1    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2957, 1387, 2, N'TEXT-2    ', 6, CAST(59.00 AS Numeric(8, 2)), CAST(354.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2958, 1387, 3, N'TEXT-3    ', 17, CAST(69.00 AS Numeric(8, 2)), CAST(1173.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2959, 1387, 4, N'TEXT-4    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2960, 1388, 1, N'RUNMTR    ', 9, CAST(79.00 AS Numeric(8, 2)), CAST(711.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2961, 1388, 2, N'POPUP     ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2962, 1388, 3, N'DT        ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2963, 1388, 5, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2964, 1389, 1, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2965, 1389, 2, N'CITIES    ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2966, 1389, 3, N'MENU      ', 10, CAST(129.00 AS Numeric(8, 2)), CAST(1290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2967, 1389, 4, N'DT        ', 10, CAST(179.00 AS Numeric(8, 2)), CAST(1790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2968, 1390, 1, N'DATES     ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2969, 1390, 2, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2970, 1390, 3, N'TEXT-4    ', 10, CAST(99.00 AS Numeric(8, 2)), CAST(990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2971, 1390, 4, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2972, 1391, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2973, 1391, 2, N'GOLD      ', 6, CAST(779.00 AS Numeric(8, 2)), CAST(4674.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2974, 1392, 1, N'MENU      ', 11, CAST(129.00 AS Numeric(8, 2)), CAST(1419.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2975, 1392, 2, N'MODEMS    ', 12, CAST(129.00 AS Numeric(8, 2)), CAST(1548.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2976, 1392, 3, N'TABLE-MAH ', 12, CAST(1250.00 AS Numeric(8, 2)), CAST(15000.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2977, 1392, 4, N'REPORTS   ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2978, 1393, 1, N'PULLMAN   ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2979, 1393, 2, N'TABLE     ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2980, 1394, 1, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2981, 1394, 2, N'CUA       ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2982, 1395, 1, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2983, 1395, 2, N'GOLD-DLX  ', 3, CAST(1079.00 AS Numeric(8, 2)), CAST(3237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2984, 1396, 1, N'MODEMS    ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2985, 1396, 2, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2986, 1396, 3, N'TEXT-2    ', 4, CAST(59.00 AS Numeric(8, 2)), CAST(236.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2987, 1397, 1, N'TABLE-MPL ', 4, CAST(319.00 AS Numeric(8, 2)), CAST(1276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2988, 1397, 2, N'JEWELRY-I ', 9, CAST(1299.00 AS Numeric(8, 2)), CAST(11691.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2989, 1397, 3, N'UN-CL-1   ', 4, CAST(399.00 AS Numeric(8, 2)), CAST(1596.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2990, 1398, 1, N'RUNMTR    ', 6, CAST(79.00 AS Numeric(8, 2)), CAST(474.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2991, 1398, 2, N'RUNMTR2   ', 6, CAST(199.00 AS Numeric(8, 2)), CAST(1194.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2992, 1398, 3, N'POPUP     ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2993, 1399, 1, N'JEWELRY-DL', 10, CAST(1749.00 AS Numeric(8, 2)), CAST(17490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2994, 1399, 2, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2995, 1399, 3, N'UN-CL-2   ', 16, CAST(659.00 AS Numeric(8, 2)), CAST(10544.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2996, 1400, 2, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2997, 1400, 3, N'JOKES     ', 6, CAST(12.00 AS Numeric(8, 2)), CAST(72.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2998, 1400, 4, N'TEXT-ALL  ', 6, CAST(595.00 AS Numeric(8, 2)), CAST(3570.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (2999, 1400, 5, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3000, 1401, 2, N'MODEMS    ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3001, 1401, 3, N'REPORTS II', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3002, 1402, 1, N'JEWELRY-DL', 8, CAST(1749.00 AS Numeric(8, 2)), CAST(13992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3003, 1402, 2, N'FLEX-O-MAT', 8, CAST(295.00 AS Numeric(8, 2)), CAST(2360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3004, 1403, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3005, 1403, 3, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3006, 1404, 1, N'JEWELRY-I ', 3, CAST(1299.00 AS Numeric(8, 2)), CAST(3897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3007, 1405, 1, N'UN-CL-2   ', 7, CAST(659.00 AS Numeric(8, 2)), CAST(4613.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3008, 1405, 3, N'FLEX-O-MAT', 7, CAST(295.00 AS Numeric(8, 2)), CAST(2065.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3009, 1406, 1, N'OFFICE-2  ', 7, CAST(65.00 AS Numeric(8, 2)), CAST(455.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3010, 1406, 2, N'PULLMAN   ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3011, 1406, 3, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3012, 1407, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3013, 1407, 3, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3014, 1407, 4, N'PICTURE   ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3015, 1407, 5, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3016, 1408, 1, N'TEXT-ALL  ', 9, CAST(595.00 AS Numeric(8, 2)), CAST(5355.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3017, 1408, 2, N'PICTURE   ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3018, 1408, 3, N'CUA       ', 16, CAST(49.00 AS Numeric(8, 2)), CAST(784.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3019, 1409, 1, N'GOLD      ', 10, CAST(779.00 AS Numeric(8, 2)), CAST(7790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3020, 1409, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3021, 1409, 3, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3022, 1409, 4, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3023, 1410, 1, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3024, 1410, 2, N'MENU      ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3025, 1410, 3, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3026, 1410, 4, N'DT PK     ', 2, CAST(229.00 AS Numeric(8, 2)), CAST(458.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3027, 1411, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3028, 1411, 4, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3029, 1412, 16, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3030, 1412, 17, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3031, 1413, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3032, 1413, 2, N'DATES     ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3033, 1413, 3, N'DT PK     ', 5, CAST(229.00 AS Numeric(8, 2)), CAST(1145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3034, 1413, 4, N'MENU      ', 15, CAST(129.00 AS Numeric(8, 2)), CAST(1935.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3035, 1414, 1, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3036, 1414, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3037, 1414, 3, N'TEXT-3    ', 13, CAST(69.00 AS Numeric(8, 2)), CAST(897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3038, 1414, 4, N'GOLD-DLX  ', 3, CAST(1079.00 AS Numeric(8, 2)), CAST(3237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3039, 1414, 5, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3040, 1414, 6, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3041, 1415, 1, N'TEXT-3    ', 9, CAST(69.00 AS Numeric(8, 2)), CAST(621.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3042, 1415, 2, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3043, 1415, 3, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3044, 1415, 4, N'CUA       ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3045, 1415, 5, N'TEXT-3    ', 12, CAST(69.00 AS Numeric(8, 2)), CAST(828.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3046, 1416, 1, N'DATES     ', 12, CAST(29.00 AS Numeric(8, 2)), CAST(348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3047, 1416, 2, N'DT PK     ', 15, CAST(229.00 AS Numeric(8, 2)), CAST(3435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3048, 1417, 1, N'CASE      ', 15, CAST(39.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3049, 1417, 2, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3050, 1417, 3, N'CITIES    ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3051, 1417, 4, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3052, 1417, 5, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3053, 1417, 10, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3054, 1418, 1, N'BEARS     ', 9, CAST(30.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3055, 1418, 4, N'BEARS     ', 12, CAST(30.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3056, 1418, 5, N'VINO-LM   ', 3, CAST(5.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3057, 1419, 1, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3058, 1419, 2, N'DT PK     ', 2, CAST(229.00 AS Numeric(8, 2)), CAST(458.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3059, 1420, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3060, 1420, 2, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3061, 1421, 1, N'DT        ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3062, 1422, 1, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3063, 1422, 2, N'CUA       ', 17, CAST(49.00 AS Numeric(8, 2)), CAST(833.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3064, 1423, 1, N'BRIDGE    ', 17, CAST(195.00 AS Numeric(8, 2)), CAST(3315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3065, 1423, 2, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3066, 1424, 1, N'ACE1      ', 9, CAST(25.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3067, 1424, 2, N'ACE-2     ', 3, CAST(15.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3068, 1425, 1, N'BEARS     ', 3, CAST(32.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3069, 1425, 2, N'GOLD      ', 3, CAST(779.00 AS Numeric(8, 2)), CAST(2337.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3070, 1426, 1, N'JEWELRY-DL', 12, CAST(1749.00 AS Numeric(8, 2)), CAST(20988.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3071, 1427, 1, N'FLEX-O-MAT', 12, CAST(295.00 AS Numeric(8, 2)), CAST(3540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3072, 1428, 1, N'O''NEILLS  ', 12, CAST(45.00 AS Numeric(8, 2)), CAST(540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3073, 1428, 2, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3074, 1429, 1, N'MAPS      ', 14, CAST(145.00 AS Numeric(8, 2)), CAST(2030.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3075, 1430, 1, N'UPDATE    ', 11, CAST(19.00 AS Numeric(8, 2)), CAST(209.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3076, 1430, 2, N'CUA       ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3077, 1430, 3, N'DT        ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3078, 1431, 1, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3079, 1431, 2, N'POPUP     ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3080, 1432, 1, N'OFFICE-1  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3081, 1432, 2, N'OFFICE-2  ', 11, CAST(65.00 AS Numeric(8, 2)), CAST(715.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3082, 1432, 3, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3083, 1433, 1, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3084, 1433, 2, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3085, 1433, 3, N'TEXT-2    ', 7, CAST(59.00 AS Numeric(8, 2)), CAST(413.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3086, 1433, 4, N'TEXT-3    ', 11, CAST(69.00 AS Numeric(8, 2)), CAST(759.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3087, 1433, 5, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3088, 1434, 1, N'VINO-LM   ', 7, CAST(5.00 AS Numeric(8, 2)), CAST(35.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3089, 1435, 1, N'UN-CL-1   ', 13, CAST(399.00 AS Numeric(8, 2)), CAST(5187.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3090, 1435, 2, N'UN-CL-2   ', 12, CAST(659.00 AS Numeric(8, 2)), CAST(7908.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3091, 1436, 1, N'UNIXGUIDE ', 8, CAST(499.00 AS Numeric(8, 2)), CAST(3992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3092, 1437, 1, N'FLEX-O-MAT', 4, CAST(295.00 AS Numeric(8, 2)), CAST(1180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3093, 1438, 1, N'O''NEILLS  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3094, 1438, 2, N'TABLE     ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3095, 1439, 1, N'TABLE-MAH ', 5, CAST(1250.00 AS Numeric(8, 2)), CAST(6250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3096, 1439, 2, N'TABLE-MPL ', 1, CAST(319.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3097, 1440, 1, N'JEWELRY-DL', 1, CAST(1749.00 AS Numeric(8, 2)), CAST(1749.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3098, 1440, 2, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3099, 1441, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3100, 1441, 2, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3101, 1442, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3102, 1443, 1, N'PICTURE   ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3103, 1443, 2, N'PULLMAN   ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3104, 1444, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3105, 1444, 2, N'RUNMTR2   ', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3106, 1445, 1, N'OFFICE-S  ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3107, 1446, 1, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3108, 1447, 1, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3109, 1447, 2, N'REPORTS II', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3110, 1448, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3111, 1448, 2, N'CITIES    ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3112, 1449, 1, N'BEARS     ', 13, CAST(32.00 AS Numeric(8, 2)), CAST(416.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3113, 1449, 2, N'STARTREK  ', 6, CAST(1599.00 AS Numeric(8, 2)), CAST(9594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3114, 1450, 1, N'MAPS      ', 3, CAST(145.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3115, 1451, 1, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3116, 1451, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3117, 1452, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3118, 1453, 1, N'NITE-LITE ', 4, CAST(24.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3119, 1453, 2, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3120, 1453, 3, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3121, 1454, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3122, 1454, 2, N'OFFICE-1  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3123, 1455, 1, N'BRIDGE    ', 12, CAST(195.00 AS Numeric(8, 2)), CAST(2340.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3124, 1455, 2, N'CITIES    ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3125, 1455, 3, N'PICTURE   ', 12, CAST(29.00 AS Numeric(8, 2)), CAST(348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3126, 1456, 1, N'UPDATE    ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3127, 1456, 2, N'OFFICE-S  ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3128, 1457, 1, N'TEXT-1    ', 16, CAST(99.00 AS Numeric(8, 2)), CAST(1584.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3129, 1457, 2, N'TEXT-2    ', 14, CAST(59.00 AS Numeric(8, 2)), CAST(826.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3130, 1457, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3131, 1457, 4, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3132, 1457, 5, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3133, 1458, 1, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3134, 1459, 1, N'ACE-2     ', 8, CAST(15.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3135, 1459, 2, N'ACE1      ', 7, CAST(25.00 AS Numeric(8, 2)), CAST(175.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3136, 1460, 1, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3137, 1460, 2, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3138, 1461, 1, N'OFFICE-1  ', 9, CAST(45.00 AS Numeric(8, 2)), CAST(405.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3139, 1461, 2, N'OFFICE-2  ', 9, CAST(65.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3140, 1461, 3, N'OFFICE-S  ', 9, CAST(19.00 AS Numeric(8, 2)), CAST(171.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3141, 1462, 1, N'GOLD-DLX  ', 4, CAST(1079.00 AS Numeric(8, 2)), CAST(4316.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3142, 1463, 1, N'FLEX-O-MAT', 4, CAST(295.00 AS Numeric(8, 2)), CAST(1180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3143, 1464, 1, N'BRIDGE    ', 5, CAST(195.00 AS Numeric(8, 2)), CAST(975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3144, 1464, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3145, 1464, 3, N'VINO-LM   ', 8, CAST(5.00 AS Numeric(8, 2)), CAST(40.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3146, 1465, 1, N'DT PK     ', 7, CAST(229.00 AS Numeric(8, 2)), CAST(1603.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3147, 1466, 1, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3148, 1466, 2, N'TABLE-MAH ', 1, CAST(1250.00 AS Numeric(8, 2)), CAST(1250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3149, 1466, 3, N'TABLE-MPL ', 5, CAST(319.00 AS Numeric(8, 2)), CAST(1595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3150, 1466, 4, N'OFFICE-1  ', 16, CAST(45.00 AS Numeric(8, 2)), CAST(720.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3151, 1466, 5, N'OFFICE-2  ', 7, CAST(65.00 AS Numeric(8, 2)), CAST(455.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3152, 1466, 6, N'OFFICE-S  ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3153, 1467, 1, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3154, 1467, 2, N'CUA       ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3155, 1468, 1, N'BRIDGE    ', 2, CAST(195.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3156, 1469, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3157, 1469, 2, N'POPUP     ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3158, 1469, 3, N'PULLMAN   ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3159, 1470, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3160, 1470, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3161, 1470, 3, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3162, 1470, 4, N'TEXT-4    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3163, 1470, 5, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3164, 1471, 1, N'MODEMS    ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3165, 1471, 2, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3166, 1472, 1, N'JEWELRY-I ', 8, CAST(1299.00 AS Numeric(8, 2)), CAST(10392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3167, 1473, 1, N'STARTREK  ', 8, CAST(1599.00 AS Numeric(8, 2)), CAST(12792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3168, 1474, 1, N'REPORTS II', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3169, 1475, 1, N'OFFICE-1  ', 12, CAST(45.00 AS Numeric(8, 2)), CAST(540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3170, 1475, 2, N'OFFICE-2  ', 11, CAST(65.00 AS Numeric(8, 2)), CAST(715.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3171, 1475, 3, N'OFFICE-S  ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3172, 1476, 1, N'UN-CL-1   ', 6, CAST(399.00 AS Numeric(8, 2)), CAST(2394.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3173, 1476, 2, N'UN-CL-2   ', 2, CAST(659.00 AS Numeric(8, 2)), CAST(1318.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3174, 1476, 3, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3175, 1477, 1, N'RUNMTR    ', 2, CAST(79.00 AS Numeric(8, 2)), CAST(158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3176, 1477, 2, N'RUNMTR2   ', 7, CAST(199.00 AS Numeric(8, 2)), CAST(1393.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3177, 1478, 1, N'O''NEILLS  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3178, 1479, 1, N'GOLD      ', 7, CAST(779.00 AS Numeric(8, 2)), CAST(5453.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3179, 1480, 1, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3180, 1480, 2, N'MAPS      ', 10, CAST(145.00 AS Numeric(8, 2)), CAST(1450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3181, 1481, 1, N'O''NEILLS  ', 6, CAST(45.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3182, 1481, 2, N'PICTURE   ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3183, 1481, 3, N'UPDATE    ', 11, CAST(19.00 AS Numeric(8, 2)), CAST(209.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3184, 1481, 4, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3185, 1482, 1, N'POOL      ', 4, CAST(15.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3186, 1482, 2, N'POPUP     ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3187, 1483, 1, N'FLEX-O-MAT', 4, CAST(295.00 AS Numeric(8, 2)), CAST(1180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3188, 1484, 1, N'BRIDGE    ', 4, CAST(195.00 AS Numeric(8, 2)), CAST(780.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3189, 1484, 2, N'DATES     ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3190, 1485, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3191, 1485, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3192, 1485, 3, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3193, 1485, 4, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3194, 1486, 1, N'VINO-LM   ', 7, CAST(5.00 AS Numeric(8, 2)), CAST(35.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3195, 1487, 1, N'NITE-LITE ', 7, CAST(24.00 AS Numeric(8, 2)), CAST(168.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3196, 1487, 2, N'POPUP     ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3197, 1487, 3, N'STARTREK  ', 3, CAST(1599.00 AS Numeric(8, 2)), CAST(4797.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3198, 1488, 1, N'OFFICE-1  ', 12, CAST(45.00 AS Numeric(8, 2)), CAST(540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3199, 1488, 2, N'OFFICE-2  ', 12, CAST(65.00 AS Numeric(8, 2)), CAST(780.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3200, 1488, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3201, 1489, 1, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3202, 1490, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3203, 1490, 2, N'RUNMTR2   ', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3204, 1491, 1, N'MAPS      ', 5, CAST(145.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3205, 1492, 1, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3206, 1492, 2, N'POOL      ', 15, CAST(15.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3207, 1493, 1, N'VINO-LM   ', 3, CAST(5.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3208, 1494, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3209, 1495, 1, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3210, 1496, 1, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3211, 1497, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3212, 1497, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3213, 1497, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3214, 1497, 4, N'TEXT-4    ', 12, CAST(99.00 AS Numeric(8, 2)), CAST(1188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3215, 1498, 1, N'UN-CL-1   ', 12, CAST(399.00 AS Numeric(8, 2)), CAST(4788.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3216, 1498, 2, N'UN-CL-2   ', 12, CAST(659.00 AS Numeric(8, 2)), CAST(7908.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3217, 1498, 3, N'UNIXGUIDE ', 12, CAST(499.00 AS Numeric(8, 2)), CAST(5988.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3218, 1499, 1, N'CUA       ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3219, 1500, 1, N'PICTURE   ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3220, 1501, 1, N'BRIDGE    ', 10, CAST(195.00 AS Numeric(8, 2)), CAST(1950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3221, 1502, 1, N'POOL      ', 9, CAST(15.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3222, 1503, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3223, 1503, 2, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3224, 1503, 3, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3225, 1504, 1, N'TEXT-1    ', 12, CAST(99.00 AS Numeric(8, 2)), CAST(1188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3226, 1504, 2, N'TEXT-2    ', 7, CAST(59.00 AS Numeric(8, 2)), CAST(413.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3227, 1504, 3, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3228, 1504, 4, N'TEXT-4    ', 15, CAST(99.00 AS Numeric(8, 2)), CAST(1485.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3229, 1505, 1, N'RUNMTR    ', 15, CAST(79.00 AS Numeric(8, 2)), CAST(1185.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3230, 1505, 2, N'POPUP     ', 15, CAST(49.00 AS Numeric(8, 2)), CAST(735.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3231, 1505, 3, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3232, 1505, 5, N'MENU      ', 11, CAST(129.00 AS Numeric(8, 2)), CAST(1419.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3233, 1506, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3234, 1506, 2, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3235, 1506, 3, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3236, 1506, 4, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3237, 1507, 1, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3238, 1507, 2, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3239, 1507, 3, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3240, 1507, 4, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3241, 1508, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3242, 1508, 2, N'GOLD      ', 4, CAST(779.00 AS Numeric(8, 2)), CAST(3116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3243, 1509, 1, N'MENU      ', 16, CAST(129.00 AS Numeric(8, 2)), CAST(2064.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3244, 1509, 2, N'MODEMS    ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3245, 1509, 3, N'TABLE-MAH ', 2, CAST(1250.00 AS Numeric(8, 2)), CAST(2500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3246, 1509, 4, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3247, 1510, 1, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3248, 1510, 2, N'TABLE     ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3249, 1511, 1, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3250, 1511, 2, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3251, 1512, 1, N'UNIXGUIDE ', 3, CAST(499.00 AS Numeric(8, 2)), CAST(1497.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3252, 1512, 2, N'GOLD-DLX  ', 5, CAST(1079.00 AS Numeric(8, 2)), CAST(5395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3253, 1513, 1, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3254, 1513, 2, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3255, 1513, 3, N'TEXT-2    ', 5, CAST(59.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3256, 1514, 1, N'TABLE-MPL ', 5, CAST(319.00 AS Numeric(8, 2)), CAST(1595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3257, 1514, 2, N'JEWELRY-I ', 5, CAST(1299.00 AS Numeric(8, 2)), CAST(6495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3258, 1514, 3, N'UN-CL-1   ', 2, CAST(399.00 AS Numeric(8, 2)), CAST(798.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3259, 1515, 1, N'RUNMTR    ', 2, CAST(79.00 AS Numeric(8, 2)), CAST(158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3260, 1515, 2, N'RUNMTR2   ', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3261, 1515, 3, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3262, 1516, 1, N'JEWELRY-DL', 3, CAST(1749.00 AS Numeric(8, 2)), CAST(5247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3263, 1516, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3264, 1516, 3, N'UN-CL-2   ', 3, CAST(659.00 AS Numeric(8, 2)), CAST(1977.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3265, 1517, 2, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3266, 1517, 3, N'JOKES     ', 3, CAST(12.00 AS Numeric(8, 2)), CAST(36.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3267, 1517, 4, N'TEXT-ALL  ', 5, CAST(595.00 AS Numeric(8, 2)), CAST(2975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3268, 1517, 5, N'UNIXGUIDE ', 5, CAST(499.00 AS Numeric(8, 2)), CAST(2495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3269, 1518, 2, N'MODEMS    ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3270, 1518, 3, N'REPORTS II', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3271, 1519, 1, N'JEWELRY-DL', 13, CAST(1749.00 AS Numeric(8, 2)), CAST(22737.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3272, 1519, 2, N'FLEX-O-MAT', 13, CAST(295.00 AS Numeric(8, 2)), CAST(3835.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3273, 1520, 1, N'MENU      ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3274, 1520, 3, N'MAPS      ', 12, CAST(145.00 AS Numeric(8, 2)), CAST(1740.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3275, 1521, 1, N'JEWELRY-I ', 7, CAST(1299.00 AS Numeric(8, 2)), CAST(9093.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3276, 1522, 1, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3277, 1522, 3, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3278, 1523, 1, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3279, 1523, 2, N'PULLMAN   ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3280, 1523, 3, N'TEXT-1    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3281, 1524, 2, N'CASE      ', 11, CAST(39.00 AS Numeric(8, 2)), CAST(429.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3282, 1524, 3, N'DATES     ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3283, 1524, 4, N'PICTURE   ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3284, 1524, 5, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3285, 1525, 1, N'TEXT-ALL  ', 8, CAST(595.00 AS Numeric(8, 2)), CAST(4760.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3286, 1525, 2, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3287, 1525, 3, N'CUA       ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3288, 1526, 1, N'GOLD      ', 10, CAST(779.00 AS Numeric(8, 2)), CAST(7790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3289, 1526, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3290, 1526, 3, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3291, 1526, 4, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3292, 1527, 1, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3293, 1527, 2, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3294, 1527, 3, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3295, 1527, 4, N'DT PK     ', 8, CAST(229.00 AS Numeric(8, 2)), CAST(1832.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3296, 1528, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3297, 1528, 4, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3298, 1529, 16, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3299, 1529, 17, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3300, 1530, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3301, 1530, 2, N'DATES     ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3302, 1530, 3, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3303, 1530, 4, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3304, 1531, 1, N'DT        ', 15, CAST(179.00 AS Numeric(8, 2)), CAST(2685.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3305, 1531, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3306, 1531, 3, N'TEXT-3    ', 9, CAST(69.00 AS Numeric(8, 2)), CAST(621.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3307, 1531, 4, N'GOLD-DLX  ', 7, CAST(1079.00 AS Numeric(8, 2)), CAST(7553.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3308, 1531, 5, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3309, 1531, 6, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3310, 1532, 1, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3311, 1532, 2, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3312, 1532, 3, N'DATES     ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3313, 1532, 4, N'CUA       ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3314, 1532, 5, N'TEXT-3    ', 9, CAST(69.00 AS Numeric(8, 2)), CAST(621.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3315, 1533, 1, N'DATES     ', 13, CAST(29.00 AS Numeric(8, 2)), CAST(377.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3316, 1533, 2, N'DT PK     ', 13, CAST(229.00 AS Numeric(8, 2)), CAST(2977.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3317, 1534, 1, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3318, 1534, 2, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3319, 1534, 3, N'CITIES    ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3320, 1534, 4, N'MENU      ', 13, CAST(129.00 AS Numeric(8, 2)), CAST(1677.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3321, 1534, 5, N'DATES     ', 13, CAST(29.00 AS Numeric(8, 2)), CAST(377.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3322, 1534, 10, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3323, 1535, 1, N'BEARS     ', 3, CAST(30.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3324, 1535, 4, N'BEARS     ', 11, CAST(30.00 AS Numeric(8, 2)), CAST(330.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3325, 1535, 5, N'VINO-LM   ', 11, CAST(5.00 AS Numeric(8, 2)), CAST(55.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3326, 1536, 1, N'DT        ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3327, 1536, 2, N'DT PK     ', 3, CAST(229.00 AS Numeric(8, 2)), CAST(687.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3328, 1537, 1, N'CASE      ', 15, CAST(39.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3329, 1537, 2, N'DT        ', 15, CAST(179.00 AS Numeric(8, 2)), CAST(2685.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3330, 1538, 1, N'DT        ', 15, CAST(179.00 AS Numeric(8, 2)), CAST(2685.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3331, 1539, 1, N'CASE      ', 15, CAST(39.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3332, 1539, 2, N'CUA       ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3333, 1540, 1, N'BRIDGE    ', 14, CAST(195.00 AS Numeric(8, 2)), CAST(2730.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3334, 1540, 2, N'CITIES    ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3335, 1541, 1, N'ACE1      ', 14, CAST(25.00 AS Numeric(8, 2)), CAST(350.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3336, 1541, 2, N'ACE-2     ', 14, CAST(15.00 AS Numeric(8, 2)), CAST(210.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3337, 1542, 1, N'BEARS     ', 12, CAST(32.00 AS Numeric(8, 2)), CAST(384.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3338, 1542, 2, N'GOLD      ', 9, CAST(779.00 AS Numeric(8, 2)), CAST(7011.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3339, 1543, 1, N'JEWELRY-DL', 13, CAST(1749.00 AS Numeric(8, 2)), CAST(22737.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3340, 1544, 1, N'FLEX-O-MAT', 5, CAST(295.00 AS Numeric(8, 2)), CAST(1475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3341, 1545, 1, N'O''NEILLS  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3342, 1545, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3343, 1546, 1, N'MAPS      ', 5, CAST(145.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3344, 1547, 1, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3345, 1547, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3346, 1547, 3, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3347, 1548, 1, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3348, 1548, 2, N'POPUP     ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3349, 1549, 1, N'OFFICE-1  ', 10, CAST(45.00 AS Numeric(8, 2)), CAST(450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3350, 1549, 2, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3351, 1549, 3, N'OFFICE-S  ', 9, CAST(19.00 AS Numeric(8, 2)), CAST(171.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3352, 1550, 1, N'UPDATE    ', 9, CAST(19.00 AS Numeric(8, 2)), CAST(171.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3353, 1550, 2, N'TEXT-1    ', 9, CAST(99.00 AS Numeric(8, 2)), CAST(891.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3354, 1550, 3, N'TEXT-2    ', 3, CAST(59.00 AS Numeric(8, 2)), CAST(177.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3355, 1550, 4, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3356, 1550, 5, N'TEXT-4    ', 12, CAST(99.00 AS Numeric(8, 2)), CAST(1188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3357, 1551, 1, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3358, 1552, 1, N'UN-CL-1   ', 7, CAST(399.00 AS Numeric(8, 2)), CAST(2793.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3359, 1552, 2, N'UN-CL-2   ', 3, CAST(659.00 AS Numeric(8, 2)), CAST(1977.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3360, 1553, 1, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3361, 1554, 1, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3362, 1555, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3363, 1555, 2, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3364, 1556, 1, N'TABLE-MAH ', 5, CAST(1250.00 AS Numeric(8, 2)), CAST(6250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3365, 1556, 2, N'TABLE-MPL ', 4, CAST(319.00 AS Numeric(8, 2)), CAST(1276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3366, 1557, 1, N'JEWELRY-DL', 4, CAST(1749.00 AS Numeric(8, 2)), CAST(6996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3367, 1557, 2, N'JEWELRY-I ', 16, CAST(1299.00 AS Numeric(8, 2)), CAST(20784.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3368, 1558, 1, N'CASE      ', 16, CAST(39.00 AS Numeric(8, 2)), CAST(624.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3369, 1558, 2, N'DT PK     ', 3, CAST(229.00 AS Numeric(8, 2)), CAST(687.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3370, 1559, 1, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3371, 1560, 1, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3372, 1560, 2, N'PULLMAN   ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3373, 1561, 1, N'RUNMTR    ', 9, CAST(79.00 AS Numeric(8, 2)), CAST(711.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3374, 1561, 2, N'RUNMTR2   ', 13, CAST(199.00 AS Numeric(8, 2)), CAST(2587.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3375, 1562, 1, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3376, 1563, 1, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3377, 1564, 1, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3378, 1564, 2, N'REPORTS II', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3379, 1565, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3380, 1565, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3381, 1566, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3382, 1566, 2, N'STARTREK  ', 4, CAST(1599.00 AS Numeric(8, 2)), CAST(6396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3383, 1567, 1, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3384, 1568, 1, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3385, 1568, 2, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3386, 1569, 1, N'MENU      ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3387, 1570, 1, N'NITE-LITE ', 5, CAST(24.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3388, 1570, 2, N'TABLE     ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3389, 1570, 3, N'UPDATE    ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3390, 1571, 1, N'CASE      ', 12, CAST(39.00 AS Numeric(8, 2)), CAST(468.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3391, 1571, 2, N'OFFICE-1  ', 6, CAST(45.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3392, 1572, 1, N'BRIDGE    ', 10, CAST(195.00 AS Numeric(8, 2)), CAST(1950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3393, 1572, 2, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3394, 1572, 3, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3395, 1573, 1, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3396, 1573, 2, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3397, 1574, 1, N'TEXT-1    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3398, 1574, 2, N'TEXT-2    ', 3, CAST(59.00 AS Numeric(8, 2)), CAST(177.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3399, 1574, 3, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3400, 1574, 4, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3401, 1574, 5, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3402, 1575, 1, N'JOKES     ', 2, CAST(12.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3403, 1576, 1, N'ACE-2     ', 2, CAST(15.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3404, 1576, 2, N'ACE1      ', 6, CAST(25.00 AS Numeric(8, 2)), CAST(150.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3405, 1577, 1, N'DATES     ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3406, 1577, 2, N'DT        ', 12, CAST(179.00 AS Numeric(8, 2)), CAST(2148.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3407, 1578, 1, N'OFFICE-1  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3408, 1578, 2, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3409, 1578, 3, N'OFFICE-S  ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3410, 1579, 1, N'GOLD-DLX  ', 15, CAST(1079.00 AS Numeric(8, 2)), CAST(16185.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3411, 1580, 1, N'FLEX-O-MAT', 12, CAST(295.00 AS Numeric(8, 2)), CAST(3540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3412, 1581, 1, N'BRIDGE    ', 8, CAST(195.00 AS Numeric(8, 2)), CAST(1560.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3413, 1581, 2, N'PICTURE   ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3414, 1581, 3, N'VINO-LM   ', 9, CAST(5.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3415, 1582, 1, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3416, 1583, 1, N'TABLE     ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3417, 1583, 2, N'TABLE-MAH ', 10, CAST(1250.00 AS Numeric(8, 2)), CAST(12500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3418, 1583, 3, N'TABLE-MPL ', 5, CAST(319.00 AS Numeric(8, 2)), CAST(1595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3419, 1583, 4, N'OFFICE-1  ', 13, CAST(45.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3420, 1583, 5, N'OFFICE-2  ', 13, CAST(65.00 AS Numeric(8, 2)), CAST(845.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3421, 1583, 6, N'OFFICE-S  ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3422, 1584, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3423, 1584, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3424, 1585, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3425, 1586, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3426, 1586, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3427, 1586, 3, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3428, 1587, 1, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3429, 1587, 2, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3430, 1587, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3431, 1587, 4, N'TEXT-4    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3432, 1587, 5, N'TEXT-ALL  ', 5, CAST(595.00 AS Numeric(8, 2)), CAST(2975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3433, 1588, 1, N'MODEMS    ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3434, 1588, 2, N'REPORTS   ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3435, 1589, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3436, 1590, 1, N'STARTREK  ', 14, CAST(1599.00 AS Numeric(8, 2)), CAST(22386.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3437, 1591, 1, N'REPORTS II', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3438, 1592, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3439, 1592, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3440, 1592, 3, N'OFFICE-S  ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3441, 1593, 1, N'UN-CL-1   ', 6, CAST(399.00 AS Numeric(8, 2)), CAST(2394.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3442, 1593, 2, N'UN-CL-2   ', 6, CAST(659.00 AS Numeric(8, 2)), CAST(3954.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3443, 1593, 3, N'UNIXGUIDE ', 12, CAST(499.00 AS Numeric(8, 2)), CAST(5988.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3444, 1594, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3445, 1594, 2, N'RUNMTR2   ', 9, CAST(199.00 AS Numeric(8, 2)), CAST(1791.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3446, 1595, 1, N'O''NEILLS  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3447, 1596, 1, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3448, 1597, 1, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3449, 1597, 2, N'MAPS      ', 7, CAST(145.00 AS Numeric(8, 2)), CAST(1015.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3450, 1598, 1, N'O''NEILLS  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3451, 1598, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3452, 1598, 3, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3453, 1598, 4, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3454, 1599, 1, N'POOL      ', 5, CAST(15.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3455, 1599, 2, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3456, 1600, 1, N'FLEX-O-MAT', 2, CAST(295.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3457, 1601, 1, N'BRIDGE    ', 6, CAST(195.00 AS Numeric(8, 2)), CAST(1170.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3458, 1601, 2, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3459, 1602, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3460, 1602, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3461, 1602, 3, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3462, 1602, 4, N'VINO-LM   ', 10, CAST(5.00 AS Numeric(8, 2)), CAST(50.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3463, 1603, 1, N'VINO-LM   ', 10, CAST(5.00 AS Numeric(8, 2)), CAST(50.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3464, 1604, 1, N'NITE-LITE ', 10, CAST(24.00 AS Numeric(8, 2)), CAST(240.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3465, 1604, 2, N'POPUP     ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3466, 1604, 3, N'STARTREK  ', 2, CAST(1599.00 AS Numeric(8, 2)), CAST(3198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3467, 1605, 1, N'OFFICE-1  ', 16, CAST(45.00 AS Numeric(8, 2)), CAST(720.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3468, 1605, 2, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3469, 1605, 3, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3470, 1606, 1, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3471, 1607, 1, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3472, 1607, 2, N'RUNMTR2   ', 4, CAST(199.00 AS Numeric(8, 2)), CAST(796.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3473, 1608, 1, N'MAPS      ', 4, CAST(145.00 AS Numeric(8, 2)), CAST(580.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3474, 1609, 1, N'JOKES     ', 11, CAST(12.00 AS Numeric(8, 2)), CAST(132.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3475, 1609, 2, N'POOL      ', 2, CAST(15.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3476, 1610, 1, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3477, 1611, 1, N'BEARS     ', 10, CAST(32.00 AS Numeric(8, 2)), CAST(320.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3478, 1612, 1, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3479, 1613, 1, N'TEXT-ALL  ', 8, CAST(595.00 AS Numeric(8, 2)), CAST(4760.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3480, 1614, 1, N'TEXT-1    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3481, 1614, 2, N'TEXT-2    ', 8, CAST(59.00 AS Numeric(8, 2)), CAST(472.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3482, 1614, 3, N'TEXT-3    ', 5, CAST(69.00 AS Numeric(8, 2)), CAST(345.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3483, 1614, 4, N'TEXT-4    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3484, 1615, 1, N'UN-CL-1   ', 10, CAST(399.00 AS Numeric(8, 2)), CAST(3990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3485, 1615, 2, N'UN-CL-2   ', 10, CAST(659.00 AS Numeric(8, 2)), CAST(6590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3486, 1615, 3, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3487, 1616, 1, N'CUA       ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3488, 1617, 1, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3489, 1618, 1, N'BRIDGE    ', 2, CAST(195.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3490, 1619, 1, N'POOL      ', 12, CAST(15.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3491, 1620, 1, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3492, 1620, 2, N'DT        ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3493, 1620, 3, N'DT PK     ', 17, CAST(229.00 AS Numeric(8, 2)), CAST(3893.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3494, 1621, 1, N'TEXT-1    ', 17, CAST(99.00 AS Numeric(8, 2)), CAST(1683.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3495, 1621, 2, N'TEXT-2    ', 17, CAST(59.00 AS Numeric(8, 2)), CAST(1003.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3496, 1621, 3, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3497, 1621, 4, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3498, 1622, 1, N'RUNMTR    ', 7, CAST(79.00 AS Numeric(8, 2)), CAST(553.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3499, 1622, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3500, 1622, 3, N'DT        ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3501, 1622, 5, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3502, 1623, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3503, 1623, 2, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3504, 1623, 3, N'MENU      ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3505, 1623, 4, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3506, 1624, 1, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3507, 1624, 2, N'RUNMTR    ', 6, CAST(79.00 AS Numeric(8, 2)), CAST(474.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3508, 1624, 3, N'TEXT-4    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3509, 1624, 4, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3510, 1625, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3511, 1625, 2, N'GOLD      ', 11, CAST(779.00 AS Numeric(8, 2)), CAST(8569.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3512, 1626, 1, N'MENU      ', 11, CAST(129.00 AS Numeric(8, 2)), CAST(1419.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3513, 1626, 2, N'MODEMS    ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3514, 1626, 3, N'TABLE-MAH ', 2, CAST(1250.00 AS Numeric(8, 2)), CAST(2500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3515, 1626, 4, N'REPORTS   ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3516, 1627, 1, N'PULLMAN   ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3517, 1627, 2, N'TABLE     ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3518, 1628, 1, N'REPORTS   ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3519, 1628, 2, N'CUA       ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3520, 1629, 1, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3521, 1629, 2, N'GOLD-DLX  ', 7, CAST(1079.00 AS Numeric(8, 2)), CAST(7553.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3522, 1630, 1, N'MODEMS    ', 7, CAST(129.00 AS Numeric(8, 2)), CAST(903.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3523, 1630, 2, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3524, 1630, 3, N'TEXT-2    ', 4, CAST(59.00 AS Numeric(8, 2)), CAST(236.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3525, 1631, 1, N'TABLE-MPL ', 4, CAST(319.00 AS Numeric(8, 2)), CAST(1276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3526, 1631, 2, N'JEWELRY-I ', 8, CAST(1299.00 AS Numeric(8, 2)), CAST(10392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3527, 1631, 3, N'UN-CL-1   ', 3, CAST(399.00 AS Numeric(8, 2)), CAST(1197.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3528, 1632, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3529, 1632, 2, N'RUNMTR2   ', 3, CAST(199.00 AS Numeric(8, 2)), CAST(597.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3530, 1632, 3, N'POPUP     ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3531, 1633, 1, N'JEWELRY-DL', 8, CAST(1749.00 AS Numeric(8, 2)), CAST(13992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3532, 1633, 2, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3533, 1633, 3, N'UN-CL-2   ', 5, CAST(659.00 AS Numeric(8, 2)), CAST(3295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3534, 1634, 2, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3535, 1634, 3, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3536, 1634, 4, N'TEXT-ALL  ', 4, CAST(595.00 AS Numeric(8, 2)), CAST(2380.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3537, 1634, 5, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3538, 1635, 2, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3539, 1635, 3, N'REPORTS II', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3540, 1636, 1, N'JEWELRY-DL', 6, CAST(1749.00 AS Numeric(8, 2)), CAST(10494.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3541, 1636, 2, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3542, 1637, 1, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3543, 1637, 3, N'MAPS      ', 12, CAST(145.00 AS Numeric(8, 2)), CAST(1740.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3544, 1638, 1, N'JEWELRY-I ', 10, CAST(1299.00 AS Numeric(8, 2)), CAST(12990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3545, 1639, 1, N'UN-CL-2   ', 4, CAST(659.00 AS Numeric(8, 2)), CAST(2636.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3546, 1639, 3, N'FLEX-O-MAT', 15, CAST(295.00 AS Numeric(8, 2)), CAST(4425.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3547, 1640, 1, N'OFFICE-2  ', 15, CAST(65.00 AS Numeric(8, 2)), CAST(975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3548, 1640, 2, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3549, 1640, 3, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3550, 1641, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3551, 1641, 3, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3552, 1641, 4, N'PICTURE   ', 15, CAST(29.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3553, 1641, 5, N'TEXT-3    ', 15, CAST(69.00 AS Numeric(8, 2)), CAST(1035.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3554, 1642, 1, N'TEXT-ALL  ', 10, CAST(595.00 AS Numeric(8, 2)), CAST(5950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3555, 1642, 2, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3556, 1642, 3, N'CUA       ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3557, 1643, 1, N'GOLD      ', 16, CAST(779.00 AS Numeric(8, 2)), CAST(12464.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3558, 1643, 2, N'CASE      ', 16, CAST(39.00 AS Numeric(8, 2)), CAST(624.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3559, 1643, 3, N'CITIES    ', 16, CAST(49.00 AS Numeric(8, 2)), CAST(784.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3560, 1643, 4, N'PICTURE   ', 16, CAST(29.00 AS Numeric(8, 2)), CAST(464.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3561, 1644, 1, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3562, 1644, 2, N'MENU      ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3563, 1644, 3, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3564, 1644, 4, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3565, 1645, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3566, 1645, 4, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3567, 1646, 16, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3568, 1646, 17, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3569, 1647, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3570, 1647, 2, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3571, 1647, 3, N'DT PK     ', 11, CAST(229.00 AS Numeric(8, 2)), CAST(2519.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3572, 1647, 4, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3573, 1648, 1, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3574, 1648, 2, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3575, 1648, 3, N'TEXT-3    ', 10, CAST(69.00 AS Numeric(8, 2)), CAST(690.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3576, 1648, 4, N'GOLD-DLX  ', 1, CAST(1079.00 AS Numeric(8, 2)), CAST(1079.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3577, 1648, 5, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3578, 1648, 6, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3579, 1649, 1, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3580, 1649, 2, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3581, 1649, 3, N'DATES     ', 17, CAST(29.00 AS Numeric(8, 2)), CAST(493.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3582, 1649, 4, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3583, 1649, 5, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3584, 1650, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3585, 1650, 2, N'DT PK     ', 3, CAST(229.00 AS Numeric(8, 2)), CAST(687.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3586, 1651, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3587, 1651, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3588, 1651, 3, N'CITIES    ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3589, 1651, 4, N'MENU      ', 10, CAST(129.00 AS Numeric(8, 2)), CAST(1290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3590, 1651, 5, N'DATES     ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3591, 1651, 10, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3592, 1652, 1, N'BEARS     ', 5, CAST(30.00 AS Numeric(8, 2)), CAST(150.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3593, 1652, 4, N'BEARS     ', 8, CAST(30.00 AS Numeric(8, 2)), CAST(240.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3594, 1652, 5, N'VINO-LM   ', 8, CAST(5.00 AS Numeric(8, 2)), CAST(40.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3595, 1653, 1, N'DT        ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3596, 1653, 2, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3597, 1654, 1, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3598, 1654, 2, N'DT        ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3599, 1655, 1, N'DT        ', 14, CAST(179.00 AS Numeric(8, 2)), CAST(2506.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3600, 1656, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3601, 1656, 2, N'CUA       ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3602, 1657, 1, N'BRIDGE    ', 6, CAST(195.00 AS Numeric(8, 2)), CAST(1170.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3603, 1657, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3604, 1658, 1, N'ACE1      ', 16, CAST(25.00 AS Numeric(8, 2)), CAST(400.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3605, 1658, 2, N'ACE-2     ', 13, CAST(15.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3606, 1659, 1, N'BEARS     ', 4, CAST(32.00 AS Numeric(8, 2)), CAST(128.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3607, 1659, 2, N'GOLD      ', 8, CAST(779.00 AS Numeric(8, 2)), CAST(6232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3608, 1660, 1, N'JEWELRY-DL', 9, CAST(1749.00 AS Numeric(8, 2)), CAST(15741.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3609, 1661, 1, N'FLEX-O-MAT', 3, CAST(295.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3610, 1662, 1, N'O''NEILLS  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3611, 1662, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3612, 1663, 1, N'MAPS      ', 9, CAST(145.00 AS Numeric(8, 2)), CAST(1305.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3613, 1664, 1, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3614, 1664, 2, N'CUA       ', 15, CAST(49.00 AS Numeric(8, 2)), CAST(735.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3615, 1664, 3, N'DT        ', 15, CAST(179.00 AS Numeric(8, 2)), CAST(2685.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3616, 1665, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3617, 1665, 2, N'POPUP     ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3618, 1666, 1, N'OFFICE-1  ', 8, CAST(45.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3619, 1666, 2, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3620, 1666, 3, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3621, 1667, 1, N'UPDATE    ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3622, 1667, 2, N'TEXT-1    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3623, 1667, 3, N'TEXT-2    ', 6, CAST(59.00 AS Numeric(8, 2)), CAST(354.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3624, 1667, 4, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3625, 1667, 5, N'TEXT-4    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3626, 1668, 1, N'VINO-LM   ', 7, CAST(5.00 AS Numeric(8, 2)), CAST(35.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3627, 1669, 1, N'UN-CL-1   ', 16, CAST(399.00 AS Numeric(8, 2)), CAST(6384.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3628, 1669, 2, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3629, 1670, 1, N'UNIXGUIDE ', 15, CAST(499.00 AS Numeric(8, 2)), CAST(7485.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3630, 1671, 1, N'FLEX-O-MAT', 10, CAST(295.00 AS Numeric(8, 2)), CAST(2950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3631, 1672, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3632, 1672, 2, N'TABLE     ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3633, 1673, 1, N'TABLE-MAH ', 11, CAST(1250.00 AS Numeric(8, 2)), CAST(13750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3634, 1673, 2, N'TABLE-MPL ', 11, CAST(319.00 AS Numeric(8, 2)), CAST(3509.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3635, 1674, 1, N'JEWELRY-DL', 11, CAST(1749.00 AS Numeric(8, 2)), CAST(19239.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3636, 1674, 2, N'JEWELRY-I ', 11, CAST(1299.00 AS Numeric(8, 2)), CAST(14289.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3637, 1675, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3638, 1675, 2, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3639, 1676, 1, N'MAPS      ', 3, CAST(145.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3640, 1677, 1, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3641, 1677, 2, N'PULLMAN   ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3642, 1678, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3643, 1678, 2, N'RUNMTR2   ', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3644, 1679, 1, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3645, 1680, 1, N'JOKES     ', 3, CAST(12.00 AS Numeric(8, 2)), CAST(36.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3646, 1681, 1, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3647, 1681, 2, N'REPORTS II', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3648, 1682, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3649, 1682, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3650, 1683, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3651, 1683, 2, N'STARTREK  ', 1, CAST(1599.00 AS Numeric(8, 2)), CAST(1599.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3652, 1684, 1, N'MAPS      ', 4, CAST(145.00 AS Numeric(8, 2)), CAST(580.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3653, 1685, 1, N'OFFICE-S  ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3654, 1685, 2, N'OFFICE-2  ', 4, CAST(65.00 AS Numeric(8, 2)), CAST(260.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3655, 1686, 1, N'MENU      ', 7, CAST(129.00 AS Numeric(8, 2)), CAST(903.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3656, 1687, 1, N'NITE-LITE ', 4, CAST(24.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3657, 1687, 2, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3658, 1687, 3, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3659, 1688, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3660, 1688, 2, N'OFFICE-1  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3661, 1689, 1, N'BRIDGE    ', 3, CAST(195.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3662, 1689, 2, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3663, 1689, 3, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3664, 1690, 1, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3665, 1690, 2, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3666, 1691, 1, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3667, 1691, 2, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3668, 1691, 3, N'TEXT-3    ', 8, CAST(69.00 AS Numeric(8, 2)), CAST(552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3669, 1691, 4, N'TEXT-4    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3670, 1691, 5, N'TEXT-ALL  ', 8, CAST(595.00 AS Numeric(8, 2)), CAST(4760.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3671, 1692, 1, N'JOKES     ', 15, CAST(12.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3672, 1693, 1, N'ACE-2     ', 15, CAST(15.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3673, 1693, 2, N'ACE1      ', 15, CAST(25.00 AS Numeric(8, 2)), CAST(375.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3674, 1694, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3675, 1694, 2, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3676, 1695, 1, N'OFFICE-1  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3677, 1695, 2, N'OFFICE-2  ', 11, CAST(65.00 AS Numeric(8, 2)), CAST(715.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3678, 1695, 3, N'OFFICE-S  ', 11, CAST(19.00 AS Numeric(8, 2)), CAST(209.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3679, 1696, 1, N'GOLD-DLX  ', 9, CAST(1079.00 AS Numeric(8, 2)), CAST(9711.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3680, 1697, 1, N'FLEX-O-MAT', 11, CAST(295.00 AS Numeric(8, 2)), CAST(3245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3681, 1698, 1, N'BRIDGE    ', 13, CAST(195.00 AS Numeric(8, 2)), CAST(2535.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3682, 1698, 2, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3683, 1698, 3, N'VINO-LM   ', 10, CAST(5.00 AS Numeric(8, 2)), CAST(50.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3684, 1699, 1, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3685, 1700, 1, N'TABLE     ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3686, 1700, 2, N'TABLE-MAH ', 9, CAST(1250.00 AS Numeric(8, 2)), CAST(11250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3687, 1700, 3, N'TABLE-MPL ', 6, CAST(319.00 AS Numeric(8, 2)), CAST(1914.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3688, 1700, 4, N'OFFICE-1  ', 16, CAST(45.00 AS Numeric(8, 2)), CAST(720.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3689, 1700, 5, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3690, 1700, 6, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3691, 1701, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3692, 1701, 2, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3693, 1702, 1, N'BRIDGE    ', 7, CAST(195.00 AS Numeric(8, 2)), CAST(1365.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3694, 1703, 1, N'O''NEILLS  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3695, 1703, 2, N'POPUP     ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3696, 1703, 3, N'PULLMAN   ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3697, 1704, 1, N'TEXT-1    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3698, 1704, 2, N'TEXT-2    ', 3, CAST(59.00 AS Numeric(8, 2)), CAST(177.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3699, 1704, 3, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3700, 1704, 4, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3701, 1704, 5, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3702, 1705, 1, N'MODEMS    ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3703, 1705, 2, N'REPORTS   ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3704, 1706, 1, N'JEWELRY-I ', 6, CAST(1299.00 AS Numeric(8, 2)), CAST(7794.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3705, 1707, 1, N'STARTREK  ', 6, CAST(1599.00 AS Numeric(8, 2)), CAST(9594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3706, 1708, 1, N'REPORTS II', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3707, 1709, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3708, 1709, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3709, 1709, 3, N'OFFICE-S  ', 13, CAST(19.00 AS Numeric(8, 2)), CAST(247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3710, 1710, 1, N'UN-CL-1   ', 13, CAST(399.00 AS Numeric(8, 2)), CAST(5187.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3711, 1710, 2, N'UN-CL-2   ', 13, CAST(659.00 AS Numeric(8, 2)), CAST(8567.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3712, 1710, 3, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3713, 1711, 1, N'RUNMTR    ', 15, CAST(79.00 AS Numeric(8, 2)), CAST(1185.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3714, 1711, 2, N'RUNMTR2   ', 7, CAST(199.00 AS Numeric(8, 2)), CAST(1393.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3715, 1712, 1, N'O''NEILLS  ', 15, CAST(45.00 AS Numeric(8, 2)), CAST(675.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3716, 1713, 1, N'GOLD      ', 14, CAST(779.00 AS Numeric(8, 2)), CAST(10906.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3717, 1714, 1, N'CITIES    ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3718, 1714, 2, N'MAPS      ', 14, CAST(145.00 AS Numeric(8, 2)), CAST(2030.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3719, 1715, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3720, 1715, 2, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3721, 1715, 3, N'UPDATE    ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3722, 1715, 4, N'VINO-LM   ', 3, CAST(5.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3723, 1716, 1, N'POOL      ', 3, CAST(15.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3724, 1716, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3725, 1717, 1, N'FLEX-O-MAT', 3, CAST(295.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3726, 1718, 1, N'BRIDGE    ', 8, CAST(195.00 AS Numeric(8, 2)), CAST(1560.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3727, 1718, 2, N'DATES     ', 12, CAST(29.00 AS Numeric(8, 2)), CAST(348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3728, 1719, 1, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3729, 1719, 2, N'OFFICE-2  ', 10, CAST(65.00 AS Numeric(8, 2)), CAST(650.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3730, 1719, 3, N'REPORTS   ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3731, 1719, 4, N'VINO-LM   ', 5, CAST(5.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3732, 1720, 1, N'VINO-LM   ', 6, CAST(5.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3733, 1721, 1, N'NITE-LITE ', 4, CAST(24.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3734, 1721, 2, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3735, 1721, 3, N'STARTREK  ', 1, CAST(1599.00 AS Numeric(8, 2)), CAST(1599.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3736, 1722, 1, N'OFFICE-1  ', 13, CAST(45.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3737, 1722, 2, N'OFFICE-2  ', 9, CAST(65.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3738, 1722, 3, N'OFFICE-S  ', 9, CAST(19.00 AS Numeric(8, 2)), CAST(171.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3739, 1723, 1, N'PICTURE   ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3740, 1724, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3741, 1724, 2, N'RUNMTR2   ', 16, CAST(199.00 AS Numeric(8, 2)), CAST(3184.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3742, 1725, 1, N'MAPS      ', 16, CAST(145.00 AS Numeric(8, 2)), CAST(2320.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3743, 1726, 1, N'JOKES     ', 6, CAST(12.00 AS Numeric(8, 2)), CAST(72.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3744, 1726, 2, N'POOL      ', 6, CAST(15.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3745, 1727, 1, N'VINO-LM   ', 9, CAST(5.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3746, 1728, 1, N'BEARS     ', 4, CAST(32.00 AS Numeric(8, 2)), CAST(128.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3747, 1729, 1, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3748, 1730, 1, N'TEXT-ALL  ', 7, CAST(595.00 AS Numeric(8, 2)), CAST(4165.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3749, 1731, 1, N'TEXT-1    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3750, 1731, 2, N'TEXT-2    ', 8, CAST(59.00 AS Numeric(8, 2)), CAST(472.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3751, 1731, 3, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3752, 1731, 4, N'TEXT-4    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3753, 1732, 1, N'UN-CL-1   ', 3, CAST(399.00 AS Numeric(8, 2)), CAST(1197.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3754, 1732, 2, N'UN-CL-2   ', 8, CAST(659.00 AS Numeric(8, 2)), CAST(5272.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3755, 1732, 3, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3756, 1733, 1, N'CUA       ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3757, 1734, 1, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3758, 1735, 1, N'BRIDGE    ', 4, CAST(195.00 AS Numeric(8, 2)), CAST(780.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3759, 1736, 1, N'POOL      ', 6, CAST(15.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3760, 1737, 1, N'DATES     ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3761, 1737, 2, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3762, 1737, 3, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3763, 1738, 1, N'TEXT-1    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3764, 1738, 2, N'TEXT-2    ', 11, CAST(59.00 AS Numeric(8, 2)), CAST(649.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3765, 1738, 3, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3766, 1738, 4, N'TEXT-4    ', 15, CAST(99.00 AS Numeric(8, 2)), CAST(1485.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3767, 1739, 1, N'RUNMTR    ', 15, CAST(79.00 AS Numeric(8, 2)), CAST(1185.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3768, 1739, 2, N'POPUP     ', 15, CAST(49.00 AS Numeric(8, 2)), CAST(735.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3769, 1739, 3, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3770, 1739, 5, N'MENU      ', 12, CAST(129.00 AS Numeric(8, 2)), CAST(1548.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3771, 1740, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3772, 1740, 2, N'CITIES    ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3773, 1740, 3, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3774, 1740, 4, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3775, 1741, 1, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3776, 1741, 2, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3777, 1741, 3, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3778, 1741, 4, N'REPORTS   ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3779, 1742, 1, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3780, 1742, 2, N'GOLD      ', 4, CAST(779.00 AS Numeric(8, 2)), CAST(3116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3781, 1743, 1, N'MENU      ', 14, CAST(129.00 AS Numeric(8, 2)), CAST(1806.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3782, 1743, 2, N'MODEMS    ', 14, CAST(129.00 AS Numeric(8, 2)), CAST(1806.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3783, 1743, 3, N'TABLE-MAH ', 1, CAST(1250.00 AS Numeric(8, 2)), CAST(1250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3784, 1743, 4, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3785, 1744, 1, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3786, 1744, 2, N'TABLE     ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3787, 1745, 1, N'REPORTS   ', 16, CAST(179.00 AS Numeric(8, 2)), CAST(2864.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3788, 1745, 2, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3789, 1746, 1, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3790, 1746, 2, N'GOLD-DLX  ', 7, CAST(1079.00 AS Numeric(8, 2)), CAST(7553.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3791, 1747, 1, N'MODEMS    ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3792, 1747, 2, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3793, 1747, 3, N'TEXT-2    ', 1, CAST(59.00 AS Numeric(8, 2)), CAST(59.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3794, 1748, 1, N'TABLE-MPL ', 10, CAST(319.00 AS Numeric(8, 2)), CAST(3190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3795, 1748, 2, N'JEWELRY-I ', 4, CAST(1299.00 AS Numeric(8, 2)), CAST(5196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3796, 1748, 3, N'UN-CL-1   ', 4, CAST(399.00 AS Numeric(8, 2)), CAST(1596.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3797, 1749, 1, N'RUNMTR    ', 4, CAST(79.00 AS Numeric(8, 2)), CAST(316.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3798, 1749, 2, N'RUNMTR2   ', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3799, 1749, 3, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3800, 1750, 1, N'JEWELRY-DL', 4, CAST(1749.00 AS Numeric(8, 2)), CAST(6996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3801, 1750, 2, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3802, 1750, 3, N'UN-CL-2   ', 13, CAST(659.00 AS Numeric(8, 2)), CAST(8567.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3803, 1751, 2, N'UPDATE    ', 9, CAST(19.00 AS Numeric(8, 2)), CAST(171.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3804, 1751, 3, N'JOKES     ', 4, CAST(12.00 AS Numeric(8, 2)), CAST(48.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3805, 1751, 4, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3806, 1751, 5, N'UNIXGUIDE ', 3, CAST(499.00 AS Numeric(8, 2)), CAST(1497.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3807, 1752, 2, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3808, 1752, 3, N'REPORTS II', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3809, 1753, 1, N'JEWELRY-DL', 5, CAST(1749.00 AS Numeric(8, 2)), CAST(8745.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3810, 1753, 2, N'FLEX-O-MAT', 11, CAST(295.00 AS Numeric(8, 2)), CAST(3245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3811, 1754, 1, N'MENU      ', 11, CAST(129.00 AS Numeric(8, 2)), CAST(1419.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3812, 1754, 3, N'MAPS      ', 11, CAST(145.00 AS Numeric(8, 2)), CAST(1595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3813, 1755, 1, N'JEWELRY-I ', 10, CAST(1299.00 AS Numeric(8, 2)), CAST(12990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3814, 1756, 1, N'UN-CL-2   ', 10, CAST(659.00 AS Numeric(8, 2)), CAST(6590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3815, 1756, 3, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3816, 1757, 1, N'OFFICE-2  ', 6, CAST(65.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3817, 1757, 2, N'PULLMAN   ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3818, 1757, 3, N'TEXT-1    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3819, 1758, 2, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3820, 1758, 3, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3821, 1758, 4, N'PICTURE   ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3822, 1758, 5, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3823, 1759, 1, N'TEXT-ALL  ', 6, CAST(595.00 AS Numeric(8, 2)), CAST(3570.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3824, 1759, 2, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3825, 1759, 3, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3826, 1760, 1, N'GOLD      ', 4, CAST(779.00 AS Numeric(8, 2)), CAST(3116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3827, 1760, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3828, 1760, 3, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3829, 1760, 4, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3830, 1761, 1, N'CITIES    ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3831, 1761, 2, N'MENU      ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3832, 1761, 3, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3833, 1761, 4, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3834, 1762, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3835, 1762, 4, N'DT        ', 17, CAST(179.00 AS Numeric(8, 2)), CAST(3043.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3836, 1763, 16, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3837, 1763, 17, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3838, 1764, 1, N'CASE      ', 16, CAST(39.00 AS Numeric(8, 2)), CAST(624.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3839, 1764, 2, N'DATES     ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3840, 1764, 3, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3841, 1764, 4, N'MENU      ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3842, 1765, 1, N'DT        ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3843, 1765, 2, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3844, 1765, 3, N'TEXT-3    ', 8, CAST(69.00 AS Numeric(8, 2)), CAST(552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3845, 1765, 4, N'GOLD-DLX  ', 2, CAST(1079.00 AS Numeric(8, 2)), CAST(2158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3846, 1765, 5, N'TEXT-3    ', 11, CAST(69.00 AS Numeric(8, 2)), CAST(759.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3847, 1765, 6, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3848, 1766, 1, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3849, 1766, 2, N'CASE      ', 17, CAST(39.00 AS Numeric(8, 2)), CAST(663.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3850, 1766, 3, N'DATES     ', 17, CAST(29.00 AS Numeric(8, 2)), CAST(493.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3851, 1766, 4, N'CUA       ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3852, 1766, 5, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3853, 1767, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3854, 1767, 2, N'DT PK     ', 2, CAST(229.00 AS Numeric(8, 2)), CAST(458.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3855, 1768, 1, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3856, 1768, 2, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3857, 1768, 3, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3858, 1768, 4, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3859, 1768, 5, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3860, 1768, 10, N'CASE      ', 16, CAST(39.00 AS Numeric(8, 2)), CAST(624.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3861, 1769, 1, N'BEARS     ', 16, CAST(30.00 AS Numeric(8, 2)), CAST(480.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3862, 1769, 4, N'BEARS     ', 16, CAST(30.00 AS Numeric(8, 2)), CAST(480.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3863, 1769, 5, N'VINO-LM   ', 6, CAST(5.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3864, 1770, 1, N'DT        ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3865, 1770, 2, N'DT PK     ', 14, CAST(229.00 AS Numeric(8, 2)), CAST(3206.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3866, 1771, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3867, 1771, 2, N'DT        ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3868, 1772, 1, N'DT        ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3869, 1773, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3870, 1773, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3871, 1774, 1, N'BRIDGE    ', 8, CAST(195.00 AS Numeric(8, 2)), CAST(1560.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3872, 1774, 2, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3873, 1775, 1, N'ACE1      ', 12, CAST(25.00 AS Numeric(8, 2)), CAST(300.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3874, 1775, 2, N'ACE-2     ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3875, 1776, 1, N'BEARS     ', 9, CAST(32.00 AS Numeric(8, 2)), CAST(288.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3876, 1776, 2, N'GOLD      ', 14, CAST(779.00 AS Numeric(8, 2)), CAST(10906.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3877, 1777, 1, N'JEWELRY-DL', 14, CAST(1749.00 AS Numeric(8, 2)), CAST(24486.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3878, 1778, 1, N'FLEX-O-MAT', 14, CAST(295.00 AS Numeric(8, 2)), CAST(4130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3879, 1779, 1, N'O''NEILLS  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3880, 1779, 2, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3881, 1780, 1, N'MAPS      ', 8, CAST(145.00 AS Numeric(8, 2)), CAST(1160.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3882, 1781, 1, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3883, 1781, 2, N'CUA       ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3884, 1781, 3, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3885, 1782, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3886, 1782, 2, N'POPUP     ', 16, CAST(49.00 AS Numeric(8, 2)), CAST(784.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3887, 1783, 1, N'OFFICE-1  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3888, 1783, 2, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3889, 1783, 3, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3890, 1784, 1, N'UPDATE    ', 16, CAST(19.00 AS Numeric(8, 2)), CAST(304.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3891, 1784, 2, N'TEXT-1    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3892, 1784, 3, N'TEXT-2    ', 7, CAST(59.00 AS Numeric(8, 2)), CAST(413.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3893, 1784, 4, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3894, 1784, 5, N'TEXT-4    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3895, 1785, 1, N'VINO-LM   ', 8, CAST(5.00 AS Numeric(8, 2)), CAST(40.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3896, 1786, 1, N'UN-CL-1   ', 14, CAST(399.00 AS Numeric(8, 2)), CAST(5586.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3897, 1786, 2, N'UN-CL-2   ', 12, CAST(659.00 AS Numeric(8, 2)), CAST(7908.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3898, 1787, 1, N'UNIXGUIDE ', 12, CAST(499.00 AS Numeric(8, 2)), CAST(5988.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3899, 1788, 1, N'FLEX-O-MAT', 3, CAST(295.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3900, 1789, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3901, 1789, 2, N'TABLE     ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3902, 1790, 1, N'TABLE-MAH ', 2, CAST(1250.00 AS Numeric(8, 2)), CAST(2500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3903, 1790, 2, N'TABLE-MPL ', 2, CAST(319.00 AS Numeric(8, 2)), CAST(638.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3904, 1791, 1, N'JEWELRY-DL', 9, CAST(1749.00 AS Numeric(8, 2)), CAST(15741.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3905, 1791, 2, N'JEWELRY-I ', 9, CAST(1299.00 AS Numeric(8, 2)), CAST(11691.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3906, 1792, 1, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3907, 1792, 2, N'DT PK     ', 8, CAST(229.00 AS Numeric(8, 2)), CAST(1832.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3908, 1793, 1, N'MAPS      ', 4, CAST(145.00 AS Numeric(8, 2)), CAST(580.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3909, 1794, 1, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3910, 1794, 2, N'PULLMAN   ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3911, 1795, 1, N'RUNMTR    ', 8, CAST(79.00 AS Numeric(8, 2)), CAST(632.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3912, 1795, 2, N'RUNMTR2   ', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3913, 1796, 1, N'OFFICE-S  ', 11, CAST(19.00 AS Numeric(8, 2)), CAST(209.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3914, 1797, 1, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3915, 1798, 1, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3916, 1798, 2, N'REPORTS II', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3917, 1799, 1, N'MAPS      ', 4, CAST(145.00 AS Numeric(8, 2)), CAST(580.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3918, 1799, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3919, 1800, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3920, 1800, 2, N'STARTREK  ', 3, CAST(1599.00 AS Numeric(8, 2)), CAST(4797.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3921, 1801, 1, N'MAPS      ', 10, CAST(145.00 AS Numeric(8, 2)), CAST(1450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3922, 1802, 1, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3923, 1802, 2, N'OFFICE-2  ', 12, CAST(65.00 AS Numeric(8, 2)), CAST(780.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3924, 1803, 1, N'MENU      ', 2, CAST(129.00 AS Numeric(8, 2)), CAST(258.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3925, 1804, 1, N'NITE-LITE ', 2, CAST(24.00 AS Numeric(8, 2)), CAST(48.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3926, 1804, 2, N'TABLE     ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3927, 1804, 3, N'UPDATE    ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3928, 1805, 1, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3929, 1805, 2, N'OFFICE-1  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3930, 1806, 1, N'BRIDGE    ', 11, CAST(195.00 AS Numeric(8, 2)), CAST(2145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3931, 1806, 2, N'CITIES    ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3932, 1806, 3, N'PICTURE   ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3933, 1807, 1, N'UPDATE    ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3934, 1807, 2, N'OFFICE-S  ', 13, CAST(19.00 AS Numeric(8, 2)), CAST(247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3935, 1808, 1, N'TEXT-1    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3936, 1808, 2, N'TEXT-2    ', 8, CAST(59.00 AS Numeric(8, 2)), CAST(472.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3937, 1808, 3, N'TEXT-3    ', 8, CAST(69.00 AS Numeric(8, 2)), CAST(552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3938, 1808, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3939, 1808, 5, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3940, 1809, 1, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3941, 1810, 1, N'ACE-2     ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3942, 1810, 2, N'ACE1      ', 1, CAST(25.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3943, 1811, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3944, 1811, 2, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3945, 1812, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3946, 1812, 2, N'OFFICE-2  ', 4, CAST(65.00 AS Numeric(8, 2)), CAST(260.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3947, 1812, 3, N'OFFICE-S  ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3948, 1813, 1, N'GOLD-DLX  ', 1, CAST(1079.00 AS Numeric(8, 2)), CAST(1079.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3949, 1814, 1, N'FLEX-O-MAT', 5, CAST(295.00 AS Numeric(8, 2)), CAST(1475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3950, 1815, 1, N'BRIDGE    ', 2, CAST(195.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3951, 1815, 2, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3952, 1815, 3, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3953, 1816, 1, N'DT PK     ', 10, CAST(229.00 AS Numeric(8, 2)), CAST(2290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3954, 1817, 1, N'TABLE     ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3955, 1817, 2, N'TABLE-MAH ', 6, CAST(1250.00 AS Numeric(8, 2)), CAST(7500.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3956, 1817, 3, N'TABLE-MPL ', 1, CAST(319.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3957, 1817, 4, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3958, 1817, 5, N'OFFICE-2  ', 14, CAST(65.00 AS Numeric(8, 2)), CAST(910.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3959, 1817, 6, N'OFFICE-S  ', 11, CAST(19.00 AS Numeric(8, 2)), CAST(209.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3960, 1818, 1, N'CASE      ', 11, CAST(39.00 AS Numeric(8, 2)), CAST(429.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3961, 1818, 2, N'CUA       ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3962, 1819, 1, N'BRIDGE    ', 12, CAST(195.00 AS Numeric(8, 2)), CAST(2340.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3963, 1820, 1, N'O''NEILLS  ', 12, CAST(45.00 AS Numeric(8, 2)), CAST(540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3964, 1820, 2, N'POPUP     ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3965, 1820, 3, N'PULLMAN   ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3966, 1821, 1, N'TEXT-1    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3967, 1821, 2, N'TEXT-2    ', 5, CAST(59.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3968, 1821, 3, N'TEXT-3    ', 10, CAST(69.00 AS Numeric(8, 2)), CAST(690.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3969, 1821, 4, N'TEXT-4    ', 10, CAST(99.00 AS Numeric(8, 2)), CAST(990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3970, 1821, 5, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3971, 1822, 1, N'MODEMS    ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3972, 1822, 2, N'REPORTS   ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3973, 1823, 1, N'JEWELRY-I ', 6, CAST(1299.00 AS Numeric(8, 2)), CAST(7794.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3974, 1824, 1, N'STARTREK  ', 6, CAST(1599.00 AS Numeric(8, 2)), CAST(9594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3975, 1825, 1, N'REPORTS II', 6, CAST(199.00 AS Numeric(8, 2)), CAST(1194.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3976, 1826, 1, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3977, 1826, 2, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3978, 1826, 3, N'OFFICE-S  ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3979, 1827, 1, N'UN-CL-1   ', 15, CAST(399.00 AS Numeric(8, 2)), CAST(5985.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3980, 1827, 2, N'UN-CL-2   ', 15, CAST(659.00 AS Numeric(8, 2)), CAST(9885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3981, 1827, 3, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3982, 1828, 1, N'RUNMTR    ', 10, CAST(79.00 AS Numeric(8, 2)), CAST(790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3983, 1828, 2, N'RUNMTR2   ', 10, CAST(199.00 AS Numeric(8, 2)), CAST(1990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3984, 1829, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3985, 1830, 1, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3986, 1831, 1, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3987, 1831, 2, N'MAPS      ', 7, CAST(145.00 AS Numeric(8, 2)), CAST(1015.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3988, 1832, 1, N'O''NEILLS  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3989, 1832, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3990, 1832, 3, N'UPDATE    ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3991, 1832, 4, N'VINO-LM   ', 12, CAST(5.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3992, 1833, 1, N'POOL      ', 9, CAST(15.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3993, 1833, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3994, 1834, 1, N'FLEX-O-MAT', 8, CAST(295.00 AS Numeric(8, 2)), CAST(2360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3995, 1835, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3996, 1835, 2, N'DATES     ', 14, CAST(29.00 AS Numeric(8, 2)), CAST(406.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3997, 1836, 1, N'MENU      ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3998, 1836, 2, N'OFFICE-2  ', 4, CAST(65.00 AS Numeric(8, 2)), CAST(260.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (3999, 1836, 3, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4000, 1836, 4, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4001, 1837, 1, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4002, 1838, 1, N'NITE-LITE ', 1, CAST(24.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4003, 1838, 2, N'POPUP     ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4004, 1838, 3, N'STARTREK  ', 8, CAST(1599.00 AS Numeric(8, 2)), CAST(12792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4005, 1839, 1, N'OFFICE-1  ', 8, CAST(45.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4006, 1839, 2, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4007, 1839, 3, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4008, 1840, 1, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4009, 1841, 1, N'RUNMTR    ', 2, CAST(79.00 AS Numeric(8, 2)), CAST(158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4010, 1841, 2, N'RUNMTR2   ', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4011, 1842, 1, N'MAPS      ', 5, CAST(145.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4012, 1843, 1, N'JOKES     ', 9, CAST(12.00 AS Numeric(8, 2)), CAST(108.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4013, 1843, 2, N'POOL      ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4014, 1844, 1, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4015, 1845, 1, N'BEARS     ', 4, CAST(32.00 AS Numeric(8, 2)), CAST(128.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4016, 1846, 1, N'CITIES    ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4017, 1847, 1, N'TEXT-ALL  ', 8, CAST(595.00 AS Numeric(8, 2)), CAST(4760.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4018, 1848, 1, N'TEXT-1    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4019, 1848, 2, N'TEXT-2    ', 8, CAST(59.00 AS Numeric(8, 2)), CAST(472.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4020, 1848, 3, N'TEXT-3    ', 8, CAST(69.00 AS Numeric(8, 2)), CAST(552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4021, 1848, 4, N'TEXT-4    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4022, 1849, 1, N'UN-CL-1   ', 1, CAST(399.00 AS Numeric(8, 2)), CAST(399.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4023, 1849, 2, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4024, 1849, 3, N'UNIXGUIDE ', 5, CAST(499.00 AS Numeric(8, 2)), CAST(2495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4025, 1850, 1, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4026, 1851, 1, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4027, 1852, 1, N'BRIDGE    ', 12, CAST(195.00 AS Numeric(8, 2)), CAST(2340.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4028, 1853, 1, N'POOL      ', 8, CAST(15.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4029, 1854, 1, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4030, 1854, 2, N'DT        ', 14, CAST(179.00 AS Numeric(8, 2)), CAST(2506.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4031, 1854, 3, N'DT PK     ', 14, CAST(229.00 AS Numeric(8, 2)), CAST(3206.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4032, 1855, 1, N'TEXT-1    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4033, 1855, 2, N'TEXT-2    ', 6, CAST(59.00 AS Numeric(8, 2)), CAST(354.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4034, 1855, 3, N'TEXT-3    ', 5, CAST(69.00 AS Numeric(8, 2)), CAST(345.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4035, 1855, 4, N'TEXT-4    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4036, 1856, 1, N'RUNMTR    ', 8, CAST(79.00 AS Numeric(8, 2)), CAST(632.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4037, 1856, 2, N'POPUP     ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4038, 1856, 3, N'DT        ', 18, CAST(179.00 AS Numeric(8, 2)), CAST(3222.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4039, 1856, 5, N'MENU      ', 18, CAST(129.00 AS Numeric(8, 2)), CAST(2322.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4040, 1857, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4041, 1857, 2, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4042, 1857, 3, N'MENU      ', 13, CAST(129.00 AS Numeric(8, 2)), CAST(1677.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4043, 1857, 4, N'DT        ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4044, 1858, 1, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4045, 1858, 2, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4046, 1858, 3, N'TEXT-4    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4047, 1858, 4, N'REPORTS   ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4048, 1859, 1, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4049, 1859, 2, N'GOLD      ', 10, CAST(779.00 AS Numeric(8, 2)), CAST(7790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4050, 1860, 1, N'MENU      ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4051, 1860, 2, N'MODEMS    ', 11, CAST(129.00 AS Numeric(8, 2)), CAST(1419.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4052, 1860, 3, N'TABLE-MAH ', 11, CAST(1250.00 AS Numeric(8, 2)), CAST(13750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4053, 1860, 4, N'REPORTS   ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4054, 1861, 1, N'PULLMAN   ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4055, 1861, 2, N'TABLE     ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4056, 1862, 1, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4057, 1862, 2, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4058, 1863, 1, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4059, 1863, 2, N'GOLD-DLX  ', 8, CAST(1079.00 AS Numeric(8, 2)), CAST(8632.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4060, 1864, 1, N'MODEMS    ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4061, 1864, 2, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4062, 1864, 3, N'TEXT-2    ', 6, CAST(59.00 AS Numeric(8, 2)), CAST(354.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4063, 1865, 1, N'TABLE-MPL ', 8, CAST(319.00 AS Numeric(8, 2)), CAST(2552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4064, 1865, 2, N'JEWELRY-I ', 8, CAST(1299.00 AS Numeric(8, 2)), CAST(10392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4065, 1865, 3, N'UN-CL-1   ', 3, CAST(399.00 AS Numeric(8, 2)), CAST(1197.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4066, 1866, 1, N'RUNMTR    ', 6, CAST(79.00 AS Numeric(8, 2)), CAST(474.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4067, 1866, 2, N'RUNMTR2   ', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4068, 1866, 3, N'POPUP     ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4069, 1867, 1, N'JEWELRY-DL', 6, CAST(1749.00 AS Numeric(8, 2)), CAST(10494.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4070, 1867, 2, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4071, 1867, 3, N'UN-CL-2   ', 6, CAST(659.00 AS Numeric(8, 2)), CAST(3954.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4072, 1868, 2, N'UPDATE    ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4073, 1868, 3, N'JOKES     ', 13, CAST(12.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4074, 1868, 4, N'TEXT-ALL  ', 4, CAST(595.00 AS Numeric(8, 2)), CAST(2380.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4075, 1868, 5, N'UNIXGUIDE ', 4, CAST(499.00 AS Numeric(8, 2)), CAST(1996.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4076, 1869, 2, N'MODEMS    ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4077, 1869, 3, N'REPORTS II', 4, CAST(199.00 AS Numeric(8, 2)), CAST(796.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4078, 1870, 1, N'JEWELRY-DL', 14, CAST(1749.00 AS Numeric(8, 2)), CAST(24486.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4079, 1870, 2, N'FLEX-O-MAT', 14, CAST(295.00 AS Numeric(8, 2)), CAST(4130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4080, 1871, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4081, 1871, 3, N'MAPS      ', 12, CAST(145.00 AS Numeric(8, 2)), CAST(1740.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4082, 1872, 1, N'JEWELRY-I ', 9, CAST(1299.00 AS Numeric(8, 2)), CAST(11691.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4083, 1873, 1, N'UN-CL-2   ', 9, CAST(659.00 AS Numeric(8, 2)), CAST(5931.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4084, 1873, 3, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4085, 1874, 1, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4086, 1874, 2, N'PULLMAN   ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4087, 1874, 3, N'TEXT-1    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4088, 1875, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4089, 1875, 3, N'DATES     ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4090, 1875, 4, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4091, 1875, 5, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4092, 1876, 1, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4093, 1876, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4094, 1876, 3, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4095, 1877, 1, N'GOLD      ', 2, CAST(779.00 AS Numeric(8, 2)), CAST(1558.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4096, 1877, 2, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4097, 1877, 3, N'CITIES    ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4098, 1877, 4, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4099, 1878, 1, N'CITIES    ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4100, 1878, 2, N'MENU      ', 11, CAST(129.00 AS Numeric(8, 2)), CAST(1419.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4101, 1878, 3, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4102, 1878, 4, N'DT PK     ', 12, CAST(229.00 AS Numeric(8, 2)), CAST(2748.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4103, 1879, 2, N'CASE      ', 12, CAST(39.00 AS Numeric(8, 2)), CAST(468.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4104, 1879, 4, N'DT        ', 12, CAST(179.00 AS Numeric(8, 2)), CAST(2148.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4105, 1880, 16, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4106, 1880, 17, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4107, 1881, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4108, 1881, 2, N'DATES     ', 12, CAST(29.00 AS Numeric(8, 2)), CAST(348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4109, 1881, 3, N'DT PK     ', 12, CAST(229.00 AS Numeric(8, 2)), CAST(2748.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4110, 1881, 4, N'MENU      ', 14, CAST(129.00 AS Numeric(8, 2)), CAST(1806.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4111, 1882, 1, N'DT        ', 14, CAST(179.00 AS Numeric(8, 2)), CAST(2506.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4112, 1882, 2, N'CITIES    ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4113, 1882, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4114, 1882, 4, N'GOLD-DLX  ', 4, CAST(1079.00 AS Numeric(8, 2)), CAST(4316.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4115, 1882, 5, N'TEXT-3    ', 9, CAST(69.00 AS Numeric(8, 2)), CAST(621.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4116, 1882, 6, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4117, 1883, 1, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4118, 1883, 2, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4119, 1883, 3, N'DATES     ', 14, CAST(29.00 AS Numeric(8, 2)), CAST(406.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4120, 1883, 4, N'CUA       ', 14, CAST(49.00 AS Numeric(8, 2)), CAST(686.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4121, 1883, 5, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4122, 1884, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4123, 1884, 2, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4124, 1885, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4125, 1885, 2, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4126, 1885, 3, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4127, 1885, 4, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4128, 1885, 5, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4129, 1885, 10, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4130, 1886, 1, N'BEARS     ', 11, CAST(30.00 AS Numeric(8, 2)), CAST(330.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4131, 1886, 4, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4132, 1886, 5, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4133, 1887, 1, N'DT        ', 18, CAST(179.00 AS Numeric(8, 2)), CAST(3222.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4134, 1887, 2, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4135, 1888, 1, N'CASE      ', 12, CAST(39.00 AS Numeric(8, 2)), CAST(468.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4136, 1888, 2, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4137, 1889, 1, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4138, 1890, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4139, 1890, 2, N'CUA       ', 17, CAST(49.00 AS Numeric(8, 2)), CAST(833.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4140, 1891, 1, N'BRIDGE    ', 3, CAST(195.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4141, 1891, 2, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4142, 1892, 1, N'ACE1      ', 8, CAST(25.00 AS Numeric(8, 2)), CAST(200.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4143, 1892, 2, N'ACE-2     ', 5, CAST(15.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4144, 1893, 1, N'BEARS     ', 8, CAST(32.00 AS Numeric(8, 2)), CAST(256.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4145, 1893, 2, N'GOLD      ', 8, CAST(779.00 AS Numeric(8, 2)), CAST(6232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4146, 1894, 1, N'JEWELRY-DL', 9, CAST(1749.00 AS Numeric(8, 2)), CAST(15741.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4147, 1895, 1, N'FLEX-O-MAT', 9, CAST(295.00 AS Numeric(8, 2)), CAST(2655.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4148, 1896, 1, N'O''NEILLS  ', 9, CAST(45.00 AS Numeric(8, 2)), CAST(405.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4149, 1896, 2, N'PICTURE   ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4150, 1897, 1, N'MAPS      ', 7, CAST(145.00 AS Numeric(8, 2)), CAST(1015.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4151, 1898, 1, N'UPDATE    ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4152, 1898, 2, N'CUA       ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4153, 1898, 3, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4154, 1899, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4155, 1899, 2, N'POPUP     ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4156, 1900, 1, N'OFFICE-1  ', 14, CAST(45.00 AS Numeric(8, 2)), CAST(630.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4157, 1900, 2, N'OFFICE-2  ', 14, CAST(65.00 AS Numeric(8, 2)), CAST(910.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4158, 1900, 3, N'OFFICE-S  ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4159, 1901, 1, N'UPDATE    ', 5, CAST(19.00 AS Numeric(8, 2)), CAST(95.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4160, 1901, 2, N'TEXT-1    ', 12, CAST(99.00 AS Numeric(8, 2)), CAST(1188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4161, 1901, 3, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4162, 1901, 4, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4163, 1901, 5, N'TEXT-4    ', 11, CAST(99.00 AS Numeric(8, 2)), CAST(1089.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4164, 1902, 1, N'VINO-LM   ', 10, CAST(5.00 AS Numeric(8, 2)), CAST(50.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4165, 1903, 1, N'UN-CL-1   ', 10, CAST(399.00 AS Numeric(8, 2)), CAST(3990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4166, 1903, 2, N'UN-CL-2   ', 10, CAST(659.00 AS Numeric(8, 2)), CAST(6590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4167, 1904, 1, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4168, 1905, 1, N'FLEX-O-MAT', 3, CAST(295.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4169, 1906, 1, N'O''NEILLS  ', 3, CAST(45.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4170, 1906, 2, N'TABLE     ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4171, 1907, 1, N'TABLE-MAH ', 11, CAST(1250.00 AS Numeric(8, 2)), CAST(13750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4172, 1907, 2, N'TABLE-MPL ', 11, CAST(319.00 AS Numeric(8, 2)), CAST(3509.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4173, 1908, 1, N'JEWELRY-DL', 11, CAST(1749.00 AS Numeric(8, 2)), CAST(19239.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4174, 1908, 2, N'JEWELRY-I ', 11, CAST(1299.00 AS Numeric(8, 2)), CAST(14289.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4175, 1909, 1, N'CASE      ', 11, CAST(39.00 AS Numeric(8, 2)), CAST(429.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4176, 1909, 2, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4177, 1910, 1, N'MAPS      ', 13, CAST(145.00 AS Numeric(8, 2)), CAST(1885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4178, 1911, 1, N'PICTURE   ', 13, CAST(29.00 AS Numeric(8, 2)), CAST(377.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4179, 1911, 2, N'PULLMAN   ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4180, 1912, 1, N'RUNMTR    ', 10, CAST(79.00 AS Numeric(8, 2)), CAST(790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4181, 1912, 2, N'RUNMTR2   ', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4182, 1913, 1, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4183, 1914, 1, N'JOKES     ', 12, CAST(12.00 AS Numeric(8, 2)), CAST(144.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4184, 1915, 1, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4185, 1915, 2, N'REPORTS II', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4186, 1916, 1, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4187, 1916, 2, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4188, 1917, 1, N'BEARS     ', 4, CAST(32.00 AS Numeric(8, 2)), CAST(128.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4189, 1917, 2, N'STARTREK  ', 1, CAST(1599.00 AS Numeric(8, 2)), CAST(1599.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4190, 1918, 1, N'MAPS      ', 7, CAST(145.00 AS Numeric(8, 2)), CAST(1015.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4191, 1919, 1, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4192, 1919, 2, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4193, 1920, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4194, 1921, 1, N'NITE-LITE ', 9, CAST(24.00 AS Numeric(8, 2)), CAST(216.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4195, 1921, 2, N'TABLE     ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4196, 1921, 3, N'UPDATE    ', 9, CAST(19.00 AS Numeric(8, 2)), CAST(171.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4197, 1922, 1, N'CASE      ', 12, CAST(39.00 AS Numeric(8, 2)), CAST(468.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4198, 1922, 2, N'OFFICE-1  ', 12, CAST(45.00 AS Numeric(8, 2)), CAST(540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4199, 1923, 1, N'BRIDGE    ', 12, CAST(195.00 AS Numeric(8, 2)), CAST(2340.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4200, 1923, 2, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4201, 1923, 3, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4202, 1924, 1, N'UPDATE    ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4203, 1924, 2, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4204, 1925, 1, N'TEXT-1    ', 16, CAST(99.00 AS Numeric(8, 2)), CAST(1584.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4205, 1925, 2, N'TEXT-2    ', 3, CAST(59.00 AS Numeric(8, 2)), CAST(177.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4206, 1925, 3, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4207, 1925, 4, N'TEXT-4    ', 9, CAST(99.00 AS Numeric(8, 2)), CAST(891.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4208, 1925, 5, N'TEXT-ALL  ', 9, CAST(595.00 AS Numeric(8, 2)), CAST(5355.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4209, 1926, 1, N'JOKES     ', 9, CAST(12.00 AS Numeric(8, 2)), CAST(108.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4210, 1927, 1, N'ACE-2     ', 4, CAST(15.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4211, 1927, 2, N'ACE1      ', 3, CAST(25.00 AS Numeric(8, 2)), CAST(75.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4212, 1928, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4213, 1928, 2, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4214, 1929, 1, N'OFFICE-1  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4215, 1929, 2, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4216, 1929, 3, N'OFFICE-S  ', 18, CAST(19.00 AS Numeric(8, 2)), CAST(342.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4217, 1930, 1, N'GOLD-DLX  ', 5, CAST(1079.00 AS Numeric(8, 2)), CAST(5395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4218, 1931, 1, N'FLEX-O-MAT', 6, CAST(295.00 AS Numeric(8, 2)), CAST(1770.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4219, 1932, 1, N'BRIDGE    ', 6, CAST(195.00 AS Numeric(8, 2)), CAST(1170.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4220, 1932, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4221, 1932, 3, N'VINO-LM   ', 4, CAST(5.00 AS Numeric(8, 2)), CAST(20.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4222, 1933, 1, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4223, 1934, 1, N'TABLE     ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4224, 1934, 2, N'TABLE-MAH ', 1, CAST(1250.00 AS Numeric(8, 2)), CAST(1250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4225, 1934, 3, N'TABLE-MPL ', 4, CAST(319.00 AS Numeric(8, 2)), CAST(1276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4226, 1934, 4, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4227, 1934, 5, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4228, 1934, 6, N'OFFICE-S  ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4229, 1935, 1, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4230, 1935, 2, N'CUA       ', 17, CAST(49.00 AS Numeric(8, 2)), CAST(833.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4231, 1936, 1, N'BRIDGE    ', 3, CAST(195.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4232, 1937, 1, N'O''NEILLS  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4233, 1937, 2, N'POPUP     ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4234, 1937, 3, N'PULLMAN   ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4235, 1938, 1, N'TEXT-1    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4236, 1938, 2, N'TEXT-2    ', 14, CAST(59.00 AS Numeric(8, 2)), CAST(826.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4237, 1938, 3, N'TEXT-3    ', 14, CAST(69.00 AS Numeric(8, 2)), CAST(966.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4238, 1938, 4, N'TEXT-4    ', 14, CAST(99.00 AS Numeric(8, 2)), CAST(1386.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4239, 1938, 5, N'TEXT-ALL  ', 14, CAST(595.00 AS Numeric(8, 2)), CAST(8330.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4240, 1939, 1, N'MODEMS    ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4241, 1939, 2, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4242, 1940, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4243, 1941, 1, N'STARTREK  ', 4, CAST(1599.00 AS Numeric(8, 2)), CAST(6396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4244, 1942, 1, N'REPORTS II', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4245, 1943, 1, N'OFFICE-1  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4246, 1943, 2, N'OFFICE-2  ', 10, CAST(65.00 AS Numeric(8, 2)), CAST(650.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4247, 1943, 3, N'OFFICE-S  ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4248, 1944, 1, N'UN-CL-1   ', 5, CAST(399.00 AS Numeric(8, 2)), CAST(1995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4249, 1944, 2, N'UN-CL-2   ', 2, CAST(659.00 AS Numeric(8, 2)), CAST(1318.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4250, 1944, 3, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4251, 1945, 1, N'RUNMTR    ', 7, CAST(79.00 AS Numeric(8, 2)), CAST(553.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4252, 1945, 2, N'RUNMTR2   ', 7, CAST(199.00 AS Numeric(8, 2)), CAST(1393.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4253, 1946, 1, N'O''NEILLS  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4254, 1947, 1, N'GOLD      ', 4, CAST(779.00 AS Numeric(8, 2)), CAST(3116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4255, 1948, 1, N'CITIES    ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4256, 1948, 2, N'MAPS      ', 7, CAST(145.00 AS Numeric(8, 2)), CAST(1015.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4257, 1949, 1, N'O''NEILLS  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4258, 1949, 2, N'PICTURE   ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4259, 1949, 3, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4260, 1949, 4, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4261, 1950, 1, N'POOL      ', 7, CAST(15.00 AS Numeric(8, 2)), CAST(105.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4262, 1950, 2, N'POPUP     ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4263, 1951, 1, N'FLEX-O-MAT', 14, CAST(295.00 AS Numeric(8, 2)), CAST(4130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4264, 1952, 1, N'BRIDGE    ', 15, CAST(195.00 AS Numeric(8, 2)), CAST(2925.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4265, 1952, 2, N'DATES     ', 15, CAST(29.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4266, 1953, 1, N'MENU      ', 15, CAST(129.00 AS Numeric(8, 2)), CAST(1935.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4267, 1953, 2, N'OFFICE-2  ', 15, CAST(65.00 AS Numeric(8, 2)), CAST(975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4268, 1953, 3, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4269, 1953, 4, N'VINO-LM   ', 12, CAST(5.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4270, 1954, 1, N'VINO-LM   ', 12, CAST(5.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4271, 1955, 1, N'NITE-LITE ', 12, CAST(24.00 AS Numeric(8, 2)), CAST(288.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4272, 1955, 2, N'POPUP     ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4273, 1955, 3, N'STARTREK  ', 12, CAST(1599.00 AS Numeric(8, 2)), CAST(19188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4274, 1956, 1, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4275, 1956, 2, N'OFFICE-2  ', 11, CAST(65.00 AS Numeric(8, 2)), CAST(715.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4276, 1956, 3, N'OFFICE-S  ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4277, 1957, 1, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4278, 1958, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4279, 1958, 2, N'RUNMTR2   ', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4280, 1959, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4281, 1960, 1, N'JOKES     ', 10, CAST(12.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4282, 1960, 2, N'POOL      ', 10, CAST(15.00 AS Numeric(8, 2)), CAST(150.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4283, 1961, 1, N'VINO-LM   ', 9, CAST(5.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4284, 1962, 1, N'BEARS     ', 4, CAST(32.00 AS Numeric(8, 2)), CAST(128.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4285, 1963, 1, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4286, 1964, 1, N'TEXT-ALL  ', 5, CAST(595.00 AS Numeric(8, 2)), CAST(2975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4287, 1965, 1, N'TEXT-1    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4288, 1965, 2, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4289, 1965, 3, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4290, 1965, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4291, 1966, 1, N'UN-CL-1   ', 6, CAST(399.00 AS Numeric(8, 2)), CAST(2394.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4292, 1966, 2, N'UN-CL-2   ', 6, CAST(659.00 AS Numeric(8, 2)), CAST(3954.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4293, 1966, 3, N'UNIXGUIDE ', 3, CAST(499.00 AS Numeric(8, 2)), CAST(1497.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4294, 1967, 1, N'CUA       ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4295, 1968, 1, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4296, 1969, 1, N'BRIDGE    ', 10, CAST(195.00 AS Numeric(8, 2)), CAST(1950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4297, 1970, 1, N'POOL      ', 2, CAST(15.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4298, 1971, 1, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4299, 1971, 2, N'DT        ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4300, 1971, 3, N'DT PK     ', 8, CAST(229.00 AS Numeric(8, 2)), CAST(1832.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4301, 1972, 1, N'TEXT-1    ', 8, CAST(99.00 AS Numeric(8, 2)), CAST(792.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4302, 1972, 2, N'TEXT-2    ', 8, CAST(59.00 AS Numeric(8, 2)), CAST(472.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4303, 1972, 3, N'TEXT-3    ', 5, CAST(69.00 AS Numeric(8, 2)), CAST(345.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4304, 1972, 4, N'TEXT-4    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4305, 1973, 1, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4306, 1973, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4307, 1973, 3, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4308, 1973, 5, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4309, 1974, 1, N'CASE      ', 14, CAST(39.00 AS Numeric(8, 2)), CAST(546.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4310, 1974, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4311, 1974, 3, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4312, 1974, 4, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4313, 1975, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4314, 1975, 2, N'RUNMTR    ', 12, CAST(79.00 AS Numeric(8, 2)), CAST(948.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4315, 1975, 3, N'TEXT-4    ', 12, CAST(99.00 AS Numeric(8, 2)), CAST(1188.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4316, 1975, 4, N'REPORTS   ', 12, CAST(179.00 AS Numeric(8, 2)), CAST(2148.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4317, 1976, 1, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4318, 1976, 2, N'GOLD      ', 7, CAST(779.00 AS Numeric(8, 2)), CAST(5453.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4319, 1977, 1, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4320, 1977, 2, N'MODEMS    ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4321, 1977, 3, N'TABLE-MAH ', 12, CAST(1250.00 AS Numeric(8, 2)), CAST(15000.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4322, 1977, 4, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4323, 1978, 1, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4324, 1978, 2, N'TABLE     ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4325, 1979, 1, N'REPORTS   ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4326, 1979, 2, N'CUA       ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4327, 1980, 1, N'UNIXGUIDE ', 9, CAST(499.00 AS Numeric(8, 2)), CAST(4491.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4328, 1980, 2, N'GOLD-DLX  ', 13, CAST(1079.00 AS Numeric(8, 2)), CAST(14027.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4329, 1981, 1, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4330, 1981, 2, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4331, 1981, 3, N'TEXT-2    ', 7, CAST(59.00 AS Numeric(8, 2)), CAST(413.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4332, 1982, 1, N'TABLE-MPL ', 12, CAST(319.00 AS Numeric(8, 2)), CAST(3828.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4333, 1982, 2, N'JEWELRY-I ', 12, CAST(1299.00 AS Numeric(8, 2)), CAST(15588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4334, 1982, 3, N'UN-CL-1   ', 2, CAST(399.00 AS Numeric(8, 2)), CAST(798.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4335, 1983, 1, N'RUNMTR    ', 7, CAST(79.00 AS Numeric(8, 2)), CAST(553.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4336, 1983, 2, N'RUNMTR2   ', 2, CAST(199.00 AS Numeric(8, 2)), CAST(398.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4337, 1983, 3, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4338, 1984, 1, N'JEWELRY-DL', 2, CAST(1749.00 AS Numeric(8, 2)), CAST(3498.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4339, 1984, 2, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4340, 1984, 3, N'UN-CL-2   ', 11, CAST(659.00 AS Numeric(8, 2)), CAST(7249.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4341, 1985, 2, N'UPDATE    ', 11, CAST(19.00 AS Numeric(8, 2)), CAST(209.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4342, 1985, 3, N'JOKES     ', 5, CAST(12.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4343, 1985, 4, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4344, 1985, 5, N'UNIXGUIDE ', 1, CAST(499.00 AS Numeric(8, 2)), CAST(499.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4345, 1986, 2, N'MODEMS    ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4346, 1986, 3, N'REPORTS II', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4347, 1987, 1, N'JEWELRY-DL', 5, CAST(1749.00 AS Numeric(8, 2)), CAST(8745.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4348, 1987, 2, N'FLEX-O-MAT', 5, CAST(295.00 AS Numeric(8, 2)), CAST(1475.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4349, 1988, 1, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4350, 1988, 3, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4351, 1989, 1, N'JEWELRY-I ', 2, CAST(1299.00 AS Numeric(8, 2)), CAST(2598.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4352, 1990, 1, N'UN-CL-2   ', 2, CAST(659.00 AS Numeric(8, 2)), CAST(1318.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4353, 1990, 3, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4354, 1991, 1, N'OFFICE-2  ', 6, CAST(65.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4355, 1991, 2, N'PULLMAN   ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4356, 1991, 3, N'TEXT-1    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4357, 1992, 2, N'CASE      ', 14, CAST(39.00 AS Numeric(8, 2)), CAST(546.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4358, 1992, 3, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4359, 1992, 4, N'PICTURE   ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4360, 1992, 5, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4361, 1993, 1, N'TEXT-ALL  ', 8, CAST(595.00 AS Numeric(8, 2)), CAST(4760.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4362, 1993, 2, N'PICTURE   ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4363, 1993, 3, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4364, 1994, 1, N'GOLD      ', 5, CAST(779.00 AS Numeric(8, 2)), CAST(3895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4365, 1994, 2, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4366, 1994, 3, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4367, 1994, 4, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4368, 1995, 1, N'CITIES    ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4369, 1995, 2, N'MENU      ', 3, CAST(129.00 AS Numeric(8, 2)), CAST(387.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4370, 1995, 3, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4371, 1995, 4, N'DT PK     ', 11, CAST(229.00 AS Numeric(8, 2)), CAST(2519.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4372, 1996, 2, N'CASE      ', 12, CAST(39.00 AS Numeric(8, 2)), CAST(468.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4373, 1996, 4, N'DT        ', 10, CAST(179.00 AS Numeric(8, 2)), CAST(1790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4374, 1997, 16, N'CASE      ', 10, CAST(39.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4375, 1997, 17, N'DATES     ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4376, 1998, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4377, 1998, 2, N'DATES     ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4378, 1998, 3, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4379, 1998, 4, N'MENU      ', 9, CAST(129.00 AS Numeric(8, 2)), CAST(1161.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4380, 1999, 1, N'DT        ', 2, CAST(179.00 AS Numeric(8, 2)), CAST(358.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4381, 1999, 2, N'CITIES    ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4382, 1999, 3, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4383, 1999, 4, N'GOLD-DLX  ', 6, CAST(1079.00 AS Numeric(8, 2)), CAST(6474.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4384, 1999, 5, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4385, 1999, 6, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4386, 2000, 1, N'TEXT-3    ', 6, CAST(69.00 AS Numeric(8, 2)), CAST(414.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4387, 2000, 2, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4388, 2000, 3, N'DATES     ', 14, CAST(29.00 AS Numeric(8, 2)), CAST(406.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4389, 2000, 4, N'CUA       ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4390, 2000, 5, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4391, 2001, 1, N'DATES     ', 8, CAST(29.00 AS Numeric(8, 2)), CAST(232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4392, 2001, 2, N'DT PK     ', 8, CAST(229.00 AS Numeric(8, 2)), CAST(1832.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4393, 2002, 1, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4394, 2002, 2, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4395, 2002, 3, N'CITIES    ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4396, 2002, 4, N'MENU      ', 7, CAST(129.00 AS Numeric(8, 2)), CAST(903.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4397, 2002, 5, N'DATES     ', 15, CAST(29.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4398, 2002, 10, N'CASE      ', 15, CAST(39.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4399, 2003, 1, N'BEARS     ', 15, CAST(30.00 AS Numeric(8, 2)), CAST(450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4400, 2003, 4, N'BEARS     ', 10, CAST(30.00 AS Numeric(8, 2)), CAST(300.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4401, 2003, 5, N'VINO-LM   ', 7, CAST(5.00 AS Numeric(8, 2)), CAST(35.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4402, 2004, 1, N'DT        ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4403, 2004, 2, N'DT PK     ', 3, CAST(229.00 AS Numeric(8, 2)), CAST(687.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4404, 2005, 1, N'CASE      ', 11, CAST(39.00 AS Numeric(8, 2)), CAST(429.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4405, 2005, 2, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4406, 2006, 1, N'DT        ', 12, CAST(179.00 AS Numeric(8, 2)), CAST(2148.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4407, 2007, 1, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4408, 2007, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4409, 2008, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4410, 2008, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4411, 2009, 1, N'ACE1      ', 1, CAST(25.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4412, 2009, 2, N'ACE-2     ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4413, 2010, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4414, 2010, 2, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4415, 2011, 1, N'JEWELRY-DL', 1, CAST(1749.00 AS Numeric(8, 2)), CAST(1749.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4416, 2012, 1, N'FLEX-O-MAT', 12, CAST(295.00 AS Numeric(8, 2)), CAST(3540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4417, 2013, 1, N'O''NEILLS  ', 12, CAST(45.00 AS Numeric(8, 2)), CAST(540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4418, 2013, 2, N'PICTURE   ', 12, CAST(29.00 AS Numeric(8, 2)), CAST(348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4419, 2014, 1, N'MAPS      ', 7, CAST(145.00 AS Numeric(8, 2)), CAST(1015.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4420, 2015, 1, N'UPDATE    ', 7, CAST(19.00 AS Numeric(8, 2)), CAST(133.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4421, 2015, 2, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4422, 2015, 3, N'DT        ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4423, 2016, 1, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4424, 2016, 2, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4425, 2017, 1, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4426, 2017, 2, N'OFFICE-2  ', 4, CAST(65.00 AS Numeric(8, 2)), CAST(260.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4427, 2017, 3, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4428, 2018, 1, N'UPDATE    ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4429, 2018, 2, N'TEXT-1    ', 10, CAST(99.00 AS Numeric(8, 2)), CAST(990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4430, 2018, 3, N'TEXT-2    ', 10, CAST(59.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4431, 2018, 4, N'TEXT-3    ', 14, CAST(69.00 AS Numeric(8, 2)), CAST(966.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4432, 2018, 5, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4433, 2019, 1, N'VINO-LM   ', 7, CAST(5.00 AS Numeric(8, 2)), CAST(35.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4434, 2020, 1, N'UN-CL-1   ', 7, CAST(399.00 AS Numeric(8, 2)), CAST(2793.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4435, 2020, 2, N'UN-CL-2   ', 11, CAST(659.00 AS Numeric(8, 2)), CAST(7249.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4436, 2021, 1, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4437, 2022, 1, N'FLEX-O-MAT', 11, CAST(295.00 AS Numeric(8, 2)), CAST(3245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4438, 2023, 1, N'O''NEILLS  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4439, 2023, 2, N'TABLE     ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4440, 2024, 1, N'TABLE-MAH ', 17, CAST(1250.00 AS Numeric(8, 2)), CAST(21250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4441, 2024, 2, N'TABLE-MPL ', 6, CAST(319.00 AS Numeric(8, 2)), CAST(1914.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4442, 2025, 1, N'JEWELRY-DL', 5, CAST(1749.00 AS Numeric(8, 2)), CAST(8745.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4443, 2025, 2, N'JEWELRY-I ', 3, CAST(1299.00 AS Numeric(8, 2)), CAST(3897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4444, 2026, 1, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4445, 2026, 2, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4446, 2027, 1, N'MAPS      ', 5, CAST(145.00 AS Numeric(8, 2)), CAST(725.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4447, 2028, 1, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4448, 2028, 2, N'PULLMAN   ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4449, 2029, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4450, 2029, 2, N'RUNMTR2   ', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4451, 2030, 1, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4452, 2031, 1, N'JOKES     ', 6, CAST(12.00 AS Numeric(8, 2)), CAST(72.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4453, 2032, 1, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4454, 2032, 2, N'REPORTS II', 1, CAST(199.00 AS Numeric(8, 2)), CAST(199.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4455, 2033, 1, N'MAPS      ', 7, CAST(145.00 AS Numeric(8, 2)), CAST(1015.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4456, 2033, 2, N'CITIES    ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4457, 2034, 1, N'BEARS     ', 2, CAST(32.00 AS Numeric(8, 2)), CAST(64.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4458, 2034, 2, N'STARTREK  ', 4, CAST(1599.00 AS Numeric(8, 2)), CAST(6396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4459, 2035, 1, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4460, 2036, 1, N'OFFICE-S  ', 11, CAST(19.00 AS Numeric(8, 2)), CAST(209.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4461, 2036, 2, N'OFFICE-2  ', 11, CAST(65.00 AS Numeric(8, 2)), CAST(715.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4462, 2037, 1, N'MENU      ', 11, CAST(129.00 AS Numeric(8, 2)), CAST(1419.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4463, 2038, 1, N'NITE-LITE ', 11, CAST(24.00 AS Numeric(8, 2)), CAST(264.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4464, 2038, 2, N'TABLE     ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4465, 2038, 3, N'UPDATE    ', 11, CAST(19.00 AS Numeric(8, 2)), CAST(209.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4466, 2039, 1, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4467, 2039, 2, N'OFFICE-1  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4468, 2040, 1, N'BRIDGE    ', 5, CAST(195.00 AS Numeric(8, 2)), CAST(975.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4469, 2040, 2, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4470, 2040, 3, N'PICTURE   ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4471, 2041, 1, N'UPDATE    ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4472, 2041, 2, N'OFFICE-S  ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4473, 2042, 1, N'TEXT-1    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4474, 2042, 2, N'TEXT-2    ', 6, CAST(59.00 AS Numeric(8, 2)), CAST(354.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4475, 2042, 3, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4476, 2042, 4, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4477, 2042, 5, N'TEXT-ALL  ', 7, CAST(595.00 AS Numeric(8, 2)), CAST(4165.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4478, 2043, 1, N'JOKES     ', 3, CAST(12.00 AS Numeric(8, 2)), CAST(36.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4479, 2044, 1, N'ACE-2     ', 12, CAST(15.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4480, 2044, 2, N'ACE1      ', 2, CAST(25.00 AS Numeric(8, 2)), CAST(50.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4481, 2045, 1, N'DATES     ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4482, 2045, 2, N'DT        ', 10, CAST(179.00 AS Numeric(8, 2)), CAST(1790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4483, 2046, 1, N'OFFICE-1  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4484, 2046, 2, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4485, 2046, 3, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4486, 2047, 1, N'GOLD-DLX  ', 2, CAST(1079.00 AS Numeric(8, 2)), CAST(2158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4487, 2048, 1, N'FLEX-O-MAT', 2, CAST(295.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4488, 2049, 1, N'BRIDGE    ', 2, CAST(195.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4489, 2049, 2, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4490, 2049, 3, N'VINO-LM   ', 7, CAST(5.00 AS Numeric(8, 2)), CAST(35.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4491, 2050, 1, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4492, 2051, 1, N'TABLE     ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4493, 2051, 2, N'TABLE-MAH ', 1, CAST(1250.00 AS Numeric(8, 2)), CAST(1250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4494, 2051, 3, N'TABLE-MPL ', 1, CAST(319.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4495, 2051, 4, N'OFFICE-1  ', 12, CAST(45.00 AS Numeric(8, 2)), CAST(540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4496, 2051, 5, N'OFFICE-2  ', 6, CAST(65.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4497, 2051, 6, N'OFFICE-S  ', 2, CAST(19.00 AS Numeric(8, 2)), CAST(38.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4498, 2052, 1, N'CASE      ', 11, CAST(39.00 AS Numeric(8, 2)), CAST(429.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4499, 2052, 2, N'CUA       ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4500, 2053, 1, N'BRIDGE    ', 2, CAST(195.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4501, 2054, 1, N'O''NEILLS  ', 2, CAST(45.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4502, 2054, 2, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4503, 2054, 3, N'PULLMAN   ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4504, 2055, 1, N'TEXT-1    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4505, 2055, 2, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4506, 2055, 3, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4507, 2055, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4508, 2055, 5, N'TEXT-ALL  ', 1, CAST(595.00 AS Numeric(8, 2)), CAST(595.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4509, 2056, 1, N'MODEMS    ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4510, 2056, 2, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4511, 2057, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4512, 2058, 1, N'STARTREK  ', 14, CAST(1599.00 AS Numeric(8, 2)), CAST(22386.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4513, 2059, 1, N'REPORTS II', 4, CAST(199.00 AS Numeric(8, 2)), CAST(796.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4514, 2060, 1, N'OFFICE-1  ', 10, CAST(45.00 AS Numeric(8, 2)), CAST(450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4515, 2060, 2, N'OFFICE-2  ', 14, CAST(65.00 AS Numeric(8, 2)), CAST(910.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4516, 2060, 3, N'OFFICE-S  ', 14, CAST(19.00 AS Numeric(8, 2)), CAST(266.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4517, 2061, 1, N'UN-CL-1   ', 9, CAST(399.00 AS Numeric(8, 2)), CAST(3591.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4518, 2061, 2, N'UN-CL-2   ', 1, CAST(659.00 AS Numeric(8, 2)), CAST(659.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4519, 2061, 3, N'UNIXGUIDE ', 11, CAST(499.00 AS Numeric(8, 2)), CAST(5489.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4520, 2062, 1, N'RUNMTR    ', 5, CAST(79.00 AS Numeric(8, 2)), CAST(395.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4521, 2062, 2, N'RUNMTR2   ', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4522, 2063, 1, N'O''NEILLS  ', 5, CAST(45.00 AS Numeric(8, 2)), CAST(225.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4523, 2064, 1, N'GOLD      ', 13, CAST(779.00 AS Numeric(8, 2)), CAST(10127.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4524, 2065, 1, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4525, 2065, 2, N'MAPS      ', 6, CAST(145.00 AS Numeric(8, 2)), CAST(870.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4526, 2066, 1, N'O''NEILLS  ', 6, CAST(45.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4527, 2066, 2, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4528, 2066, 3, N'UPDATE    ', 6, CAST(19.00 AS Numeric(8, 2)), CAST(114.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4529, 2066, 4, N'VINO-LM   ', 5, CAST(5.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4530, 2067, 1, N'POOL      ', 9, CAST(15.00 AS Numeric(8, 2)), CAST(135.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4531, 2067, 2, N'POPUP     ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4532, 2068, 1, N'FLEX-O-MAT', 3, CAST(295.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4533, 2069, 1, N'BRIDGE    ', 7, CAST(195.00 AS Numeric(8, 2)), CAST(1365.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4534, 2069, 2, N'DATES     ', 7, CAST(29.00 AS Numeric(8, 2)), CAST(203.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4535, 2070, 1, N'MENU      ', 7, CAST(129.00 AS Numeric(8, 2)), CAST(903.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4536, 2070, 2, N'OFFICE-2  ', 3, CAST(65.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4537, 2070, 3, N'REPORTS   ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4538, 2070, 4, N'VINO-LM   ', 1, CAST(5.00 AS Numeric(8, 2)), CAST(5.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4539, 2071, 1, N'VINO-LM   ', 9, CAST(5.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4540, 2072, 1, N'NITE-LITE ', 9, CAST(24.00 AS Numeric(8, 2)), CAST(216.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4541, 2072, 2, N'POPUP     ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4542, 2072, 3, N'STARTREK  ', 6, CAST(1599.00 AS Numeric(8, 2)), CAST(9594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4543, 2073, 1, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4544, 2073, 2, N'OFFICE-2  ', 4, CAST(65.00 AS Numeric(8, 2)), CAST(260.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4545, 2073, 3, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4546, 2074, 1, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4547, 2075, 1, N'RUNMTR    ', 2, CAST(79.00 AS Numeric(8, 2)), CAST(158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4548, 2075, 2, N'RUNMTR2   ', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4549, 2076, 1, N'MAPS      ', 3, CAST(145.00 AS Numeric(8, 2)), CAST(435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4550, 2077, 1, N'JOKES     ', 8, CAST(12.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4551, 2077, 2, N'POOL      ', 8, CAST(15.00 AS Numeric(8, 2)), CAST(120.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4552, 2078, 1, N'VINO-LM   ', 8, CAST(5.00 AS Numeric(8, 2)), CAST(40.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4553, 2079, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4554, 2080, 1, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4555, 2081, 1, N'TEXT-ALL  ', 8, CAST(595.00 AS Numeric(8, 2)), CAST(4760.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4556, 2082, 1, N'TEXT-1    ', 13, CAST(99.00 AS Numeric(8, 2)), CAST(1287.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4557, 2082, 2, N'TEXT-2    ', 5, CAST(59.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4558, 2082, 3, N'TEXT-3    ', 2, CAST(69.00 AS Numeric(8, 2)), CAST(138.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4559, 2082, 4, N'TEXT-4    ', 2, CAST(99.00 AS Numeric(8, 2)), CAST(198.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4560, 2083, 1, N'UN-CL-1   ', 4, CAST(399.00 AS Numeric(8, 2)), CAST(1596.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4561, 2083, 2, N'UN-CL-2   ', 3, CAST(659.00 AS Numeric(8, 2)), CAST(1977.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4562, 2083, 3, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4563, 2084, 1, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4564, 2085, 1, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4565, 2086, 1, N'BRIDGE    ', 2, CAST(195.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4566, 2087, 1, N'POOL      ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4567, 2088, 1, N'DATES     ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4568, 2088, 2, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4569, 2088, 3, N'DT PK     ', 4, CAST(229.00 AS Numeric(8, 2)), CAST(916.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4570, 2089, 1, N'TEXT-1    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4571, 2089, 2, N'TEXT-2    ', 6, CAST(59.00 AS Numeric(8, 2)), CAST(354.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4572, 2089, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4573, 2089, 4, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4574, 2090, 1, N'RUNMTR    ', 6, CAST(79.00 AS Numeric(8, 2)), CAST(474.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4575, 2090, 2, N'POPUP     ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4576, 2090, 3, N'DT        ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4577, 2090, 5, N'MENU      ', 12, CAST(129.00 AS Numeric(8, 2)), CAST(1548.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4578, 2091, 1, N'CASE      ', 12, CAST(39.00 AS Numeric(8, 2)), CAST(468.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4579, 2091, 2, N'CITIES    ', 12, CAST(49.00 AS Numeric(8, 2)), CAST(588.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4580, 2091, 3, N'MENU      ', 12, CAST(129.00 AS Numeric(8, 2)), CAST(1548.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4581, 2091, 4, N'DT        ', 12, CAST(179.00 AS Numeric(8, 2)), CAST(2148.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4582, 2092, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4583, 2092, 2, N'RUNMTR    ', 3, CAST(79.00 AS Numeric(8, 2)), CAST(237.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4584, 2092, 3, N'TEXT-4    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4585, 2092, 4, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4586, 2093, 1, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4587, 2093, 2, N'GOLD      ', 5, CAST(779.00 AS Numeric(8, 2)), CAST(3895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4588, 2094, 1, N'MENU      ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4589, 2094, 2, N'MODEMS    ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4590, 2094, 3, N'TABLE-MAH ', 4, CAST(1250.00 AS Numeric(8, 2)), CAST(5000.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4591, 2094, 4, N'REPORTS   ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4592, 2095, 1, N'PULLMAN   ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4593, 2095, 2, N'TABLE     ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4594, 2096, 1, N'REPORTS   ', 8, CAST(179.00 AS Numeric(8, 2)), CAST(1432.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4595, 2096, 2, N'CUA       ', 6, CAST(49.00 AS Numeric(8, 2)), CAST(294.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4596, 2097, 1, N'UNIXGUIDE ', 8, CAST(499.00 AS Numeric(8, 2)), CAST(3992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4597, 2097, 2, N'GOLD-DLX  ', 8, CAST(1079.00 AS Numeric(8, 2)), CAST(8632.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4598, 2098, 1, N'MODEMS    ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4599, 2098, 2, N'REPORTS   ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
GO
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4600, 2098, 3, N'TEXT-2    ', 5, CAST(59.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4601, 2099, 1, N'TABLE-MPL ', 1, CAST(319.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4602, 2099, 2, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4603, 2099, 3, N'UN-CL-1   ', 1, CAST(399.00 AS Numeric(8, 2)), CAST(399.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4604, 2100, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4605, 2100, 2, N'RUNMTR2   ', 7, CAST(199.00 AS Numeric(8, 2)), CAST(1393.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4606, 2100, 3, N'POPUP     ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4607, 2101, 1, N'JEWELRY-DL', 11, CAST(1749.00 AS Numeric(8, 2)), CAST(19239.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4608, 2101, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4609, 2101, 3, N'UN-CL-2   ', 3, CAST(659.00 AS Numeric(8, 2)), CAST(1977.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4610, 2102, 2, N'UPDATE    ', 9, CAST(19.00 AS Numeric(8, 2)), CAST(171.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4611, 2102, 3, N'JOKES     ', 9, CAST(12.00 AS Numeric(8, 2)), CAST(108.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4612, 2102, 4, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4613, 2102, 5, N'UNIXGUIDE ', 2, CAST(499.00 AS Numeric(8, 2)), CAST(998.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4614, 2103, 2, N'MODEMS    ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4615, 2103, 3, N'REPORTS II', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4616, 2104, 1, N'JEWELRY-DL', 3, CAST(1749.00 AS Numeric(8, 2)), CAST(5247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4617, 2104, 2, N'FLEX-O-MAT', 4, CAST(295.00 AS Numeric(8, 2)), CAST(1180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4618, 2105, 1, N'MENU      ', 16, CAST(129.00 AS Numeric(8, 2)), CAST(2064.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4619, 2105, 3, N'MAPS      ', 6, CAST(145.00 AS Numeric(8, 2)), CAST(870.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4620, 2106, 1, N'JEWELRY-I ', 6, CAST(1299.00 AS Numeric(8, 2)), CAST(7794.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4621, 2107, 1, N'UN-CL-2   ', 14, CAST(659.00 AS Numeric(8, 2)), CAST(9226.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4622, 2107, 3, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4623, 2108, 1, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4624, 2108, 2, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4625, 2108, 3, N'TEXT-1    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4626, 2109, 2, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4627, 2109, 3, N'DATES     ', 6, CAST(29.00 AS Numeric(8, 2)), CAST(174.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4628, 2109, 4, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4629, 2109, 5, N'TEXT-3    ', 10, CAST(69.00 AS Numeric(8, 2)), CAST(690.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4630, 2110, 1, N'TEXT-ALL  ', 2, CAST(595.00 AS Numeric(8, 2)), CAST(1190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4631, 2110, 2, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4632, 2110, 3, N'CUA       ', 11, CAST(49.00 AS Numeric(8, 2)), CAST(539.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4633, 2111, 1, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4634, 2111, 2, N'CASE      ', 1, CAST(39.00 AS Numeric(8, 2)), CAST(39.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4635, 2111, 3, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4636, 2111, 4, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4637, 2112, 1, N'CITIES    ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4638, 2112, 2, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4639, 2112, 3, N'PICTURE   ', 5, CAST(29.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4640, 2112, 4, N'DT PK     ', 5, CAST(229.00 AS Numeric(8, 2)), CAST(1145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4641, 2113, 2, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4642, 2113, 4, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4643, 2114, 16, N'CASE      ', 7, CAST(39.00 AS Numeric(8, 2)), CAST(273.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4644, 2114, 17, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4645, 2115, 1, N'CASE      ', 2, CAST(39.00 AS Numeric(8, 2)), CAST(78.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4646, 2115, 2, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4647, 2115, 3, N'DT PK     ', 1, CAST(229.00 AS Numeric(8, 2)), CAST(229.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4648, 2115, 4, N'MENU      ', 1, CAST(129.00 AS Numeric(8, 2)), CAST(129.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4649, 2116, 1, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4650, 2116, 2, N'CITIES    ', 17, CAST(49.00 AS Numeric(8, 2)), CAST(833.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4651, 2116, 3, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4652, 2116, 4, N'GOLD-DLX  ', 2, CAST(1079.00 AS Numeric(8, 2)), CAST(2158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4653, 2116, 5, N'TEXT-3    ', 13, CAST(69.00 AS Numeric(8, 2)), CAST(897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4654, 2116, 6, N'CASE      ', 8, CAST(39.00 AS Numeric(8, 2)), CAST(312.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4655, 2117, 1, N'TEXT-3    ', 3, CAST(69.00 AS Numeric(8, 2)), CAST(207.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4656, 2117, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4657, 2117, 3, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4658, 2117, 4, N'CUA       ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4659, 2117, 5, N'TEXT-3    ', 13, CAST(69.00 AS Numeric(8, 2)), CAST(897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4660, 2118, 1, N'DATES     ', 13, CAST(29.00 AS Numeric(8, 2)), CAST(377.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4661, 2118, 2, N'DT PK     ', 13, CAST(229.00 AS Numeric(8, 2)), CAST(2977.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4662, 2119, 1, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4663, 2119, 2, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4664, 2119, 3, N'CITIES    ', 9, CAST(49.00 AS Numeric(8, 2)), CAST(441.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4665, 2119, 4, N'MENU      ', 13, CAST(129.00 AS Numeric(8, 2)), CAST(1677.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4666, 2119, 5, N'DATES     ', 13, CAST(29.00 AS Numeric(8, 2)), CAST(377.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4667, 2119, 10, N'CASE      ', 9, CAST(39.00 AS Numeric(8, 2)), CAST(351.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4668, 2120, 1, N'BEARS     ', 9, CAST(30.00 AS Numeric(8, 2)), CAST(270.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4669, 2120, 4, N'BEARS     ', 1, CAST(30.00 AS Numeric(8, 2)), CAST(30.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4670, 2120, 5, N'VINO-LM   ', 5, CAST(5.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4671, 2121, 1, N'DT        ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4672, 2121, 2, N'DT PK     ', 15, CAST(229.00 AS Numeric(8, 2)), CAST(3435.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4673, 2122, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4674, 2122, 2, N'DT        ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4675, 2123, 1, N'DT        ', 1, CAST(179.00 AS Numeric(8, 2)), CAST(179.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4676, 2124, 1, N'CASE      ', 4, CAST(39.00 AS Numeric(8, 2)), CAST(156.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4677, 2124, 2, N'CUA       ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4678, 2125, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4679, 2125, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4680, 2126, 1, N'ACE1      ', 10, CAST(25.00 AS Numeric(8, 2)), CAST(250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4681, 2126, 2, N'ACE-2     ', 10, CAST(15.00 AS Numeric(8, 2)), CAST(150.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4682, 2127, 1, N'BEARS     ', 1, CAST(32.00 AS Numeric(8, 2)), CAST(32.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4683, 2127, 2, N'GOLD      ', 8, CAST(779.00 AS Numeric(8, 2)), CAST(6232.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4684, 2128, 1, N'JEWELRY-DL', 8, CAST(1749.00 AS Numeric(8, 2)), CAST(13992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4685, 2129, 1, N'FLEX-O-MAT', 6, CAST(295.00 AS Numeric(8, 2)), CAST(1770.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4686, 2130, 1, N'O''NEILLS  ', 17, CAST(45.00 AS Numeric(8, 2)), CAST(765.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4687, 2130, 2, N'PICTURE   ', 10, CAST(29.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4688, 2131, 1, N'MAPS      ', 10, CAST(145.00 AS Numeric(8, 2)), CAST(1450.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4689, 2132, 1, N'UPDATE    ', 10, CAST(19.00 AS Numeric(8, 2)), CAST(190.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4690, 2132, 2, N'CUA       ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4691, 2132, 3, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4692, 2133, 1, N'DATES     ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4693, 2133, 2, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4694, 2134, 1, N'OFFICE-1  ', 8, CAST(45.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4695, 2134, 2, N'OFFICE-2  ', 13, CAST(65.00 AS Numeric(8, 2)), CAST(845.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4696, 2134, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4697, 2135, 1, N'UPDATE    ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4698, 2135, 2, N'TEXT-1    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4699, 2135, 3, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4700, 2135, 4, N'TEXT-3    ', 7, CAST(69.00 AS Numeric(8, 2)), CAST(483.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4701, 2135, 5, N'TEXT-4    ', 7, CAST(99.00 AS Numeric(8, 2)), CAST(693.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4702, 2136, 1, N'VINO-LM   ', 7, CAST(5.00 AS Numeric(8, 2)), CAST(35.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4703, 2137, 1, N'UN-CL-1   ', 7, CAST(399.00 AS Numeric(8, 2)), CAST(2793.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4704, 2137, 2, N'UN-CL-2   ', 7, CAST(659.00 AS Numeric(8, 2)), CAST(4613.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4705, 2138, 1, N'UNIXGUIDE ', 3, CAST(499.00 AS Numeric(8, 2)), CAST(1497.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4706, 2139, 1, N'FLEX-O-MAT', 3, CAST(295.00 AS Numeric(8, 2)), CAST(885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4707, 2140, 1, N'O''NEILLS  ', 18, CAST(45.00 AS Numeric(8, 2)), CAST(810.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4708, 2140, 2, N'TABLE     ', 15, CAST(179.00 AS Numeric(8, 2)), CAST(2685.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4709, 2141, 1, N'TABLE-MAH ', 11, CAST(1250.00 AS Numeric(8, 2)), CAST(13750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4710, 2141, 2, N'TABLE-MPL ', 11, CAST(319.00 AS Numeric(8, 2)), CAST(3509.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4711, 2142, 1, N'JEWELRY-DL', 11, CAST(1749.00 AS Numeric(8, 2)), CAST(19239.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4712, 2142, 2, N'JEWELRY-I ', 9, CAST(1299.00 AS Numeric(8, 2)), CAST(11691.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4713, 2143, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4714, 2143, 2, N'DT PK     ', 9, CAST(229.00 AS Numeric(8, 2)), CAST(2061.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4715, 2144, 1, N'MAPS      ', 13, CAST(145.00 AS Numeric(8, 2)), CAST(1885.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4716, 2145, 1, N'PICTURE   ', 13, CAST(29.00 AS Numeric(8, 2)), CAST(377.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4717, 2145, 2, N'PULLMAN   ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4718, 2146, 1, N'RUNMTR    ', 1, CAST(79.00 AS Numeric(8, 2)), CAST(79.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4719, 2146, 2, N'RUNMTR2   ', 14, CAST(199.00 AS Numeric(8, 2)), CAST(2786.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4720, 2147, 1, N'OFFICE-S  ', 14, CAST(19.00 AS Numeric(8, 2)), CAST(266.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4721, 2148, 1, N'JOKES     ', 2, CAST(12.00 AS Numeric(8, 2)), CAST(24.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4722, 2149, 1, N'REPORTS   ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4723, 2149, 2, N'REPORTS II', 9, CAST(199.00 AS Numeric(8, 2)), CAST(1791.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4724, 2150, 1, N'MAPS      ', 4, CAST(145.00 AS Numeric(8, 2)), CAST(580.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4725, 2150, 2, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4726, 2151, 1, N'BEARS     ', 3, CAST(32.00 AS Numeric(8, 2)), CAST(96.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4727, 2151, 2, N'STARTREK  ', 1, CAST(1599.00 AS Numeric(8, 2)), CAST(1599.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4728, 2152, 1, N'MAPS      ', 2, CAST(145.00 AS Numeric(8, 2)), CAST(290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4729, 2153, 1, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4730, 2153, 2, N'OFFICE-2  ', 5, CAST(65.00 AS Numeric(8, 2)), CAST(325.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4731, 2154, 1, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4732, 2155, 1, N'NITE-LITE ', 8, CAST(24.00 AS Numeric(8, 2)), CAST(192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4733, 2155, 2, N'TABLE     ', 7, CAST(179.00 AS Numeric(8, 2)), CAST(1253.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4734, 2155, 3, N'UPDATE    ', 12, CAST(19.00 AS Numeric(8, 2)), CAST(228.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4735, 2156, 1, N'CASE      ', 12, CAST(39.00 AS Numeric(8, 2)), CAST(468.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4736, 2156, 2, N'OFFICE-1  ', 12, CAST(45.00 AS Numeric(8, 2)), CAST(540.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4737, 2157, 1, N'BRIDGE    ', 11, CAST(195.00 AS Numeric(8, 2)), CAST(2145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4738, 2157, 2, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4739, 2157, 3, N'PICTURE   ', 9, CAST(29.00 AS Numeric(8, 2)), CAST(261.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4740, 2158, 1, N'UPDATE    ', 15, CAST(19.00 AS Numeric(8, 2)), CAST(285.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4741, 2158, 2, N'OFFICE-S  ', 3, CAST(19.00 AS Numeric(8, 2)), CAST(57.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4742, 2159, 1, N'TEXT-1    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4743, 2159, 2, N'TEXT-2    ', 2, CAST(59.00 AS Numeric(8, 2)), CAST(118.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4744, 2159, 3, N'TEXT-3    ', 15, CAST(69.00 AS Numeric(8, 2)), CAST(1035.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4745, 2159, 4, N'TEXT-4    ', 15, CAST(99.00 AS Numeric(8, 2)), CAST(1485.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4746, 2159, 5, N'TEXT-ALL  ', 15, CAST(595.00 AS Numeric(8, 2)), CAST(8925.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4747, 2160, 1, N'JOKES     ', 1, CAST(12.00 AS Numeric(8, 2)), CAST(12.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4748, 2161, 1, N'ACE-2     ', 1, CAST(15.00 AS Numeric(8, 2)), CAST(15.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4749, 2161, 2, N'ACE1      ', 1, CAST(25.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4750, 2162, 1, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4751, 2162, 2, N'DT        ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4752, 2163, 1, N'OFFICE-1  ', 4, CAST(45.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4753, 2163, 2, N'OFFICE-2  ', 6, CAST(65.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4754, 2163, 3, N'OFFICE-S  ', 4, CAST(19.00 AS Numeric(8, 2)), CAST(76.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4755, 2164, 1, N'GOLD-DLX  ', 4, CAST(1079.00 AS Numeric(8, 2)), CAST(4316.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4756, 2165, 1, N'FLEX-O-MAT', 4, CAST(295.00 AS Numeric(8, 2)), CAST(1180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4757, 2166, 1, N'BRIDGE    ', 2, CAST(195.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4758, 2166, 2, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4759, 2166, 3, N'VINO-LM   ', 2, CAST(5.00 AS Numeric(8, 2)), CAST(10.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4760, 2167, 1, N'DT PK     ', 2, CAST(229.00 AS Numeric(8, 2)), CAST(458.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4761, 2168, 1, N'TABLE     ', 9, CAST(179.00 AS Numeric(8, 2)), CAST(1611.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4762, 2168, 2, N'TABLE-MAH ', 3, CAST(1250.00 AS Numeric(8, 2)), CAST(3750.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4763, 2168, 3, N'TABLE-MPL ', 3, CAST(319.00 AS Numeric(8, 2)), CAST(957.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4764, 2168, 4, N'OFFICE-1  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4765, 2168, 5, N'OFFICE-2  ', 1, CAST(65.00 AS Numeric(8, 2)), CAST(65.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4766, 2168, 6, N'OFFICE-S  ', 13, CAST(19.00 AS Numeric(8, 2)), CAST(247.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4767, 2169, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4768, 2169, 2, N'CUA       ', 10, CAST(49.00 AS Numeric(8, 2)), CAST(490.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4769, 2170, 1, N'BRIDGE    ', 3, CAST(195.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4770, 2171, 1, N'O''NEILLS  ', 7, CAST(45.00 AS Numeric(8, 2)), CAST(315.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4771, 2171, 2, N'POPUP     ', 7, CAST(49.00 AS Numeric(8, 2)), CAST(343.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4772, 2171, 3, N'PULLMAN   ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4773, 2172, 1, N'TEXT-1    ', 5, CAST(99.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4774, 2172, 2, N'TEXT-2    ', 8, CAST(59.00 AS Numeric(8, 2)), CAST(472.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4775, 2172, 3, N'TEXT-3    ', 8, CAST(69.00 AS Numeric(8, 2)), CAST(552.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4776, 2172, 4, N'TEXT-4    ', 1, CAST(99.00 AS Numeric(8, 2)), CAST(99.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4777, 2172, 5, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4778, 2173, 1, N'MODEMS    ', 6, CAST(129.00 AS Numeric(8, 2)), CAST(774.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4779, 2173, 2, N'REPORTS   ', 3, CAST(179.00 AS Numeric(8, 2)), CAST(537.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4780, 2174, 1, N'JEWELRY-I ', 3, CAST(1299.00 AS Numeric(8, 2)), CAST(3897.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4781, 2175, 1, N'STARTREK  ', 14, CAST(1599.00 AS Numeric(8, 2)), CAST(22386.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4782, 2176, 1, N'REPORTS II', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4783, 2177, 1, N'OFFICE-1  ', 8, CAST(45.00 AS Numeric(8, 2)), CAST(360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4784, 2177, 2, N'OFFICE-2  ', 8, CAST(65.00 AS Numeric(8, 2)), CAST(520.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4785, 2177, 3, N'OFFICE-S  ', 8, CAST(19.00 AS Numeric(8, 2)), CAST(152.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4786, 2178, 1, N'UN-CL-1   ', 8, CAST(399.00 AS Numeric(8, 2)), CAST(3192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4787, 2178, 2, N'UN-CL-2   ', 8, CAST(659.00 AS Numeric(8, 2)), CAST(5272.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4788, 2178, 3, N'UNIXGUIDE ', 8, CAST(499.00 AS Numeric(8, 2)), CAST(3992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4789, 2179, 1, N'RUNMTR    ', 8, CAST(79.00 AS Numeric(8, 2)), CAST(632.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4790, 2179, 2, N'RUNMTR2   ', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4791, 2180, 1, N'O''NEILLS  ', 1, CAST(45.00 AS Numeric(8, 2)), CAST(45.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4792, 2181, 1, N'GOLD      ', 12, CAST(779.00 AS Numeric(8, 2)), CAST(9348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4793, 2182, 1, N'CITIES    ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4794, 2182, 2, N'MAPS      ', 16, CAST(145.00 AS Numeric(8, 2)), CAST(2320.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4795, 2183, 1, N'O''NEILLS  ', 11, CAST(45.00 AS Numeric(8, 2)), CAST(495.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4796, 2183, 2, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4797, 2183, 3, N'UPDATE    ', 17, CAST(19.00 AS Numeric(8, 2)), CAST(323.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4798, 2183, 4, N'VINO-LM   ', 17, CAST(5.00 AS Numeric(8, 2)), CAST(85.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4799, 2184, 1, N'POOL      ', 17, CAST(15.00 AS Numeric(8, 2)), CAST(255.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4800, 2184, 2, N'POPUP     ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4801, 2185, 1, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4802, 2186, 1, N'BRIDGE    ', 1, CAST(195.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4803, 2186, 2, N'DATES     ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4804, 2187, 1, N'MENU      ', 4, CAST(129.00 AS Numeric(8, 2)), CAST(516.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4805, 2187, 2, N'OFFICE-2  ', 4, CAST(65.00 AS Numeric(8, 2)), CAST(260.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4806, 2187, 3, N'REPORTS   ', 4, CAST(179.00 AS Numeric(8, 2)), CAST(716.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4807, 2187, 4, N'VINO-LM   ', 11, CAST(5.00 AS Numeric(8, 2)), CAST(55.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4808, 2188, 1, N'VINO-LM   ', 11, CAST(5.00 AS Numeric(8, 2)), CAST(55.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4809, 2189, 1, N'NITE-LITE ', 11, CAST(24.00 AS Numeric(8, 2)), CAST(264.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4810, 2189, 2, N'POPUP     ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4811, 2189, 3, N'STARTREK  ', 1, CAST(1599.00 AS Numeric(8, 2)), CAST(1599.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4812, 2190, 1, N'OFFICE-1  ', 13, CAST(45.00 AS Numeric(8, 2)), CAST(585.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4813, 2190, 2, N'OFFICE-2  ', 13, CAST(65.00 AS Numeric(8, 2)), CAST(845.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4814, 2190, 3, N'OFFICE-S  ', 1, CAST(19.00 AS Numeric(8, 2)), CAST(19.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4815, 2191, 1, N'PICTURE   ', 2, CAST(29.00 AS Numeric(8, 2)), CAST(58.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4816, 2192, 1, N'RUNMTR    ', 10, CAST(79.00 AS Numeric(8, 2)), CAST(790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4817, 2192, 2, N'RUNMTR2   ', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4818, 2193, 1, N'MAPS      ', 8, CAST(145.00 AS Numeric(8, 2)), CAST(1160.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4819, 2194, 1, N'JOKES     ', 5, CAST(12.00 AS Numeric(8, 2)), CAST(60.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4820, 2194, 2, N'POOL      ', 6, CAST(15.00 AS Numeric(8, 2)), CAST(90.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4821, 2195, 1, N'VINO-LM   ', 5, CAST(5.00 AS Numeric(8, 2)), CAST(25.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4822, 2196, 1, N'BEARS     ', 6, CAST(32.00 AS Numeric(8, 2)), CAST(192.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4823, 2197, 1, N'CITIES    ', 1, CAST(49.00 AS Numeric(8, 2)), CAST(49.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4824, 2198, 1, N'TEXT-ALL  ', 10, CAST(595.00 AS Numeric(8, 2)), CAST(5950.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4825, 2199, 1, N'TEXT-1    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4826, 2199, 2, N'TEXT-2    ', 4, CAST(59.00 AS Numeric(8, 2)), CAST(236.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4827, 2199, 3, N'TEXT-3    ', 4, CAST(69.00 AS Numeric(8, 2)), CAST(276.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4828, 2199, 4, N'TEXT-4    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4829, 2200, 1, N'UN-CL-1   ', 3, CAST(399.00 AS Numeric(8, 2)), CAST(1197.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4830, 2200, 2, N'UN-CL-2   ', 3, CAST(659.00 AS Numeric(8, 2)), CAST(1977.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4831, 2200, 3, N'UNIXGUIDE ', 8, CAST(499.00 AS Numeric(8, 2)), CAST(3992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4832, 2201, 1, N'CUA       ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4833, 2202, 1, N'PICTURE   ', 1, CAST(29.00 AS Numeric(8, 2)), CAST(29.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4834, 2203, 1, N'BRIDGE    ', 2, CAST(195.00 AS Numeric(8, 2)), CAST(390.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4835, 2204, 1, N'POOL      ', 12, CAST(15.00 AS Numeric(8, 2)), CAST(180.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4836, 2205, 1, N'DATES     ', 12, CAST(29.00 AS Numeric(8, 2)), CAST(348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4837, 2205, 2, N'DT        ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4838, 2205, 3, N'DT PK     ', 3, CAST(229.00 AS Numeric(8, 2)), CAST(687.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4839, 2206, 1, N'TEXT-1    ', 3, CAST(99.00 AS Numeric(8, 2)), CAST(297.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4840, 2206, 2, N'TEXT-2    ', 3, CAST(59.00 AS Numeric(8, 2)), CAST(177.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4841, 2206, 3, N'TEXT-3    ', 10, CAST(69.00 AS Numeric(8, 2)), CAST(690.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4842, 2206, 4, N'TEXT-4    ', 4, CAST(99.00 AS Numeric(8, 2)), CAST(396.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4843, 2207, 1, N'RUNMTR    ', 2, CAST(79.00 AS Numeric(8, 2)), CAST(158.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4844, 2207, 2, N'POPUP     ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4845, 2207, 3, N'DT        ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4846, 2207, 5, N'MENU      ', 11, CAST(129.00 AS Numeric(8, 2)), CAST(1419.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4847, 2208, 1, N'CASE      ', 5, CAST(39.00 AS Numeric(8, 2)), CAST(195.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4848, 2208, 2, N'CITIES    ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4849, 2208, 3, N'MENU      ', 5, CAST(129.00 AS Numeric(8, 2)), CAST(645.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4850, 2208, 4, N'DT        ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4851, 2209, 1, N'DATES     ', 12, CAST(29.00 AS Numeric(8, 2)), CAST(348.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4852, 2209, 2, N'RUNMTR    ', 6, CAST(79.00 AS Numeric(8, 2)), CAST(474.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4853, 2209, 3, N'TEXT-4    ', 6, CAST(99.00 AS Numeric(8, 2)), CAST(594.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4854, 2209, 4, N'REPORTS   ', 6, CAST(179.00 AS Numeric(8, 2)), CAST(1074.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4855, 2210, 1, N'CASE      ', 6, CAST(39.00 AS Numeric(8, 2)), CAST(234.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4856, 2210, 2, N'GOLD      ', 1, CAST(779.00 AS Numeric(8, 2)), CAST(779.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4857, 2211, 1, N'MENU      ', 13, CAST(129.00 AS Numeric(8, 2)), CAST(1677.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4858, 2211, 2, N'MODEMS    ', 13, CAST(129.00 AS Numeric(8, 2)), CAST(1677.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4859, 2211, 3, N'TABLE-MAH ', 13, CAST(1250.00 AS Numeric(8, 2)), CAST(16250.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4860, 2211, 4, N'REPORTS   ', 13, CAST(179.00 AS Numeric(8, 2)), CAST(2327.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4861, 2212, 1, N'PULLMAN   ', 8, CAST(49.00 AS Numeric(8, 2)), CAST(392.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4862, 2212, 2, N'TABLE     ', 5, CAST(179.00 AS Numeric(8, 2)), CAST(895.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4863, 2213, 1, N'REPORTS   ', 11, CAST(179.00 AS Numeric(8, 2)), CAST(1969.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4864, 2213, 2, N'CUA       ', 13, CAST(49.00 AS Numeric(8, 2)), CAST(637.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4865, 2214, 1, N'UNIXGUIDE ', 10, CAST(499.00 AS Numeric(8, 2)), CAST(4990.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4866, 2214, 2, N'GOLD-DLX  ', 10, CAST(1079.00 AS Numeric(8, 2)), CAST(10790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4867, 2215, 1, N'MODEMS    ', 10, CAST(129.00 AS Numeric(8, 2)), CAST(1290.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4868, 2215, 2, N'REPORTS   ', 10, CAST(179.00 AS Numeric(8, 2)), CAST(1790.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4869, 2215, 3, N'TEXT-2    ', 10, CAST(59.00 AS Numeric(8, 2)), CAST(590.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4870, 2216, 1, N'TABLE-MPL ', 13, CAST(319.00 AS Numeric(8, 2)), CAST(4147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4871, 2216, 2, N'JEWELRY-I ', 14, CAST(1299.00 AS Numeric(8, 2)), CAST(18186.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4872, 2216, 3, N'UN-CL-1   ', 14, CAST(399.00 AS Numeric(8, 2)), CAST(5586.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4873, 2217, 1, N'RUNMTR    ', 13, CAST(79.00 AS Numeric(8, 2)), CAST(1027.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4874, 2217, 2, N'RUNMTR2   ', 5, CAST(199.00 AS Numeric(8, 2)), CAST(995.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4875, 2217, 3, N'POPUP     ', 5, CAST(49.00 AS Numeric(8, 2)), CAST(245.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4876, 2218, 1, N'JEWELRY-DL', 5, CAST(1749.00 AS Numeric(8, 2)), CAST(8745.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4877, 2218, 2, N'CASE      ', 13, CAST(39.00 AS Numeric(8, 2)), CAST(507.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4878, 2218, 3, N'UN-CL-2   ', 13, CAST(659.00 AS Numeric(8, 2)), CAST(8567.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4879, 2219, 2, N'UPDATE    ', 12, CAST(19.00 AS Numeric(8, 2)), CAST(228.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4880, 2219, 3, N'JOKES     ', 12, CAST(12.00 AS Numeric(8, 2)), CAST(144.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4881, 2219, 4, N'TEXT-ALL  ', 4, CAST(595.00 AS Numeric(8, 2)), CAST(2380.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4882, 2219, 5, N'UNIXGUIDE ', 9, CAST(499.00 AS Numeric(8, 2)), CAST(4491.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4883, 2220, 2, N'MODEMS    ', 8, CAST(129.00 AS Numeric(8, 2)), CAST(1032.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4884, 2220, 3, N'REPORTS II', 8, CAST(199.00 AS Numeric(8, 2)), CAST(1592.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4885, 2221, 1, N'JEWELRY-DL', 8, CAST(1749.00 AS Numeric(8, 2)), CAST(13992.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4886, 2221, 2, N'FLEX-O-MAT', 1, CAST(295.00 AS Numeric(8, 2)), CAST(295.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4887, 2222, 1, N'MENU      ', 14, CAST(129.00 AS Numeric(8, 2)), CAST(1806.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4888, 2222, 3, N'MAPS      ', 1, CAST(145.00 AS Numeric(8, 2)), CAST(145.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4889, 2223, 1, N'JEWELRY-I ', 1, CAST(1299.00 AS Numeric(8, 2)), CAST(1299.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4890, 2224, 1, N'UN-CL-2   ', 8, CAST(659.00 AS Numeric(8, 2)), CAST(5272.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4891, 2224, 3, N'FLEX-O-MAT', 8, CAST(295.00 AS Numeric(8, 2)), CAST(2360.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4892, 2225, 1, N'OFFICE-2  ', 2, CAST(65.00 AS Numeric(8, 2)), CAST(130.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4893, 2225, 2, N'PULLMAN   ', 2, CAST(49.00 AS Numeric(8, 2)), CAST(98.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4894, 2225, 3, N'TEXT-1    ', 16, CAST(99.00 AS Numeric(8, 2)), CAST(1584.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4895, 2226, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4896, 2226, 3, N'DATES     ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4897, 2226, 4, N'PICTURE   ', 4, CAST(29.00 AS Numeric(8, 2)), CAST(116.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4898, 2226, 5, N'TEXT-3    ', 1, CAST(69.00 AS Numeric(8, 2)), CAST(69.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4899, 2227, 1, N'TEXT-ALL  ', 3, CAST(595.00 AS Numeric(8, 2)), CAST(1785.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4900, 2227, 2, N'PICTURE   ', 3, CAST(29.00 AS Numeric(8, 2)), CAST(87.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4901, 2227, 3, N'CUA       ', 3, CAST(49.00 AS Numeric(8, 2)), CAST(147.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4902, 2228, 1, N'GOLD      ', 3, CAST(779.00 AS Numeric(8, 2)), CAST(2337.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4903, 2228, 2, N'CASE      ', 3, CAST(39.00 AS Numeric(8, 2)), CAST(117.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4904, 2228, 3, N'CITIES    ', 4, CAST(49.00 AS Numeric(8, 2)), CAST(196.00 AS Numeric(10, 2)))
INSERT [dbo].[OrderDtl] ([RECNUM], [Order_Number], [Detail_Number], [Item_ID], [Qty_Ordered], [Price], [Extended_Price]) VALUES (4905, 2228, 4, N'PICTURE   ', 11, CAST(29.00 AS Numeric(8, 2)), CAST(319.00 AS Numeric(10, 2)))
SET IDENTITY_INSERT [dbo].[OrderDtl] OFF
SET IDENTITY_INSERT [dbo].[OrderHea] ON 

INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1, 101, 1, CAST(N'2012-02-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(1668.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2, 102, 12, CAST(N'2012-02-26T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(396.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (3, 103, 3, CAST(N'2012-02-29T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(565.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (4, 104, 4, CAST(N'2012-02-29T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(818.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (5, 105, 8, CAST(N'2012-03-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(1687.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (6, 106, 6, CAST(N'2012-03-13T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(228.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (7, 107, 7, CAST(N'2012-03-16T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(277.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (8, 108, 8, CAST(N'2012-03-23T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(2657.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (9, 109, 9, CAST(N'2012-04-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(367.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (10, 110, 10, CAST(N'2012-04-09T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(2336.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (11, 111, 11, CAST(N'2012-04-13T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(1586.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (12, 112, 6, CAST(N'2012-04-19T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(3145.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (13, 113, 1, CAST(N'2012-04-24T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(2766.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (14, 114, 1, CAST(N'2012-04-25T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(328.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (15, 115, 2, CAST(N'2012-05-08T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(2044.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (16, 116, 6, CAST(N'2012-05-15T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(4479.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (17, 117, 5, CAST(N'2012-05-18T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (18, 118, 3, CAST(N'2012-05-18T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(1613.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (19, 119, 8, CAST(N'2012-05-26T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(213.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (20, 120, 11, CAST(N'2012-05-29T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(235.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (21, 121, 12, CAST(N'2012-06-02T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(722.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (22, 122, 7, CAST(N'2012-06-08T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(896.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (23, 123, 10, CAST(N'2012-06-18T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(436.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (24, 124, 6, CAST(N'2012-06-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(436.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (25, 125, 1, CAST(N'2012-06-19T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(5878.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (26, 126, 12, CAST(N'2012-06-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(913.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (27, 127, 13, CAST(N'2012-06-19T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(3169.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (28, 128, 13, CAST(N'2012-06-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(381.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (29, 129, 14, CAST(N'2012-06-20T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(345.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (30, 130, 14, CAST(N'2012-06-20T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(441.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (31, 131, 14, CAST(N'2012-06-20T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(125.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (32, 132, 24, CAST(N'2012-06-22T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(408.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (33, 133, 94, CAST(N'2012-06-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(218.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (34, 134, 99, CAST(N'2012-06-22T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(358.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (35, 135, 27, CAST(N'2012-06-24T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(244.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (36, 136, 32, CAST(N'2012-06-24T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(440.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (37, 137, 92, CAST(N'2012-06-24T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(400.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (38, 138, 33, CAST(N'2012-06-24T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(875.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (39, 139, 77, CAST(N'2012-06-26T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(1749.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (40, 140, 80, CAST(N'2012-06-26T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(1475.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (41, 141, 30, CAST(N'2012-06-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(190.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (42, 142, 100, CAST(N'2012-06-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(7250.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (43, 143, 64, CAST(N'2012-06-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(315.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (44, 144, 95, CAST(N'2012-06-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(1950.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (45, 145, 24, CAST(N'2012-06-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(129.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (46, 146, 82, CAST(N'2012-06-27T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(345.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (47, 147, 85, CAST(N'2012-06-27T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(50.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (48, 148, 28, CAST(N'2012-06-27T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(1856.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (49, 149, 29, CAST(N'2012-06-27T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(499.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (50, 150, 32, CAST(N'2012-06-27T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(14750.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (51, 151, 44, CAST(N'2012-06-27T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(1483.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (52, 152, 49, CAST(N'2012-06-27T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(1569.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (53, 153, 54, CAST(N'2012-06-27T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(3048.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (54, 154, 69, CAST(N'2012-06-27T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(3825.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (55, 155, 97, CAST(N'2012-06-28T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(14500.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (56, 156, 82, CAST(N'2012-06-28T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(390.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (57, 157, 80, CAST(N'2012-06-28T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(2862.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (58, 158, 34, CAST(N'2012-06-28T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(19.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (59, 159, 36, CAST(N'2012-06-28T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(120.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (60, 160, 41, CAST(N'2012-06-28T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(756.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (61, 161, 42, CAST(N'2012-06-28T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(4850.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (62, 162, 52, CAST(N'2012-06-28T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(4925.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (63, 163, 99, CAST(N'2012-06-29T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(14500.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (64, 164, 29, CAST(N'2012-06-29T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(84.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (65, 165, 35, CAST(N'2012-06-29T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(3225.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (66, 166, 38, CAST(N'2012-06-29T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(241.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (67, 167, 43, CAST(N'2012-06-29T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(840.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (68, 168, 48, CAST(N'2012-06-29T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(302.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (69, 169, 53, CAST(N'2012-06-29T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(38.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (70, 170, 59, CAST(N'2012-06-30T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(921.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (71, 171, 63, CAST(N'2012-06-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(60.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (72, 172, 71, CAST(N'2012-06-30T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(40.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (73, 173, 96, CAST(N'2012-06-30T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(387.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (74, 174, 51, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(129.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (75, 175, 74, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(1079.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (76, 176, 56, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(2950.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (77, 177, 62, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(1125.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (78, 178, 85, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(458.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (79, 179, 47, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(1877.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (80, 180, 94, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(440.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (81, 181, 36, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(585.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (82, 182, 31, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(2495.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (83, 183, 41, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(1842.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (84, 184, 49, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(308.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (85, 185, 59, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (86, 186, 99, CAST(N'2012-07-04T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(7995.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (87, 187, 34, CAST(N'2012-07-04T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(199.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (88, 188, 26, CAST(N'2012-07-04T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(258.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (89, 189, 27, CAST(N'2012-07-04T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(18684.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (90, 190, 33, CAST(N'2012-07-04T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(6555.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (91, 191, 37, CAST(N'2012-07-05T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(585.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (92, 192, 38, CAST(N'2012-07-05T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(3895.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (93, 193, 42, CAST(N'2012-07-05T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(4074.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (94, 194, 46, CAST(N'2012-07-05T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(245.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (95, 195, 50, CAST(N'2012-07-05T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(64.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (96, 196, 55, CAST(N'2012-07-05T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(14750.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (97, 197, 61, CAST(N'2012-07-06T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(340.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (98, 198, 65, CAST(N'2012-07-06T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(512.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (99, 199, 66, CAST(N'2012-07-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(500.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (100, 200, 67, CAST(N'2012-07-06T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(7558.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (101, 201, 69, CAST(N'2012-07-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(129.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (102, 202, 70, CAST(N'2012-07-06T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(1450.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (103, 203, 72, CAST(N'2012-07-06T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(1390.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (104, 204, 74, CAST(N'2012-07-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(2175.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (105, 205, 75, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(1350.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (106, 206, 76, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(500.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (107, 207, 79, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(3200.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (108, 208, 82, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(2450.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (109, 209, 77, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(2975.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (110, 210, 78, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(652.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (111, 211, 89, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(1557.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (112, 212, 90, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(4900.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (113, 213, 96, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(2900.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (114, 214, 100, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(9750.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (115, 215, 35, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(1500.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (116, 216, 97, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(10925.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (117, 217, 41, CAST(N'2012-07-07T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(326.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (118, 218, 1, CAST(N'2012-04-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(2676.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (119, 219, 12, CAST(N'2012-04-30T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(836.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (120, 220, 3, CAST(N'2012-05-03T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1979.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (121, 221, 4, CAST(N'2012-05-03T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(3350.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (122, 222, 8, CAST(N'2012-05-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(11930.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (123, 223, 6, CAST(N'2012-05-27T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(1662.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (124, 224, 7, CAST(N'2012-05-30T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(1140.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (125, 225, 8, CAST(N'2012-06-06T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(1578.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (126, 226, 9, CAST(N'2012-06-17T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(2242.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (127, 227, 10, CAST(N'2012-06-23T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(13481.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (128, 228, 11, CAST(N'2012-06-27T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(3777.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (129, 229, 6, CAST(N'2012-07-03T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(2681.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (130, 230, 1, CAST(N'2012-07-08T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(8169.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (131, 231, 1, CAST(N'2012-07-09T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(1640.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (132, 232, 2, CAST(N'2012-07-22T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(10220.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (133, 233, 6, CAST(N'2012-07-29T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(274.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (134, 234, 5, CAST(N'2012-08-01T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(5196.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (135, 235, 3, CAST(N'2012-08-01T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(6471.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (136, 236, 8, CAST(N'2012-08-09T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(1881.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (137, 237, 11, CAST(N'2012-08-12T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(1330.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (138, 238, 12, CAST(N'2012-08-16T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(2536.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (139, 239, 7, CAST(N'2012-08-22T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(1130.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (140, 240, 10, CAST(N'2012-09-01T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(1695.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (141, 241, 6, CAST(N'2012-09-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(436.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (142, 242, 1, CAST(N'2012-09-02T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(204.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (143, 243, 12, CAST(N'2012-09-02T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(3837.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (144, 244, 13, CAST(N'2012-09-02T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(8295.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (145, 245, 13, CAST(N'2012-09-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(510.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (146, 246, 14, CAST(N'2012-09-03T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(745.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (147, 247, 14, CAST(N'2012-09-03T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(1259.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (148, 248, 14, CAST(N'2012-09-03T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(115.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (149, 249, 24, CAST(N'2012-09-05T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(2448.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (150, 250, 94, CAST(N'2012-09-05T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(1308.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (151, 251, 99, CAST(N'2012-09-05T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(358.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (152, 252, 27, CAST(N'2012-09-07T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(323.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (153, 253, 32, CAST(N'2012-09-07T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(1806.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (154, 254, 92, CAST(N'2012-09-07T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(65.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (155, 255, 33, CAST(N'2012-09-07T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(2433.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (156, 256, 77, CAST(N'2012-09-09T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(10494.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (157, 257, 80, CAST(N'2012-09-09T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(1475.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (158, 258, 30, CAST(N'2012-09-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(325.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (159, 259, 100, CAST(N'2012-09-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(725.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (160, 260, 64, CAST(N'2012-09-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(2966.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (161, 261, 95, CAST(N'2012-09-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(390.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (162, 262, 24, CAST(N'2012-09-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(1067.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (163, 263, 82, CAST(N'2012-09-10T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(1013.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (164, 264, 85, CAST(N'2012-09-10T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(5.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (165, 265, 28, CAST(N'2012-09-10T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(5290.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (166, 266, 29, CAST(N'2012-09-10T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(499.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (167, 267, 32, CAST(N'2012-09-10T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(295.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (168, 268, 44, CAST(N'2012-09-10T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(224.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (169, 269, 49, CAST(N'2012-09-10T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(9440.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (170, 270, 54, CAST(N'2012-09-10T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(11742.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (171, 271, 69, CAST(N'2012-09-10T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(1798.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (172, 272, 97, CAST(N'2012-09-11T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(725.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (173, 273, 82, CAST(N'2012-09-11T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(194.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (174, 274, 80, CAST(N'2012-09-11T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(2382.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (175, 275, 34, CAST(N'2012-09-11T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(323.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (176, 276, 36, CAST(N'2012-09-11T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(12.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (177, 277, 41, CAST(N'2012-09-11T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(378.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (178, 278, 42, CAST(N'2012-09-11T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(341.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (179, 279, 52, CAST(N'2012-09-11T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(22514.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (180, 280, 99, CAST(N'2012-09-12T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(2320.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (181, 281, 29, CAST(N'2012-09-12T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(634.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (182, 282, 35, CAST(N'2012-09-12T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(516.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (183, 283, 38, CAST(N'2012-09-12T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(2670.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (184, 284, 43, CAST(N'2012-09-12T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(588.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (185, 285, 48, CAST(N'2012-09-12T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(1704.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (186, 286, 53, CAST(N'2012-09-12T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(228.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (187, 287, 59, CAST(N'2012-09-13T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(3047.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (188, 288, 63, CAST(N'2012-09-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(24.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (189, 289, 71, CAST(N'2012-09-13T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(120.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (190, 290, 96, CAST(N'2012-09-13T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(624.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (191, 291, 51, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(632.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (192, 292, 74, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(1079.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (193, 293, 56, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(1475.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (194, 294, 62, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(1125.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (195, 295, 85, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(229.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (196, 296, 47, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(14690.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (197, 297, 94, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(283.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (198, 298, 36, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(1560.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (199, 299, 31, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(1144.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (200, 300, 41, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(2660.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (201, 301, 49, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(824.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (202, 302, 59, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(18186.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (203, 303, 99, CAST(N'2012-09-17T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(4797.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (204, 304, 34, CAST(N'2012-09-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(597.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (205, 305, 26, CAST(N'2012-09-17T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(516.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (206, 306, 27, CAST(N'2012-09-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(5070.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (207, 307, 33, CAST(N'2012-09-17T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(1232.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (208, 308, 37, CAST(N'2012-09-18T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(45.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (209, 309, 38, CAST(N'2012-09-18T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(779.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (210, 310, 42, CAST(N'2012-09-18T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(1413.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (211, 311, 46, CAST(N'2012-09-18T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(295.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (212, 312, 50, CAST(N'2012-09-18T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(497.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (213, 313, 55, CAST(N'2012-09-18T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(2360.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (214, 314, 61, CAST(N'2012-09-19T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(1966.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (215, 315, 65, CAST(N'2012-09-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(4340.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (216, 316, 66, CAST(N'2012-09-19T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(40.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (217, 317, 67, CAST(N'2012-09-19T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(5408.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (218, 318, 69, CAST(N'2012-09-19T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(342.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (219, 319, 70, CAST(N'2012-09-19T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(87.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (220, 320, 72, CAST(N'2012-09-19T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(834.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (221, 321, 74, CAST(N'2012-09-19T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(870.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (222, 322, 75, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(162.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (223, 323, 76, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(10.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (224, 324, 79, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(32.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (225, 325, 82, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(147.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (226, 326, 77, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1785.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (227, 327, 78, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(1630.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (228, 328, 89, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(9781.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (229, 329, 90, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(49.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (230, 330, 96, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(29.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (231, 331, 100, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(195.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (232, 332, 35, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(120.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (233, 333, 97, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(848.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (234, 334, 41, CAST(N'2012-09-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(494.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (235, 335, 1, CAST(N'2012-07-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(4617.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (236, 336, 12, CAST(N'2012-07-14T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(1188.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (237, 337, 3, CAST(N'2012-07-17T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(5415.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (238, 338, 4, CAST(N'2012-07-17T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(4129.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (239, 339, 8, CAST(N'2012-08-06T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(8614.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (240, 340, 6, CAST(N'2012-08-10T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(3192.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (241, 341, 7, CAST(N'2012-08-13T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(993.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (242, 342, 8, CAST(N'2012-08-20T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(3736.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (243, 343, 9, CAST(N'2012-08-31T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(2815.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (244, 344, 10, CAST(N'2012-09-06T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(22107.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (245, 345, 11, CAST(N'2012-09-10T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(1349.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (246, 346, 6, CAST(N'2012-09-16T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(8039.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (247, 347, 1, CAST(N'2012-09-21T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(5616.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (248, 348, 1, CAST(N'2012-09-22T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(1968.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (249, 349, 2, CAST(N'2012-10-05T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(13739.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (250, 350, 6, CAST(N'2012-10-12T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(548.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (251, 351, 5, CAST(N'2012-10-15T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(14289.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (252, 352, 3, CAST(N'2012-10-15T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(9314.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (253, 353, 8, CAST(N'2012-10-23T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(670.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (254, 354, 11, CAST(N'2012-10-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(957.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (255, 355, 12, CAST(N'2012-10-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(3804.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (256, 356, 7, CAST(N'2012-11-05T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(3234.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (257, 357, 10, CAST(N'2012-11-15T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(1969.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (258, 358, 6, CAST(N'2012-11-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(335.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (259, 359, 1, CAST(N'2012-11-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(213.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (260, 360, 12, CAST(N'2012-11-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(610.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (261, 361, 13, CAST(N'2012-11-16T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(8774.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (262, 362, 13, CAST(N'2012-11-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(2687.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (263, 363, 14, CAST(N'2012-11-17T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(2038.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (264, 364, 14, CAST(N'2012-11-17T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(2158.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (265, 365, 14, CAST(N'2012-11-17T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(500.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (266, 366, 24, CAST(N'2012-11-19T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(2019.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (267, 367, 94, CAST(N'2012-11-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(1471.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (268, 368, 99, CAST(N'2012-11-19T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(1432.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (269, 369, 27, CAST(N'2012-11-21T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(880.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (270, 370, 32, CAST(N'2012-11-21T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(2195.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (271, 371, 92, CAST(N'2012-11-21T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(200.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (272, 372, 33, CAST(N'2012-11-21T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(12496.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (273, 373, 77, CAST(N'2012-11-23T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(27984.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (274, 374, 80, CAST(N'2012-11-23T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(4720.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (275, 375, 30, CAST(N'2012-11-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(749.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (276, 376, 100, CAST(N'2012-11-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (277, 377, 64, CAST(N'2012-11-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(2753.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (278, 378, 95, CAST(N'2012-11-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(156.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (279, 379, 24, CAST(N'2012-11-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(892.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (280, 380, 82, CAST(N'2012-11-24T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(3333.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (281, 381, 85, CAST(N'2012-11-24T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(85.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (282, 382, 28, CAST(N'2012-11-24T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(8464.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (283, 383, 29, CAST(N'2012-11-24T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(3992.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (284, 384, 32, CAST(N'2012-11-24T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(2360.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (285, 385, 44, CAST(N'2012-11-24T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(1479.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (286, 386, 49, CAST(N'2012-11-24T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(5371.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (287, 387, 54, CAST(N'2012-11-24T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(9144.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (288, 388, 69, CAST(N'2012-11-24T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(1491.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (289, 389, 97, CAST(N'2012-11-25T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(1450.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (290, 390, 82, CAST(N'2012-11-25T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(1248.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (291, 391, 80, CAST(N'2012-11-25T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(1861.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (292, 392, 34, CAST(N'2012-11-25T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(133.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (293, 393, 36, CAST(N'2012-11-25T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(144.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (294, 394, 41, CAST(N'2012-11-25T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(1373.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (295, 395, 42, CAST(N'2012-11-25T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(586.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (296, 396, 52, CAST(N'2012-11-25T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(9882.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (297, 397, 99, CAST(N'2012-11-26T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(2320.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (298, 398, 29, CAST(N'2012-11-26T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(672.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (299, 399, 35, CAST(N'2012-11-26T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(1419.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (300, 400, 38, CAST(N'2012-11-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(690.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (301, 401, 43, CAST(N'2012-11-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(252.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (302, 402, 48, CAST(N'2012-11-26T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(547.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (303, 403, 53, CAST(N'2012-11-26T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(76.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (304, 404, 59, CAST(N'2012-11-27T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(6332.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (305, 405, 63, CAST(N'2012-11-27T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(24.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (306, 406, 71, CAST(N'2012-11-27T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(130.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (307, 407, 96, CAST(N'2012-11-27T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(745.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (308, 408, 51, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(725.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (309, 409, 74, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(9711.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (310, 410, 56, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(2065.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (311, 411, 62, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(442.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (312, 412, 85, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(1832.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (313, 413, 47, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(13158.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (314, 414, 94, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(557.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (315, 415, 36, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(2340.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (316, 416, 31, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(736.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (317, 417, 41, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(921.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (318, 418, 49, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(924.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (319, 419, 59, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (320, 420, 99, CAST(N'2012-12-01T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(25584.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (321, 421, 34, CAST(N'2012-12-01T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(1393.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (322, 422, 26, CAST(N'2012-12-01T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(659.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (323, 423, 27, CAST(N'2012-12-01T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(7443.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (324, 424, 33, CAST(N'2012-12-01T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(834.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (325, 425, 37, CAST(N'2012-12-02T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(90.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (326, 426, 38, CAST(N'2012-12-02T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(1558.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (327, 427, 42, CAST(N'2012-12-02T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(682.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (328, 428, 46, CAST(N'2012-12-02T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(547.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (329, 429, 50, CAST(N'2012-12-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(433.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (330, 430, 55, CAST(N'2012-12-02T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(295.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (331, 431, 61, CAST(N'2012-12-03T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(1589.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (332, 432, 65, CAST(N'2012-12-03T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(1980.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (333, 433, 66, CAST(N'2012-12-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(25.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (334, 434, 67, CAST(N'2012-12-03T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(1672.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (335, 435, 69, CAST(N'2012-12-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(668.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (336, 436, 70, CAST(N'2012-12-03T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(203.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (337, 437, 72, CAST(N'2012-12-03T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(278.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (338, 438, 74, CAST(N'2012-12-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (339, 439, 75, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(27.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (340, 440, 76, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(10.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (341, 441, 79, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(64.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (342, 442, 82, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(343.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (343, 443, 77, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(9520.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (344, 444, 78, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(1412.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (345, 445, 89, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(12634.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (346, 446, 90, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(441.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (347, 447, 96, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(87.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (348, 448, 100, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(195.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (349, 449, 35, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(45.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (350, 450, 97, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(1748.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (351, 451, 41, CAST(N'2012-12-04T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(326.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (352, 452, 1, CAST(N'2012-09-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(744.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (353, 453, 12, CAST(N'2012-09-27T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(1747.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (354, 454, 3, CAST(N'2012-09-30T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(2464.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (355, 455, 4, CAST(N'2012-09-30T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(3272.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (356, 456, 8, CAST(N'2012-10-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(17077.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (357, 457, 6, CAST(N'2012-10-24T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(1824.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (358, 458, 7, CAST(N'2012-10-27T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(1824.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (359, 459, 8, CAST(N'2012-11-03T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(4815.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (360, 460, 9, CAST(N'2012-11-14T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(4181.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (361, 461, 10, CAST(N'2012-11-20T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(16842.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (362, 462, 11, CAST(N'2012-11-24T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(4889.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (363, 463, 6, CAST(N'2012-11-30T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(28399.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (364, 464, 1, CAST(N'2012-12-05T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(7761.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (365, 465, 1, CAST(N'2012-12-06T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(1909.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (366, 466, 2, CAST(N'2012-12-19T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(3814.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (367, 467, 6, CAST(N'2012-12-26T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(1918.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (368, 468, 5, CAST(N'2012-12-29T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(5196.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (369, 469, 3, CAST(N'2012-12-29T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(9521.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (370, 470, 8, CAST(N'2013-01-06T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(882.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (371, 471, 11, CAST(N'2013-01-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(1660.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (372, 472, 12, CAST(N'2013-01-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(6975.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (373, 473, 7, CAST(N'2013-01-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(11179.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (374, 474, 10, CAST(N'2013-01-29T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(3755.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (375, 475, 6, CAST(N'2013-01-30T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(1471.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (376, 476, 1, CAST(N'2013-01-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(544.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (377, 477, 12, CAST(N'2013-01-30T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(5278.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (378, 478, 13, CAST(N'2013-01-30T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(18724.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (379, 479, 13, CAST(N'2013-01-30T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(3668.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (380, 480, 14, CAST(N'2013-01-31T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(545.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (381, 481, 14, CAST(N'2013-01-31T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(559.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (382, 482, 14, CAST(N'2013-01-31T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(95.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (383, 483, 24, CAST(N'2013-02-02T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(3135.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (384, 484, 94, CAST(N'2013-02-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(872.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (385, 485, 99, CAST(N'2013-02-02T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(716.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (386, 486, 27, CAST(N'2013-02-04T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(431.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (387, 487, 32, CAST(N'2013-02-04T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(1952.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (388, 488, 92, CAST(N'2013-02-04T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(320.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (389, 489, 33, CAST(N'2013-02-04T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(5485.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (390, 490, 77, CAST(N'2013-02-06T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(3498.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (391, 491, 80, CAST(N'2013-02-06T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(590.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (392, 492, 30, CAST(N'2013-02-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(119.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (393, 493, 100, CAST(N'2013-02-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (394, 494, 64, CAST(N'2013-02-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(737.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (395, 495, 95, CAST(N'2013-02-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(205.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (396, 496, 24, CAST(N'2013-02-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(768.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (397, 497, 82, CAST(N'2013-02-07T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(1476.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (398, 498, 85, CAST(N'2013-02-07T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(25.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (399, 499, 28, CAST(N'2013-02-07T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(3694.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (400, 500, 29, CAST(N'2013-02-07T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(2495.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (401, 501, 32, CAST(N'2013-02-07T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(590.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (402, 502, 44, CAST(N'2013-02-07T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(806.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (403, 503, 49, CAST(N'2013-02-07T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(12819.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (404, 504, 54, CAST(N'2013-02-07T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(3048.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (405, 505, 69, CAST(N'2013-02-07T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(994.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (406, 506, 97, CAST(N'2013-02-08T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(1015.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (407, 507, 82, CAST(N'2013-02-08T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(252.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (408, 508, 80, CAST(N'2013-02-08T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(2780.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (409, 509, 34, CAST(N'2013-02-08T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(57.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (410, 510, 36, CAST(N'2013-02-08T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(36.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (411, 511, 41, CAST(N'2013-02-08T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(756.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (412, 512, 42, CAST(N'2013-02-08T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(586.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (413, 513, 52, CAST(N'2013-02-08T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(19572.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (414, 514, 99, CAST(N'2013-02-09T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (415, 515, 29, CAST(N'2013-02-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(672.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (416, 516, 35, CAST(N'2013-02-09T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(903.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (417, 517, 38, CAST(N'2013-02-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(575.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (418, 518, 43, CAST(N'2013-02-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(567.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (419, 519, 48, CAST(N'2013-02-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(2694.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (420, 520, 53, CAST(N'2013-02-09T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(171.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (421, 521, 59, CAST(N'2013-02-10T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(5192.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (422, 522, 63, CAST(N'2013-02-10T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(96.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (423, 523, 71, CAST(N'2013-02-10T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(145.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (424, 524, 96, CAST(N'2013-02-10T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(2704.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (425, 525, 51, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(669.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (426, 526, 74, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(1079.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (427, 527, 56, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(2655.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (428, 528, 62, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(1082.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (429, 529, 85, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(916.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (430, 530, 47, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(2045.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (431, 531, 94, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(460.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (432, 532, 36, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(390.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (433, 533, 31, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(282.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (434, 534, 41, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(5203.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (435, 535, 49, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(695.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (436, 536, 59, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (437, 537, 99, CAST(N'2013-02-14T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(4797.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (438, 538, 34, CAST(N'2013-02-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(597.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (439, 539, 26, CAST(N'2013-02-14T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(1022.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (440, 540, 27, CAST(N'2013-02-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(4350.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (441, 541, 33, CAST(N'2013-02-14T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(3058.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (442, 542, 37, CAST(N'2013-02-15T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (443, 543, 38, CAST(N'2013-02-15T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(3116.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (444, 544, 42, CAST(N'2013-02-15T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(2081.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (445, 545, 46, CAST(N'2013-02-15T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(352.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (446, 546, 50, CAST(N'2013-02-15T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(128.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (447, 547, 55, CAST(N'2013-02-15T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(590.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (448, 548, 61, CAST(N'2013-02-16T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(448.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (449, 549, 65, CAST(N'2013-02-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(2202.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (450, 550, 66, CAST(N'2013-02-16T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(65.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (451, 551, 67, CAST(N'2013-02-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(14954.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (452, 552, 69, CAST(N'2013-02-16T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(425.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (453, 553, 70, CAST(N'2013-02-16T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(319.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (454, 554, 72, CAST(N'2013-02-16T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(1861.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (455, 555, 74, CAST(N'2013-02-16T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(1305.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (456, 556, 75, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(300.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (457, 557, 76, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(15.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (458, 558, 79, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(384.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (459, 559, 82, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(196.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (460, 560, 77, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1190.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (461, 561, 78, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(1560.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (462, 562, 89, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(3613.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (463, 563, 90, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(49.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (464, 564, 96, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(29.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (465, 565, 100, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(195.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (466, 566, 35, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(15.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (467, 567, 97, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(4483.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (468, 568, 41, CAST(N'2013-02-17T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(2480.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (469, 569, 1, CAST(N'2012-12-11T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(3093.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (470, 570, 12, CAST(N'2012-12-11T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(1696.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (471, 571, 3, CAST(N'2012-12-14T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(3296.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (472, 572, 4, CAST(N'2012-12-14T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(818.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (473, 573, 8, CAST(N'2013-01-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(15730.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (474, 574, 6, CAST(N'2013-01-07T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(995.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (475, 575, 7, CAST(N'2013-01-10T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(456.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (476, 576, 8, CAST(N'2013-01-17T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(10803.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (477, 577, 9, CAST(N'2013-01-28T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(2176.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (478, 578, 10, CAST(N'2013-02-03T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(10096.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (479, 579, 11, CAST(N'2013-02-07T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(3924.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (480, 580, 6, CAST(N'2013-02-13T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(30062.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (481, 581, 1, CAST(N'2013-02-18T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(4614.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (482, 582, 1, CAST(N'2013-02-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(1511.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (483, 583, 2, CAST(N'2013-03-04T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(16057.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (484, 584, 6, CAST(N'2013-03-11T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(1289.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (485, 585, 5, CAST(N'2013-03-14T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (486, 586, 3, CAST(N'2013-03-14T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(10839.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (487, 587, 8, CAST(N'2013-03-22T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(856.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (488, 588, 11, CAST(N'2013-03-25T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(1228.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (489, 589, 12, CAST(N'2013-03-29T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(1636.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (490, 590, 7, CAST(N'2013-04-04T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(4050.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (491, 591, 10, CAST(N'2013-04-14T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(2887.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (492, 592, 6, CAST(N'2013-04-15T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(1028.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (493, 593, 1, CAST(N'2013-04-15T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(272.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (494, 594, 12, CAST(N'2013-04-15T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(2724.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (495, 595, 13, CAST(N'2013-04-15T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(7744.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (496, 596, 13, CAST(N'2013-04-15T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(2091.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (497, 597, 14, CAST(N'2013-04-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(3928.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (498, 598, 14, CAST(N'2013-04-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(2341.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (499, 599, 14, CAST(N'2013-04-16T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(550.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (500, 600, 24, CAST(N'2013-04-18T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(1911.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (501, 601, 94, CAST(N'2013-04-18T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(436.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (502, 602, 99, CAST(N'2013-04-18T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(358.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (503, 603, 27, CAST(N'2013-04-20T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(1144.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (504, 604, 32, CAST(N'2013-04-20T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(3219.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (505, 605, 92, CAST(N'2013-04-20T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(435.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (506, 606, 33, CAST(N'2013-04-20T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(11354.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (507, 607, 77, CAST(N'2013-04-22T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(24486.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (508, 608, 80, CAST(N'2013-04-22T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(3245.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (509, 609, 30, CAST(N'2013-04-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(740.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (510, 610, 100, CAST(N'2013-04-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(1305.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (511, 611, 64, CAST(N'2013-04-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(741.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (512, 612, 95, CAST(N'2013-04-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(780.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (513, 613, 24, CAST(N'2013-04-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(174.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (514, 614, 82, CAST(N'2013-04-23T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(1452.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (515, 615, 85, CAST(N'2013-04-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(45.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (516, 616, 28, CAST(N'2013-04-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(10822.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (517, 617, 29, CAST(N'2013-04-23T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(6986.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (518, 618, 32, CAST(N'2013-04-23T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(2360.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (519, 619, 44, CAST(N'2013-04-23T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(1121.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (520, 620, 49, CAST(N'2013-04-23T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(5319.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (521, 621, 54, CAST(N'2013-04-23T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(23883.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (522, 622, 69, CAST(N'2013-04-23T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(2568.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (523, 623, 97, CAST(N'2013-04-24T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(1015.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (524, 624, 82, CAST(N'2013-04-24T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(546.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (525, 625, 80, CAST(N'2013-04-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(357.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (526, 626, 34, CAST(N'2013-04-24T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(171.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (527, 627, 36, CAST(N'2013-04-24T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(108.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (528, 628, 41, CAST(N'2013-04-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(378.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (529, 629, 42, CAST(N'2013-04-24T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(584.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (530, 630, 52, CAST(N'2013-04-24T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(4989.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (531, 631, 99, CAST(N'2013-04-25T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(1740.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (532, 632, 29, CAST(N'2013-04-25T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(103.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (533, 633, 35, CAST(N'2013-04-25T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(129.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (534, 634, 38, CAST(N'2013-04-25T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(558.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (535, 635, 43, CAST(N'2013-04-25T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(354.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (536, 636, 48, CAST(N'2013-04-25T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(2145.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (537, 637, 53, CAST(N'2013-04-25T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(456.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (538, 638, 59, CAST(N'2013-04-26T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(3763.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (539, 639, 63, CAST(N'2013-04-26T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(36.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (540, 640, 71, CAST(N'2013-04-26T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(170.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (541, 641, 96, CAST(N'2013-04-26T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(1282.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (542, 642, 51, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(702.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (543, 643, 74, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(9711.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (544, 644, 56, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(2655.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (545, 645, 62, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(2017.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (546, 646, 85, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(2519.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (547, 647, 47, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(17696.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (548, 648, 94, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(88.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (549, 649, 36, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(195.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (550, 650, 31, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(535.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (551, 651, 41, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(7055.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (552, 652, 49, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(4004.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (553, 653, 59, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(3897.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (554, 654, 99, CAST(N'2013-04-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(14391.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (555, 655, 34, CAST(N'2013-04-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(1194.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (556, 656, 26, CAST(N'2013-04-30T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(1077.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (557, 657, 27, CAST(N'2013-04-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(17926.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (558, 658, 33, CAST(N'2013-04-30T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(755.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (559, 659, 37, CAST(N'2013-05-01T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (560, 660, 38, CAST(N'2013-05-01T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(6232.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (561, 661, 42, CAST(N'2013-05-01T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(1164.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (562, 662, 46, CAST(N'2013-05-01T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(196.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (563, 663, 50, CAST(N'2013-05-01T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(79.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (564, 664, 55, CAST(N'2013-05-01T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(295.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (565, 665, 61, CAST(N'2013-05-02T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(2464.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (566, 666, 65, CAST(N'2013-05-02T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(587.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (567, 667, 66, CAST(N'2013-05-02T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(30.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (568, 668, 67, CAST(N'2013-05-02T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(21568.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (569, 669, 69, CAST(N'2013-05-02T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(1677.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (570, 670, 70, CAST(N'2013-05-02T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(348.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (571, 671, 72, CAST(N'2013-05-02T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(4170.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (572, 672, 74, CAST(N'2013-05-02T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(725.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (573, 673, 75, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(135.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (574, 674, 76, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(10.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (575, 675, 79, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(96.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (576, 676, 82, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(147.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (577, 677, 77, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(3570.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (578, 678, 78, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(1924.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (579, 679, 89, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(10340.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (580, 680, 90, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(392.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (581, 681, 96, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(232.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (582, 682, 100, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(585.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (583, 683, 35, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(45.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (584, 684, 97, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(2101.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (585, 685, 41, CAST(N'2013-05-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(2184.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (586, 686, 1, CAST(N'2013-02-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(1636.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (587, 687, 12, CAST(N'2013-02-24T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(1931.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (588, 688, 3, CAST(N'2013-02-27T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(2644.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (589, 689, 4, CAST(N'2013-02-27T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(13516.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (590, 690, 8, CAST(N'2013-03-19T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(4090.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (591, 691, 6, CAST(N'2013-03-23T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(1709.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (592, 692, 7, CAST(N'2013-03-26T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(505.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (593, 693, 8, CAST(N'2013-04-02T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(6892.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (594, 694, 9, CAST(N'2013-04-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(1833.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (595, 695, 10, CAST(N'2013-04-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(16877.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (596, 696, 11, CAST(N'2013-04-23T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(2649.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (597, 697, 6, CAST(N'2013-04-29T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(6023.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (598, 698, 1, CAST(N'2013-05-04T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(3905.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (599, 699, 1, CAST(N'2013-05-05T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(2952.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (600, 700, 2, CAST(N'2013-05-18T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(21283.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (601, 701, 6, CAST(N'2013-05-25T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(274.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (602, 702, 5, CAST(N'2013-05-28T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(5196.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (603, 703, 3, CAST(N'2013-05-28T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(10494.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (604, 704, 8, CAST(N'2013-06-05T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(1887.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (605, 705, 11, CAST(N'2013-06-08T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(431.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (606, 706, 12, CAST(N'2013-06-12T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(1863.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (607, 707, 7, CAST(N'2013-06-18T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(935.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (608, 708, 10, CAST(N'2013-06-28T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(4365.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (609, 709, 6, CAST(N'2013-06-29T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(436.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (610, 710, 1, CAST(N'2013-06-29T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(68.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (611, 711, 12, CAST(N'2013-06-29T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(3295.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (612, 712, 13, CAST(N'2013-06-29T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(13631.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (613, 713, 13, CAST(N'2013-06-29T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(1383.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (614, 714, 14, CAST(N'2013-06-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(2464.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (615, 715, 14, CAST(N'2013-06-30T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(1812.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (616, 716, 14, CAST(N'2013-06-30T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(410.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (617, 717, 24, CAST(N'2013-07-02T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(2198.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (618, 718, 94, CAST(N'2013-07-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(1090.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (619, 719, 99, CAST(N'2013-07-02T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(895.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (620, 720, 27, CAST(N'2013-07-04T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(342.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (621, 721, 32, CAST(N'2013-07-04T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(1415.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (622, 722, 92, CAST(N'2013-07-04T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(530.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (623, 723, 33, CAST(N'2013-07-04T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(5837.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (624, 724, 77, CAST(N'2013-07-06T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(6996.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (625, 725, 80, CAST(N'2013-07-06T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(1180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (626, 726, 30, CAST(N'2013-07-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(296.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (627, 727, 100, CAST(N'2013-07-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(1160.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (628, 728, 64, CAST(N'2013-07-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(494.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (629, 729, 95, CAST(N'2013-07-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(78.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (630, 730, 24, CAST(N'2013-07-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(522.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (631, 731, 82, CAST(N'2013-07-07T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(1175.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (632, 732, 85, CAST(N'2013-07-07T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(5.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (633, 733, 28, CAST(N'2013-07-07T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(12279.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (634, 734, 29, CAST(N'2013-07-07T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(5988.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (635, 735, 32, CAST(N'2013-07-07T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(2950.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (636, 736, 44, CAST(N'2013-07-07T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(672.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (637, 737, 49, CAST(N'2013-07-07T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(6276.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (638, 738, 54, CAST(N'2013-07-07T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(12192.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (639, 739, 69, CAST(N'2013-07-07T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(843.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (640, 740, 97, CAST(N'2013-07-08T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(435.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (641, 741, 82, CAST(N'2013-07-08T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(136.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (642, 742, 80, CAST(N'2013-07-08T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(2783.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (643, 743, 34, CAST(N'2013-07-08T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(304.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (644, 744, 36, CAST(N'2013-07-08T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(60.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (645, 745, 41, CAST(N'2013-07-08T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(1631.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (646, 746, 42, CAST(N'2013-07-08T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(537.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (647, 747, 52, CAST(N'2013-07-08T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(3358.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (648, 748, 99, CAST(N'2013-07-09T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(290.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (649, 749, 29, CAST(N'2013-07-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(252.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (650, 750, 35, CAST(N'2013-07-09T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(1161.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (651, 751, 38, CAST(N'2013-07-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(1719.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (652, 752, 43, CAST(N'2013-07-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(420.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (653, 753, 48, CAST(N'2013-07-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(1443.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (654, 754, 53, CAST(N'2013-07-09T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(152.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (655, 755, 59, CAST(N'2013-07-10T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(3278.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (656, 756, 63, CAST(N'2013-07-10T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(96.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (657, 757, 71, CAST(N'2013-07-10T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(225.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (658, 758, 96, CAST(N'2013-07-10T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(2772.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (659, 759, 51, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(739.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (660, 760, 74, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(3237.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (661, 761, 56, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(1475.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (662, 762, 62, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(1862.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (663, 763, 85, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(916.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (664, 764, 47, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(7701.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (665, 765, 94, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(528.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (666, 766, 36, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(390.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (667, 767, 31, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(572.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (668, 768, 41, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(8431.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (669, 769, 49, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(1053.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (670, 770, 59, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (671, 771, 99, CAST(N'2013-07-14T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(3198.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (672, 772, 34, CAST(N'2013-07-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(995.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (673, 773, 26, CAST(N'2013-07-14T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(903.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (674, 774, 27, CAST(N'2013-07-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(4571.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (675, 775, 33, CAST(N'2013-07-14T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(556.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (676, 776, 37, CAST(N'2013-07-15T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(90.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (677, 777, 38, CAST(N'2013-07-15T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(1558.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (678, 778, 42, CAST(N'2013-07-15T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(388.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (679, 779, 46, CAST(N'2013-07-15T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(418.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (680, 780, 50, CAST(N'2013-07-15T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(384.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (681, 781, 55, CAST(N'2013-07-15T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(1770.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (682, 782, 61, CAST(N'2013-07-16T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(1784.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (683, 783, 65, CAST(N'2013-07-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(1850.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (684, 784, 66, CAST(N'2013-07-16T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(25.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (685, 785, 67, CAST(N'2013-07-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(6712.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (686, 786, 69, CAST(N'2013-07-16T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(538.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (687, 787, 70, CAST(N'2013-07-16T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(377.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (688, 788, 72, CAST(N'2013-07-16T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(3064.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (689, 789, 74, CAST(N'2013-07-16T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(2175.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (690, 790, 75, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(330.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (691, 791, 76, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(10.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (692, 792, 79, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(96.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (693, 793, 82, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(441.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (694, 794, 77, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(7735.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (695, 795, 78, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(2597.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (696, 796, 89, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(1557.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (697, 797, 90, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(49.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (698, 798, 96, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(29.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (699, 799, 100, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(195.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (700, 800, 35, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(105.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (701, 801, 97, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(2601.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (702, 802, 41, CAST(N'2013-07-17T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(949.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (703, 803, 1, CAST(N'2013-05-10T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(4768.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (704, 804, 12, CAST(N'2013-05-10T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(4242.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (705, 805, 3, CAST(N'2013-05-13T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(4928.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (706, 806, 4, CAST(N'2013-05-13T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(4090.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (707, 807, 8, CAST(N'2013-06-02T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(5577.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (708, 808, 6, CAST(N'2013-06-06T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(505.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (709, 809, 7, CAST(N'2013-06-09T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(228.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (710, 810, 8, CAST(N'2013-06-16T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(3736.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (711, 811, 9, CAST(N'2013-06-27T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(3303.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (712, 812, 10, CAST(N'2013-07-03T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(23247.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (713, 813, 11, CAST(N'2013-07-07T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(2829.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (714, 814, 6, CAST(N'2013-07-13T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(3765.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (715, 815, 1, CAST(N'2013-07-18T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(5777.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (716, 816, 1, CAST(N'2013-07-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(2624.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (717, 817, 2, CAST(N'2013-08-01T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(14287.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (718, 818, 6, CAST(N'2013-08-08T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(548.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (719, 819, 5, CAST(N'2013-08-11T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(16887.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (720, 820, 3, CAST(N'2013-08-11T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(9452.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (721, 821, 8, CAST(N'2013-08-19T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(1509.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (722, 822, 11, CAST(N'2013-08-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(983.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (723, 823, 12, CAST(N'2013-08-26T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(1941.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (724, 824, 7, CAST(N'2013-09-01T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(8316.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (725, 825, 10, CAST(N'2013-09-11T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(3975.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (726, 826, 6, CAST(N'2013-09-12T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(2180.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (727, 827, 1, CAST(N'2013-09-12T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(263.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (728, 828, 12, CAST(N'2013-09-12T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(852.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (729, 829, 13, CAST(N'2013-09-12T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(17335.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (730, 830, 13, CAST(N'2013-09-12T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(2463.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (731, 831, 14, CAST(N'2013-09-13T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(2380.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (732, 832, 14, CAST(N'2013-09-13T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(1357.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (733, 833, 14, CAST(N'2013-09-13T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(90.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (734, 834, 24, CAST(N'2013-09-15T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(2448.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (735, 835, 94, CAST(N'2013-09-15T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(553.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (736, 836, 99, CAST(N'2013-09-15T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(358.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (737, 837, 27, CAST(N'2013-09-17T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(998.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (738, 838, 32, CAST(N'2013-09-17T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(2779.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (739, 839, 92, CAST(N'2013-09-17T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(90.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (740, 840, 33, CAST(N'2013-09-17T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(811.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (741, 841, 77, CAST(N'2013-09-19T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(8745.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (742, 842, 80, CAST(N'2013-09-19T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(1180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (743, 843, 30, CAST(N'2013-09-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(103.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (744, 844, 100, CAST(N'2013-09-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(290.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (745, 845, 64, CAST(N'2013-09-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(1729.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (746, 846, 95, CAST(N'2013-09-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(321.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (747, 847, 24, CAST(N'2013-09-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(631.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (748, 848, 82, CAST(N'2013-09-20T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(966.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (749, 849, 85, CAST(N'2013-09-20T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(5.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (750, 850, 28, CAST(N'2013-09-20T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(6088.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (751, 851, 29, CAST(N'2013-09-20T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(998.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (752, 852, 32, CAST(N'2013-09-20T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(590.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (753, 853, 44, CAST(N'2013-09-20T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(1792.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (754, 854, 49, CAST(N'2013-09-20T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(17259.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (755, 855, 54, CAST(N'2013-09-20T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(16140.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (756, 856, 69, CAST(N'2013-09-20T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(2144.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (757, 857, 97, CAST(N'2013-09-21T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(1450.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (758, 858, 82, CAST(N'2013-09-21T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(780.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (759, 859, 80, CAST(N'2013-09-21T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(2780.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (760, 860, 34, CAST(N'2013-09-21T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(76.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (761, 861, 36, CAST(N'2013-09-21T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(48.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (762, 862, 41, CAST(N'2013-09-21T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(1512.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (763, 863, 42, CAST(N'2013-09-21T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(582.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (764, 864, 52, CAST(N'2013-09-21T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(1791.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (765, 865, 99, CAST(N'2013-09-22T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(435.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (766, 866, 29, CAST(N'2013-09-22T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(439.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (767, 867, 35, CAST(N'2013-09-22T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(129.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (768, 868, 38, CAST(N'2013-09-22T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(2210.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (769, 869, 43, CAST(N'2013-09-22T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(645.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (770, 870, 48, CAST(N'2013-09-22T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(2341.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (771, 871, 53, CAST(N'2013-09-22T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(513.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (772, 872, 59, CAST(N'2013-09-23T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(6227.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (773, 873, 63, CAST(N'2013-09-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(60.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (774, 874, 71, CAST(N'2013-09-23T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(200.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (775, 875, 96, CAST(N'2013-09-23T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(1664.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (776, 876, 51, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(529.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (777, 877, 74, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(3237.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (778, 878, 56, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(1475.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (779, 879, 62, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(1199.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (780, 880, 85, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(229.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (781, 881, 47, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(11003.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (782, 882, 94, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(176.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (783, 883, 36, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(585.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (784, 884, 31, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(331.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (785, 885, 41, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(6110.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (786, 886, 49, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(4620.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (787, 887, 59, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(19485.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (788, 888, 99, CAST(N'2013-09-27T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(14391.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (789, 889, 34, CAST(N'2013-09-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(1791.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (790, 890, 26, CAST(N'2013-09-27T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(1335.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (791, 891, 27, CAST(N'2013-09-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(11019.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (792, 892, 33, CAST(N'2013-09-27T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(635.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (793, 893, 37, CAST(N'2013-09-28T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(90.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (794, 894, 38, CAST(N'2013-09-28T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(10906.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (795, 895, 42, CAST(N'2013-09-28T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(2716.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (796, 896, 46, CAST(N'2013-09-28T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(282.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (797, 897, 50, CAST(N'2013-09-28T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(384.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (798, 898, 55, CAST(N'2013-09-28T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(1770.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (799, 899, 61, CAST(N'2013-09-29T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(253.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (800, 900, 65, CAST(N'2013-09-29T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(627.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (801, 901, 66, CAST(N'2013-09-29T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(70.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (802, 902, 67, CAST(N'2013-09-29T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(10616.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (803, 903, 69, CAST(N'2013-09-29T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(698.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (804, 904, 70, CAST(N'2013-09-29T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(29.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (805, 905, 72, CAST(N'2013-09-29T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(1229.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (806, 906, 74, CAST(N'2013-09-29T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(725.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (807, 907, 75, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(174.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (808, 908, 76, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(30.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (809, 909, 79, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(192.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (810, 910, 82, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(441.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (811, 911, 77, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(5355.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (812, 912, 78, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(2036.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (813, 913, 89, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(5430.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (814, 914, 90, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(441.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (815, 915, 96, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(261.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (816, 916, 100, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(1755.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (817, 917, 35, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(120.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (818, 918, 97, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(1527.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (819, 919, 41, CAST(N'2013-09-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(3250.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (820, 920, 1, CAST(N'2013-07-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(1906.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (821, 921, 12, CAST(N'2013-07-24T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(2904.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (822, 922, 3, CAST(N'2013-07-27T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1842.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (823, 923, 4, CAST(N'2013-07-27T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(818.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (824, 924, 8, CAST(N'2013-08-16T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(8167.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (825, 925, 6, CAST(N'2013-08-20T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(2231.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (826, 926, 7, CAST(N'2013-08-23T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(3648.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (827, 927, 8, CAST(N'2013-08-30T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(22011.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (828, 928, 9, CAST(N'2013-09-10T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(4771.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (829, 929, 10, CAST(N'2013-09-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(5847.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (830, 930, 11, CAST(N'2013-09-20T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(1716.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (831, 931, 6, CAST(N'2013-09-26T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(21678.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (832, 932, 1, CAST(N'2013-10-01T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(5028.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (833, 933, 1, CAST(N'2013-10-02T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(1839.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (834, 934, 2, CAST(N'2013-10-15T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(12264.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (835, 935, 6, CAST(N'2013-10-22T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(2208.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (836, 936, 5, CAST(N'2013-10-25T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(11691.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (837, 937, 3, CAST(N'2013-10-25T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(4180.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (838, 938, 8, CAST(N'2013-11-02T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(1630.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (839, 939, 11, CAST(N'2013-11-05T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(592.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (840, 940, 12, CAST(N'2013-11-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(771.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (841, 941, 7, CAST(N'2013-11-15T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(2961.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (842, 942, 10, CAST(N'2013-11-25T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(1497.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (843, 943, 6, CAST(N'2013-11-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(2187.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (844, 944, 1, CAST(N'2013-11-26T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(476.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (845, 945, 12, CAST(N'2013-11-26T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(3228.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (846, 946, 13, CAST(N'2013-11-26T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(11223.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (847, 947, 13, CAST(N'2013-11-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(1455.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (848, 948, 14, CAST(N'2013-11-27T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(258.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (849, 949, 14, CAST(N'2013-11-27T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(903.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (850, 950, 14, CAST(N'2013-11-27T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(65.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (851, 951, 24, CAST(N'2013-11-29T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(4488.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (852, 952, 94, CAST(N'2013-11-29T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(2935.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (853, 953, 99, CAST(N'2013-11-29T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(358.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (854, 954, 27, CAST(N'2013-12-01T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(176.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (855, 955, 32, CAST(N'2013-12-01T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(3172.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (856, 956, 92, CAST(N'2013-12-01T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(530.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (857, 957, 33, CAST(N'2013-12-01T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(3244.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (858, 958, 77, CAST(N'2013-12-03T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(24486.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (859, 959, 80, CAST(N'2013-12-03T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(885.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (860, 960, 30, CAST(N'2013-12-03T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(309.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (861, 961, 100, CAST(N'2013-12-03T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (862, 962, 64, CAST(N'2013-12-03T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(1843.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (863, 963, 95, CAST(N'2013-12-03T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(225.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (864, 964, 24, CAST(N'2013-12-03T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(516.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (865, 965, 82, CAST(N'2013-12-04T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(1685.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (866, 966, 85, CAST(N'2013-12-04T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(65.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (867, 967, 28, CAST(N'2013-12-04T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(6469.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (868, 968, 29, CAST(N'2013-12-04T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(3992.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (869, 969, 32, CAST(N'2013-12-04T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(1475.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (870, 970, 44, CAST(N'2013-12-04T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(448.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (871, 971, 49, CAST(N'2013-12-04T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(9095.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (872, 972, 54, CAST(N'2013-12-04T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(15240.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (873, 973, 69, CAST(N'2013-12-04T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(1072.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (874, 974, 97, CAST(N'2013-12-05T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(725.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (875, 975, 82, CAST(N'2013-12-05T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(762.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (876, 976, 80, CAST(N'2013-12-05T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(910.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (877, 977, 34, CAST(N'2013-12-05T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(19.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (878, 978, 36, CAST(N'2013-12-05T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(96.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (879, 979, 41, CAST(N'2013-12-05T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(2626.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (880, 980, 42, CAST(N'2013-12-05T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(1066.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (881, 981, 52, CAST(N'2013-12-05T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(11417.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (882, 982, 99, CAST(N'2013-12-06T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(1305.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (883, 983, 29, CAST(N'2013-12-06T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(840.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (884, 984, 35, CAST(N'2013-12-06T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(1032.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (885, 985, 38, CAST(N'2013-12-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(1608.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (886, 986, 43, CAST(N'2013-12-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(252.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (887, 987, 48, CAST(N'2013-12-06T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(819.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (888, 988, 53, CAST(N'2013-12-06T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(266.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (889, 989, 59, CAST(N'2013-12-07T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(9393.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (890, 990, 63, CAST(N'2013-12-07T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(144.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (891, 991, 71, CAST(N'2013-12-07T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(280.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (892, 992, 96, CAST(N'2013-12-07T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(1040.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (893, 993, 51, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(528.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (894, 994, 74, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(3237.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (895, 995, 56, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(885.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (896, 996, 62, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(2036.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (897, 997, 85, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(3206.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (898, 998, 47, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(9707.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (899, 999, 94, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(235.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (900, 1000, 36, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(195.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (901, 1001, 31, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(829.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (902, 1002, 41, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(2531.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (903, 1003, 49, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(308.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (904, 1004, 59, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (905, 1005, 99, CAST(N'2013-12-11T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(9594.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (906, 1006, 34, CAST(N'2013-12-11T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(995.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (907, 1007, 26, CAST(N'2013-12-11T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(309.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (908, 1008, 27, CAST(N'2013-12-11T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(3534.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (909, 1009, 33, CAST(N'2013-12-11T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(2704.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (910, 1010, 37, CAST(N'2013-12-12T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(540.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (911, 1011, 38, CAST(N'2013-12-12T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(9348.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (912, 1012, 42, CAST(N'2013-12-12T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(878.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (913, 1013, 46, CAST(N'2013-12-12T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(242.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (914, 1014, 50, CAST(N'2013-12-12T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(124.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (915, 1015, 55, CAST(N'2013-12-12T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(2360.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (916, 1016, 61, CAST(N'2013-12-13T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(1589.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (917, 1017, 65, CAST(N'2013-12-13T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(1623.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (918, 1018, 66, CAST(N'2013-12-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(20.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (919, 1019, 67, CAST(N'2013-12-13T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(14731.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (920, 1020, 69, CAST(N'2013-12-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(701.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (921, 1021, 70, CAST(N'2013-12-13T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(406.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (922, 1022, 72, CAST(N'2013-12-13T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(3892.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (923, 1023, 74, CAST(N'2013-12-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(435.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (924, 1024, 75, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(186.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (925, 1025, 76, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(15.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (926, 1026, 79, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(96.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (927, 1027, 82, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(147.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (928, 1028, 77, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1190.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (929, 1029, 78, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(1602.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (930, 1030, 89, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(9641.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (931, 1031, 90, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(245.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (932, 1032, 96, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(58.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (933, 1033, 100, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(195.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (934, 1034, 35, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(15.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (935, 1035, 97, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(437.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (936, 1036, 41, CAST(N'2013-12-14T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(1975.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (937, 1037, 1, CAST(N'2013-10-07T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(1950.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (938, 1038, 12, CAST(N'2013-10-07T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(5706.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (939, 1039, 3, CAST(N'2013-10-10T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1303.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (940, 1040, 4, CAST(N'2013-10-10T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(7323.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (941, 1041, 8, CAST(N'2013-10-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(23772.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (942, 1042, 6, CAST(N'2013-11-03T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(912.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (943, 1043, 7, CAST(N'2013-11-06T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(912.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (944, 1044, 8, CAST(N'2013-11-13T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(7391.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (945, 1045, 9, CAST(N'2013-11-24T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(1835.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (946, 1046, 10, CAST(N'2013-11-30T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(24466.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (947, 1047, 11, CAST(N'2013-12-04T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(1400.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (948, 1048, 6, CAST(N'2013-12-10T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(15341.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (949, 1049, 1, CAST(N'2013-12-15T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(9065.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (950, 1050, 1, CAST(N'2013-12-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(3571.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (951, 1051, 2, CAST(N'2013-12-29T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(12285.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (952, 1052, 6, CAST(N'2014-01-05T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(1322.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (953, 1053, 5, CAST(N'2014-01-08T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(2598.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (954, 1054, 3, CAST(N'2014-01-08T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(954.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (955, 1055, 8, CAST(N'2014-01-16T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(1917.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (956, 1056, 11, CAST(N'2014-01-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(649.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (957, 1057, 12, CAST(N'2014-01-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(4916.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (958, 1058, 7, CAST(N'2014-01-29T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(11569.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (959, 1059, 10, CAST(N'2014-02-08T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(2267.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (960, 1060, 6, CAST(N'2014-02-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(218.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (961, 1061, 1, CAST(N'2014-02-09T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(340.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (962, 1062, 12, CAST(N'2014-02-09T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(1872.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (963, 1063, 13, CAST(N'2014-02-09T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(2058.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (964, 1064, 13, CAST(N'2014-02-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(1767.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (965, 1065, 14, CAST(N'2014-02-10T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(1290.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (966, 1066, 14, CAST(N'2014-02-10T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(2323.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (967, 1067, 14, CAST(N'2014-02-10T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(200.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (968, 1068, 24, CAST(N'2014-02-12T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(1553.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (969, 1069, 94, CAST(N'2014-02-12T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(1324.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (970, 1070, 99, CAST(N'2014-02-12T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(895.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (971, 1071, 27, CAST(N'2014-02-14T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(616.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (972, 1072, 32, CAST(N'2014-02-14T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(1854.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (973, 1073, 92, CAST(N'2014-02-14T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(360.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (974, 1074, 33, CAST(N'2014-02-14T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(1067.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (975, 1075, 77, CAST(N'2014-02-16T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(5247.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (976, 1076, 80, CAST(N'2014-02-16T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(1770.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (977, 1077, 30, CAST(N'2014-02-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(502.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (978, 1078, 100, CAST(N'2014-02-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(1015.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (979, 1079, 64, CAST(N'2014-02-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(2718.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (980, 1080, 95, CAST(N'2014-02-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(1092.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (981, 1081, 24, CAST(N'2014-02-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(129.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (982, 1082, 82, CAST(N'2014-02-17T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(1707.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (983, 1083, 85, CAST(N'2014-02-17T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(20.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (984, 1084, 28, CAST(N'2014-02-17T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(2914.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (985, 1085, 29, CAST(N'2014-02-17T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(998.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (986, 1086, 32, CAST(N'2014-02-17T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(590.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (987, 1087, 44, CAST(N'2014-02-17T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(808.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (988, 1088, 49, CAST(N'2014-02-17T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(4707.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (989, 1089, 54, CAST(N'2014-02-17T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(24384.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (990, 1090, 69, CAST(N'2014-02-17T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(1569.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (991, 1091, 97, CAST(N'2014-02-18T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(1160.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (992, 1092, 82, CAST(N'2014-02-18T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(283.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (993, 1093, 80, CAST(N'2014-02-18T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(676.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (994, 1094, 34, CAST(N'2014-02-18T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(133.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (995, 1095, 36, CAST(N'2014-02-18T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(84.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (996, 1096, 41, CAST(N'2014-02-18T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(4874.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (997, 1097, 42, CAST(N'2014-02-18T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(2134.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (998, 1098, 52, CAST(N'2014-02-18T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(1631.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (999, 1099, 99, CAST(N'2014-02-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1000, 1100, 29, CAST(N'2014-02-19T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(84.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1001, 1101, 35, CAST(N'2014-02-19T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(1161.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1002, 1102, 38, CAST(N'2014-02-19T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(791.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1003, 1103, 43, CAST(N'2014-02-19T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(84.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1004, 1104, 48, CAST(N'2014-02-19T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(875.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1005, 1105, 53, CAST(N'2014-02-19T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(570.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1006, 1106, 59, CAST(N'2014-02-20T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(5151.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1007, 1107, 63, CAST(N'2014-02-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(84.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1008, 1108, 71, CAST(N'2014-02-20T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(185.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1009, 1109, 96, CAST(N'2014-02-20T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(1398.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1010, 1110, 51, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(762.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1011, 1111, 74, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(1079.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1012, 1112, 56, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(295.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1013, 1113, 62, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(569.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1014, 1114, 85, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(2519.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1015, 1115, 47, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(19201.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1016, 1116, 94, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(880.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1017, 1117, 36, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(1950.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1018, 1118, 31, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(527.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1019, 1119, 41, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(4240.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1020, 1120, 49, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(2643.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1021, 1121, 59, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1022, 1122, 99, CAST(N'2014-02-24T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(1599.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1023, 1123, 34, CAST(N'2014-02-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(995.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1024, 1124, 26, CAST(N'2014-02-24T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(624.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1025, 1125, 27, CAST(N'2014-02-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(8166.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1026, 1126, 33, CAST(N'2014-02-24T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(2584.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1027, 1127, 37, CAST(N'2014-02-25T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(585.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1028, 1128, 38, CAST(N'2014-02-25T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(10127.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1029, 1129, 42, CAST(N'2014-02-25T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(1027.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1030, 1130, 46, CAST(N'2014-02-25T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(175.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1031, 1131, 50, CAST(N'2014-02-25T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(583.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1032, 1132, 55, CAST(N'2014-02-25T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(5310.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1033, 1133, 61, CAST(N'2014-02-26T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(3742.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1034, 1134, 65, CAST(N'2014-02-26T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(701.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1035, 1135, 66, CAST(N'2014-02-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(5.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1036, 1136, 67, CAST(N'2014-02-26T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(8336.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1037, 1137, 69, CAST(N'2014-02-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(283.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1038, 1138, 70, CAST(N'2014-02-26T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1039, 1139, 72, CAST(N'2014-02-26T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(1987.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1040, 1140, 74, CAST(N'2014-02-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(1160.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1041, 1141, 75, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(99.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1042, 1142, 76, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(25.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1043, 1143, 79, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(96.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1044, 1144, 82, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(98.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1045, 1145, 77, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(4165.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1046, 1146, 78, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(1746.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1047, 1147, 89, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(5549.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1048, 1148, 90, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(392.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1049, 1149, 96, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(174.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1050, 1150, 100, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(585.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1051, 1151, 35, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(75.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1052, 1152, 97, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(1990.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1053, 1153, 41, CAST(N'2014-02-27T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(1018.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1054, 1154, 1, CAST(N'2013-12-21T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(1779.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1055, 1155, 12, CAST(N'2013-12-21T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(3104.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1056, 1156, 3, CAST(N'2013-12-24T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1358.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1057, 1157, 4, CAST(N'2013-12-24T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(7362.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1058, 1158, 8, CAST(N'2014-01-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(20512.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1059, 1159, 6, CAST(N'2014-01-17T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(2964.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1060, 1160, 7, CAST(N'2014-01-20T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(2508.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1061, 1161, 8, CAST(N'2014-01-27T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(7809.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1062, 1162, 9, CAST(N'2014-02-07T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(1399.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1063, 1163, 10, CAST(N'2014-02-13T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(4012.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1064, 1164, 11, CAST(N'2014-02-17T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(4606.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1065, 1165, 6, CAST(N'2014-02-23T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(19576.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1066, 1166, 1, CAST(N'2014-02-28T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(6325.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1067, 1167, 1, CAST(N'2014-03-01T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(1640.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1068, 1168, 2, CAST(N'2014-03-14T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(10810.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1069, 1169, 6, CAST(N'2014-03-21T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(2498.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1070, 1170, 5, CAST(N'2014-03-24T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(7794.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1071, 1171, 3, CAST(N'2014-03-24T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(6678.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1072, 1172, 8, CAST(N'2014-04-01T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(1260.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1073, 1173, 11, CAST(N'2014-04-04T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(819.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1074, 1174, 12, CAST(N'2014-04-08T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(2986.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1075, 1175, 7, CAST(N'2014-04-14T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(4558.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1076, 1176, 10, CAST(N'2014-04-24T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(5188.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1077, 1177, 6, CAST(N'2014-04-25T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(888.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1078, 1178, 1, CAST(N'2014-04-25T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(185.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1079, 1179, 12, CAST(N'2014-04-25T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(3651.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1080, 1180, 13, CAST(N'2014-04-25T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(13849.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1081, 1181, 13, CAST(N'2014-04-25T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(1764.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1082, 1182, 14, CAST(N'2014-04-26T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(1203.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1083, 1183, 14, CAST(N'2014-04-26T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(1359.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1084, 1184, 14, CAST(N'2014-04-26T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(440.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1085, 1185, 24, CAST(N'2014-04-28T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(1174.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1086, 1186, 94, CAST(N'2014-04-28T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(872.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1087, 1187, 99, CAST(N'2014-04-28T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(716.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1088, 1188, 27, CAST(N'2014-04-30T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(352.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1089, 1189, 32, CAST(N'2014-04-30T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(2196.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1090, 1190, 92, CAST(N'2014-04-30T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(215.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1091, 1191, 33, CAST(N'2014-04-30T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(8110.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1092, 1192, 77, CAST(N'2014-05-02T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(12243.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1093, 1193, 80, CAST(N'2014-05-02T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(1180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1094, 1194, 30, CAST(N'2014-05-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(296.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1095, 1195, 100, CAST(N'2014-05-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(580.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1096, 1196, 64, CAST(N'2014-05-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(1265.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1097, 1197, 95, CAST(N'2014-05-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(595.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1098, 1198, 24, CAST(N'2014-05-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(636.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1099, 1199, 82, CAST(N'2014-05-03T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(2764.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1100, 1200, 85, CAST(N'2014-05-03T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(65.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1101, 1201, 28, CAST(N'2014-05-03T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(6608.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1102, 1202, 29, CAST(N'2014-05-03T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(998.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1103, 1203, 32, CAST(N'2014-05-03T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(2360.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1104, 1204, 44, CAST(N'2014-05-03T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(718.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1105, 1205, 49, CAST(N'2014-05-03T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(3164.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1106, 1206, 54, CAST(N'2014-05-03T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(6096.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1107, 1207, 69, CAST(N'2014-05-03T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(2110.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1108, 1208, 97, CAST(N'2014-05-04T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(580.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1109, 1209, 82, CAST(N'2014-05-04T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(312.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1110, 1210, 80, CAST(N'2014-05-04T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(278.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1111, 1211, 34, CAST(N'2014-05-04T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(19.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1112, 1212, 36, CAST(N'2014-05-04T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(108.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1113, 1213, 41, CAST(N'2014-05-04T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(1373.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1114, 1214, 42, CAST(N'2014-05-04T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(1311.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1115, 1215, 52, CAST(N'2014-05-04T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(11481.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1116, 1216, 99, CAST(N'2014-05-05T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(1740.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1117, 1217, 29, CAST(N'2014-05-05T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(959.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1118, 1218, 35, CAST(N'2014-05-05T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(1548.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1119, 1219, 38, CAST(N'2014-05-05T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(737.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1120, 1220, 43, CAST(N'2014-05-05T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(672.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1121, 1221, 48, CAST(N'2014-05-05T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(1469.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1122, 1222, 53, CAST(N'2014-05-05T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(285.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1123, 1223, 59, CAST(N'2014-05-06T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(2976.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1124, 1224, 63, CAST(N'2014-05-06T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(60.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1125, 1225, 71, CAST(N'2014-05-06T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(145.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1126, 1226, 96, CAST(N'2014-05-06T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(2288.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1127, 1227, 51, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(1267.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1128, 1228, 74, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(3237.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1129, 1229, 56, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(1475.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1130, 1230, 62, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(997.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1131, 1231, 85, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(1603.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1132, 1232, 47, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(21505.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1133, 1233, 94, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(313.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1134, 1234, 36, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(195.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1135, 1235, 31, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(429.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1136, 1236, 41, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(5845.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1137, 1237, 49, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(2572.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1138, 1238, 59, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(15588.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1139, 1239, 99, CAST(N'2014-05-10T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(19188.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1140, 1240, 34, CAST(N'2014-05-10T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(796.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1141, 1241, 26, CAST(N'2014-05-10T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(1237.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1142, 1242, 27, CAST(N'2014-05-10T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(9162.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1143, 1243, 33, CAST(N'2014-05-10T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(875.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1144, 1244, 37, CAST(N'2014-05-11T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(225.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1145, 1245, 38, CAST(N'2014-05-11T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(9348.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1146, 1246, 42, CAST(N'2014-05-11T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(1115.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1147, 1247, 46, CAST(N'2014-05-11T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(257.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1148, 1248, 50, CAST(N'2014-05-11T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(162.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1149, 1249, 55, CAST(N'2014-05-11T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(2065.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1150, 1250, 61, CAST(N'2014-05-12T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(1655.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1151, 1251, 65, CAST(N'2014-05-12T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(2134.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1152, 1252, 66, CAST(N'2014-05-12T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(15.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1153, 1253, 67, CAST(N'2014-05-12T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(6615.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1154, 1254, 69, CAST(N'2014-05-12T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(698.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1155, 1255, 70, CAST(N'2014-05-12T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1156, 1256, 72, CAST(N'2014-05-12T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(1390.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1157, 1257, 74, CAST(N'2014-05-12T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(1160.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1158, 1258, 75, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(39.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1159, 1259, 76, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(65.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1160, 1260, 79, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(352.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1161, 1261, 82, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(539.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1162, 1262, 77, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1190.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1163, 1263, 78, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(2668.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1164, 1264, 89, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(10299.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1165, 1265, 90, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(49.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1166, 1266, 96, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(29.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1167, 1267, 100, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(1170.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1168, 1268, 35, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(90.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1169, 1269, 97, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(2514.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1170, 1270, 41, CAST(N'2014-05-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(2823.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1171, 1271, 1, CAST(N'2014-03-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(2139.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1172, 1272, 12, CAST(N'2014-03-06T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(1029.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1173, 1273, 3, CAST(N'2014-03-09T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(2129.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1174, 1274, 4, CAST(N'2014-03-09T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(3194.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1175, 1275, 8, CAST(N'2014-03-29T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(3374.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1176, 1276, 6, CAST(N'2014-04-02T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(1368.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1177, 1277, 7, CAST(N'2014-04-05T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(1711.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1178, 1278, 8, CAST(N'2014-04-12T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(9468.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1179, 1279, 9, CAST(N'2014-04-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(2202.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1180, 1280, 10, CAST(N'2014-04-29T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(13675.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1181, 1281, 11, CAST(N'2014-05-03T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(1128.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1182, 1282, 6, CAST(N'2014-05-09T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(15341.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1183, 1283, 1, CAST(N'2014-05-14T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(8981.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1184, 1284, 1, CAST(N'2014-05-15T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(984.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1185, 1285, 2, CAST(N'2014-05-28T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(28616.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1186, 1286, 6, CAST(N'2014-06-04T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(1128.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1187, 1287, 5, CAST(N'2014-06-07T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(7794.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1188, 1288, 3, CAST(N'2014-06-07T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(5203.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1189, 1289, 8, CAST(N'2014-06-15T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(1526.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1190, 1290, 11, CAST(N'2014-06-18T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(751.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1191, 1291, 12, CAST(N'2014-06-22T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(829.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1192, 1292, 7, CAST(N'2014-06-28T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(2892.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1193, 1293, 10, CAST(N'2014-07-08T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(3052.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1194, 1294, 6, CAST(N'2014-07-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(2008.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1195, 1295, 1, CAST(N'2014-07-09T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(748.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1196, 1296, 12, CAST(N'2014-07-09T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(3151.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1197, 1297, 13, CAST(N'2014-07-09T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(8621.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1198, 1298, 13, CAST(N'2014-07-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(1103.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1199, 1299, 14, CAST(N'2014-07-10T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(2838.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1200, 1300, 14, CAST(N'2014-07-10T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(1322.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1201, 1301, 14, CAST(N'2014-07-10T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(65.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1202, 1302, 24, CAST(N'2014-07-12T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(1782.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1203, 1303, 94, CAST(N'2014-07-12T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(1526.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1204, 1304, 99, CAST(N'2014-07-12T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(1253.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1205, 1305, 27, CAST(N'2014-07-14T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(322.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1206, 1306, 32, CAST(N'2014-07-14T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(1366.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1207, 1307, 92, CAST(N'2014-07-14T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(460.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1208, 1308, 33, CAST(N'2014-07-14T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(3959.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1209, 1309, 77, CAST(N'2014-07-16T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(5247.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1210, 1310, 80, CAST(N'2014-07-16T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(2655.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1211, 1311, 30, CAST(N'2014-07-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(415.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1212, 1312, 100, CAST(N'2014-07-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(725.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1213, 1313, 64, CAST(N'2014-07-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(456.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1214, 1314, 95, CAST(N'2014-07-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(176.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1215, 1315, 24, CAST(N'2014-07-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(389.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1216, 1316, 82, CAST(N'2014-07-17T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(4661.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1217, 1317, 85, CAST(N'2014-07-17T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(60.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1218, 1318, 28, CAST(N'2014-07-17T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(12696.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1219, 1319, 29, CAST(N'2014-07-17T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(6487.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1220, 1320, 32, CAST(N'2014-07-17T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(3835.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1221, 1321, 44, CAST(N'2014-07-17T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(448.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1222, 1322, 49, CAST(N'2014-07-17T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(12604.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1223, 1323, 54, CAST(N'2014-07-17T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(16038.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1224, 1324, 69, CAST(N'2014-07-17T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(2943.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1225, 1325, 97, CAST(N'2014-07-18T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(1740.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1226, 1326, 82, CAST(N'2014-07-18T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(127.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1227, 1327, 80, CAST(N'2014-07-18T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(1510.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1228, 1328, 34, CAST(N'2014-07-18T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(114.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1229, 1329, 36, CAST(N'2014-07-18T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(36.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1230, 1330, 41, CAST(N'2014-07-18T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(935.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1231, 1331, 42, CAST(N'2014-07-18T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(874.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1232, 1332, 52, CAST(N'2014-07-18T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(19380.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1233, 1333, 99, CAST(N'2014-07-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1234, 1334, 29, CAST(N'2014-07-19T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(864.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1235, 1335, 35, CAST(N'2014-07-19T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(258.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1236, 1336, 38, CAST(N'2014-07-19T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(246.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1237, 1337, 43, CAST(N'2014-07-19T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(84.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1238, 1338, 48, CAST(N'2014-07-19T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(476.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1239, 1339, 53, CAST(N'2014-07-19T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(152.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1240, 1340, 59, CAST(N'2014-07-20T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(1981.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1241, 1341, 63, CAST(N'2014-07-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(24.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1242, 1342, 71, CAST(N'2014-07-20T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(55.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1243, 1343, 96, CAST(N'2014-07-20T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(1311.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1244, 1344, 51, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(1155.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1245, 1345, 74, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(10790.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1246, 1346, 56, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(3540.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1247, 1347, 62, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(950.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1248, 1348, 85, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(2061.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1249, 1349, 47, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(8490.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1250, 1350, 94, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(176.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1251, 1351, 36, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(1365.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1252, 1352, 31, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(1091.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1253, 1353, 41, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(7570.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1254, 1354, 49, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(1024.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1255, 1355, 59, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(18186.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1256, 1356, 99, CAST(N'2014-07-24T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(4797.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1257, 1357, 34, CAST(N'2014-07-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(597.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1258, 1358, 26, CAST(N'2014-07-24T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(1356.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1259, 1359, 27, CAST(N'2014-07-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(16689.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1260, 1360, 33, CAST(N'2014-07-24T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(1033.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1261, 1361, 37, CAST(N'2014-07-25T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1262, 1362, 38, CAST(N'2014-07-25T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(3116.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1263, 1363, 42, CAST(N'2014-07-25T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(823.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1264, 1364, 46, CAST(N'2014-07-25T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(1195.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1265, 1365, 50, CAST(N'2014-07-25T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(256.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1266, 1366, 55, CAST(N'2014-07-25T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(885.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1267, 1367, 61, CAST(N'2014-07-26T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(672.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1268, 1368, 65, CAST(N'2014-07-26T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(1881.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1269, 1369, 66, CAST(N'2014-07-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(55.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1270, 1370, 67, CAST(N'2014-07-26T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(7345.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1271, 1371, 69, CAST(N'2014-07-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(738.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1272, 1372, 70, CAST(N'2014-07-26T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(58.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1273, 1373, 72, CAST(N'2014-07-26T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(556.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1274, 1374, 74, CAST(N'2014-07-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(290.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1275, 1375, 75, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(291.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1276, 1376, 76, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(65.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1277, 1377, 79, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(32.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1278, 1378, 82, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(49.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1279, 1379, 77, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(2975.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1280, 1380, 78, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(860.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1281, 1381, 89, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(8725.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1282, 1382, 90, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(196.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1283, 1383, 96, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(435.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1284, 1384, 100, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(2925.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1285, 1385, 35, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(225.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1286, 1386, 97, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(3291.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1287, 1387, 41, CAST(N'2014-07-27T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(2616.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1288, 1388, 1, CAST(N'2014-05-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(3924.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1289, 1389, 12, CAST(N'2014-05-20T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(4009.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1290, 1390, 3, CAST(N'2014-05-23T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(2212.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1291, 1391, 4, CAST(N'2014-05-23T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(4791.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1292, 1392, 8, CAST(N'2014-06-12T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(19220.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1293, 1393, 6, CAST(N'2014-06-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(1824.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1294, 1394, 7, CAST(N'2014-06-19T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(750.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1295, 1395, 8, CAST(N'2014-06-26T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(5233.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1296, 1396, 9, CAST(N'2014-07-07T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(1339.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1297, 1397, 10, CAST(N'2014-07-13T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(14563.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1298, 1398, 11, CAST(N'2014-07-17T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(2109.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1299, 1399, 6, CAST(N'2014-07-23T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(28268.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1300, 1400, 1, CAST(N'2014-07-28T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(4198.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1301, 1401, 1, CAST(N'2014-07-29T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(2753.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1302, 1402, 2, CAST(N'2014-08-11T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(16352.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1303, 1403, 6, CAST(N'2014-08-18T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(274.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1304, 1404, 5, CAST(N'2014-08-21T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(3897.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1305, 1405, 3, CAST(N'2014-08-21T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(6678.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1306, 1406, 8, CAST(N'2014-08-29T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(897.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1307, 1407, 11, CAST(N'2014-09-01T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(734.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1308, 1408, 12, CAST(N'2014-09-05T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(6400.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1309, 1409, 7, CAST(N'2014-09-11T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(8168.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1310, 1410, 10, CAST(N'2014-09-21T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(1335.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1311, 1411, 6, CAST(N'2014-09-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(833.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1312, 1412, 1, CAST(N'2014-09-22T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(536.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1313, 1413, 12, CAST(N'2014-09-22T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(3594.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1314, 1414, 13, CAST(N'2014-09-22T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(5636.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1315, 1415, 13, CAST(N'2014-09-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(2377.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1316, 1416, 14, CAST(N'2014-09-23T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(3783.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1317, 1417, 14, CAST(N'2014-09-23T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(1546.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1318, 1418, 14, CAST(N'2014-09-23T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(645.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1319, 1419, 24, CAST(N'2014-09-25T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(995.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1320, 1420, 94, CAST(N'2014-09-25T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(771.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1321, 1421, 99, CAST(N'2014-09-25T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(1611.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1322, 1422, 27, CAST(N'2014-09-27T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(1184.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1323, 1423, 32, CAST(N'2014-09-27T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(3756.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1324, 1424, 92, CAST(N'2014-09-27T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(270.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1325, 1425, 33, CAST(N'2014-09-27T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(2433.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1326, 1426, 77, CAST(N'2014-09-29T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(20988.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1327, 1427, 80, CAST(N'2014-09-29T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(3540.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1328, 1428, 30, CAST(N'2014-09-29T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(830.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1329, 1429, 100, CAST(N'2014-09-29T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(2030.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1330, 1430, 64, CAST(N'2014-09-29T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(2016.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1331, 1431, 95, CAST(N'2014-09-29T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(849.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1332, 1432, 24, CAST(N'2014-09-29T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(843.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1333, 1433, 82, CAST(N'2014-09-30T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(2002.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1334, 1434, 85, CAST(N'2014-09-30T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(35.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1335, 1435, 28, CAST(N'2014-09-30T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(13095.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1336, 1436, 29, CAST(N'2014-09-30T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(3992.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1337, 1437, 32, CAST(N'2014-09-30T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(1180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1338, 1438, 44, CAST(N'2014-09-30T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(538.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1339, 1439, 49, CAST(N'2014-09-30T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(6569.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1340, 1440, 54, CAST(N'2014-09-30T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(3048.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1341, 1441, 69, CAST(N'2014-09-30T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(268.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1342, 1442, 97, CAST(N'2014-10-01T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1343, 1443, 82, CAST(N'2014-10-01T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(858.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1344, 1444, 80, CAST(N'2014-10-01T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(1390.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1345, 1445, 34, CAST(N'2014-10-01T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(95.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1346, 1446, 36, CAST(N'2014-10-01T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(12.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1347, 1447, 41, CAST(N'2014-10-01T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(378.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1348, 1448, 42, CAST(N'2014-10-01T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(782.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1349, 1449, 52, CAST(N'2014-10-01T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(10010.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1350, 1450, 99, CAST(N'2014-10-02T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(435.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1351, 1451, 29, CAST(N'2014-10-02T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(122.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1352, 1452, 35, CAST(N'2014-10-02T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(129.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1353, 1453, 38, CAST(N'2014-10-02T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(313.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1354, 1454, 43, CAST(N'2014-10-02T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(168.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1355, 1455, 48, CAST(N'2014-10-02T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(3276.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1356, 1456, 53, CAST(N'2014-10-02T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(190.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1357, 1457, 59, CAST(N'2014-10-03T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(3173.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1358, 1458, 63, CAST(N'2014-10-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(12.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1359, 1459, 71, CAST(N'2014-10-03T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(295.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1360, 1460, 96, CAST(N'2014-10-03T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(624.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1361, 1461, 51, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(1161.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1362, 1462, 74, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(4316.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1363, 1463, 56, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(1180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1364, 1464, 62, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(1160.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1365, 1465, 85, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(1603.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1366, 1466, 47, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(4332.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1367, 1467, 94, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(616.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1368, 1468, 36, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(390.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1369, 1469, 31, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(923.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1370, 1470, 41, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(2477.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1371, 1471, 49, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(616.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1372, 1472, 59, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(10392.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1373, 1473, 99, CAST(N'2014-10-07T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(12792.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1374, 1474, 34, CAST(N'2014-10-07T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(398.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1375, 1475, 26, CAST(N'2014-10-07T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(1388.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1376, 1476, 27, CAST(N'2014-10-07T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(4710.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1377, 1477, 33, CAST(N'2014-10-07T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(1551.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1378, 1478, 37, CAST(N'2014-10-08T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(315.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1379, 1479, 38, CAST(N'2014-10-08T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(5453.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1380, 1480, 42, CAST(N'2014-10-08T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(1793.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1381, 1481, 46, CAST(N'2014-10-08T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(663.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1382, 1482, 50, CAST(N'2014-10-08T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(501.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1383, 1483, 55, CAST(N'2014-10-08T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(1180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1384, 1484, 61, CAST(N'2014-10-09T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(896.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1385, 1485, 65, CAST(N'2014-10-09T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(378.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1386, 1486, 66, CAST(N'2014-10-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(35.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1387, 1487, 67, CAST(N'2014-10-09T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(5308.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1388, 1488, 69, CAST(N'2014-10-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(1339.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1389, 1489, 70, CAST(N'2014-10-09T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(290.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1390, 1490, 72, CAST(N'2014-10-09T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(1390.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1391, 1491, 74, CAST(N'2014-10-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(725.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1392, 1492, 75, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(237.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1393, 1493, 76, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(15.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1394, 1494, 79, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(32.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1395, 1495, 82, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(49.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1396, 1496, 77, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(595.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1397, 1497, 78, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(1415.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1398, 1498, 89, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(18684.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1399, 1499, 90, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(588.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1400, 1500, 96, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(261.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1401, 1501, 100, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(1950.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1402, 1502, 35, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(135.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1403, 1503, 97, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(437.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1404, 1504, 41, CAST(N'2014-10-10T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(3569.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1405, 1505, 1, CAST(N'2014-08-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(4055.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1406, 1506, 12, CAST(N'2014-08-03T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(1501.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1407, 1507, 3, CAST(N'2014-08-06T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1454.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1408, 1508, 4, CAST(N'2014-08-06T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(3233.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1409, 1509, 8, CAST(N'2014-08-26T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(5796.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1410, 1510, 6, CAST(N'2014-08-30T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(1302.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1411, 1511, 7, CAST(N'2014-09-02T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(505.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1412, 1512, 8, CAST(N'2014-09-09T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(6892.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1413, 1513, 9, CAST(N'2014-09-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(1477.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1414, 1514, 10, CAST(N'2014-09-26T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(8888.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1415, 1515, 11, CAST(N'2014-09-30T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(654.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1416, 1516, 6, CAST(N'2014-10-06T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(7341.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1417, 1517, 1, CAST(N'2014-10-11T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(5563.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1418, 1518, 1, CAST(N'2014-10-12T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(726.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1419, 1519, 2, CAST(N'2014-10-25T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(26572.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1420, 1520, 6, CAST(N'2014-11-01T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(2514.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1421, 1521, 5, CAST(N'2014-11-04T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(9093.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1422, 1522, 3, CAST(N'2014-11-04T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(954.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1423, 1523, 8, CAST(N'2014-11-12T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(1162.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1424, 1524, 11, CAST(N'2014-11-15T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(1434.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1425, 1525, 12, CAST(N'2014-11-19T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(5384.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1426, 1526, 7, CAST(N'2014-11-25T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(8024.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1427, 1527, 10, CAST(N'2014-12-05T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(2039.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1428, 1528, 6, CAST(N'2014-12-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(436.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1429, 1529, 1, CAST(N'2014-12-06T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(281.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1430, 1530, 12, CAST(N'2014-12-06T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(1662.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1431, 1531, 13, CAST(N'2014-12-06T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(11508.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1432, 1532, 13, CAST(N'2014-12-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(1365.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1433, 1533, 14, CAST(N'2014-12-07T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(3354.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1434, 1534, 14, CAST(N'2014-12-07T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(4056.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1435, 1535, 14, CAST(N'2014-12-07T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(475.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1436, 1536, 24, CAST(N'2014-12-09T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(2656.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1437, 1537, 94, CAST(N'2014-12-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(3270.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1438, 1538, 99, CAST(N'2014-12-09T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(2685.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1439, 1539, 27, CAST(N'2014-12-11T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(1271.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1440, 1540, 32, CAST(N'2014-12-11T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(3416.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1441, 1541, 92, CAST(N'2014-12-11T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(560.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1442, 1542, 33, CAST(N'2014-12-11T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(7395.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1443, 1543, 77, CAST(N'2014-12-13T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(22737.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1444, 1544, 80, CAST(N'2014-12-13T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(1475.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1445, 1545, 30, CAST(N'2014-12-13T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(370.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1446, 1546, 100, CAST(N'2014-12-13T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(725.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1447, 1547, 64, CAST(N'2014-12-13T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(247.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1448, 1548, 95, CAST(N'2014-12-13T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(702.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1449, 1549, 24, CAST(N'2014-12-13T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(816.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1450, 1550, 82, CAST(N'2014-12-14T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(2703.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1451, 1551, 85, CAST(N'2014-12-14T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(10.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1452, 1552, 28, CAST(N'2014-12-14T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(4770.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1453, 1553, 29, CAST(N'2014-12-14T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(499.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1454, 1554, 32, CAST(N'2014-12-14T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(295.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1455, 1555, 44, CAST(N'2014-12-14T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(224.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1456, 1556, 49, CAST(N'2014-12-14T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(7526.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1457, 1557, 54, CAST(N'2014-12-14T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(27780.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1458, 1558, 69, CAST(N'2014-12-14T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(1311.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1459, 1559, 97, CAST(N'2014-12-15T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(290.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1460, 1560, 82, CAST(N'2014-12-15T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(624.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1461, 1561, 80, CAST(N'2014-12-15T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(3298.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1462, 1562, 34, CAST(N'2014-12-15T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(19.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1463, 1563, 36, CAST(N'2014-12-15T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(12.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1464, 1564, 41, CAST(N'2014-12-15T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(378.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1465, 1565, 42, CAST(N'2014-12-15T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(194.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1466, 1566, 52, CAST(N'2014-12-15T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(6428.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1467, 1567, 99, CAST(N'2014-12-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(290.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1468, 1568, 29, CAST(N'2014-12-16T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(168.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1469, 1569, 35, CAST(N'2014-12-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(1032.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1470, 1570, 38, CAST(N'2014-12-16T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(1110.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1471, 1571, 43, CAST(N'2014-12-16T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(738.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1472, 1572, 48, CAST(N'2014-12-16T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(2387.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1473, 1573, 53, CAST(N'2014-12-16T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(114.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1474, 1574, 59, CAST(N'2014-12-17T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(2246.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1475, 1575, 63, CAST(N'2014-12-17T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(24.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1476, 1576, 71, CAST(N'2014-12-17T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(180.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1477, 1577, 96, CAST(N'2014-12-17T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(2322.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1478, 1578, 51, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(645.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1479, 1579, 74, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(16185.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1480, 1580, 56, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(3540.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1481, 1581, 62, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(1866.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1482, 1582, 85, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(2061.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1483, 1583, 47, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(17231.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1484, 1584, 94, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(88.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1485, 1585, 36, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(195.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1486, 1586, 31, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(143.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1487, 1587, 41, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(3499.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1488, 1588, 49, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(2464.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1489, 1589, 59, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1490, 1590, 99, CAST(N'2014-12-21T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(22386.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1491, 1591, 34, CAST(N'2014-12-21T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(995.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1492, 1592, 26, CAST(N'2014-12-21T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(224.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1493, 1593, 27, CAST(N'2014-12-21T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(12336.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1494, 1594, 33, CAST(N'2014-12-21T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(2186.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1495, 1595, 37, CAST(N'2014-12-22T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(225.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1496, 1596, 38, CAST(N'2014-12-22T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(779.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1497, 1597, 42, CAST(N'2014-12-22T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(1358.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1498, 1598, 46, CAST(N'2014-12-22T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(368.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1499, 1599, 50, CAST(N'2014-12-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(173.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1500, 1600, 55, CAST(N'2014-12-22T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(590.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1501, 1601, 61, CAST(N'2014-12-23T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(1402.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1502, 1602, 65, CAST(N'2014-12-23T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(423.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1503, 1603, 66, CAST(N'2014-12-23T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(50.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1504, 1604, 67, CAST(N'2014-12-23T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(3928.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1505, 1605, 69, CAST(N'2014-12-23T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(972.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1506, 1606, 70, CAST(N'2014-12-23T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(87.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1507, 1607, 72, CAST(N'2014-12-23T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(1033.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1508, 1608, 74, CAST(N'2014-12-23T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(580.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1509, 1609, 75, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(162.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1510, 1610, 76, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(10.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1511, 1611, 79, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(320.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1512, 1612, 82, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(392.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1513, 1613, 77, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(4760.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1514, 1614, 78, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(2203.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1515, 1615, 89, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(11079.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1516, 1616, 90, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(245.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1517, 1617, 96, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(232.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1518, 1618, 100, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(390.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1519, 1619, 35, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1520, 1620, 97, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(5586.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1521, 1621, 41, CAST(N'2014-12-24T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(3862.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1522, 1622, 1, CAST(N'2014-10-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(3285.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1523, 1623, 12, CAST(N'2014-10-17T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(1436.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1524, 1624, 3, CAST(N'2014-10-20T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1658.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1525, 1625, 4, CAST(N'2014-10-20T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(8608.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1526, 1626, 8, CAST(N'2014-11-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(6146.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1527, 1627, 6, CAST(N'2014-11-13T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(2508.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1528, 1628, 7, CAST(N'2014-11-16T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(2263.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1529, 1629, 8, CAST(N'2014-11-23T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(8551.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1530, 1630, 9, CAST(N'2014-12-04T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(1855.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1531, 1631, 10, CAST(N'2014-12-10T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(12865.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1532, 1632, 11, CAST(N'2014-12-14T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(1068.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1533, 1633, 6, CAST(N'2014-12-20T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(17521.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1534, 1634, 1, CAST(N'2014-12-25T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(4407.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1535, 1635, 1, CAST(N'2014-12-26T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(844.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1536, 1636, 2, CAST(N'2015-01-08T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(10789.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1537, 1637, 6, CAST(N'2015-01-15T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(1998.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1538, 1638, 5, CAST(N'2015-01-18T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(12990.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1539, 1639, 3, CAST(N'2015-01-18T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(7061.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1540, 1640, 8, CAST(N'2015-01-26T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(1222.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1541, 1641, 11, CAST(N'2015-01-29T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(1606.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1542, 1642, 12, CAST(N'2015-02-02T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(6534.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1543, 1643, 7, CAST(N'2015-02-08T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(14336.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1544, 1644, 10, CAST(N'2015-02-18T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(1417.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1545, 1645, 6, CAST(N'2015-02-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(397.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1546, 1646, 1, CAST(N'2015-02-19T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(359.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1547, 1647, 12, CAST(N'2015-02-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(4058.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1548, 1648, 13, CAST(N'2015-02-19T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(3233.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1549, 1649, 13, CAST(N'2015-02-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(1287.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1550, 1650, 14, CAST(N'2015-02-20T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(745.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1551, 1651, 14, CAST(N'2015-02-20T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(2208.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1552, 1652, 14, CAST(N'2015-02-20T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(430.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1553, 1653, 24, CAST(N'2015-02-22T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(1661.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1554, 1654, 94, CAST(N'2015-02-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(1962.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1555, 1655, 99, CAST(N'2015-02-22T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(2506.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1556, 1656, 27, CAST(N'2015-02-24T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(489.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1557, 1657, 32, CAST(N'2015-02-24T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(1219.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1558, 1658, 92, CAST(N'2015-02-24T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(595.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1559, 1659, 33, CAST(N'2015-02-24T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(6360.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1560, 1660, 77, CAST(N'2015-02-26T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(15741.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1561, 1661, 80, CAST(N'2015-02-26T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(885.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1562, 1662, 30, CAST(N'2015-02-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(164.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1563, 1663, 100, CAST(N'2015-02-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(1305.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1564, 1664, 64, CAST(N'2015-02-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(3458.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1565, 1665, 95, CAST(N'2015-02-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(303.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1566, 1666, 24, CAST(N'2015-02-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(1032.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1567, 1667, 82, CAST(N'2015-02-27T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(2070.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1568, 1668, 85, CAST(N'2015-02-27T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(35.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1569, 1669, 28, CAST(N'2015-02-27T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(7043.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1570, 1670, 29, CAST(N'2015-02-27T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(7485.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1571, 1671, 32, CAST(N'2015-02-27T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(2950.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1572, 1672, 44, CAST(N'2015-02-27T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(582.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1573, 1673, 49, CAST(N'2015-02-27T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(17259.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1574, 1674, 54, CAST(N'2015-02-27T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(33528.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1575, 1675, 69, CAST(N'2015-02-27T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(2295.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1576, 1676, 97, CAST(N'2015-02-28T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(435.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1577, 1677, 82, CAST(N'2015-02-28T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(234.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1578, 1678, 80, CAST(N'2015-02-28T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(477.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1579, 1679, 34, CAST(N'2015-02-28T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(38.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1580, 1680, 36, CAST(N'2015-02-28T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(36.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1581, 1681, 41, CAST(N'2015-02-28T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(378.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1582, 1682, 42, CAST(N'2015-02-28T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(194.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1583, 1683, 52, CAST(N'2015-02-28T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(1631.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1584, 1684, 99, CAST(N'2015-03-01T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(580.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1585, 1685, 29, CAST(N'2015-03-01T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(336.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1586, 1686, 35, CAST(N'2015-03-01T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(903.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1587, 1687, 38, CAST(N'2015-03-01T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(294.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1588, 1688, 43, CAST(N'2015-03-01T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(252.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1589, 1689, 48, CAST(N'2015-03-01T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(975.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1590, 1690, 53, CAST(N'2015-03-01T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(57.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1591, 1691, 59, CAST(N'2015-03-02T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(6420.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1592, 1692, 63, CAST(N'2015-03-02T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1593, 1693, 71, CAST(N'2015-03-02T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(600.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1594, 1694, 96, CAST(N'2015-03-02T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(953.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1595, 1695, 51, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(1014.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1596, 1696, 74, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(9711.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1597, 1697, 56, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(3245.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1598, 1698, 62, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(2672.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1599, 1699, 85, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(916.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1600, 1700, 47, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(14768.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1601, 1701, 94, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(332.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1602, 1702, 36, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(1365.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1603, 1703, 31, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(854.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1604, 1704, 41, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(1474.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1605, 1705, 49, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(616.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1606, 1706, 59, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(7794.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1607, 1707, 99, CAST(N'2015-03-06T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(9594.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1608, 1708, 34, CAST(N'2015-03-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(199.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1609, 1709, 26, CAST(N'2015-03-06T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(357.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1610, 1710, 27, CAST(N'2015-03-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(14752.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1611, 1711, 33, CAST(N'2015-03-06T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(2578.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1612, 1712, 37, CAST(N'2015-03-07T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(675.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1613, 1713, 38, CAST(N'2015-03-07T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(10906.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1614, 1714, 42, CAST(N'2015-03-07T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(2716.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1615, 1715, 46, CAST(N'2015-03-07T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(220.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1616, 1716, 50, CAST(N'2015-03-07T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(192.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1617, 1717, 55, CAST(N'2015-03-07T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(885.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1618, 1718, 61, CAST(N'2015-03-08T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(1908.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1619, 1719, 65, CAST(N'2015-03-08T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(1828.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1620, 1720, 66, CAST(N'2015-03-08T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(30.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1621, 1721, 67, CAST(N'2015-03-08T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(1793.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1622, 1722, 69, CAST(N'2015-03-08T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(1341.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1623, 1723, 70, CAST(N'2015-03-08T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(261.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1624, 1724, 72, CAST(N'2015-03-08T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(3263.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1625, 1725, 74, CAST(N'2015-03-08T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(2320.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1626, 1726, 75, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(162.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1627, 1727, 76, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(45.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1628, 1728, 79, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(128.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1629, 1729, 82, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(343.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1630, 1730, 77, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(4165.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1631, 1731, 78, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(1699.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1632, 1732, 89, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(6968.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1633, 1733, 90, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(637.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1634, 1734, 96, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(232.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1635, 1735, 100, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(780.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1636, 1736, 35, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(90.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1637, 1737, 97, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(582.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1638, 1738, 41, CAST(N'2015-03-09T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(2638.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1639, 1739, 1, CAST(N'2014-12-31T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(4721.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1640, 1740, 12, CAST(N'2014-12-31T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(1990.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1641, 1741, 3, CAST(N'2015-01-03T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(2286.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1642, 1742, 4, CAST(N'2015-01-03T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(3428.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1643, 1743, 8, CAST(N'2015-01-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(5041.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1644, 1744, 6, CAST(N'2015-01-27T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(586.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1645, 1745, 7, CAST(N'2015-01-30T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(3011.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1646, 1746, 8, CAST(N'2015-02-06T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(8052.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1647, 1747, 9, CAST(N'2015-02-17T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(367.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1648, 1748, 10, CAST(N'2015-02-23T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(9982.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1649, 1749, 11, CAST(N'2015-02-27T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(763.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1650, 1750, 6, CAST(N'2015-03-05T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(15719.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1651, 1751, 1, CAST(N'2015-03-10T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(3501.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1652, 1752, 1, CAST(N'2015-03-11T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(1640.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1653, 1753, 2, CAST(N'2015-03-24T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(11990.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1654, 1754, 6, CAST(N'2015-03-31T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(3014.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1655, 1755, 5, CAST(N'2015-04-03T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(12990.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1656, 1756, 3, CAST(N'2015-04-03T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(6885.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1657, 1757, 8, CAST(N'2015-04-11T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(2314.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1658, 1758, 11, CAST(N'2015-04-14T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(1327.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1659, 1759, 12, CAST(N'2015-04-18T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(3706.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1660, 1760, 7, CAST(N'2015-04-24T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(3614.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1661, 1761, 10, CAST(N'2015-05-04T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(2365.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1662, 1762, 6, CAST(N'2015-05-05T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(3160.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1663, 1763, 1, CAST(N'2015-05-05T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(282.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1664, 1764, 12, CAST(N'2015-05-05T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(3520.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1665, 1765, 13, CAST(N'2015-05-05T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(5410.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1666, 1766, 13, CAST(N'2015-05-05T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(1766.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1667, 1767, 14, CAST(N'2015-05-06T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(487.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1668, 1768, 14, CAST(N'2015-05-06T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(1801.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1669, 1769, 14, CAST(N'2015-05-06T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(990.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1670, 1770, 24, CAST(N'2015-05-08T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(4280.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1671, 1771, 94, CAST(N'2015-05-08T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(1308.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1672, 1772, 99, CAST(N'2015-05-08T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(1074.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1673, 1773, 27, CAST(N'2015-05-10T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(127.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1674, 1774, 32, CAST(N'2015-05-10T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(1952.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1675, 1775, 92, CAST(N'2015-05-10T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(315.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1676, 1776, 33, CAST(N'2015-05-10T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(11194.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1677, 1777, 77, CAST(N'2015-05-12T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(24486.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1678, 1778, 80, CAST(N'2015-05-12T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(4130.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1679, 1779, 30, CAST(N'2015-05-12T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(515.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1680, 1780, 100, CAST(N'2015-05-12T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(1160.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1681, 1781, 64, CAST(N'2015-05-12T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(967.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1682, 1782, 95, CAST(N'2015-05-12T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(813.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1683, 1783, 24, CAST(N'2015-05-12T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(393.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1684, 1784, 82, CAST(N'2015-05-13T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(3279.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1685, 1785, 85, CAST(N'2015-05-13T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(40.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1686, 1786, 28, CAST(N'2015-05-13T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(13494.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1687, 1787, 29, CAST(N'2015-05-13T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(5988.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1688, 1788, 32, CAST(N'2015-05-13T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(885.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1689, 1789, 44, CAST(N'2015-05-13T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(448.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1690, 1790, 49, CAST(N'2015-05-13T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(3138.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1691, 1791, 54, CAST(N'2015-05-13T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(27432.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1692, 1792, 69, CAST(N'2015-05-13T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(2222.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1693, 1793, 97, CAST(N'2015-05-14T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(580.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1694, 1794, 82, CAST(N'2015-05-14T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(312.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1695, 1795, 80, CAST(N'2015-05-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(831.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1696, 1796, 34, CAST(N'2015-05-14T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(209.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1697, 1797, 36, CAST(N'2015-05-14T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(12.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1698, 1798, 41, CAST(N'2015-05-14T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(1771.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1699, 1799, 42, CAST(N'2015-05-14T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(629.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1700, 1800, 52, CAST(N'2015-05-14T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(4829.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1701, 1801, 99, CAST(N'2015-05-15T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(1450.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1702, 1802, 29, CAST(N'2015-05-15T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(837.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1703, 1803, 35, CAST(N'2015-05-15T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(258.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1704, 1804, 38, CAST(N'2015-05-15T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(1434.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1705, 1805, 43, CAST(N'2015-05-15T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(588.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1706, 1806, 48, CAST(N'2015-05-15T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(3003.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1707, 1807, 53, CAST(N'2015-05-15T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(342.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1708, 1808, 59, CAST(N'2015-05-16T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(2411.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1709, 1809, 63, CAST(N'2015-05-16T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(12.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1710, 1810, 71, CAST(N'2015-05-16T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(40.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1711, 1811, 96, CAST(N'2015-05-16T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(208.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1712, 1812, 51, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(400.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1713, 1813, 74, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(1079.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1714, 1814, 56, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(1475.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1715, 1815, 62, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(690.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1716, 1816, 85, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(2290.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1717, 1817, 47, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(10057.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1718, 1818, 94, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(1017.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1719, 1819, 36, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(2340.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1720, 1820, 31, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(1373.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1721, 1821, 41, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(3660.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1722, 1822, 49, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(1590.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1723, 1823, 59, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(7794.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1724, 1824, 99, CAST(N'2015-05-20T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(9594.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1725, 1825, 34, CAST(N'2015-05-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(1194.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1726, 1826, 26, CAST(N'2015-05-20T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(600.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1727, 1827, 27, CAST(N'2015-05-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(17866.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1728, 1828, 33, CAST(N'2015-05-20T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(2780.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1729, 1829, 37, CAST(N'2015-05-21T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(45.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1730, 1830, 38, CAST(N'2015-05-21T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(779.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1731, 1831, 42, CAST(N'2015-05-21T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(1407.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1732, 1832, 46, CAST(N'2015-05-21T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(615.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1733, 1833, 50, CAST(N'2015-05-21T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(184.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1734, 1834, 55, CAST(N'2015-05-21T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(2360.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1735, 1835, 61, CAST(N'2015-05-22T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(601.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1736, 1836, 65, CAST(N'2015-05-22T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(1755.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1737, 1837, 66, CAST(N'2015-05-22T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(5.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1738, 1838, 67, CAST(N'2015-05-22T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(12865.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1739, 1839, 69, CAST(N'2015-05-22T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(612.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1740, 1840, 70, CAST(N'2015-05-22T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(58.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1741, 1841, 72, CAST(N'2015-05-22T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(1153.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1742, 1842, 74, CAST(N'2015-05-22T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(725.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1743, 1843, 75, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(123.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1744, 1844, 76, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(5.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1745, 1845, 79, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(128.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1746, 1846, 82, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(343.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1747, 1847, 77, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(4760.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1748, 1848, 78, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(2608.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1749, 1849, 89, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(3553.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1750, 1850, 90, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(147.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1751, 1851, 96, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(29.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1752, 1852, 100, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(2340.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1753, 1853, 35, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(120.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1754, 1854, 97, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(5944.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1755, 1855, 41, CAST(N'2015-05-23T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(1986.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1756, 1856, 1, CAST(N'2015-03-16T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(6470.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1757, 1857, 12, CAST(N'2015-03-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(3344.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1758, 1858, 3, CAST(N'2015-03-19T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(2466.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1759, 1859, 4, CAST(N'2015-03-19T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(8102.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1760, 1860, 8, CAST(N'2015-04-08T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(17554.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1761, 1861, 6, CAST(N'2015-04-12T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(782.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1762, 1862, 7, CAST(N'2015-04-15T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(684.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1763, 1863, 8, CAST(N'2015-04-22T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(10628.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1764, 1864, 9, CAST(N'2015-05-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(1694.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1765, 1865, 10, CAST(N'2015-05-09T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(14141.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1766, 1866, 11, CAST(N'2015-05-13T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(2360.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1767, 1867, 6, CAST(N'2015-05-19T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(14682.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1768, 1868, 1, CAST(N'2015-05-24T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(4646.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1769, 1869, 1, CAST(N'2015-05-25T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(1312.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1770, 1870, 2, CAST(N'2015-06-07T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(28616.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1771, 1871, 6, CAST(N'2015-06-14T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(1869.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1772, 1872, 5, CAST(N'2015-06-17T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(11691.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1773, 1873, 3, CAST(N'2015-06-17T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(6226.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1774, 1874, 8, CAST(N'2015-06-25T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(639.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1775, 1875, 11, CAST(N'2015-06-28T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(418.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1776, 1876, 12, CAST(N'2015-07-02T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(838.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1777, 1877, 7, CAST(N'2015-07-08T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(2409.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1778, 1878, 10, CAST(N'2015-07-18T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(4851.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1779, 1879, 6, CAST(N'2015-07-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(2616.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1780, 1880, 1, CAST(N'2015-07-19T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(175.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1781, 1881, 12, CAST(N'2015-07-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(4980.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1782, 1882, 13, CAST(N'2015-07-19T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(8354.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1783, 1883, 13, CAST(N'2015-07-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(1662.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1784, 1884, 14, CAST(N'2015-07-20T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(974.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1785, 1885, 14, CAST(N'2015-07-20T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(1279.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1786, 1886, 14, CAST(N'2015-07-20T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(365.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1787, 1887, 24, CAST(N'2015-07-22T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(4138.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1788, 1888, 94, CAST(N'2015-07-22T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(1184.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1789, 1889, 99, CAST(N'2015-07-22T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(716.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1790, 1890, 27, CAST(N'2015-07-24T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(989.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1791, 1891, 32, CAST(N'2015-07-24T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(732.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1792, 1892, 92, CAST(N'2015-07-24T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(275.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1793, 1893, 33, CAST(N'2015-07-24T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(6488.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1794, 1894, 77, CAST(N'2015-07-26T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(15741.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1795, 1895, 80, CAST(N'2015-07-26T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(2655.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1796, 1896, 30, CAST(N'2015-07-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(666.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1797, 1897, 100, CAST(N'2015-07-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(1015.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1798, 1898, 64, CAST(N'2015-07-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(698.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1799, 1899, 95, CAST(N'2015-07-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(695.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1800, 1900, 24, CAST(N'2015-07-26T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(1673.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1801, 1901, 82, CAST(N'2015-07-27T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(2559.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1802, 1902, 85, CAST(N'2015-07-27T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(50.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1803, 1903, 28, CAST(N'2015-07-27T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(10580.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1804, 1904, 29, CAST(N'2015-07-27T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(499.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1805, 1905, 32, CAST(N'2015-07-27T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(885.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1806, 1906, 44, CAST(N'2015-07-27T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(672.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1807, 1907, 49, CAST(N'2015-07-27T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(17259.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1808, 1908, 54, CAST(N'2015-07-27T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(33528.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1809, 1909, 69, CAST(N'2015-07-27T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(658.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1810, 1910, 97, CAST(N'2015-07-28T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(1885.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1811, 1911, 82, CAST(N'2015-07-28T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(769.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1812, 1912, 80, CAST(N'2015-07-28T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(989.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1813, 1913, 34, CAST(N'2015-07-28T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(19.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1814, 1914, 36, CAST(N'2015-07-28T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(144.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1815, 1915, 41, CAST(N'2015-07-28T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(935.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1816, 1916, 42, CAST(N'2015-07-28T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(388.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1817, 1917, 52, CAST(N'2015-07-28T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(1727.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1818, 1918, 99, CAST(N'2015-07-29T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(1015.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1819, 1919, 29, CAST(N'2015-07-29T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(672.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1820, 1920, 35, CAST(N'2015-07-29T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(129.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1821, 1921, 38, CAST(N'2015-07-29T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(1998.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1822, 1922, 43, CAST(N'2015-07-29T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(1008.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1823, 1923, 48, CAST(N'2015-07-29T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(2652.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1824, 1924, 53, CAST(N'2015-07-29T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(95.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1825, 1925, 59, CAST(N'2015-07-30T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(8214.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1826, 1926, 63, CAST(N'2015-07-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(108.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1827, 1927, 71, CAST(N'2015-07-30T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(135.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1828, 1928, 96, CAST(N'2015-07-30T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(387.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1829, 1929, 51, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(627.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1830, 1930, 74, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(5395.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1831, 1931, 56, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(1770.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1832, 1932, 62, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(1219.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1833, 1933, 85, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(916.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1834, 1934, 47, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(4734.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1835, 1935, 94, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(1145.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1836, 1936, 36, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(585.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1837, 1937, 31, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(866.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1838, 1938, 41, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(12102.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1839, 1939, 49, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(924.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1840, 1940, 59, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1841, 1941, 99, CAST(N'2015-08-03T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(6396.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1842, 1942, 34, CAST(N'2015-08-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(398.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1843, 1943, 26, CAST(N'2015-08-03T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(1008.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1844, 1944, 27, CAST(N'2015-08-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(4311.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1845, 1945, 33, CAST(N'2015-08-03T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(1946.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1846, 1946, 37, CAST(N'2015-08-04T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1847, 1947, 38, CAST(N'2015-08-04T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(3116.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1848, 1948, 42, CAST(N'2015-08-04T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(1554.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1849, 1949, 46, CAST(N'2015-08-04T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(542.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1850, 1950, 50, CAST(N'2015-08-04T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(399.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1851, 1951, 55, CAST(N'2015-08-04T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(4130.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1852, 1952, 61, CAST(N'2015-08-05T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(3360.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1853, 1953, 65, CAST(N'2015-08-05T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(3149.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1854, 1954, 66, CAST(N'2015-08-05T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(60.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1855, 1955, 67, CAST(N'2015-08-05T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(19819.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1856, 1956, 69, CAST(N'2015-08-05T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(1028.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1857, 1957, 70, CAST(N'2015-08-05T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(87.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1858, 1958, 72, CAST(N'2015-08-05T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(278.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1859, 1959, 74, CAST(N'2015-08-05T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1860, 1960, 75, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(270.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1861, 1961, 76, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(45.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1862, 1962, 79, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(128.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1863, 1963, 82, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(245.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1864, 1964, 77, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(2975.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1865, 1965, 78, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(1048.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1866, 1966, 89, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(7845.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1867, 1967, 90, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(343.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1868, 1968, 96, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(290.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1869, 1969, 100, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(1950.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1870, 1970, 35, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(30.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1871, 1971, 97, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(3496.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1872, 1972, 41, CAST(N'2015-08-06T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(1906.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1873, 1973, 1, CAST(N'2015-05-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(1308.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1874, 1974, 12, CAST(N'2015-05-30T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(903.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1875, 1975, 3, CAST(N'2015-06-02T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(4313.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1876, 1976, 4, CAST(N'2015-06-02T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(5960.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1877, 1977, 8, CAST(N'2015-06-22T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(17006.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1878, 1978, 6, CAST(N'2015-06-26T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(1481.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1879, 1979, 7, CAST(N'2015-06-29T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(2150.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1880, 1980, 8, CAST(N'2015-07-06T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(18518.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1881, 1981, 9, CAST(N'2015-07-17T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(1595.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1882, 1982, 10, CAST(N'2015-07-23T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(20214.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1883, 1983, 11, CAST(N'2015-07-27T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(1049.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1884, 1984, 6, CAST(N'2015-08-02T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(10942.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1885, 1985, 1, CAST(N'2015-08-07T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(2553.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1886, 1986, 1, CAST(N'2015-08-08T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(1640.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1887, 1987, 2, CAST(N'2015-08-21T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(10220.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1888, 1988, 6, CAST(N'2015-08-28T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(935.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1889, 1989, 5, CAST(N'2015-08-31T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(2598.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1890, 1990, 3, CAST(N'2015-08-31T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(1613.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1891, 1991, 8, CAST(N'2015-09-08T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(1426.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1892, 1992, 11, CAST(N'2015-09-11T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(905.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1893, 1993, 12, CAST(N'2015-09-15T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(5139.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1894, 1994, 7, CAST(N'2015-09-21T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(4168.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1895, 1995, 10, CAST(N'2015-10-01T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(3590.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1896, 1996, 6, CAST(N'2015-10-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(2258.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1897, 1997, 1, CAST(N'2015-10-02T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(680.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1898, 1998, 12, CAST(N'2015-10-02T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(3678.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1899, 1999, 13, CAST(N'2015-10-02T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(7452.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1900, 2000, 13, CAST(N'2015-10-02T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(1880.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1901, 2001, 14, CAST(N'2015-10-03T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(2064.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1902, 2002, 14, CAST(N'2015-10-03T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(2930.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1903, 2003, 14, CAST(N'2015-10-03T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(785.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1904, 2004, 24, CAST(N'2015-10-05T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(3014.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1905, 2005, 94, CAST(N'2015-10-05T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(1324.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1906, 2006, 99, CAST(N'2015-10-05T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(2148.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1907, 2007, 27, CAST(N'2015-10-07T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(322.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1908, 2008, 32, CAST(N'2015-10-07T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(244.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1909, 2009, 92, CAST(N'2015-10-07T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(40.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1910, 2010, 33, CAST(N'2015-10-07T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(811.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1911, 2011, 77, CAST(N'2015-10-09T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(1749.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1912, 2012, 80, CAST(N'2015-10-09T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(3540.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1913, 2013, 30, CAST(N'2015-10-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(888.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1914, 2014, 100, CAST(N'2015-10-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(1015.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1915, 2015, 64, CAST(N'2015-10-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(1891.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1916, 2016, 95, CAST(N'2015-10-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(185.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1917, 2017, 24, CAST(N'2015-10-09T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(343.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1918, 2018, 82, CAST(N'2015-10-10T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(3277.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1919, 2019, 85, CAST(N'2015-10-10T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(35.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1920, 2020, 28, CAST(N'2015-10-10T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(10042.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1921, 2021, 29, CAST(N'2015-10-10T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(998.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1922, 2022, 32, CAST(N'2015-10-10T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(3245.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1923, 2023, 44, CAST(N'2015-10-10T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(1657.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1924, 2024, 49, CAST(N'2015-10-10T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(23164.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1925, 2025, 54, CAST(N'2015-10-10T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(12642.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1926, 2026, 69, CAST(N'2015-10-10T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(2412.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1927, 2027, 97, CAST(N'2015-10-11T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(725.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1928, 2028, 82, CAST(N'2015-10-11T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(390.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1929, 2029, 80, CAST(N'2015-10-11T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(1390.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1930, 2030, 34, CAST(N'2015-10-11T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(38.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1931, 2031, 36, CAST(N'2015-10-11T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(72.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1932, 2032, 41, CAST(N'2015-10-11T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(378.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1933, 2033, 42, CAST(N'2015-10-11T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(1554.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1934, 2034, 52, CAST(N'2015-10-11T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(6460.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1935, 2035, 99, CAST(N'2015-10-12T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(145.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1936, 2036, 29, CAST(N'2015-10-12T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(924.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1937, 2037, 35, CAST(N'2015-10-12T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(1419.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1938, 2038, 38, CAST(N'2015-10-12T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(2442.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1939, 2039, 43, CAST(N'2015-10-12T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(342.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1940, 2040, 48, CAST(N'2015-10-12T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(1345.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1941, 2041, 53, CAST(N'2015-10-12T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(228.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1942, 2042, 59, CAST(N'2015-10-13T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(6289.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1943, 2043, 63, CAST(N'2015-10-13T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(36.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1944, 2044, 71, CAST(N'2015-10-13T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(230.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1945, 2045, 96, CAST(N'2015-10-13T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(1964.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1946, 2046, 51, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(328.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1947, 2047, 74, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(2158.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1948, 2048, 56, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(590.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1949, 2049, 62, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(483.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1950, 2050, 85, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(2061.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1951, 2051, 47, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(2716.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1952, 2052, 94, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(527.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1953, 2053, 36, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(390.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1954, 2054, 31, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(286.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1955, 2055, 41, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(1385.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1956, 2056, 49, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(308.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1957, 2057, 59, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1958, 2058, 99, CAST(N'2015-10-17T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(22386.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1959, 2059, 34, CAST(N'2015-10-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(796.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1960, 2060, 26, CAST(N'2015-10-17T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(1626.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1961, 2061, 27, CAST(N'2015-10-17T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(9739.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1962, 2062, 33, CAST(N'2015-10-17T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(1390.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1963, 2063, 37, CAST(N'2015-10-18T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(225.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1964, 2064, 38, CAST(N'2015-10-18T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(10127.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1965, 2065, 42, CAST(N'2015-10-18T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(1115.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1966, 2066, 46, CAST(N'2015-10-18T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(467.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1967, 2067, 50, CAST(N'2015-10-18T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(576.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1968, 2068, 55, CAST(N'2015-10-18T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(885.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1969, 2069, 61, CAST(N'2015-10-19T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(1568.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1970, 2070, 65, CAST(N'2015-10-19T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(1282.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1971, 2071, 66, CAST(N'2015-10-19T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(45.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1972, 2072, 67, CAST(N'2015-10-19T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(10251.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1973, 2073, 69, CAST(N'2015-10-19T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(497.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1974, 2074, 70, CAST(N'2015-10-19T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(58.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1975, 2075, 72, CAST(N'2015-10-19T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(1750.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1976, 2076, 74, CAST(N'2015-10-19T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(435.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1977, 2077, 75, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(216.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1978, 2078, 76, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(40.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1979, 2079, 79, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(32.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1980, 2080, 82, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(392.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1981, 2081, 77, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(4760.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1982, 2082, 78, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(1918.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1983, 2083, 89, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(4571.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1984, 2084, 90, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(49.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1985, 2085, 96, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(58.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1986, 2086, 100, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(390.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1987, 2087, 35, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(15.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1988, 2088, 97, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(1956.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1989, 2089, 41, CAST(N'2015-10-20T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(918.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1990, 2090, 1, CAST(N'2015-08-13T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(2804.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1991, 2091, 12, CAST(N'2015-08-13T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(4752.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1992, 2092, 3, CAST(N'2015-08-16T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(1100.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1993, 2093, 4, CAST(N'2015-08-16T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(3934.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1994, 2094, 8, CAST(N'2015-09-05T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(7106.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1995, 2095, 6, CAST(N'2015-09-09T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(1726.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1996, 2096, 7, CAST(N'2015-09-12T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(1726.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1997, 2097, 8, CAST(N'2015-09-19T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(12624.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1998, 2098, 9, CAST(N'2015-09-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(1964.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (1999, 2099, 10, CAST(N'2015-10-06T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(2017.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2000, 2100, 11, CAST(N'2015-10-10T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(1815.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2001, 2101, 6, CAST(N'2015-10-16T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(21333.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2002, 2102, 1, CAST(N'2015-10-21T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(2467.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2003, 2103, 1, CAST(N'2015-10-22T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(2624.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2004, 2104, 2, CAST(N'2015-11-04T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(6427.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2005, 2105, 6, CAST(N'2015-11-11T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(2934.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2006, 2106, 5, CAST(N'2015-11-14T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(7794.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2007, 2107, 3, CAST(N'2015-11-14T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(9521.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2008, 2108, 8, CAST(N'2015-11-22T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(213.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2009, 2109, 11, CAST(N'2015-11-25T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(1388.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2010, 2110, 12, CAST(N'2015-11-29T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(1874.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2011, 2111, 7, CAST(N'2015-12-05T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(896.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2012, 2112, 10, CAST(N'2015-12-15T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MM  ', CAST(2327.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2013, 2113, 6, CAST(N'2015-12-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(1090.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2014, 2114, 1, CAST(N'2015-12-16T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'RO  ', CAST(331.00 AS Numeric(10, 2)), 18)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2015, 2115, 12, CAST(N'2015-12-16T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JC  ', CAST(494.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2016, 2116, 13, CAST(N'2015-12-16T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(5164.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2017, 2117, 13, CAST(N'2015-12-16T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'PD  ', CAST(1887.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2018, 2118, 14, CAST(N'2015-12-17T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JC  ', CAST(3354.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2019, 2119, 14, CAST(N'2015-12-17T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'LM  ', CAST(3860.00 AS Numeric(10, 2)), 10)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2020, 2120, 14, CAST(N'2015-12-17T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'AS  ', CAST(325.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2021, 2121, 24, CAST(N'2015-12-19T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BR  ', CAST(4688.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2022, 2122, 94, CAST(N'2015-12-19T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'CM  ', CAST(1308.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2023, 2123, 99, CAST(N'2015-12-19T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'BR  ', CAST(179.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2024, 2124, 27, CAST(N'2015-12-21T00:00:00.000' AS DateTime), N'COD         ', N'WILLCALL    ', N'            ', N'SQ  ', CAST(205.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2025, 2125, 32, CAST(N'2015-12-21T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'BS  ', CAST(244.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2026, 2126, 92, CAST(N'2015-12-21T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'CM  ', CAST(400.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2027, 2127, 33, CAST(N'2015-12-21T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CS  ', CAST(6264.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2028, 2128, 77, CAST(N'2015-12-23T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'DJ  ', CAST(13992.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2029, 2129, 80, CAST(N'2015-12-23T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'DM  ', CAST(1770.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2030, 2130, 30, CAST(N'2015-12-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'FF  ', CAST(1055.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2031, 2131, 100, CAST(N'2015-12-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'FMB ', CAST(1450.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2032, 2132, 64, CAST(N'2015-12-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'HS  ', CAST(1722.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2033, 2133, 95, CAST(N'2015-12-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'JC  ', CAST(156.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2034, 2134, 24, CAST(N'2015-12-23T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JS  ', CAST(1224.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2035, 2135, 82, CAST(N'2015-12-24T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'JW  ', CAST(1907.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2036, 2136, 85, CAST(N'2015-12-24T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'JW  ', CAST(35.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2037, 2137, 28, CAST(N'2015-12-24T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'KS  ', CAST(7406.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2038, 2138, 29, CAST(N'2015-12-24T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'LM  ', CAST(1497.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2039, 2139, 32, CAST(N'2015-12-24T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'MH  ', CAST(885.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2040, 2140, 44, CAST(N'2015-12-24T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'MK  ', CAST(3495.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2041, 2141, 49, CAST(N'2015-12-24T00:00:00.000' AS DateTime), N'COD         ', N'USINTL      ', N'            ', N'MM  ', CAST(17259.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2042, 2142, 54, CAST(N'2015-12-24T00:00:00.000' AS DateTime), N'NET90       ', N'WILLCALL    ', N'            ', N'MS  ', CAST(30930.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2043, 2143, 69, CAST(N'2015-12-24T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'NJ  ', CAST(2295.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2044, 2144, 97, CAST(N'2015-12-25T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'PD  ', CAST(1885.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2045, 2145, 82, CAST(N'2015-12-25T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'RM  ', CAST(426.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2046, 2146, 80, CAST(N'2015-12-25T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(2865.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2047, 2147, 34, CAST(N'2015-12-25T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'SQ  ', CAST(266.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2048, 2148, 36, CAST(N'2015-12-25T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'TT  ', CAST(24.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2049, 2149, 41, CAST(N'2015-12-25T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CM  ', CAST(3044.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2050, 2150, 42, CAST(N'2015-12-25T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(727.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2051, 2151, 52, CAST(N'2015-12-25T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'HS  ', CAST(1695.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2052, 2152, 99, CAST(N'2015-12-26T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'FF  ', CAST(290.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2053, 2153, 29, CAST(N'2015-12-26T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'FMB ', CAST(477.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2054, 2154, 35, CAST(N'2015-12-26T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(645.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2055, 2155, 38, CAST(N'2015-12-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'LM  ', CAST(1673.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2056, 2156, 43, CAST(N'2015-12-26T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JW  ', CAST(1008.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2057, 2157, 48, CAST(N'2015-12-26T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(2455.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2058, 2158, 53, CAST(N'2015-12-26T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'JW  ', CAST(342.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2059, 2159, 59, CAST(N'2015-12-27T00:00:00.000' AS DateTime), N'NET90       ', N'USMAIL      ', N'            ', N'LM  ', CAST(11860.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2060, 2160, 63, CAST(N'2015-12-27T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JC  ', CAST(12.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2061, 2161, 71, CAST(N'2015-12-27T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'CW  ', CAST(40.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2062, 2162, 96, CAST(N'2015-12-27T00:00:00.000' AS DateTime), N'NET90       ', N'USINTL      ', N'            ', N'BS  ', CAST(745.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2063, 2163, 51, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'HS  ', CAST(646.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2064, 2164, 74, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEXCOD    ', N'            ', N'LM  ', CAST(4316.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2065, 2165, 56, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(1180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2066, 2166, 62, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'TT  ', CAST(458.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2067, 2167, 85, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JW  ', CAST(458.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2068, 2168, 47, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'KS  ', CAST(6675.00 AS Numeric(10, 2)), 6)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2069, 2169, 94, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(685.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2070, 2170, 36, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'NET90       ', N'UPS         ', N'            ', N'MK  ', CAST(585.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2071, 2171, 31, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'BR  ', CAST(756.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2072, 2172, 41, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'CM  ', CAST(3403.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2073, 2173, 49, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'CW  ', CAST(1311.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2074, 2174, 59, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(3897.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2075, 2175, 99, CAST(N'2015-12-31T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'AS  ', CAST(22386.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2076, 2176, 34, CAST(N'2015-12-31T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JS  ', CAST(1592.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2077, 2177, 26, CAST(N'2015-12-31T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MK  ', CAST(1032.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2078, 2178, 27, CAST(N'2015-12-31T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(12456.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2079, 2179, 33, CAST(N'2015-12-31T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'CM  ', CAST(2224.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2080, 2180, 37, CAST(N'2016-01-01T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'MH  ', CAST(45.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2081, 2181, 38, CAST(N'2016-01-01T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'KS  ', CAST(9348.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2082, 2182, 42, CAST(N'2016-01-01T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'MM  ', CAST(2467.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2083, 2183, 46, CAST(N'2016-01-01T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'MH  ', CAST(932.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2084, 2184, 50, CAST(N'2016-01-01T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'TT  ', CAST(402.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2085, 2185, 55, CAST(N'2016-01-01T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'JW  ', CAST(295.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2086, 2186, 61, CAST(N'2016-01-02T00:00:00.000' AS DateTime), N'NONE        ', N'WILLCALL    ', N'            ', N'FF  ', CAST(224.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2087, 2187, 65, CAST(N'2016-01-02T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'JS  ', CAST(1547.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2088, 2188, 66, CAST(N'2016-01-02T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MK  ', CAST(55.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2089, 2189, 67, CAST(N'2016-01-02T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'JS  ', CAST(1961.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2090, 2190, 69, CAST(N'2016-01-02T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'HS  ', CAST(1449.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2091, 2191, 70, CAST(N'2016-01-02T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'NJ  ', CAST(58.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2092, 2192, 72, CAST(N'2016-01-02T00:00:00.000' AS DateTime), N'NET30       ', N'WILLCALL    ', N'            ', N'NONE', CAST(2382.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2093, 2193, 74, CAST(N'2016-01-02T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'JC  ', CAST(1160.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2094, 2194, 75, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'AS  ', CAST(150.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2095, 2195, 76, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'BR  ', CAST(25.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2096, 2196, 79, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'NET60       ', N'FEDEX       ', N'            ', N'BS  ', CAST(192.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2097, 2197, 82, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CM  ', CAST(49.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2098, 2198, 77, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(5950.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2099, 2199, 78, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RM  ', CAST(1304.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2100, 2200, 89, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'RO  ', CAST(7166.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2101, 2201, 90, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MM  ', CAST(637.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2102, 2202, 96, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'TT  ', CAST(29.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2103, 2203, 100, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'CS  ', CAST(390.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2104, 2204, 35, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'COD         ', N'FEDEXCOD    ', N'            ', N'CW  ', CAST(180.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2105, 2205, 97, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'MH  ', CAST(2109.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2106, 2206, 41, CAST(N'2016-01-03T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'MK  ', CAST(1560.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2107, 2207, 1, CAST(N'2015-10-27T00:00:00.000' AS DateTime), N'NET30       ', N'FEDEX       ', N'            ', N'NONE', CAST(2847.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2108, 2208, 12, CAST(N'2015-10-27T00:00:00.000' AS DateTime), N'PREPAY      ', N'FEDEX       ', N'            ', N'LM  ', CAST(1980.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2109, 2209, 3, CAST(N'2015-10-30T00:00:00.000' AS DateTime), N'NET60       ', N'USMAIL      ', N'            ', N'NJ  ', CAST(2490.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2110, 2210, 4, CAST(N'2015-10-30T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'KS  ', CAST(1013.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2111, 2211, 8, CAST(N'2015-11-19T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'SQ  ', CAST(21931.00 AS Numeric(10, 2)), 4)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2112, 2212, 6, CAST(N'2015-11-23T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'FMB ', CAST(1287.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2113, 2213, 7, CAST(N'2015-11-26T00:00:00.000' AS DateTime), N'NET60       ', N'WILLCALL    ', N'            ', N'DM  ', CAST(2606.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2114, 2214, 8, CAST(N'2015-12-03T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'NONE', CAST(15780.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2115, 2215, 9, CAST(N'2015-12-14T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'RO  ', CAST(3670.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2116, 2216, 10, CAST(N'2015-12-20T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'JW  ', CAST(27919.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2117, 2217, 11, CAST(N'2015-12-24T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'PD  ', CAST(2267.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2118, 2218, 6, CAST(N'2015-12-30T00:00:00.000' AS DateTime), N'COD         ', N'UPS         ', N'            ', N'JC  ', CAST(17819.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2119, 2219, 1, CAST(N'2016-01-04T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'TT  ', CAST(7243.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2120, 2220, 1, CAST(N'2016-01-05T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'CM  ', CAST(2624.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2121, 2221, 2, CAST(N'2016-01-18T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'AS  ', CAST(14287.00 AS Numeric(10, 2)), 2)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2122, 2222, 6, CAST(N'2016-01-25T00:00:00.000' AS DateTime), N'COD         ', N'USMAIL      ', N'            ', N'KS  ', CAST(1951.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2123, 2223, 5, CAST(N'2016-01-28T00:00:00.000' AS DateTime), N'NET30       ', N'USMAIL      ', N'            ', N'FF  ', CAST(1299.00 AS Numeric(10, 2)), 1)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2124, 2224, 3, CAST(N'2016-01-28T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'AS  ', CAST(7632.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2125, 2225, 8, CAST(N'2016-02-05T00:00:00.000' AS DateTime), N'NET60       ', N'UPS         ', N'            ', N'MS  ', CAST(1812.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2126, 2226, 11, CAST(N'2016-02-08T00:00:00.000' AS DateTime), N'COD         ', N'FEDEX       ', N'            ', N'RM  ', CAST(389.00 AS Numeric(10, 2)), 5)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2127, 2227, 12, CAST(N'2016-02-12T00:00:00.000' AS DateTime), N'NET30       ', N'UPS         ', N'            ', N'HS  ', CAST(2019.00 AS Numeric(10, 2)), 3)
INSERT [dbo].[OrderHea] ([RECNUM], [Order_Number], [Customer_Number], [Order_Date], [Terms], [Ship_Via], [Ordered_By], [SalesPerson_ID], [Order_Total], [Last_Detail_Num]) VALUES (2128, 2228, 7, CAST(N'2016-02-18T00:00:00.000' AS DateTime), N'PREPAY      ', N'UPS         ', N'            ', N'BS  ', CAST(2969.00 AS Numeric(10, 2)), 4)
SET IDENTITY_INSERT [dbo].[OrderHea] OFF
INSERT [dbo].[OrdSys] ([Order_Number], [Cust_Number], [Vendor_Number]) VALUES (2228, 100, 10)
SET IDENTITY_INSERT [dbo].[SalesP] ON 

INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (15, N'AS  ', N'Alina Suarez             ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (11, N'BR  ', N'Barney Roberts           ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (2, N'BS  ', N'Bob Stimpson             ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (13, N'CM  ', N'Carlos Montero           ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (14, N'CS  ', N'Charles Suitor           ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (22, N'CW  ', N'Carol Watson             ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (24, N'DJ  ', N'David Jones              ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (4, N'DM  ', N'Diana Marino             ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (10, N'FF  ', N'Fred Fearson             ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (6, N'FMB ', N'Fernando M. Barrera      ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (23, N'HS  ', N'Hugo Sampson             ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (12, N'JC  ', N'Joe Carson               ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (21, N'JS  ', N'Judy Supinsky            ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (27, N'JW  ', N'Jonathan Walton          ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (20, N'KS  ', N'Kellie Smith             ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (1, N'LM  ', N'Liza Collinsworht        ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (25, N'MH  ', N'Martha Hyde              ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (7, N'MK  ', N'Mack Kraft               ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (28, N'MM  ', N'Mary Miller              ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (17, N'MS  ', N'Mariana Suarez           ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (3, N'NEW ', N'New Salesperson          ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (9, N'NJ  ', N'Nick Johnson             ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (5, N'NONE', N'None Specified           ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (8, N'PD  ', N'Pam Dickson              ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (19, N'RM  ', N'Randy Miller             ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (26, N'RO  ', N'Rita O''Donaldson         ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (18, N'SQ  ', N'Susan Quicksilver        ')
INSERT [dbo].[SalesP] ([RECNUM], [ID], [Name]) VALUES (16, N'TT  ', N'Tina Tompson             ')
SET IDENTITY_INSERT [dbo].[SalesP] OFF
SET IDENTITY_INSERT [dbo].[Users] ON 

INSERT [dbo].[Users] ([RECNUM], [LoginName], [Password], [Rights], [Full_Name], [Last_Login]) VALUES (1, N'JOHN      ', N'JOHN      ', 1, N'John J. Smith                 ', CAST(N'1753-01-01T00:00:00.000' AS DateTime))
SET IDENTITY_INSERT [dbo].[Users] OFF

SET IDENTITY_INSERT [dbo].[Vendor] ON 
INSERT [dbo].[Vendor] ([RECNUM], [ID], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number]) VALUES (2, 2, N'Book World                    ', N'6501 S.E. 25th Ave.           ', N'Coral Gables  ', N'FL', N'44427     ', N'(305) 445-9723      ', N'(305) 555-9875      ')
INSERT [dbo].[Vendor] ([RECNUM], [ID], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number]) VALUES (3, 3, N'The Book Emporium             ', N'145 N.E. 56th AVE.            ', N'Coral Springs ', N'FL', N'67823     ', N'(407) 223-5678      ', N'                    ')
INSERT [dbo].[Vendor] ([RECNUM], [ID], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number]) VALUES (4, 4, N'Technical Book Supply         ', N'14 E. Main Street             ', N'San Diego     ', N'CA', N'91941     ', N'(800) TECHBOOK      ', N'                    ')
INSERT [dbo].[Vendor] ([RECNUM], [ID], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number]) VALUES (5, 5, N'Construction Resource         ', N'P.O. Box 1792                 ', N'Denver        ', N'CO', N'92345     ', N'(800) 545-7236      ', N'                    ')
INSERT [dbo].[Vendor] ([RECNUM], [ID], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number]) VALUES (6, 6, N'Ace Publications              ', N'4514 Lombard St - Suite 123   ', N'San Fransisco ', N'CA', N'92014     ', N'(415) 456-8765 x.888', N'                    ')
INSERT [dbo].[Vendor] ([RECNUM], [ID], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number]) VALUES (7, 7, N'Software Publishing           ', N'P.O. Box 123                  ', N'Bostn         ', N'MA', N'91234     ', N'(800) 567-9875      ', N'                    ')
INSERT [dbo].[Vendor] ([RECNUM], [ID], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number]) VALUES (8, 8, N'Paperback Merchant            ', N'2734 Center Blvd.             ', N'Fort Worth    ', N'TX', N'87632     ', N'404 879-9999        ', N'                    ')
INSERT [dbo].[Vendor] ([RECNUM], [ID], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number]) VALUES (9, 9, N'Business Work Books           ', N'9182A A. Street               ', N'San Diego     ', N'CA', N'91920     ', N'(619) 555-1231      ', N'                    ')
INSERT [dbo].[Vendor] ([RECNUM], [ID], [Name], [Address], [City], [State], [Zip], [Phone_Number], [Fax_Number]) VALUES (10, 10, N'Olde Book Merchant            ', N'1371 Market Street            ', N'San Fransisco ', N'CA', N'92314     ', N'(415) 555-9823      ', N'                    ')
SET IDENTITY_INSERT [dbo].[Vendor] OFF
